/****************************************************************************
 *  Caprice32 libretro unit-tests for clean-cpc-db
 *
 *  Copyright David Colmenero - D_Skywalk (2019-2022)
 *
 *  Redistribution and use of this code or any derivative works are permitted
 *  provided that the following conditions are met:
 *
 *   - Redistributions may not be sold, nor may they be used in a commercial
 *     product or activity.
 *
 *   - Redistributions that are modified from the original source must include the
 *     complete source code, including the source code for all components used by a
 *     binary built from the modified sources. However, as a special exception, the
 *     source code distributed need not include anything that is normally distributed
 *     (in either source or binary form) with the major components (compiler, kernel,
 *     and so on) of the operating system on which the executable runs, unless that
 *     component itself accompanies the executable.
 *
 *   - Redistributions must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other
 *     materials provided with the distribution.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************************/

#include <libretro-core.h>

typedef struct {
   uint32_t hash;
   char cmdhash[32+1];
   char filepath[512];
} t_test_entry;

// clean-cpc-db test database v1.1
t_test_entry cleancpcdb[] = {
   {0xa5df0936, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"3D Voicechess (CP Software) (Spain)/3D Voicechess (1985)(CP Software)(es).dsk"} },
   {0xb70c908c, {"0f3ce766494c244fb3e069ee60809d95"}, {"2112 AD (Design Design Software) (M4)/2112 AD (1986)(Design Design Software)(M4).dsk"} },
   {0x90c6d8cc, {"630e52538ea9aaebc8b4b4e23602a3cf"}, {"12 Lost Souls (Amstrad Adventure PD Library)/12 Lost Souls (1987)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0x3892dad5, {"fa35badee14303fbd560c1cbc7f345f6"}, {"3DC (Encore)/3DC (1987)(Encore)[cr].dsk"} },
   {0x16b25d5f, {"e0777f2bc6b60c37d7d9613810b63335"}, {"2 Player Soccer Squad (Cult Games)/2 Player Soccer Squad (1986)(Cult Games)[cr].dsk"} },
   {0xf4bb9c85, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"4 Soccer Simulators (Codemasters Gold)/4 Soccer Simulators (1989)(Codemasters Gold).dsk"} },
   {0x90b13e33, {"09b117431fbf400125e2af87867b443f"}, {"180 (Mastertronic)/180 (1986)(Mastertronic)[cr].dsk"} },
   {0x84efcc59, {"f638ad1bf1de22e73b36c058f55a1a2a"}, {"750cc Grand Prix (Codemasters Software)/750cc Grand Prix (1989)(Codemasters Software)[cr].dsk"} },
   {0xc14ee245, {"2da02675ee288b6d6c2697545088ebeb"}, {"7 Card Stud (Martech Games)/7 Card Stud (1986)(Martech Games).dsk"} },
   {0x6bb453d1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"1815 (Cobra Soft) (France)/1815 (1985)(Cobra Soft)(fr).dsk"} },
// {0x638c76d0, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"3D Stunt Rider (Amsoft)/3D Stunt Rider (1985)(Amsoft).dsk"} },
   {0xb60b8c58, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"007 - Live and Let Die (Domark)/007 - Live and Let Die (1988)(Domark).dsk"} },
   {0x91da0112, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"4x4 Off-Road Racing (US Gold)/4x4 Off-Road Racing (1988)(US Gold).dsk"} },
   {0xb78305d5, {"38ed0692864fe4e703f4dcf7d8b7a661"}, {"1914 (Amstar) (France)/1914 (1987)(Amstar)(fr)[cr].dsk"} },
   {0xb8b6a065, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"20000 Lieus sous les Mers (Coktel Vision) (France)/20000 Lieus sous les Mers (1988)(Coktel Vision)(fr)(Side A)[CPM].dsk"} },
   {0x0972c229, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"720 Degrees (US Gold)/720 Degrees (1986)(US Gold).dsk"} },
   {0x8769d0b1, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"1943 - The Battle of Midway (US Gold)/1943 - The Battle of Midway (1988)(US Gold).dsk"} },
   {0x5e15e228, {"820373d126ec4b561d522042164e3d54"}, {"3D Starstrike (Realtime Games Software)/3D Starstrike (1985)(Realtime Games Software)[cr].dsk"} },
   {0x104e2d14, {"810e151df637c5b89a880d3c6c7a89de"}, {"3D Monster Chase (Romik Software)/3D Monster Chase (1984)(Romik Software)[cr].dsk"} },
   {0x1e1411be, {"90967ecefb594512ca1780107c3debc0"}, {"10th Frame (US Gold)/10th Frame (1986)(US Gold).dsk"} },
   {0x0611e83f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"3D Voicechess (CP Software) (France)/3D Voicechess (1985)(CP Software)(fr).dsk"} },
   {0xddc7a9a8, {"334e81b2ea4561bb202cf1774d3768f3"}, {"20000 Avant J.C. (Chip) (France)/20000 Avant J.C. (1987)(Chip)(fr).dsk"} },
   {0x12ed8818, {"397d12a922488a8264228c56916d445a"}, {"1001 BC (ERE Informatique) (France)/1001 BC (1986)(ERE Informatique)(fr).dsk"} },
   {0x0c2d33c9, {"bd009fbdcac6af1cdc161e46ad839c4a"}, {"5th Axis, The (Loriciels) (France)/5th Axis, The (1985)(Loriciels)(fr).dsk"} },
   {0xe1e61287, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"3D Grand Prix (Amsoft)/3D Grand Prix (1985)(Amsoft).dsk"} },
   {0x9cee0fb7, {"0f3ce766494c244fb3e069ee60809d95"}, {"3D Fight (Loriciels) (France)/3D Fight (1985)(Loriciels)(fr).dsk"} },
   {0x3db6ed05, {"10f8138cdd6c921d76b0abc20448f4d2"}, {"3D Morpion (Hebdogiciel) (France)/3D Morpion (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0xeae4f4b0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"3D Pool (Firebird Software)/3D Pool (1989)(Firebird Software).dsk"} },
   {0xb6ca86e1, {"042790b86267039b200cf7ea4f0e3000"}, {"007 - A View To A Kill (Eureka) (France)/007 - A View To A Kill (1985)(Eureka)(fr).dsk"} },
   {0x81df2ee2, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"007 - The Spy Who Loved Me (Domark)/007 - The Spy Who Loved Me (1990)(Domark)(Side A).dsk"} },
   {0xb7c31b0d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"007 - The Living Daylights (Domark)/007 - The Living Daylights (1987)(Domark).dsk"} },
   {0x65872552, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"4th Protocol, The (Century Communications)/4th Protocol, The (1986)(Century Communications)[cr].dsk"} },
   {0x9aaec7e3, {"4c12ebe79bdbf8c4b0b1c09ba09e39f0"}, {"3D-Sub (Loriciels) (France)/3D-Sub (1985)(Loriciels)(fr)[cr].dsk"} },
   {0x4b2b8949, {"d63de5fd545e4b5312201fe79e34a903"}, {"5th Axis, The (Loriciels)/5th Axis, The (1985)(Loriciels).dsk"} },
// {0xf23f30d4, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"3D Boxing (Amsoft)/3D Boxing (1985)(Amsoft).dsk"} },
   {0x53e36bf4, {"d7bdb9ff4f88477802139fe19a497019"}, {"3D Starfighter (Codemasters Software)/3D Starfighter (1988)(Codemasters Software)[cr].dsk"} },
   {0xd9866b04, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"3D Voicechess (CP Software)/3D Voicechess (1985)(CP Software).dsk"} },
   {0xab928e90, {"23762081dab77e438bd29ba648ef1e7e"}, {"1942 (Elite Systems)/1942 (1986)(Elite Systems).dsk"} },
   {0xeb184a31, {"9def26e476522c98afaa92f0c6e2b4ea"}, {"1914 (Amstrad User)/1914 (1987)(Amstrad User)[cr].dsk"} },
   {0x557729ab, {"60a65a7ff1a377ae8701e1f6cb0e9041"}, {"3D Quark Invaders (Amsoft)/3D Quark Invaders (1985)(Amsoft)[cr].dsk"} },
   {0x0009f378, {"ae4caba3b1854c06e54006aaf061f918"}, {"3 Guerra Mundial (Pactum) (Spain)/3 Guerra Mundial (1989)(Pactum)(es)(Side A)[cr].dsk"} },
   {0xd5369bd2, {"92056f3392eb909b7dc0564b743a18fa"}, {"007 - A View To A Kill (Domark)/007 - A View To A Kill (1985)(Domark).dsk"} },
   {0x5ecef1ab, {"304f56622d16068b48a764428c6c6785"}, {"Adventures of Basildon Bond, The (Probe Software)/Adventures of Basildon Bond, The (1986)(Probe Software)[cr].dsk"} },
   {0xebdc9ba9, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Adidas Championship Football (Ocean)/Adidas Championship Football (1990)(Ocean).dsk"} },
   {0x17dd8795, {"fcd88017c6c63b85d714f4e3edf03034"}, {"Adventure D - Espionage Island (Artic Computing)/Adventure D - Espionage Island (1985)(Artic Computing)[cr].dsk"} },
   {0xd68054e1, {"232238c843ab6506669b55921d44a994"}, {"Apprentice, The (Mastertronic)/Apprentice, The (1986)(Mastertronic)[tape].dsk"} },
   {0xf4aba310, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Afteroids (Zigurat Software) (Spain)/Afteroids (1988)(Zigurat Software)(es).dsk"} },
   {0x1f368d7b, {"59aa12468c1d216a42416c60b7f715a3"}, {"Arachnophobia (Titus) (M5)/Arachnophobia (1991)(Titus)(M5)(Side A).dsk"} },
   {0x705ef1ce, {"90a7dd905a259cbcbe4bdf8aba3e5f67"}, {"Aton (Sygram) (Spain)/Aton (1987)(Sygram)(es)[tape].dsk"} },
   {0xa9e693e3, {"3c2180c89e49bde5e24d148da7afacd3"}, {"American Turbo King (1990)/American Turbo King (UK) (1990)[tape].dsk"} },
   {0x363cfc7c, {"2af8b176ce88110d9a3c0b359bffc755"}, {"Advanced Destroyer Simulator (Futura) (Spain)/Advanced Destroyer Simulator (1990)(Futura)(es).dsk"} },
   {0x7037c06c, {"fcf02f5a159417c04cc14151deaa547c"}, {"Abu Simbel Profanation (Dinamic Software) (Spain)/Abu Simbel Profanation (1986)(Dinamic Software)(es)[cr].dsk"} },
   {0xf9a760ff, {"0f3ce766494c244fb3e069ee60809d95"}, {"Action Service (Cobra Soft)/Action Service (1988)(Cobra Soft).dsk"} },
   {0x2ec8ee25, {"fbac182a87a08800246a7d1da1dc4a69"}, {"Arnold Goes to Somewhere Else (Nemesis)/Arnold Goes to Somewhere Else (1984)(Nemesis)[cr].dsk"} },
   {0x2996cc8b, {"901617bc968b8b818244658d76fba6a7"}, {"Anna (Edsa) (France)/Anna (1988)(Edsa)(fr)[cr].dsk"} },
   {0x76bbc7a0, {"0d1362e3fe8db24ddbb87ca42c44210c"}, {"Atomic Battle (R.A. Waddilove)/Atomic Battle (1988)(R.A. Waddilove)[cr].dsk"} },
   {0xb3137d19, {"28cc434b92c5201a975cb0b485f1330a"}, {"Ajedrez Tridimensional (Amsoft) (Spain)/Ajedrez Tridimensional (1985)(Amsoft)(es)[cr].dsk"} },
   {0xe8b02164, {"20d406922f247c55b209454db226f76d"}, {"Amsoccer (Amsoft)/Amsoccer (1986)(Amsoft)[tape].dsk"} },
   {0x3489ff00, {"0f3ce766494c244fb3e069ee60809d95"}, {"Amazing Shrinking Man (Infogrames) (M4)/Amazing Shrinking Man (1986)(Infogrames)(M4).dsk"} },
   {0x77860bfe, {"5f2475d2a71fd7129c17350f77fd556f"}, {"Amsgolf (Amsoft) (de)/Amsgolf (1984)(Amsoft)(de).dsk"} },
   {0x74458dd9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Afterburner (Activision)/Afterburner (1988)(Activision).dsk"} },
   {0xb884ccab, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Autre Aventure, L' (Genisoft) (France)/Autre Aventure, L' (1987)(Genisoft)(fr)[cr][f].dsk"} },
   {0x28b56166, {"d8f910787fa8daaecaadcf9ab7b93e08"}, {"America's Cup Challenge (Armchair Entertainment)/America's Cup Challenge (1986)(Armchair Entertainment).dsk"} },
   {0x74ee6f60, {"b49014bfa47b8a4f6cb8365e20537cc2"}, {"Animated Strip Poker (Knight Soft)/Animated Strip Poker (1985)(Knight Soft)[cr].dsk"} },
   {0xf3f06148, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Alien Highway - Encounter 2 (Vortex Software)/Alien Highway - Encounter 2 (1986)(Vortex Software).dsk"} },
   {0xe9058607, {"600cdcee0d4de8288db6963ab8edf6da"}, {"Amaurote (Mastertronic)/Amaurote (1987)(Mastertronic)[cr][f].dsk"} },
   {0xfe232a4d, {"4eb77cee99810ca4019a09e3bc60405a"}, {"African Trail Simulator (Positive) (Spain)/African Trail Simulator (1990)(Positive)(es).dsk"} },
   {0x87524abd, {"aa5d182a771521a3739b4d80106b8cec"}, {"Amnesia (DBT) (M2)/Amnesia (1998)(DBT)(M2)[cr].dsk"} },
// {0x50f59666, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Assault On Port Stanley (Amsoft)/Assault On Port Stanley (1985)(Amsoft).dsk"} },
   {0x270e4f88, {"c8d268fd9fc238f871825004d012d411"}, {"Abadlend (Damstar) (France)/Abadlend (1985)(Damstar)(fr)[cr].dsk"} },
   {0x53f17767, {"79311a578d1a2e935d7b5d032da892d8"}, {"Amstroids (CPC Computing)/Amstroids (1985)(CPC Computing)[tape].dsk"} },
   {0xe849458a, {"92b06aaa37ff31576aad81ef6102a819"}, {"Aquanaute (FIL) (France)/Aquanaute (1988)(FIL)(fr).dsk"} },
   {0x1039467d, {"cc934e078d0aa572c6adda281df7c750"}, {"Aqua - Viaje a la Superficie (CEZ Games Studio)/Aqua - Viaje a la Superficie (2006)(CEZ Games Studio)[tape].dsk"} },
   {0x92e55932, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Alien Storm (US Gold)/Alien Storm (1991)(US Gold)(v2)(Side A).dsk"} },
   {0x33e38c87, {"15008e6282979b98252e08055ea23d28"}, {"Asterix Chez Rahazade (Coktel Vision) (France)/Asterix Chez Rahazade (1988)(Coktel Vision)(fr)(Side A).dsk"} },
   {0x551da885, {"43372205e8d1ed1c6f3dc01bbbedc1f4"}, {"Archon (Electronic Arts)/Archon (1988)(Electronic Arts)[cr].dsk"} },
   {0xbdc9f811, {"05daa3f95d3b233346798b460218e78f"}, {"Agent-X II (Mastertronic)/Agent-X II (1987)(Mastertronic)[cr].dsk"} },
   {0x5a2f2ab0, {"3d707e1752a78b2f096c98a1cdc61ea2"}, {"Angelique - A Grief Encounter (Nemesis)/Angelique - A Grief Encounter (1985)(Nemesis)[tape].dsk"} },
   {0x7eaa9ca6, {"1d2f68b19c43e0cb376c0f9afe4269b1"}, {"Alinka (Eric Boucher) (France)/Alinka (1991)(Eric Boucher)(fr)[cr].dsk"} },
   {0xa529f3c4, {"52493f07aa201b61fa64a42203c3558f"}, {"Alpine Games (Atlantis Software)/Alpine Games (1987)(Atlantis Software)[tape].dsk"} },
   {0x8b94c44c, {"0f3ce766494c244fb3e069ee60809d95"}, {"After the War (Dinamic Software) (Spain)/After the War (1989)(Dinamic Software)(es).dsk"} },
   {0x1905733c, {"23ad4e7adb32e3a6924568f73db2e342"}, {"Adventure C - The Ship of Doom (Artic Computing)/Adventure C - The Ship of Doom (1985)(Artic Computing)[cr].dsk"} },
   {0x471d7147, {"ebaa23a19cb4fd55ebffd0a34d4c6cbf"}, {"Ashkeron (Mirrorsoft)/Ashkeron (1985)(Mirrorsoft)[tape].dsk"} },
   {0x82ce300d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"After Shock (Interceptor Micros Software)/After Shock (1986)(Interceptor Micros Software).dsk"} },
   {0x5ee2116a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Affaire Sydney, L' (Infogrames) (France)/Affaire Sydney, L' (1986)(Infogrames)(fr).dsk"} },
   {0xc963bfe0, {"24e5eda8764a66c95a601eb548a33f4b"}, {"Asphalt (Ubi Soft) (France)/Asphalt (1987)(Ubi Soft)(fr)(v2).dsk"} },
   {0x1d7cea37, {"0f3ce766494c244fb3e069ee60809d95"}, {"Arkos (Zigurat Software) (Spain)/Arkos (1988)(Zigurat Software)(es).dsk"} },
   {0xaa05ed4a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Abadia del Crimen, La (Opera Soft) (Spain)/Abadia del Crimen, La (1988)(Opera Soft)(es).dsk"} },
   {0x0fa8f55e, {"505e3ed5e42529602e4690693de7b8ae"}, {"Atomic Driver (Loriciels) (France)/Atomic Driver (1988)(Loriciels)(fr)[tape].dsk"} },
   {0xe468306f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Autocrash (Zigurat Software) (Spain)/Autocrash (1991)(Zigurat Software)(es).dsk"} },
   {0x2c97c481, {"ccb82b452da82c86a1253602c11814e2"}, {"Admiral Graf Spee (Temptation Software - Amsoft)/Admiral Graf Spee (1984)(Temptation Software - Amsoft)[cr].dsk"} },
   {0x1eea288d, {"ce38f8e042c0a3864a92a7538700d5ca"}, {"Action Fighter (Firebird Software)/Action Fighter (1989)(Firebird Software).dsk"} },
   {0xf6b68eb8, {"c68076620e353d3feae594cc90a2f4ca"}, {"Averno (Proein Soft Line) (Spain)/Averno (1989)(Proein Soft Line)(es).dsk"} },
   {0xf48d4bdc, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Academy - Tau Ceti II (CRL Group) (France)/Academy - Tau Ceti II (1987)(CRL Group)(fr).dsk"} },
   {0x23768ed0, {"0f3ce766494c244fb3e069ee60809d95"}, {"Aussie Safari (U.S.Gold)/Aussie Safari (1990)(U.S.Gold)(Side A).dsk"} },
   {0x9949bce5, {"f07964416279ab918cfa618d6d321aab"}, {"Alien Break-In (Romik Software - Amsoft) (Spain)/Alien Break-In (1985)(Romik Software - Amsoft)(es)[tape].dsk"} },
   {0xc488a2c4, {"f1c7e3a6f882cf1fe2d2cec0282fcad9"}, {"Amthello (Amstrad Computer User) (Spain)/Amthello (1984)(Amstrad Computer User)(es)[cr].dsk"} },
   {0x2458ff4d, {"307aa3aa971fd94c1078e92a8042e647"}, {"Ataque Nuclear (Amstrad User Club) (Spain)/Ataque Nuclear (1987)(Amstrad User Club)(es)[cr].dsk"} },
   {0x17b1b38d, {"422d00dcad0e515ee63547f484f72692"}, {"Atomik (Loriciels) (France)/Atomik (1988)(Loriciels)(fr)[tape].dsk"} },
   {0x00e4bf51, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Arkanoid (Imagine Software)/Arkanoid (1987)(Imagine Software).dsk"} },
   {0x3db8fc89, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Army Moves (Dinamic Software)/Army Moves (1986)(Dinamic Software).dsk"} },
   {0x7b3fda27, {"af21107e806a395e62759627c0466445"}, {"Ariane (21 St Century Soft) (France)/Ariane (1985)(21 St Century Soft)(fr)[cr].dsk"} },
   {0xf43cb524, {"0f3ce766494c244fb3e069ee60809d95"}, {"AMC - Astro Marine Corps (Dinamic Software)/AMC - Astro Marine Corps (1989)(Dinamic Software).dsk"} },
   {0x937a947c, {"36fccedabab0bdfad475b1293553d01a"}, {"ACE - Air Combat Emulator (Cascade Games)/ACE - Air Combat Emulator (1986)(Cascade Games).dsk"} },
   {0x8232e909, {"92056f3392eb909b7dc0564b743a18fa"}, {"Activator (Cascade Games)/Activator (1986)(Cascade Games).dsk"} },
   {0x7f369255, {"c68076620e353d3feae594cc90a2f4ca"}, {"Andy Capp (Mirrorsoft)/Andy Capp (1987)(Mirrorsoft).dsk"} },
   {0x934357ae, {"8dcd9a6a47171d8436e347d2f4b0b030"}, {"Anneau de Zengara (Ubi Soft) (France)/Anneau de Zengara (1987)(Ubi Soft)(fr)(Side A).dsk"} },
// {0x4cffaa69, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Aventures de Moktar, Les (Titus) (France)/Aventures de Moktar, Les (1992)(Titus)(fr).dsk"} },
   {0x6e1d6208, {"bd3cf51ab0c1123610c737d9e0f2f288"}, {"Astro Plumber (Blue Ribbon Software)/Astro Plumber (1985)(Blue Ribbon Software)[tape].dsk"} },
   {0xbd70a734, {"b477b5cc1aaef81a9ef52a47136fbcd0"}, {"Astroball (The Power House)/Astroball (1988)(The Power House)[tape].dsk"} },
   {0x2c17fb46, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Amsgolf (Amsoft)/Amsgolf (1984)(Amsoft).dsk"} },
   {0x00588f97, {"816d2ab945e9b1fbeb04db26ebf70062"}, {"Amsilvania Castle (Veosoft) (Spain)/Amsilvania Castle (1987)(Veosoft)(es)[cr].dsk"} },
   {0xf53ce2a9, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Atomic Fiction (Chip) (France)/Atomic Fiction (1987)(Chip)(fr).dsk"} },
// {0x483d8366, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Alphakhor (Loriciels) (France)/Alphakhor (1989)(Loriciels)(fr)(Side A).dsk"} },
   {0xad523cb2, {"e1669b680cf96bed17c725072e90c0b8"}, {"Adult One (Simon Avery)/Adult One (19xx)(Simon Avery)[cr].dsk"} },
   {0xcb97a9e0, {"0f3ce766494c244fb3e069ee60809d95"}, {"Adidas Championship Tie-Break (Ocean)/Adidas Championship Tie-Break (1990)(Ocean).dsk"} },
   {0x2203c641, {"ee0bfe15a9e1830dda3e1c918e8f4dcf"}, {"Affaire Santa Fe, L' (Infogrames) (France)/Affaire Santa Fe, L' (1988)(Infogrames)(fr)(Side A).dsk"} },
   {0x43a65e0b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Axys - The Last Battle (CPC Infos, Amstar)/Axys - The Last Battle (1991)(CPC Infos, Amstar)[cr][m].dsk"} },
   {0x42ac44d5, {"0a97dff6ce064907300be0e5983a0fda"}, {"Animal Vegetable Mineral (Amsoft) (Spain)/Animal Vegetable Mineral (1984)(Amsoft)(es)[cr].dsk"} },
   {0xaa9f21c3, {"ecdcf869363cf1ec821ca15e140345a4"}, {"A320 (Loriciels) (France)/A320 (1989)(Loriciels)(fr)(Side A).dsk"} },
   {0xd82c9f67, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Atlantis (Cobra Soft) (France)/Atlantis (1988)(Cobra Soft)(fr).dsk"} },
   {0xf56c5741, {"fb14ab55aaee166a2dc66d593621296d"}, {"ATV Simulator (Codemasters Software)/ATV Simulator (1988)(Codemasters Software)[cr].dsk"} },
   {0xfa44813b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"APB - All Point Bulletin (Domark)/APB - All Point Bulletin (1989)(Domark).dsk"} },
   {0x569c2c48, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Academy - Tau Ceti II (CRL Group)/Academy - Tau Ceti II (1987)(CRL Group).dsk"} },
   {0x2ac1e169, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Animal Vegetable Mineral (Amsoft)/Animal Vegetable Mineral (1984)(Amsoft).dsk"} },
   {0x392fbb50, {"15008e6282979b98252e08055ea23d28"}, {"Asterix En La India (Coktel Vision) (Spain)/Asterix En La India (1988)(Coktel Vision)(es)(Side A).dsk"} },
// {0x4c35740d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Asterix et la Potion Magique (Coktel Vision) (France)/Asterix et la Potion Magique (1988)(Coktel Vision)(fr).dsk"} },
   {0xfc4837a4, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Anna (Edsa) (Spain) (Hack)/Anna (2019)(Edsa)(es)(Hack)[cr].dsk"} },
   {0x33f566e2, {"dde92d8208bf9123f539314141147ab3"}, {"Affaire Ravenhood, L' (Bruno Fonters) (France)/Affaire Ravenhood, L' (1993)(Bruno Fonters)(fr)(Side A)[cr].dsk"} },
   {0x4f1d2dd9, {"761f25fa61bebc97514d641b3273acc7"}, {"Aliens US (Electric Dreams Software)/Aliens US (1987)(Electric Dreams Software).dsk"} },
   {0x30e15ff9, {"2f7b279bcd14af1cfff08597e46f3c35"}, {"Armageddon Man, The (Martech Games)/Armageddon Man, The (1987)(Martech Games).dsk"} },
   {0x14db334c, {"b256b6ce955ad8f32678915932362f8a"}, {"Attentat (Rainbow Productions) (France)/Attentat (1986)(Rainbow Productions)(fr)(Side A).dsk"} },
   {0xf297d09c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Attack of the Killer Tomatoes (Global Software)/Attack of the Killer Tomatoes (1986)(Global Software).dsk"} },
   {0x56f7e773, {"c68076620e353d3feae594cc90a2f4ca"}, {"Aventures de Jack Burton, Les (Electric Dreams Software) (France)/Aventures de Jack Burton, Les (1987)(Electric Dreams Software)(fr).dsk"} },
   {0xc989a491, {"c1304f5cd096aff73fefe8518947fe29"}, {"Aladdin's Cave (Artic Computing)/Aladdin's Cave (1985)(Artic Computing)[cr].dsk"} },
   {0x1323190c, {"b477b5cc1aaef81a9ef52a47136fbcd0"}, {"Astro Attack (Amsoft)/Astro Attack (1984)(Amsoft)[tape].dsk"} },
   {0xcb0dcfa0, {"f1c7e3a6f882cf1fe2d2cec0282fcad9"}, {"Amthello (Amstrad Computer User)/Amthello (1984)(Amstrad Computer User)[cr].dsk"} },
   {0x37d63655, {"5e318f5f3bab52ebac0f83ec8969e68f"}, {"Archers, The (Mosaic Publishing)/Archers, The (1987)(Mosaic Publishing)[tape].dsk"} },
   {0x5eb0ef6f, {"738297aed5825bb5bc36cb811c78b0ec"}, {"Acro Jet (US Gold)/Acro Jet (1986)(US Gold).dsk"} },
   {0x95f8abaf, {"bd671397ca7bd56aba90498aba19ef7a"}, {"Adventure B - Inca Curse (Artic Computing)/Adventure B - Inca Curse (1985)(Artic Computing)[cr].dsk"} },
   {0xe6769f19, {"2412d1f45629150dbacf51b9f3324efb"}, {"Aventures de Pepito au Mexique, Les (Microids) (France)/Aventures de Pepito au Mexique, Les (1991)(Microids)(fr)(Side A).dsk"} },
   {0x13a97ec5, {"4c25b4d73b868724e56efaa30dc458ce"}, {"Arctic Fox (Electronic Arts)/Arctic Fox (1988)(Electronic Arts).dsk"} },
   {0x6515e302, {"9d4425afa71c3d69277bafc390b19a91"}, {"American Tag Team Wrestling (Zeppelin Games)/American Tag Team Wrestling (1992)(Zeppelin Games)[cr].dsk"} },
   {0xaa08dafd, {"059129e2b2824011ea972a5e7045d702"}, {"Air Cobra (Unicornia Soft) (Spain)/Air Cobra (1987)(Unicornia Soft)(es)[cr].dsk"} },
   {0x041f9748, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Adios A La Casta - Episode 2 (4Mhz) (Spain)/Adios A La Casta - Episode 2 (2016)(4Mhz)(es)(v1.0)[cr].dsk"} },
   {0x64592815, {"c68076620e353d3feae594cc90a2f4ca"}, {"Aventura Original, La (Aventuras AD) (Spain) (Retro Alacant Turbo)/Aventura Original, La (1989)(Aventuras AD)(Retro Alacant Turbo)(es).dsk"} },
   {0xd5a4c3f2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Affaire Vera Cruz, L' (Infogrames) (France)/Affaire Vera Cruz, L' (1985)(Infogrames)(fr).dsk"} },
   {0xc809daf9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Airwolf (Elite Systems - Amsoft)/Airwolf (1985)(Elite Systems - Amsoft).dsk"} },
// {0xea140f7f, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Antre de Gork, L' (Excalibur) (France)/Antre de Gork, L' (1987)(Excalibur)(fr)(Side A)[f].dsk"} },
   {0x4af53293, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"A Question Of Scruples (Leisure Genius)/A Question Of Scruples (1987)(Leisure Genius)(Side A).dsk"} },
   {0xa9a4ecd9, {"b099e6816a4157915fb4b44a631c9c61"}, {"Atlantis (Anirog Software)/Atlantis (1985)(Anirog Software)[cr].dsk"} },
   {0x4c117ec5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Addams Family, The (Ocean)/Addams Family, The (1991)(Ocean).dsk"} },
   {0x68e5f2a1, {"419e173bad428fc8de09e8354c6bae5c"}, {"Advanced Pinball Simulator (Codemasters Software)/Advanced Pinball Simulator (1988)(Codemasters Software)[cr].dsk"} },
// {0xbb2a95f6, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Amelie Minuit (ERE Informatique) (France)/Amelie Minuit (1985)(ERE Informatique)(fr).dsk"} },
   {0x5fc272b4, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Airborne Ranger (Microprose Software)/Airborne Ranger (1988)(Microprose Software)(Side A).dsk"} },
   {0x1fae9dcb, {"6aefa114f1f94f4e55e115c8f8d72162"}, {"Archon II - Adept (Electronic Arts)/Archon II - Adept (1989)(Electronic Arts)[cr].dsk"} },
   {0x31d37ba2, {"15008e6282979b98252e08055ea23d28"}, {"Asterix Im Morgenland (Coktel Vision) (de)/Asterix Im Morgenland (1988)(Coktel Vision)(de)(Side A).dsk"} },
   {0xea9bb85d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Alex Higgins World Snooker (Amsoft)/Alex Higgins World Snooker (1985)(Amsoft).dsk"} },
   {0xa32c19fb, {"0f3ce766494c244fb3e069ee60809d95"}, {"Au Revoir Monty (Gremlin Graphics Software)/Au Revoir Monty (1987)(Gremlin Graphics Software).dsk"} },
   {0x60c00eea, {"3b707b5df366cb38c152de28d2571c00"}, {"Ace of Aces (US Gold)/Ace of Aces (1986)(US Gold).dsk"} },
   {0x2be8b9dd, {"0f3ce766494c244fb3e069ee60809d95"}, {"A-Team, The (Zafiro Software Division) (Spain) (LightGun)/A-Team, The (1989)(Zafiro Software Division)(es)(LightGun)(Side A).dsk"} },
   {0xbf188ce3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Abbey Of Crime, The (Opera Soft) (Hack)/Abbey Of Crime, The (1988)(Opera Soft)(Hack).dsk"} },
   {0x7d3fe833, {"cc934e078d0aa572c6adda281df7c750"}, {"Aqua - Viaje a la Superficie (CEZ Games Studio) (Spain)/Aqua - Viaje a la Superficie (2006)(CEZ Games Studio)(es)[tape].dsk"} },
   {0x349ae355, {"c707d3d8b7caf1bbdb664a6ace73074b"}, {"Andy Capp (Mirrorsoft) (France)/Andy Capp (1987)(Mirrorsoft)(fr)[cr].dsk"} },
   {0x98c7bf27, {"1e6b9f5115e83271dfadeb794d746959"}, {"Athlete (Microids) (France)/Athlete (1987)(Microids)(fr).dsk"} },
   {0xee5f060c, {"2af8b176ce88110d9a3c0b359bffc755"}, {"Advanced Destroyer Simulator (Futura) (France)/Advanced Destroyer Simulator (1990)(Futura)(fr).dsk"} },
   {0x4319969a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Aventura Espacial, La (Aventuras AD) (Spain)/Aventura Espacial, La (1990)(Aventuras AD)(es).dsk"} },
   {0xfadd2854, {"c68076620e353d3feae594cc90a2f4ca"}, {"Adios A La Casta - Episode 1 (4Mhz) (Spain)/Adios A La Casta - Episode 1 (2015)(4Mhz)(es).dsk"} },
   {0xe9e99d67, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Altered Beast (Activision)/Altered Beast (1989)(Activision)(Side A).dsk"} },
   {0xfea25877, {"4eb77cee99810ca4019a09e3bc60405a"}, {"African Trail Simulator (Positive) (M2)/African Trail Simulator (1990)(Positive)(M2).dsk"} },
   {0x52695660, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Artura (Gremlin Graphics Software)/Artura (1989)(Gremlin Graphics Software).dsk"} },
   {0xf7dd74b9, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Action Force (Virgin Games)/Action Force (1988)(Virgin Games).dsk"} },
   {0x790a9ac2, {"dfc1ab7ac5d314810916b6cfec0e821e"}, {"Arcade Flight Simulator (1989)/Arcade Flight Simulator (UK) (1989)[tape].dsk"} },
   {0x45ede8ec, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Aaargh! (Melbourne House) (Spain)/Aaargh! (1989)(Melbourne House)(es).dsk"} },
   {0xef2db36f, {"b477b5cc1aaef81a9ef52a47136fbcd0"}, {"Astro Attack (Amsoft) (Spain)/Astro Attack (1984)(Amsoft)(es)[tape].dsk"} },
   {0x506ce975, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Anna (Edsa)/Anna (1988)(Edsa)(de-en)[cr].dsk"} },
   {0xdb1ca9d0, {"b7814eb843099600b3f73e8e67137b9c"}, {"Antares (Dro Soft) (Spain)/Antares (1987)(Dro Soft)(es)[tape].dsk"} },
   {0x3342f662, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Amstrad Shuffle (Alpha Omega Software)/Amstrad Shuffle (1986)(Alpha Omega Software)[cr].dsk"} },
   {0x62d17d76, {"0f3ce766494c244fb3e069ee60809d95"}, {"After the War (Dinamic Software)/After the War (1989)(Dinamic Software).dsk"} },
   {0xcc7496cc, {"51504cbc4e25cb3a24a1672c21bff368"}, {"Aufwarts Zur Rettung - Climb-It (Tynesoft)/Aufwarts Zur Rettung - Climb-It (1984)(Tynesoft)[tape].dsk"} },
   {0x96ecfc4f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Armure Sacree d'Antiriad, L' (Palace Software) (France)/Armure Sacree d'Antiriad, L' (1986)(Palace Software)(fr).dsk"} },
   {0x394bbc01, {"fd920e9f39feffc8489fdb4e40e57725"}, {"Abracadabra et les Voleurs de Temps (Carraz Editions) (France)/Abracadabra et les Voleurs de Temps (1988)(Carraz Editions)(fr).dsk"} },
   {0x6720c16a, {"8cdadce815d4c88b470e825a71ab847e"}, {"Ali Candil y el Tesoro de Sierra Morena (Edisoft) (Spain)/Ali Candil y el Tesoro de Sierra Morena (1986)(Edisoft)(es)[cr].dsk"} },
   {0x17b5103e, {"c68076620e353d3feae594cc90a2f4ca"}, {"Asterix and the Magic Cauldron (Melbourne House)/Asterix and the Magic Cauldron (1986)(Melbourne House).dsk"} },
   {0xe3217d1a, {"ccb82b452da82c86a1253602c11814e2"}, {"Admiral Graf Spee (Temptation Software - Amsoft) (Spain)/Admiral Graf Spee (1984)(Temptation Software - Amsoft)(es)[cr].dsk"} },
   {0x49389379, {"0f3ce766494c244fb3e069ee60809d95"}, {"A-Team, The (Zafiro Software Division) (Spain)/A-Team, The (1989)(Zafiro Software Division)(es)(Side A).dsk"} },
   {0x160644e9, {"bb20e3ce4e882a997fba23f3d0521d2c"}, {"Alien 8 (Ultimate Play The Game)/Alien 8 (1985)(Ultimate Play The Game)[tape].dsk"} },
   {0x77e75fc5, {"6aa51754740b00c4859405b105c122ab"}, {"Advanced Tactical Fighter (Digital Integration) (Codes)/Advanced Tactical Fighter (1988)(Digital Integration)[codes].dsk"} },
   {0x42d83aa2, {"dfeca2654399c91fd3e30208df496487"}, {"Australian Rules Football (Again Again)/Australian Rules Football (1989)(Again Again)[cr].dsk"} },
   {0xb98aceb9, {"b701e29dd5a826b26acb83e36bc9b51b"}, {"Auftrag in der Bronx (Weeske Computer-Elektronik) (de)/Auftrag in der Bronx (1985)(Weeske Computer-Elektronik)(de).dsk"} },
   {0xc0405f10, {"8a1e2423192154620f6bf927c7c1d4de"}, {"A la Pursuite de Carmen Sandiego dans le Monde (Broderbund Software) (France)/A la Pursuite de Carmen Sandiego dans le Monde (1990)(Broderbund Software)(fr)(Side A).dsk"} },
   {0xe49fc694, {"66a3946177ec6093a361290f22f6f6da"}, {"Army Moves (Dinamic Software) (Spain)/Army Moves (1986)(Dinamic Software)(es).dsk"} },
   {0xe0a5e28a, {"616e4ee7245a3d427c2203bb938b488e"}, {"Alive (Lankhor) (France)/Alive (1991)(Lankhor)(fr)(Side A).dsk"} },
   {0x2dd0e609, {"d536b48ac14e55e9d1615317e83489be"}, {"Alkahera (Rino Marketing)/Alkahera (1985)(Rino Marketing)[tape].dsk"} },
   {0x90445ff6, {"a71d389dfa9f367535417d223c66b2c3"}, {"Air Traffic Control (Hewson)/Air Traffic Control (1985)(Hewson)[cr].dsk"} },
   {0xa9dd0625, {"9b89af3f6f5e2285f3e9a4bea4103b34"}, {"Ayo - The Game of Africa (Computing With The Amstrad)/Ayo - The Game of Africa (1987)(Computing With The Amstrad)[cr].dsk"} },
   {0x8d0de6e4, {"d8553d45901bd55c1025100611a49031"}, {"Alien Syndrome (ACE Software)/Alien Syndrome (1987)(ACE Software).dsk"} },
   {0xbf04b50d, {"ee593a2e7d1bb12507608d2840d5a9f5"}, {"Airwolf II (Encore)/Airwolf II (1987)(Encore)[cr].dsk"} },
   {0xb0c8cc9e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Aventura Original, La (Aventuras AD) (Spain)/Aventura Original, La (1989)(Aventuras AD)(es).dsk"} },
   {0xfccbe622, {"bf233c83a7fb53afc31eee7c0ac04690"}, {"Amsnake (Your Computer)/Amsnake (1985)(Your Computer)[cr].dsk"} },
   {0xd276b5bc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Affaire Vera Cruz, Die (Infogrames) (de)/Affaire Vera Cruz, Die  (1986)(Infogrames)(de).dsk"} },
   {0xf4621437, {"d4215c4e648aaf12df61b5a6e49bb5a4"}, {"Atomic (Fraggle and Duck)/Atomic (1992)(Fraggle and Duck)(PD)[Extended Version][cr].dsk"} },
   {0x99d1e3b0, {"c68076620e353d3feae594cc90a2f4ca"}, {"Aliens (Electric Dreams Software)/Aliens (1986)(Electric Dreams Software).dsk"} },
   {0x5867b00c, {"ec114732cac1e513a2db6c973afa3a1d"}, {"Al-Strad (Rhinosoft)/Al-Strad (1985)(Rhinosoft)[cr].dsk"} },
   {0xea6fd821, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"ACE 2 - The Ultimate Head to Head Conflict (Cascade Games)/ACE 2 - The Ultimate Head to Head Conflict (1987)(Cascade Games).dsk"} },
   {0xec7a64d2, {"b4a7f3c04697685cc5c0ab8d32ec5639"}, {"Ahhh!! (CRL Group)/Ahhh!! (1985)(CRL Group)[cr].dsk"} },
   {0x5d64313f, {"e2d159c251b5c4e3ac10c43d4dc591fe"}, {"Anduril (Schingnitz) (de)/Anduril (19xx)(Schingnitz)(de)[cr].dsk"} },
   {0x5c74e277, {"0f3ce766494c244fb3e069ee60809d95"}, {"Auf Wiedersehen Monty (Gremlin Graphics Software)/Auf Wiedersehen Monty (1987)(Gremlin Graphics Software).dsk"} },
   {0x9da1dad9, {"f46b60b89b59a900259716f211e282a2"}, {"Advanced Tactical Fighter (Digital Integration)/Advanced Tactical Fighter (1988)(Digital Integration)[cr].dsk"} },
   {0x819ea71c, {"1a178e9d20c6381dd72efa96c67a7c82"}, {"Atom Smasher (Romik Software - Amsoft)/Atom Smasher (1985)(Romik Software - Amsoft)[tape].dsk"} },
   {0x53599dd8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Amstra-Dames (Cobra Soft) (France)/Amstra-Dames (1985)(Cobra Soft)(fr).dsk"} },
   {0x6edf3b87, {"9674795845647481329c2e38c5502b2b"}, {"Asphyxie (Ludo's Software Distribution) (France)/Asphyxie (1985)(Ludo's Software Distribution)(fr)[cr].dsk"} },
   {0x8878a11b, {"75416bab6e67c0aa3c6e6824dcab6a27"}, {"Alien Break-In (Romik Software - Amsoft)/Alien Break-In (1985)(Romik Software - Amsoft)[tape].dsk"} },
   {0x29664c4c, {"f44815a9ba6cf1fff1d597ab25970f07"}, {"Adventure A - The Planet of Death (Artic Computing)/Adventure A - The Planet of Death (1985)(Artic Computing)[cr].dsk"} },
   {0xffc80866, {"4eb77cee99810ca4019a09e3bc60405a"}, {"Amo del Mundo (Positive) (Spain)/Amo del Mundo (1990)(Positive)(es).dsk"} },
   {0x16d70b4a, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Adult Two (Simon Avery)/Adult Two (1990)(Simon Avery)[cr].dsk"} },
   {0xb10a71fd, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Argo Navis (Kuma Computers)/Argo Navis (1985)(Kuma Computers).dsk"} },
   {0x6d278d3e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Angel Nieto Pole 500cc (Opera Soft) (Spain)/Angel Nieto Pole 500cc (1990)(Opera Soft)(es).dsk"} },
   {0xc6bffad9, {"19f06d10e2d7f9eb7e300ebb35abfcfd"}, {"American Football (Mind Games)/American Football (1984)(Mind Games)[tape].dsk"} },
   {0x926c30c8, {"7e2c144eba471d8d9bbad9c7b7483dad"}, {"Aftermath (Alternative Software)/Aftermath (1988)(Alternative Software)[cr].dsk"} },
   {0xe5c4a056, {"294eed806dd96e7cffb2b666d75c2764"}, {"Armadura Sacrada De Antiriad, La (Palace Software) (Spain)/Armadura Sacrada De Antiriad, La (1986)(Palace Software)(es)[cr][f].dsk"} },
   {0x8714bccc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Aspar GP Master (Dinamic Software)/Aspar GP Master (1988)(Dinamic Software).dsk"} },
   {0x503d22e7, {"17dd2ad6002702085900f160fd8722f1"}, {"Aigle d'Or, L' (Loriciels) (France)/Aigle d'Or, L' (1986)(Loriciels)(fr).dsk"} },
   {0x219d1cc5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Arkanoid II - Revenge of Doh (Imagine Software)/Arkanoid II - Revenge of Doh (1988)(Imagine Software).dsk"} },
   {0xff2e13d2, {"523c106e50a8461929d03620a54a8d90"}, {"Aventures au Chateau (Micro Application) (France)/Aventures au Chateau (1985)(Micro Application)(fr)[cr].dsk"} },
   {0x799f2e1d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Avenger (Gremlin Graphics Software)/Avenger (1986)(Gremlin Graphics Software).dsk"} },
   {0x1826ec6e, {"1e5562b307ee2ad5a4d6997dd88a478d"}, {"Anniversaire de Bobby, L' (Carraz Editions) (France)/Anniversaire de Bobby, L' (19xx)(Carraz Editions)(fr).dsk"} },
   {0xbee977b4, {"0f3ce766494c244fb3e069ee60809d95"}, {"AMC - Astro Marine Corps (Dinamic Software) (Spain)/AMC - Astro Marine Corps (1989)(Dinamic Software)(es).dsk"} },
   {0xa63c8b7e, {"891cb51ea0d01109a92d78f14f64cf1d"}, {"Animal Vegetable Mineral (Amsoft) (France)/Animal Vegetable Mineral (1984)(Amsoft)(fr)[cr].dsk"} },
   {0x1789290e, {"ab6e4b2fc52aefb7e63cc1c56badaf85"}, {"Abracadabra (Proein Soft Line) (Spain)/Abracadabra (1988)(Proein Soft Line)(es)(Side A).dsk"} },
   {0xf16ab0f6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Alex Higgins World Pool (Amsoft)/Alex Higgins World Pool (1985)(Amsoft).dsk"} },
   {0xa9047f72, {"98d1871be3e2ed54f5bcd3bd66c25c42"}, {"Airballs (Playfield)/Airballs (1989)(Playfield)[cr].dsk"} },
   {0xa81e9849, {"23762081dab77e438bd29ba648ef1e7e"}, {"Bomb Jack II (Elite Systems)/Bomb Jack II (1987)(Elite Systems).dsk"} },
   {0x5fed8f56, {"0ab7f2c6cac0591c7b9752eaaade4c58"}, {"Bustout (Amstrad Computer User)/Bustout (1984)(Amstrad Computer User)[cr].dsk"} },
   {0x9beae974, {"d57e67a1384176140fef55c319276487"}, {"Batty (Elite Systems)/Batty (1987)(Elite Systems)[cr].dsk"} },
   {0x90998c20, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Beach-Head (Amsoft) (M2)/Beach-Head (1985)(Amsoft)(M2).dsk"} },
// {0x43ce2bae, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Bob Morane - Science Fiction (Infogrames) (France)/Bob Morane - Science Fiction (1987)(Infogrames)(fr).dsk"} },
   {0xded167ba, {"993872cf449c4ee726c425ce14900f97"}, {"Bugsy (CRL Group)/Bugsy (1986)(CRL Group)[cr].dsk"} },
// {0x646b68a9, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Beurk Roger (Amstrad Computer User) (France) (Hack)/Beurk Roger (1985)(Amstrad Computer User)(fr)(Hack)[cr].dsk"} },
   {0xd3a10e04, {"4bb220961b37d265f53c92870bf4d79b"}, {"Bubble Dizzy (Codemasters Software)/Bubble Dizzy (1991)(Codemasters Software)[cr].dsk"} },
   {0x0332934f, {"b7a776f272759a351a9ab2dd040faf6d"}, {"Bronx Street Cop (Virgin Mastertronic)/Bronx Street Cop (1989)(Virgin Mastertronic)[cr].dsk"} },
   {0x0d5b365c, {"7b1512ac3cae010aa0d1c8073e7c13d3"}, {"Boulder Crash (Amstar) (France)/Boulder Crash (1987)(Amstar)(fr)[cr].dsk"} },
   {0xb0fb1bbc, {"e633047bd70222a17333cb4abc19487f"}, {"Boy Racer (Alligata Software)/Boy Racer (1987)(Alligata Software)[cr].dsk"} },
// {0x3bf52bf5, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Bounty Hunter (The Adventure Workshop)/Bounty Hunter (19xx)(The Adventure Workshop)[cr].dsk"} },
   {0x32e86faf, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"By Fair Means Or Foul (Alligata Software)/By Fair Means Or Foul (1988)(Alligata Software).dsk"} },
   {0xf0ab7aec, {"d06f53ef605ce63984d5b4bdb2a0b891"}, {"Billy The Kid (Mastertronic)/Billy The Kid (1990)(Mastertronic)[cr].dsk"} },
   {0x96d31131, {"006816a36b8b1a27366bab4cf1a547e5"}, {"Buster Block (Kuma Computers)/Buster Block (1986)(Kuma Computers)[cr].dsk"} },
   {0x5ebc61a1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Boulder Dash 3 (First Star Software)/Boulder Dash 3 (1986)(First Star Software).dsk"} },
   {0xe028abd6, {"f30e0ce4a60b625e37ce366284fdd9ee"}, {"Blasted Squares (Schneider Magazin) (de)/Blasted Squares (1988)(Schneider Magazin)(de)[cr].dsk"} },
   {0xb4e66edc, {"9c41a332eeec56ee17b473aa2427270a"}, {"Bored of the Rings (Silversoft)/Bored of the Rings (1985)(Silversoft)(Side A).dsk"} },
   {0x2f292d29, {"820373d126ec4b561d522042164e3d54"}, {"Blue Star (Free Game Blot) (France)/Blue Star (1990)(Free Game Blot)(fr).dsk"} },
   {0x762cc177, {"91649801d0ae81c79e251fd9dffa7b7b"}, {"Boinggg (Atlantis Software)/Boinggg (1988)(Atlantis Software)[cr].dsk"} },
   {0x6253270d, {"4ae19a3d8189b37dd4314eac8f5bd5b1"}, {"Bombarderos (Amstrad Users) (Spain)/Bombarderos (1984)(Amstrad Users)(es)[cr].dsk"} },
   {0x5276dcb2, {"4e03c1e36e80840d19116ffbcfe4dca3"}, {"Bionic Ninja (Zeppelin Games)/Bionic Ninja (1989)(Zeppelin Games)[cr].dsk"} },
   {0x3cb7f8e6, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Back to the Future II (Image Works)/Back to the Future II (1990)(Image Works)(Side A).dsk"} },
   {0x9cb1e0a7, {"5ca8e4fb0147111ef7a4743d93baaa41"}, {"Baba's Palace (cpcretrodev.byterealms)/Baba's Palace (2017)(cpcretrodev.byterealms).dsk"} },
   {0xdc845b6f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Batman The Caped Crusader (Ocean Software)/Batman The Caped Crusader (1988)(Ocean Software)(v2).dsk"} },
   {0x811b8f8c, {"397d12a922488a8264228c56916d445a"}, {"Bataille Pour Midway (PSS) (France)/Bataille Pour Midway(1985)(PSS)(fr).dsk"} },
   {0xde4e7b98, {"18af25a3944c81e2d4aa5fecbc4a14ed"}, {"Banda Salvaje, La (Firebird) (Spain)/Banda Salvaje, La (1985)(Firebird)(es)[cr].dsk"} },
   {0x109a104f, {"81246f5f2783192a2e0593e77563cd89"}, {"Big Screen Hero (Skyslip Computers)/Big Screen Hero (1988)(Skyslip Computers).dsk"} },
   {0xa9415a47, {"0f8ec7ce7aecd5ebeb8959b8af00392e"}, {"Bonz (CPC Oxygen)/Bonz (2003)(CPC Oxygen)[cr].dsk"} },
   {0x2cf176da, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Boulder Dash Construction Kit (First Star Software)/Boulder Dash Construction Kit (1987)(First Star Software).dsk"} },
// {0x9f759eb0, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Back To The Future III (Image Works)/Back To The Future III (1990)(Image Works)(Side A).dsk"} },
   {0x2174ec91, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Bronx (MCM Software) (Spain)/Bronx (1989)(MCM Software)(es).dsk"} },
   {0x48fcdc1e, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Boulder Dash 6 (Michael Gordon) (Hack)/Boulder Dash 6 (1986)(Michael Gordon)(Hack)[cr].dsk"} },
   {0x23096eca, {"4f40197ad709d5181fa21bfb0978d959"}, {"Barmelo 3D (Infomedia) (France)/Barmelo 3D (1987)(Infomedia)(fr)[cr].dsk"} },
   {0x4e67bd82, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Barbarian II (Palace Software)/Barbarian II (1989)(Palace Software).dsk"} },
   {0xd389082e, {"85a000554122f671c64264297c565bdd"}, {"Balle De Match (Psion) (France)/Balle De Match (1985)(Psion)(fr).dsk"} },
   {0x75069f0d, {"c4f72ae12efbda9fbe31eb88dd7bab4d"}, {"Boredom (Amstrad Adventure PD Library)/Boredom (19xx)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0x441f86e9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Basil The Great Mouse Detective (Gremlin Graphics Software)/Basil The Great Mouse Detective (1987)(Gremlin Graphics Software).dsk"} },
   {0xe5c3e538, {"87cffaa6fa861cb85d54a6242f1cae79"}, {"Back to the Golden Age (Ubi Soft) (France)/Back to the Golden Age (1991)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x310d89f4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bob Morane - Chevalerie (Infogrames) (France)/Bob Morane - Chevalerie (1987)(Infogrames)(fr).dsk"} },
   {0xdbad43f6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Bataille Pour R.F.A. (PSS) (France)/Bataille Pour R.F.A. (1987)(PSS)(fr).dsk"} },
   {0x821a0c95, {"db25c05da0c9d6508dbbc98e940b833e"}, {"Buran (OMK) (Spain)/Buran (1990)(OMK)(es).dsk"} },
   {0xa16ec840, {"ed4e829e500f8e00d700638ccf23f645"}, {"Bells, The (Blaby Computer Games)/Bells, The (1986)(Blaby Computer Games)[cr].dsk"} },
   {0xa0746010, {"e3ae33a605b7701fa46bc2d0bb375af8"}, {"Brian Jacks Superstar Challenge (Martech)/Brian Jacks Superstar Challenge (1985)(Martech)[cr].dsk"} },
   {0x845fe56d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Base, The (The Adventure Workshop)/Base, The (1985)(The Adventure Workshop).dsk"} },
   {0xffc7e373, {"933b99282452f37619d330102cd20cec"}, {"BMX Freestyle (Codemasters Software)/BMX Freestyle (1989)(Codemasters Software)[cr].dsk"} },
   {0xac0510d0, {"dec68e0e2c5abaec3fbe490469eb148b"}, {"Bobsleigh (Digital Integration)/Bobsleigh (1987)(Digital Integration)[cr].dsk"} },
   {0x80312e57, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Beverly Hills Cop (Tynesoft)/Beverly Hills Cop (1990)(Tynesoft).dsk"} },
   {0x10bd9015, {"32d3d129a7d58ba41ac9b191865b8bd3"}, {"Beach Buggy Simulator (Silverbird Software)/Beach Buggy Simulator (1988)(Silverbird Software)[cr][f].dsk"} },
   {0xc579dc8b, {"cf785f7c5baf29357d7a06b2350df89f"}, {"Biggles (Mirrorsoft)/Biggles (1986)(Mirrorsoft).dsk"} },
   {0x3c0251bf, {"f46fb068539bf47a937fc76519ea230d"}, {"Black Land (Bollaware)/Black Land (1995)(Bollaware)(Disk 1 Side A)[cr].dsk"} },
   {0xb49cc4e0, {"72fc12a1add78e6ef3c1c9af8e56d944"}, {"Bachou (Central Solutions LTD)/Bachou (1985)(Central Solutions LTD)[cr].dsk"} },
   {0xaa5757b5, {"f46fb068539bf47a937fc76519ea230d"}, {"Black Land (Bollaware) (de)/Black Land (1995)(Bollaware)(de)(Disk 1 Side A)[cr].dsk"} },
   {0x24fe433a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Bard's Tale, The (Electronic Arts)/Bard's Tale, The (1988)(Electronic Arts)(Side A).dsk"} },
   {0xa1213ee3, {"ac65221fa602a5df7e3baa038ec4b921"}, {"Blip! (Silverbird)/Blip! (1988)(Silverbird)[cr].dsk"} },
// {0x0e63c83e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Blaue Kristall, Der (Rainbow Arts) (de)/Blaue Kristall, Der (1985)(Rainbow Arts)(de)(Side A).dsk"} },
   {0x2c2eb1e9, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Beyond the Ice Palace (Elite Systems)/Beyond the Ice Palace (1988)(Elite Systems).dsk"} },
   {0x925bf86b, {"49454af5228ebb174ff28c3a069a4777"}, {"Ballyhoo (Infocom)/Ballyhoo (1986)(Infocom)(Side A)[CPM].dsk"} },
   {0x8620b5dc, {"8c957406fca5c461aab202d775aac5c9"}, {"Bump Set Spike (Mastertronic)/Bump Set Spike (1987)(Mastertronic)[cr].dsk"} },
   {0xf1598d85, {"8a8e1a8f8702eb995eeb1fa55301831e"}, {"Bubbler (Ultimate Play The Game)/Bubbler (1987)(Ultimate Play The Game).dsk"} },
   {0x065effc5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Braxx Bluff (Amsoft)/Braxx Bluff (1985)(Amsoft).dsk"} },
   {0xb0a4f51f, {"3b660b982ebf32c3a2984dabccfe430c"}, {"Barbarian Part III (Des Soft) (France) (Hack)/Barbarian Part III (1988)(Des Soft)(fr)(Hack)[cr].dsk"} },
   {0x371e44f9, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Bigfoot (Codemasters Software)/Bigfoot (1988)(Codemasters Software).dsk"} },
   {0xc36f1142, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bobo (Inforgrames) (France)/Bobo (1988)(Inforgrames(fr)(Side A).dsk"} },
// {0x12a094b3, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Bivouac - Chamonix Challenge (Infogrames) (France)/Bivouac - Chamonix Challenge (1987)(Infogrames)(fr).dsk"} },
// {0x1bb90675, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Birdie (Ere Informatique)/Birdie (1987)(Ere Informatique).dsk"} },
   {0x8b5a4eed, {"c68076620e353d3feae594cc90a2f4ca"}, {"Block Invasion (Richard Wilson)/Block Invasion (2002)(Richard Wilson).dsk"} },
   {0xa5e349a1, {"b22c58ca21ebc2968c8d66ff5374ea37"}, {"Bingo (Amstrad Magazine Publinfor) (Spain)/Bingo (1988)(Amstrad Magazine Publinfor)(es)[cr].dsk"} },
   {0x8d933a44, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Battle Command (Ocean Software) (Bugs)/Battle Command (1991)(Ocean Software)(Side A)[b].dsk"} },
   {0xfed514e8, {"e2ba0ce802410e28aa0ba08c81da4971"}, {"Boulder Dash 2 (Peter Liepa) (Hack)/Boulder Dash 2 (1985)(Peter Liepa)(Hack)[cr].dsk"} },
   {0x31341abd, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Back to the Future (Activision)/Back to the Future (1986)(Activision).dsk"} },
   {0xd7140207, {"53ba9dd8dfa673958d7ec68e8dbc0cc7"}, {"Blue Tomb (ICS)/Blue Tomb (1986)(ICS)[cr].dsk"} },
   {0xbb143978, {"3474e59c835465f1abc43a7340c9a063"}, {"Balloon Buster (Blue Ribbon Software)/Balloon Buster (1989)(Blue Ribbon Software)[cr].dsk"} },
   {0x35245e40, {"1266ef1c36229266b511d0eada8d7911"}, {"Billy 2 (Loriciels)/Billy 2 (1987)(Loriciels).dsk"} },
   {0x1f3fa9a4, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Bionic Commando (US Gold)/Bionic Commando (1988)(US Gold)(Colour).dsk"} },
// {0x7724c437, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Blood Valley (Gremlin Graphics Software) (M3)/Blood Valley (1987)(Gremlin Graphics Software)(M3).dsk"} },
   {0xfea7e2a7, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Batman The Movie (Ocean Software)/Batman The Movie (1989)(Ocean Software).dsk"} },
   {0x160cbb57, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Bobby Bearing (The Edge Software)/Bobby Bearing (1986)(The Edge Software).dsk"} },
   {0x1e366bb6, {"775e3c7947d875058f5ccd07a1aec158"}, {"Barbarian Part II (Georgessoft) (Hack)/Barbarian Part II (1988)(Georgessoft)(Hack)(v2)[cr].dsk"} },
   {0x204b87ba, {"65e1b24075124947bbdfb82c1c856c96"}, {"Blazing Thunder (Hi-Tec Software)/Blazing Thunder (1990)(Hi-Tec Software)[cr][f].dsk"} },
   {0x351a8654, {"a53248be9a3590c7accabf2ffcc14bf8"}, {"Battle For Midway (PSS)/Battle For Midway (1985)(PSS)[cr].dsk"} },
   {0xed191009, {"2dccff60b2e7dbcb7e5171607d2d79db"}, {"Basket Coach (Rym Soft) (Spain)/Basket Coach (1988)(Rym Soft)(es)[cr].dsk"} },
   {0x257f11ff, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Book of the Dead (CRL Group)/Book of the Dead (1987)(CRL Group)[cr].dsk"} },
   {0x1ad5461c, {"8edfeae06edb8aabce4fc8384cf26e96"}, {"Blockbusters (Macsen Software)/Blockbusters (1984)(Macsen Software)[cr].dsk"} },
   {0x5cb36887, {"5fdd37b8caf066cdfc4b233c8776b308"}, {"Bust Out II (Activision)/Bust Out II (1986)(Activision)[cr].dsk"} },
   {0xe3ce13f4, {"3f5decc283a7d71067e5071e455a1096"}, {"Buggy Boy (Elite Systems)/Buggy Boy (1988)(Elite Systems).dsk"} },
   {0x00e0b66d, {"f9b872fb76eb7bf0a8fb37a8f73f5c62"}, {"Battle of the Planets (Mikrogen)/Battle of the Planets (1986)(Mikrogen)[cr].dsk"} },
   {0xbc9f72c9, {"c68076620e353d3feae594cc90a2f4ca"}, {"Ballblazer (Activision)/Ballblazer (1986)(Activision).dsk"} },
   {0xf4292003, {"39e4c0c85a8bc76178f066793d8c821f"}, {"Back to Reality (Mastertronic)/Back to Reality (1986)(Mastertronic)[cr].dsk"} },
   {0x48edfc14, {"dfcd8b58e0ba2e6a5bdd1bca7192a508"}, {"Bride Of Frankenstein (Ariolasoft)/Bride Of Frankenstein (1987)(Ariolasoft)[tape].dsk"} },
   {0x5a526d33, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Bridge Player 3 (CP Software)/Bridge Player 3 (1986)(CP Software).dsk"} },
   {0xd81cd9fb, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Blueberry (Coktel Vision) (Spain)/Blueberry (1987)(Coktel Vision)(es)(Side A)[CPM].dsk"} },
   {0xeb0c1927, {"4b7d488e83737850f1e28a680a0937fa"}, {"Barry McGuigan World Championship Boxing (Activision)/Barry McGuigan World Championship Boxing (1985)(Activision).dsk"} },
   {0x5a4129f6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Blockbusters (Domark)/Blockbusters (1986)(Domark).dsk"} },
   {0x1e15ade7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Buffalo Bill's Wild West Show (Tynesoft)/Buffalo Bill's Wild West Show (1989)(Tynesoft).dsk"} },
   {0x6276192d, {"4b747247e649e9757c827631cc093120"}, {"Blackbeard (Topo Soft) (Spain)/Blackbeard (1988)(Topo Soft)(es)[cr].dsk"} },
// {0x0c27ad3d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Battle of the Bulge (Cases Computer Simulators)/Battle of the Bulge (1990)(Cases Computer Simulators).dsk"} },
   {0xcfccf0cf, {"0e2fcd314d8f57409c884b45e3caccec"}, {"BIAT (Microfutur) (France) (Bugs)/BIAT (1988)(Microfutur)(fr)(Side A)[b].dsk"} },
   {0x8d86c090, {"bdfeb1cf181870372c70c31360c2214b"}, {"Bosconian '87 (Mastertronic)/Bosconian '87 (1987)(Mastertronic)[cr].dsk"} },
   {0x92730dfa, {"0f3ce766494c244fb3e069ee60809d95"}, {"Blasteroids (Image Works)/Blasteroids (1989)(Image Works).dsk"} },
   {0x82e295b3, {"5f9e5f19a512fe071b761dba7bf05192"}, {"Bad Cat (Rainbow Arts)/Bad Cat (1987)(Rainbow Arts)(Side A).dsk"} },
   {0xb25430db, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Beach Volley (Ocean Software)/Beach Volley (1989)(Ocean Software).dsk"} },
   {0x14017f7d, {"57667a5ff2c459ebad86ee0b1c915461"}, {"Battle-Spheres (The Firm)/Battle-Spheres (1994)(The Firm)[cr].dsk"} },
   {0xdc214555, {"18c3aa853facdcd408370021f9d812e8"}, {"Bubble Bobble 2 (Saturn-Soft) (Hack)/Bubble Bobble 2 (1988)(Saturn-Soft)(Hack)[cr].dsk"} },
   {0x264c68fd, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Bomb Scare (Firebird)/Bomb Scare (1986)(Firebird)[cr].dsk"} },
   {0xbeca9867, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bob Morane Ocean (Infogrames) (M2)/Bob Morane Ocean (1988)(Infogrames)(M2).dsk"} },
   {0xfb811d2b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Bloodwych (Image Works)/Bloodwych (1990)(Image Works)(v2).dsk"} },
// {0xe55eb7d9, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Bonanza Bros (US Gold)/Bonanza Bros (1991)(US Gold).dsk"} },
   {0x4a33bfa8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Big League Soccer II (Viper)/Big League Soccer II (1985)(Viper).dsk"} },
   {0x5c140a84, {"203c6c816bc1b13c8676f9981d8e2c9b"}, {"Booly (Loriciels) (M2) (Codes)/Booly (1991)(Loriciels)(M2)(Side A)[codes].dsk"} },
   {0x7731514d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"BMX Ninja (Alternative Software) (M2)/BMX Ninja (1989)(Alternative Software)(M2).dsk"} },
   {0xdd48c5ca, {"f562e092d796c6a95cba60920689e56b"}, {"Beta 2515 (G.T.S. Editorial) (Spain)/Beta 2515 (1987)(G.T.S. Editorial)(es)[cr].dsk"} },
// {0x304b0e30, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Back To The Future III (Image Works) (Spain)/Back To The Future III (1990)(Image Works)(es)(Side A).dsk"} },
   {0x2e58903c, {"5fbca64ae9fd4982052f187050269fc4"}, {"Ball Bearing (Radical Software)/Ball Bearing (1993)(Radical Software)[cr].dsk"} },
   {0x5fc8032d, {"4862c9558b576a850d1c79fb3287a2e3"}, {"Boloncio (G.T.S. Editorial) (Spain)/Boloncio (1986)(G.T.S. Editorial)(es)[cr].dsk"} },
// {0x7234d56e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Big League Soccer (Viper) (Spain) (Hack)/Big League Soccer (1985)(Viper)(es)(Hack)[cr].dsk"} },
   {0x474a9722, {"e2ba0ce802410e28aa0ba08c81da4971"}, {"Boulder Dash 2 (Peter Liepa) (France) (Hack)/Boulder Dash 2 (1985)(Peter Liepa)(Hack)(fr)[cr].dsk"} },
   {0x5706fe0c, {"5e4264213cc7fba5919d48544557ff66"}, {"Balrog (Gac User)/Balrog (1987)(Gac User)[cr].dsk"} },
   {0x7759c6b0, {"0ab7f2c6cac0591c7b9752eaaade4c58"}, {"Bust Out (PC Schneider International)/Bust Out (1987)(PC Schneider International)[cr].dsk"} },
// {0x925415df, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Birdie (Ere Informatique) (France)/Birdie (1987)(Ere Informatique)(fr).dsk"} },
   {0xd46b9059, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bridge (Infogrames) (M2)/Bridge (1986)(Infogrames)(M2).dsk"} },
   {0x5604a788, {"214a2b2f59e8838de40962ae067d15ba"}, {"Best of the Best (Loriciels)/Best of the Best (1992)(Loriciels).dsk"} },
   {0xae24fde5, {"8e50d63fc2d6c18598ac10a854d958cb"}, {"Battle Ships (Elite Systems)/Battle Ships (1987)(Elite Systems).dsk"} },
   {0x8de80fd4, {"0e70d7d50ed83351c2e2b5d95a1fb61c"}, {"Baloncesto - NBA (es) (Spain)/Baloncesto - NBA (ABC Sports)(es)[cr].dsk"} },
   {0x417b6cbe, {"abfb25da3fe7a3599c04e89925e78967"}, {"Bomber (Amstrad Computer User)/Bomber (1985)(Amstrad Computer User)[cr].dsk"} },
   {0xf0dd6d74, {"0f3ce766494c244fb3e069ee60809d95"}, {"Blood Brothers (Gremlin Graphics Software)/Blood Brothers (1988)(Gremlin Graphics Software)(v2).dsk"} },
   {0x0a44e83e, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Bacterik Dream (Chip) (France)/Bacterik Dream (1987)(Chip)(fr).dsk"} },
   {0xdf2066fb, {"0ab7f2c6cac0591c7b9752eaaade4c58"}, {"Bustout (Amstrad Computer User) (de)/Bustout (1984)(Amstrad Computer User)(de)[cr].dsk"} },
   {0xc12d5edb, {"ac8ce894fd7237cc3144242ee6d3f7b3"}, {"Barbarian (Melbourne House)/Barbarian (1988)(Melbourne House)[cr].dsk"} },
   {0x1de8ceaa, {"837dca953de0b80e8423c601bd214236"}, {"Bunny Bricks (Silmarils)/Bunny Bricks (1992)(Silmarils)(Side A).dsk"} },
   {0x22edc1ab, {"7413671212b9e8106d2a14b5f4ad2923"}, {"Beat the Clock (Amstrad Computer User)/Beat the Clock (1985)(Amstrad Computer User)[cr].dsk"} },
   {0x21491d7a, {"a2ead95b4bb612a30752e88a53b4c81d"}, {"Bulls Eye (Macsen Software)/Bulls Eye (1985)(Macsen Software)[cr].dsk"} },
   {0x057ec7f2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Buggy Ranger (Dinamic Software) (Spain)/Buggy Ranger (1990)(Dinamic Software)(es).dsk"} },
   {0x9ac25387, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ball Breaker (CRL Group)/Ball Breaker (1987)(CRL Group)(v3).dsk"} },
   {0x50203397, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bestial Warrior (Dinamic Software) (Spain)/Bestial Warrior (1989)(Dinamic Software)(es).dsk"} },
   {0x2c7308d9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ball Breaker II (CRL Group)/Ball Breaker II (1988)(CRL Group).dsk"} },
   {0x0100bcc3, {"5952890ac66cbebed0fa657441805fe0"}, {"Black Fountain, The (Incentive Software)/Black Fountain, The (1987)(Incentive Software)[cr][f].dsk"} },
   {0x76c0f723, {"86d81fbaec5ebf8119813de94cc460a0"}, {"Biff (Beyond Belief)/Biff (1992)(Beyond Belief)[cr].dsk"} },
   {0xa88c4a27, {"2d879d51f9711b3cf5001a7c9a0c98c9"}, {"Bad Max (Transoft) (France)/Bad Max (1985)(Transoft)(fr).dsk"} },
   {0x953030d9, {"5fdd37b8caf066cdfc4b233c8776b308"}, {"Bust Out (Activision)/Bust Out (1986)(Activision)[cr].dsk"} },
   {0xcee48cc7, {"b22c58ca21ebc2968c8d66ff5374ea37"}, {"Bingo (Amstrad Magazine Publinfor)/Bingo (1988)(Amstrad Magazine Publinfor)(pt)[cr].dsk"} },
   {0x46b5fe2c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Boulder Dash (MirrorSoft)/Boulder Dash (1985)(MirrorSoft).dsk"} },
// {0x84052472, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Blues Brothers, The (Titus)/Blues Brothers, The (1991)(Titus).dsk"} },
   {0x18af16eb, {"a0f344051c0f493b9af2ea19cfc024c2"}, {"Bombfusion (Mastertronic)/Bombfusion (1989)(Mastertronic)[cr].dsk"} },
   {0x95d9f222, {"f34ab1cbbff9400438b85c37cb750043"}, {"Bubble Bobble (Firebird)/Bubble Bobble (1987)(Firebird).dsk"} },
// {0xe23c20be, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Bataille d'Angleterre, La (PSS) (France)/Bataille d'Angleterre, La (1985)(PSS)(fr).dsk"} },
   {0xee4137b7, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Bedlam (US Gold)/Bedlam (1988)(US Gold).dsk"} },
   {0xafdabd14, {"cf02dea19a7e199675236f213869fd76"}, {"Binky (Software Projects)/Binky (1985)(Software Projects)[cr].dsk"} },
   {0xe147a91e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Battlefield Germany (PSS)/Battlefield Germany (1987)(PSS)(v2).dsk"} },
   {0xa741db1e, {"b752082d62ca9691745c9a82416c1be7"}, {"Bactron (Loriciels) (France)/Bactron (1986)(Loriciels)(fr).dsk"} },
   {0x507323ba, {"e27412929cf42cf73e02a9ef315b4397"}, {"Bard's Tale, The (Electronic Arts) (France)/Bard's Tale, The (1988)(Electronic Arts)(fr)(Side A).dsk"} },
   {0xc761e738, {"58545e1a3e7ce73568cd7ca29b7fbea2"}, {"Barbarian (Palace Software)/Barbarian (1987)(Palace Software)(Side A).dsk"} },
   {0x480c9e65, {"0f3ce766494c244fb3e069ee60809d95"}, {"Budokan (Electronic Arts)/Budokan (1990)(Electronic Arts)(Side A).dsk"} },
   {0x0814d462, {"ebae1f775be43b3aa842159245545a51"}, {"Batman (Ocean Software)/Batman (1986)(Ocean Software).dsk"} },
   {0xe6fe3e2d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bob Morane Jungle 1 (Infogrames) (France)/Bob Morane Jungle 1 (1987)(Infogrames)(fr).dsk"} },
   {0xddfa0583, {"9c41a332eeec56ee17b473aa2427270a"}, {"Bumpy's Arcade Fantasy (Loriciels)/Bumpy's Arcade Fantasy (1992)(Loriciels)(v2)(Side A).dsk"} },
   {0xb94d8ef1, {"0fa39acd8c09e3cf738515b90270b669"}, {"Bob Winner (Loriciels)/Bob Winner (1986)(Loriciels)(Side A).dsk"} },
   {0x099c3c44, {"0e3df43db88e403794fbfa9adee5f3ef"}, {"Bagne de Nepharia, Le (Loriciels) (France)/Bagne de Nepharia, Le (1985)(Loriciels)(fr)(v2)[cr].dsk"} },
// {0xe0e1a064, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Blue Crystal, The (Rainbow Arts) (France)/Blue Crystal, The (1985)(Rainbow Arts)(fr)(Side A).dsk"} },
   {0x0365bb6a, {"4dd36654d239582ff2cbe3020e5b26aa"}, {"Buggy II (Chip) (France)/Buggy II (1986)(Chip)(fr)[cr].dsk"} },
   {0x07d6f24b, {"f72a76514e263924620c784daa14e692"}, {"Boggit, The (CRL Group)/Boggit, The (1986)(CRL Group)[cr].dsk"} },
   {0x4e5fa31a, {"cd8eb0f1f9b1319be1a1cc0a913485be"}, {"BMX Kidz (Firebird)/BMX Kidz (1988)(Firebird)[cr].dsk"} },
   {0x44179cde, {"4a3b9c2893232d4d7bf2695cea14b49f"}, {"Brainache (Codemasters Software)/Brainache (1987)(Codemasters Software)[cr].dsk"} },
   {0xd10b4b49, {"000d4b30adcde406caad71692857d824"}, {"Bridge It (Amsoft)/Bridge It (1984)(Amsoft)[cr].dsk"} },
   {0xf3422b3d, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Black Tiger (US Gold)/Black Tiger (1989)(US Gold).dsk"} },
   {0x30003af9, {"dff86003f74f6d9a6a2c07b1cb3d824d"}, {"Bobsleigh (Digital Integration) (Codes)/Bobsleigh (1987)(Digital Integration)[codes].dsk"} },
   {0x35fbb25e, {"6044406d31aeadbb720805a549ec018a"}, {"Beach-Head II - The Dictator Strikes Back! (US Gold)/Beach-Head II - The Dictator Strikes Back! (1986)(US Gold).dsk"} },
   {0x20355e4e, {"221ce5b62872103a643ac633d71fd67c"}, {"Brian Clough's Football Fortunes (CDS Software LTD) (Spain) (Hack)/Brian Clough's Football Fortunes (2020)(CDS Software LTD)(es)(Hack)[cr].dsk"} },
   {0xd55039f2, {"b7d7dae9438e00931ce480826717e663"}, {"Baca (Drazen)/Baca (1998)(Drazen)[cr].dsk"} },
   {0x83f93b45, {"e677186a66298380f98c7ad1b6c9a69b"}, {"Blade Runner (CRL Group)/Blade Runner (1986)(CRL Group)[cr].dsk"} },
   {0x4239f562, {"559654ccca5555c62e3964f1b7ac99fb"}, {"Balldozer (Jeroen Erkens)/Balldozer (1991)(Jeroen Erkens)(PD)[cr].dsk"} },
   {0x524f4cf7, {"c68076620e353d3feae594cc90a2f4ca"}, {"Big Trouble in Little China (Activision)/Big Trouble in Little China (1986)(Activision).dsk"} },
   {0xcb9f4162, {"2cc11b196aecd6ba093d350ff73e85d3"}, {"Burger Time (Hebdogiciel) (France)/Burger Time (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x22a04a98, {"fae74441931d4c855637431475cc5141"}, {"Beer Hunter, The (Global Software)/Beer Hunter, The (1987)(Global Software)[cr].dsk"} },
   {0xc26b2a02, {"6b543df833d30555389672ecd1b11f8c"}, {"Boeing 727 (-) (de)/Boeing 727 (19xx)(-)(de)[cr].dsk"} },
   {0x207fb361, {"e996c92ce6325ad8e614c248ade13864"}, {"Blokker (Computer Magazine)/Blokker (1985)(Computer Magazine)[cr].dsk"} },
   {0xc6349fe7, {"0f3ce766494c244fb3e069ee60809d95"}, {"B.A.T. (Ubi Soft)/B.A.T. (1991)(Ubi Soft)(Disk 1 Side A).dsk"} },
   {0xc532e616, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Bionic Commando (US Gold) (Green)/Bionic Commando (1988)(US Gold)(Green).dsk"} },
   {0x2724fe4b, {"2783049d64aa77377f32750d63659ef2"}, {"Brick, The (Delta Software) (Spain)/Brick, The (1989)(Delta Software)(es).dsk"} },
   {0x2e87d8a8, {"c68076620e353d3feae594cc90a2f4ca"}, {"Badlands (Domark)/Badlands (1990)(Domark).dsk"} },
   {0xc3283ce5, {"a2ead95b4bb612a30752e88a53b4c81d"}, {"Bullseye (Macsen Software) (France) (LightGun)/Bullseye  (1985)(Macsen Software)(fr)(LightGun)[cr].dsk"} },
   {0xa5a40741, {"397d12a922488a8264228c56916d445a"}, {"Bubble Ghost (ERE Informatique) (France)/Bubble Ghost (1988)(ERE Informatique)(fr).dsk"} },
   {0x4bf042ca, {"268691b3ccde0a2a2c7a9a20764e188e"}, {"Bomb Jack (Elite Systems)/Bomb Jack (1986)(Elite Systems).dsk"} },
   {0x739d1232, {"867ce989791e7b2002a79e21a3f87960"}, {"Barthels Dash (Bollaware) (de)/Barthels Dash (1990)(Bollaware)(de)[cr].dsk"} },
   {0x29c7970f, {"9d617e1cd9845d2c4d8121c0b7c39fd5"}, {"Berks III (The Power House)/Berks III (1985)(The Power House)[cr].dsk"} },
   {0x4e0d9163, {"0ab7f2c6cac0591c7b9752eaaade4c58"}, {"Bustout (Amstrad Computer User) (France)/Bustout (2013)(Amstrad Computer User)(fr)[cr].dsk"} },
   {0x471c5eac, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Basket Master (Dinamic Software)/Basket Master (1987)(Dinamic Software).dsk"} },
   {0xa4a0dc6e, {"221ce5b62872103a643ac633d71fd67c"}, {"Brian Clough's Football Fortunes (CDS Software LTD)/Brian Clough's Football Fortunes (1987)(CDS Software LTD).dsk"} },
   {0x98cd5629, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bestial Warrior (Dinamic Software) (Spain) (LightGun)/Bestial Warrior (1989)(Dinamic Software)(es)(LightGun).dsk"} },
// {0xdd29fe62, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Basun (Multicrom)/Basun (1986)(Multicrom).dsk"} },
   {0x8e401eb1, {"68a361370c5e466b400d738b78c4dcb7"}, {"Booty (Firebird)/Booty (1984)(Firebird)[cr].dsk"} },
   {0x69bd3223, {"0f3ce766494c244fb3e069ee60809d95"}, {"B.A.T. (Ubi Soft) (France)/B.A.T. (1991)(Ubi Soft)(fr)(Disk 1 Side A).dsk"} },
   {0xfdd2c922, {"ef5ca45cc15f55e9824d30123550623f"}, {"Bestiary (Amstrad Adventure PD Library)/Bestiary (1987)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0xbb83cd78, {"cab6d868eacb6b958107356f58196e2e"}, {"Blue-War (Free Game Blot) (France)/Blue-War (1986)(Free Game Blot)(fr).dsk"} },
   {0x7dd0a226, {"b5c76613a2b2f4ee2a9bfc95053775b2"}, {"Brian Bloodaxe (The Edge)/Brian Bloodaxe (1985)(The Edge).dsk"} },
   {0x1773adfb, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Bravestarr (US Gold)/Bravestarr (1987)(US Gold).dsk"} },
   {0x6d205cbc, {"024bcca00445ad7e08673321ab7d7231"}, {"Big League Soccer (Viper)/Big League Soccer (1985)(Viper)[cr].dsk"} },
   {0x142ab82b, {"063c7e061fe9b98705f976241198ff13"}, {"Battle Of Britain (PSS)/Battle Of Britain (1985)(PSS).dsk"} },
   {0x305153d3, {"0fa39acd8c09e3cf738515b90270b669"}, {"Bob Winner (Loriciels) (France)/Bob Winner (1986)(Loriciels)(fr)(Side A).dsk"} },
   {0x3c94e5b1, {"2b9efae81e0268a2c80fe574503150b5"}, {"Battle Beyond the Stars (Solar Software)/Battle Beyond the Stars (1985)(Solar Software)[cr].dsk"} },
   {0xa756b4fa, {"7761ed8e67dd3ceb6a5f04fe193b3c6e"}, {"Blagger (Amsoft)/Blagger (1985)(Amsoft)[cr].dsk"} },
   {0x2932ed4f, {"e677186a66298380f98c7ad1b6c9a69b"}, {"Blade Warrior (Codemasters Software)/Blade Warrior (1989)(Codemasters Software)[cr].dsk"} },
   {0xf4064b7e, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Black Magic (US Gold)/Black Magic (1987)(US Gold).dsk"} },
   {0x5ea3f8fa, {"5ec751bb50a6bc50466a25d69caed011"}, {"Black Sea (Mananuk)/Black Sea (2022)(Mananuk).dsk"} },
   {0x444c8866, {"aea7f618f8f11cade387e33fb24c422a"}, {"Billard Americain (CPC) (France)/Billard Americain (1988) (CPC)(fr)[cr].dsk"} },
   {0x254b189b, {"7aadb3f8f327db3aa5dd8778faf19947"}, {"Billy La Banlieue (Loriciels) (France)/Billy La Banlieue (1986)(Loriciels)(fr).dsk"} },
   {0xf822cc4a, {"1818c1b2c8fab5f33330b785f35c2d68"}, {"Break Thru (US Gold)/Break Thru (1986)(US Gold).dsk"} },
   {0xd74b46f4, {"7fca045b139fdc8d37c45c065b0dcc87"}, {"Burglar (Lankhor) (France)/Burglar (1991)(Lankhor)(fr)(side A)[cr].dsk"} },
   {0xeb9c2347, {"6ef6b39f184c2886e7396634523ba69e"}, {"Bo! (Bollaware) (de)/Bo! (1994)(Bollaware)(de)[cr].dsk"} },
   {0x6cf1612c, {"37a3313df2b370a23f9ee060bba5f3ea"}, {"BMX Simulator (Codemasters Software)/BMX Simulator (1987)(Codemasters Software)[cr].dsk"} },
   {0xfac68415, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Big League Soccer II (Viper) (Spain) (Hack)/Big League Soccer II (2018)(Viper)(es)(Hack)[cr].dsk"} },
   {0xdee486dd, {"0f3ce766494c244fb3e069ee60809d95"}, {"Bounder (Gremlin Graphics Software)/Bounder (1986)(Gremlin Graphics Software).dsk"} },
   {0xcf73ebd6, {"0ba9206855b53e8721d85fb05ce917db"}, {"Bruce Lee (US Gold)/Bruce Lee (1984)(US Gold).dsk"} },
   {0x4fc3ef0b, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Blue War (Free Game Blot)/Blue War (1987) (Free Game Blot).dsk"} },
// {0x02914bd1, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Blockhaus (Amstrad Magazine) (France)/Blockhaus (1986)(Amstrad Magazine)(fr)[cr].dsk"} },
   {0xa8b16df6, {"9ee2555e6b0846ed4f1004f849be8e91"}, {"Bumpy (Loriciels) (France)/Bumpy (1989)(Loriciels)(fr).dsk"} },
   {0x6b339e59, {"221ce5b62872103a643ac633d71fd67c"}, {"Brian Clough's Football Fortunes (CDS Software LTD) (de)/Brian Clough's Football Fortunes (1987)(CDS Software LTD)(de)[cr].dsk"} },
   {0xbc08dbb8, {"267a4df928e1d6d076426eb90a3d8bdf"}, {"Bigtop Barney (Players)/Bigtop Barney (1986)(Players)[cr].dsk"} },
   {0x52f53a63, {"fff8938286097392321b9b79360f846a"}, {"Beetle Mania (Software Exchange)/Beetle Mania (1985)(Software Exchange)[cr].dsk"} },
   {0x602aab4d, {"e27412929cf42cf73e02a9ef315b4397"}, {"Bard's Tale, The (Electronic Arts) (de)/Bard's Tale, The (1988)(Electronic Arts)(de)(Side A).dsk"} },
   {0xfd361799, {"4cd06128ca89c9ee1b8f0484652ad30b"}, {"Big Sleaze, The (Piranha)/Big Sleaze, The (1987)(Piranha)[cr].dsk"} },
   {0x10336c2f, {"b02c9b65b9484dcfb46d6605d88fdfbb"}, {"Bundesliga Manager 3 (O+T Soft) (de)/Bundesliga Manager 3 (1993)(O+T Soft)(de)[cr].dsk"} },
   {0xd015805a, {"b42d7f4ab78009babcba4a07d7b5af23"}, {"Baby Jo - Going Home (Imagine Software)/Baby Jo - Going Home (1991)(Imagine Software)(v2)(Side A).dsk"} },
   {0x320dff2a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Backgammon (CP Software) (Spain)/Backgammon (1985)(CP Software)(es).dsk"} },
   {0xb27705e2, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Butcher Hill (Gremlin Graphics Software)/Butcher Hill (1989)(Gremlin Graphics Software).dsk"} },
   {0x6d9aeec1, {"fafcafdff5df93fd1fbb4ccd20a8d72c"}, {"Buzzlines (The Amstrad User)/Buzzlines (1985)(The Amstrad User)[cr].dsk"} },
   {0x2dc8c009, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Blueberry (Coktel Vision) (de)/Blueberry (1987)(Coktel Vision)(de)(Side A)[CPM].dsk"} },
   {0xe17d14cb, {"92056f3392eb909b7dc0564b743a18fa"}, {"Classiques Titus Volume 2 (Titus) (France)/Classiques Titus Volume 2 (1987)(Titus)(fr).dsk"} },
   {0x514d61ad, {"3d696180978329dfdfbe29ddec2a00db"}, {"Chuck Yeager's Advanced Flight Trainer (Electronic Arts)/Chuck Yeager's Advanced Flight Trainer (1989)(Electronic Arts)(v2)(Side A).dsk"} },
   {0x2653ac21, {"205d4127d21c11321597348b17e38592"}, {"Cross Horde (Caruso, Fabrizio)/Cross Horde (2021)(Caruso, Fabrizio)(PD)[cr].dsk"} },
   {0x95a1b7fe, {"ef1b12c6fb5731a263b4b7ef8cb5bddc"}, {"City for Ransom (Wow Software)/City for Ransom (1989)(Wow Software)[cr].dsk"} },
   {0x15d28b90, {"523c106e50a8461929d03620a54a8d90"}, {"Chateau du Diable, Le (Cobra Soft) (France)/Chateau du Diable, Le (1985)(Cobra Soft)(fr)[cr].dsk"} },
   {0x8019d184, {"bd671397ca7bd56aba90498aba19ef7a"}, {"Curse of Sherwood, The (Mastertronic)/Curse of Sherwood, The (1987)(Mastertronic)[cr].dsk"} },
   {0x3a3dc732, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Crack Down (US Gold)/Crack Down (1990)(US Gold).dsk"} },
   {0xaadab65d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Cray 5 (Topo Soft) (Spain)/Cray 5 (1987)(Topo Soft)(es).dsk"} },
   {0x8ea026c8, {"cb135daaf40f34de7ba1cc76651b4704"}, {"Computer Maniac's Diary (Domark)/Computer Maniac's Diary (1989)(Domark)[cr].dsk"} },
   {0xa5e1b296, {"46232e761066d6cec52eb7d6ca33a943"}, {"Crypte des Maudits, La (Lankhor) (France)/Crypte des Maudits, La (1991)(Lankhor)(fr)(Side A).dsk"} },
   {0x7fe22387, {"d11d7eacf053483a3c47fc257d4996f3"}, {"Cyber Power (CPC Infos) (France)/Cyber Power (1992)(CPC Infos)(fr)[cr].dsk"} },
// {0xf490084a, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Cite Perdu, La (Excalibur) (France)/Cite Perdu, La (1987)(Excalibur)(fr)(Disk 1 Side A).dsk"} },
   {0xedeb95a4, {"1075c8712cfe386144ba272dfe1a4b5f"}, {"Canadair (Fil) (France)/Canadair (1987)(Fil)(fr).dsk"} },
   {0x24971ea4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Cop-Out (Mikrogen)/Cop-Out (1986)(Mikrogen).dsk"} },
   {0xf89ab99b, {"cbcdc06930d2930aa114e9dd10649699"}, {"Cyber-Tennis (Wendos PDS)/Cyber-Tennis (1997)(Wendos PDS)[cr].dsk"} },
   {0xa55c0498, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Centre Court Tennis (Amsoft)/Centre Court Tennis (1984)(Amsoft).dsk"} },
   {0x871c499c, {"c9e92964db37a0680578a3e3caa2e3b9"}, {"Chomper (Pan Books)/Chomper (1984)(Pan Books)[cr].dsk"} },
   {0x0ff250a9, {"f9316bbf4c157d831d53a32f474b4d7a"}, {"Captain Kidd (MC Lothlorien)/Captain Kidd (1985)(MC Lothlorien)[cr][f].dsk"} },
// {0xe894c4e9, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Cyrus II (Amsoft)/Cyrus II (1985)(Amsoft).dsk"} },
   {0x09d98a34, {"42a50bd475cbea780ed32059a9dbc971"}, {"Climb-It (Tynesoft)/Climb-It (1984)(Tynesoft)[tape].dsk"} },
   {0x11b9e71d, {"c68076620e353d3feae594cc90a2f4ca"}, {"Chuckie Egg II (A&F Software)/Chuckie Egg II (1985)(A&F Software).dsk"} },
// {0x25aeae06, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Chose de Grotemburg, La (Ubi Soft) (France)/Chose de Grotemburg, La (1987)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x3f6799b8, {"336f3f5de1d80dfd915cfe9ac457c38e"}, {"Croco Magneto (Public Domain) (France)/Croco Magneto (1989)(Public Domain)(fr)[cr].dsk"} },
   {0x91808822, {"0f3ce766494c244fb3e069ee60809d95"}, {"Chamonix Challenge (Infogrames)/Chamonix Challenge (1987)(Infogrames).dsk"} },
   {0xc74ff3de, {"8779b2817bb72ddea8247728b60423d0"}, {"Combat Lynx (Durell Software)/Combat Lynx (1985)(Durell Software).dsk"} },
   {0x2221ad10, {"dedff2cb8385fd79709ac57b72f3ac22"}, {"Cuatro en Raya, Las (Softbasco) (Spain)/Cuatro en Raya, Las (1988)(Softbasco)(es)[cr].dsk"} },
   {0x6d7a58c4, {"c6adfae088c140e918f329ff48b9a4ba"}, {"Crime Parfait (Logipresse) (France)/Crime Parfait (1987)(Logipresse)(fr)[cr].dsk"} },
   {0x680a8d67, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Castle Master (Incentive) (M3)/Castle Master (1990)(Incentive)(M3).dsk"} },
   {0x0cd769a6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Capitan Sevilla (Dinamic Software) (Spain)/Capitan Sevilla (1988)(Dinamic Software)(es).dsk"} },
// {0x17d4c34e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Crafton & Xunk (ERE Informatique) (M3)/Crafton & Xunk (1986)(ERE Informatique)(M3).dsk"} },
   {0xa5c893d8, {"2a74289f64692d541e730de9ee922072"}, {"Crawler (Amstrad Computer User)/Crawler (1986)(Amstrad Computer User)[cr].dsk"} },
   {0xf4ce35a8, {"ea9dc48f41f86e50b43dda6c402ebeae"}, {"Crimen Perfecto, El (Logipresse) (Spain)/Crimen Perfecto, El (1987)(Logipresse)(es)[cr].dsk"} },
   {0x9f07df32, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Crazy Cars II (Titus) (Bugs)/Crazy Cars II (1989)(Titus)[b].dsk"} },
   {0x7b270970, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cauldron (Palace Software)/Cauldron (1985)(Palace Software).dsk"} },
   {0x386f4534, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Campeones Del Mundo De Rallyes (Indescomp) (Spain)/Campeones Del Mundo De Rallyes (1985)(Indescomp)(es).dsk"} },
   {0x3e29a536, {"cfe5bfcb19ce44ce472f7b57054e70b8"}, {"Chickin Chase (Firebird)/Chickin Chase (1985)(Firebird)[cr].dsk"} },
   {0xca879e1e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Cosa Nostra (Opera Soft)/Cosa Nostra (1986)(Opera Soft).dsk"} },
   {0xd851fde0, {"6f941d504259a5fba1646d7636adc2aa"}, {"Chibi Akuma's Episode 1 Invasion (Keith Sear)/Chibi Akuma's Episode 1 Invasion (2018)(Keith Sear)(v1.666)(Side A).dsk"} },
   {0xce81cffa, {"91c0c281d7464085ed651abc48b85381"}, {"Crazy Shoot (Loriciels) (France) (Phaser)/Crazy Shoot (1989)(Loriciels)(fr)(West Phaser)(Side A).dsk"} },
   {0xaf8f2d05, {"137c400e28f0f124ca72d5c7f04a6058"}, {"CORE (A&F Software)/CORE (1986)(A&F Software)[cr].dsk"} },
   {0x84acf7c6, {"329d5e145fd3ba8366539261cfa7f484"}, {"Caves of Darkness (Emma Kingsmill)/Caves of Darkness (1991)(Emma Kingsmill)(PD)[cr].dsk"} },
// {0x4f3022bc, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Camelot Warriors (Dinamic Software)/Camelot Warriors (1987)(Dinamic Software).dsk"} },
   {0x6f367915, {"072c4e71f324c23fb5cefb2c0ffd6a82"}, {"Cursed be the City (The Adventure Workshop)/Cursed be the City (1987)(The Adventure Workshop)[cr].dsk"} },
   {0x4396b4c3, {"62c3a98c4ee221ff4006ecbdf8b38170"}, {"Classic Racing (Amsoft)/Classic Racing (1985)(Amsoft)[tape].dsk"} },
   {0x4696b247, {"532be2b725bb9d0d56a9eb8802b89a4b"}, {"Crystann (Softbook) (France)/Crystann (1987)(Softbook)(fr)[cr].dsk"} },
   {0x24de4278, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Casanova (Iber Soft) (Spain)/Casanova (1989)(Iber Soft)(es).dsk"} },
   {0x5342f9a5, {"0f3ce766494c244fb3e069ee60809d95"}, {"Ci-U-Than Trilogy II - Los Templos Sagrados (Aventuras AD) (Spain)/Ci-U-Than Trilogy II - Los Templos Sagrados (1991)(Aventuras AD)(es).dsk"} },
   {0x8828c438, {"79b4e7d38d45590c29279114aab3ffb3"}, {"Caves of Bewbews (Amstrad Adventure PD Library)/Caves of Bewbews (1990)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0x2669032b, {"ea0bc6516b926ea9dda963ce932c99ed"}, {"Camelot Warriors (Dinamic Software) (Spain)/Camelot Warriors (1986)(Dinamic Software)(es)[cr].dsk"} },
   {0xd415b403, {"62f24dcc51036e79f6ea543a6de791ba"}, {"Castle Master II - The Crypt (Incentive)/Castle Master II - The Crypt (1990)(Incentive)[tape].dsk"} },
   {0x82be3d6c, {"b3a01e1d7c60ee62f13d372236ec25f8"}, {"Crazy Brick (Ingo Bordach) (de)/Crazy Brick (1987)(Ingo Bordach)(de)[cr].dsk"} },
   {0x9e263bd7, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Combat School (Ocean Software)/Combat School (1987)(Ocean Software).dsk"} },
// {0x95724912, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Crafton & Xunk (ERE Informatique) (Spain)/Crafton & Xunk (1986)(ERE Informatique)(es).dsk"} },
   {0xf5330657, {"76c11c3ee9c0950ce1408c4a8828c81c"}, {"Codename Mat II (Domark)/Codename Mat II (1984)(Domark).dsk"} },
   {0x7bc607ba, {"b3a01e1d7c60ee62f13d372236ec25f8"}, {"Crazyfruit (Wendos PDS)/Crazyfruit (1998)(Wendos PDS)[cr].dsk"} },
   {0x353140d0, {"48428970454d07f5dc0243b6165f4dbd"}, {"Coloric (Free Game Blot) (France)/Coloric (1984)(Free Game Blot)(fr)[cr].dsk"} },
   {0x234bea84, {"cb35d6093af2d998df8c4c40405e4fd2"}, {"Critical Mass (Durell Software)/Critical Mass (1985)(Durell Software)[cr][f].dsk"} },
   {0x212f7414, {"c68076620e353d3feae594cc90a2f4ca"}, {"Cine Clap (Ubi Soft) (France)/Cine Clap (1986)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xe69a3242, {"fa420c38d04c8b292344ce8f5e456f3e"}, {"Cobra Force (Players Premier)/Cobra Force (1989)(Players Premier)[tape].dsk"} },
   {0x5d21b329, {"1553bebfdaeb735d179f150486a1e339"}, {"Cutthroats (Infocom)/Cutthroats (1984)(Infocom)[CPM].dsk"} },
   {0xc0cdbf41, {"916566f6b56256ede8d4fcce05486b34"}, {"Cosmic Shock Absorber (Martech)/Cosmic Shock Absorber (1987)(Martech).dsk"} },
   {0xcf430cd0, {"ffe8e90cfa56e88139367309199d859b"}, {"Cosmos (Amstar & CPC)/Cosmos (1989)(Amstar & CPC)[cr].dsk"} },
   {0x9403589a, {"193a4c741c51b1cfd41ee6d508a4d4af"}, {"Covenant, The (PSS)/Covenant, The (1985)(PSS)[cr].dsk"} },
   {0xd98ef21a, {"439372921adda3c654e664a1ba10114a"}, {"Crazy Snake (Fraggle and Duck)/Crazy Snake (1992)(Fraggle and Duck)(PD)[cr].dsk"} },
   {0x20d4b44a, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Cosmo (Infogrames) (France)/Cosmo (1986)(Infogrames)(fr)[cr].dsk"} },
   {0xb66fe575, {"04898f3f3ae81ea0e93809a8a36b6b99"}, {"Count Duckula 2 (Alternative Software)/Count Duckula 2 (1992)(Alternative Software)[cr].dsk"} },
   {0x8564c2d7, {"c68076620e353d3feae594cc90a2f4ca"}, {"Championship Sprint (Activision)/Championship Sprint (1988)(Activision).dsk"} },
   {0xefd57b7f, {"b3a01e1d7c60ee62f13d372236ec25f8"}, {"Crazy Cars (Titus)/Crazy Cars (1987)(Titus).dsk"} },
   {0xe698b5f6, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Classic Invaders (Bubble Bus Software)/Classic Invaders (1986)(Bubble Bus Software).dsk"} },
   {0x329ce832, {"8e0cf02bd5cbb2038e2dbd143396577b"}, {"Caves of Doom (Mastertronic)/Caves of Doom (1985)(Mastertronic)[tape].dsk"} },
   {0x13b3edcf, {"239bb41a08aed75a2a07ff37a934eda1"}, {"Carson City (Elice) (France)/Carson City (1986)(Elice)(fr)[cr].dsk"} },
   {0xac748c5b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Chase H.Q. (Ocean)/Chase H.Q. (1989)(Ocean).dsk"} },
   {0xead34ad9, {"fa420c38d04c8b292344ce8f5e456f3e"}, {"Cobra (Cobra Soft) (France)/Cobra (1985)(Cobra Soft)(fr)[tape].dsk"} },
   {0x471586fa, {"51c0c112e99db7d7f0ce510f7522069f"}, {"Comet Encounter (LiveWire Software)/Comet Encounter (1986)(LiveWire Software)[cr].dsk"} },
   {0x017234a5, {"41d0582f17b080fe2f810e83c9408bda"}, {"Crossfire (Atlantis Software)/Crossfire (1990)(Atlantis Software)[cr].dsk"} },
   {0x51bc68f5, {"c7c0bdd3b61393ae5eef743a42955a1a"}, {"Commonwealth Games (Tynesoft)/Commonwealth Games (1986)(Tynesoft)[cr].dsk"} },
   {0x80945c23, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Classic Adventure (Amsoft)/Classic Adventure (1984)(Amsoft)[cr].dsk"} },
   {0xd5bad0a4, {"549d2102794e3a154832309b4cfe0063"}, {"Crystal Theft (Wicca Soft)/Crystal Theft (1984)(Wicca Soft)[tape].dsk"} },
   {0xdc3c3cee, {"6da53fb58985a42520b910f3785c69a3"}, {"Coloriage - Les Petits Malins I (Carraz Editions) (France)/Coloriage - Les Petits Malins I (1988)(Carraz Editions)(fr)(Side A).dsk"} },
   {0x80f7d82e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Ci-U-Than Trilogy I - La Diosa de Cozumel (Aventuras AD) (Spain)/Ci-U-Than Trilogy I - La Diosa de Cozumel (1990)(Aventuras AD)(es).dsk"} },
   {0x26273e82, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cisco Heat (Image Works)/Cisco Heat (1991)(Image Works).dsk"} },
   {0x4a8fb3d4, {"a65c21f33f76b63e1be177723fb36a5e"}, {"Caverns of Mars (-)/Caverns of Mars (1985)(-)[cr].dsk"} },
   {0xe580e156, {"c12e4d041d90749e0ca655598a5a45e4"}, {"Castle Adventure Simulator (Rantanplan) (de)/Castle Adventure Simulator (1993)(Rantanplan)(PD)(de)[cr].dsk"} },
   {0xe69a8a8a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cauldron II (Palace Software) (France)/Cauldron II (1986)(Palace Software)(fr).dsk"} },
   {0x504d8d95, {"be8a54aa20504092baa7ced3b6e9118c"}, {"Cobra (Loriciels) (France)/Cobra (1987)(Loriciels)(fr).dsk"} },
   {0xf1ce4daf, {"a900244399fe66c64f405767496bcbaf"}, {"Cessna Over Moskow (Cobra Soft)/Cessna Over Moskow (1987)(Cobra Soft).dsk"} },
   {0x97ef2187, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Codename Mat (Amsoft)/Codename Mat (1984)(Amsoft).dsk"} },
   {0xfca8c1bc, {"02da161d3cb3f39fc8282dc9945654fe"}, {"Colossus 4 Bridge (CDS Software LTD)/Colossus 4 Bridge (1986)(CDS Software LTD)(Side A).dsk"} },
   {0xfe8f45a0, {"9eec72e424dab217514851f982c73336"}, {"Castle of the Skull Lord (Samurai)/Castle of the Skull Lord (1984)(Samurai)[cr].dsk"} },
   {0x398a4cb7, {"960b3610e3d876bf77ce25fd1e3afbb8"}, {"Cybor (Softhawk) (France)/Cybor (1987)(Softhawk)(fr).dsk"} },
   {0xf50b5634, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Chibi Akumas Episode 2 - Confrontation (Keith Sear)/Chibi Akumas Episode 2 - Confrontation (2017)(Keith Sear)(Disk 1 Side A).dsk"} },
   {0xf82670fa, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Chain Reaction (Elite Systems)/Chain Reaction (1988)(Elite Systems)(Side A).dsk"} },
   {0xc738216e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Cabal (Ocean Software) (Bugs)/Cabal (1989)(Ocean Software)[b].dsk"} },
   {0x67520d74, {"0f3ce766494c244fb3e069ee60809d95"}, {"Chessmaster 2000, The (Ubi Soft) (Spain)/Chessmaster 2000, The (1990)(Ubi Soft)(es).dsk"} },
   {0x94d17670, {"0f3ce766494c244fb3e069ee60809d95"}, {"Cybernoid (Hewson)/Cybernoid (1988)(Hewson).dsk"} },
   {0x9f07be43, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Cholo (Firebird)/Cholo (1986)(Firebird).dsk"} },
// {0x84e1c9fe, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Classic Axiens (Bubble Bus Software)/Classic Axiens (1988)(Bubble Bus Software).dsk"} },
   {0x3e4d2b70, {"fc91bb0a1b9230a307b77ecaff3036ad"}, {"Cubit (Amsoft)/Cubit (1984)(Amsoft)[tape].dsk"} },
   {0xaf529a6a, {"2ebe072e600612d50c61824ad554415f"}, {"Colossus Mahjong (CDS Software LTD)/Colossus Mahjong (1987)(CDS Software LTD)[CPM].dsk"} },
   {0x2bb7f2b9, {"0399054a53bbaa79ebb29bf0a66668d8"}, {"Crystal Castles (US Gold)/Crystal Castles (1986)(US Gold).dsk"} },
   {0x09718d06, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Chip's Challenge (US Gold)/Chip's Challenge (1990)(US Gold).dsk"} },
   {0xabceb000, {"fc91bb0a1b9230a307b77ecaff3036ad"}, {"Cubit (Amsoft) (de)/Cubit (1984)(Amsoft)(de)[tape].dsk"} },
   {0x0261b785, {"0f3ce766494c244fb3e069ee60809d95"}, {"Comando Tracer (Dinamic Software) (Spain)/Comando Tracer (1989)(Dinamic Software)(es).dsk"} },
   {0x7d6f78b7, {"546548923c135fa965812403d447650f"}, {"Country Cottages (Sterling Software)/Country Cottages (1984)(Sterling Software)[cr].dsk"} },
   {0xa44432b6, {"c5d418b5e85d9d39abb2fc912d806b37"}, {"Circus Games (Tynesort)/Circus Games (1989)(Tynesort)(Side A).dsk"} },
   {0xd3c89c04, {"c61dd0dcb4072b0f1c395421ab0b466e"}, {"Cylu (Firebird)/Cylu (1985)(Firebird)[cr].dsk"} },
   {0x7ce1ca31, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Crazy Shoot (Loriciels) (Phaser)/Crazy Shoot (1989)(Loriciels)(West Phaser).dsk"} },
   {0x6e5abb73, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cyberball (Domark)/Cyberball (1990)(Domark).dsk"} },
   {0x276db46d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Castle Master (Incentive) (Spain)/Castle Master (1990)(Incentive)(es).dsk"} },
   {0x8e07cbc5, {"92056f3392eb909b7dc0564b743a18fa"}, {"Classiques Titus Volume 1 (Titus) (France)/Classiques Titus Volume 1 (1987)(Titus)(fr).dsk"} },
   {0x1b3d0ddd, {"03d01d6911a9ab02d6f9254da640bebb"}, {"Cyberboy (Amstrad Action)/Cyberboy (1995)(Amstrad Action)[cr].dsk"} },
   {0xa89233ab, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Comando Quatro (Zigurat Software) (Spain)/Comando Quatro (1989)(Zigurat Software)(es).dsk"} },
   {0x5deb3022, {"0f3ce766494c244fb3e069ee60809d95"}, {"Cosmic Sheriff (Dinamic Software) (Spain) (LightGun)/Cosmic Sheriff (1989)(Dinamic Software)(es)(LightGun).dsk"} },
   {0xc7701343, {"6f941d504259a5fba1646d7636adc2aa"}, {"Cavemania (Atlantis Software)/Cavemania (1991)(Atlantis Software).dsk"} },
   {0xb52c665d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Cosa Nostra (Opera Soft) (Spain)/Cosa Nostra (1986)(Opera Soft)(es).dsk"} },
   {0x0961027f, {"ebe595696bdabde1a7b8f9098f57af84"}, {"Castle Assault (CDS Software LTD)/Castle Assault (1985)(CDS Software LTD)[tape].dsk"} },
   {0x3f81ef24, {"6b8048bdee485e001bd287fc3e58afb4"}, {"Colony (Mastertronic)/Colony (1987)(Mastertronic)[cr].dsk"} },
   {0x3cdbf0c6, {"4eb77cee99810ca4019a09e3bc60405a"}, {"Choy Lee Fut Kung-Fu Warrior (Positive) (Spain)/Choy Lee Fut Kung-Fu Warrior (1990)(Positive)(es).dsk"} },
   {0x4f93cf60, {"c950fd0765c32da670a28c431bfcb550"}, {"Cross Bomber (Caruso, Fabrizio)/Cross Bomber (2021)(Caruso, Fabrizio)(PD)[cr].dsk"} },
   {0xd15335c5, {"0f3ce766494c244fb3e069ee60809d95"}, {"Chubby Gristle (Grandslam)/Chubby Gristle (1988)(Grandslam).dsk"} },
   {0x7b2efe8b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Continental Circus (Virgin Games)/Continental Circus (1989)(Virgin Games).dsk"} },
   {0x8b330fc7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Croc' Madam' (Bug-Byte) (France)/Croc' Madam' (1986)(Bug-Byte)(fr).dsk"} },
   {0x3ac5dd74, {"6d2b43fe2d74c6728dc177e3dd2ca3f0"}, {"Chiller (Mastertronic)/Chiller (1986)(Mastertronic)[cr].dsk"} },
   {0xb431c920, {"0f3ce766494c244fb3e069ee60809d95"}, {"Carrier Command (Rainbird Software)/Carrier Command (1989)(Rainbird Software).dsk"} },
   {0xcd4b1856, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Centurions (Ariolasoft)/Centurions (1987)(Ariolasoft).dsk"} },
   {0x125d031b, {"6da53fb58985a42520b910f3785c69a3"}, {"Coloriage - Les Petits Malins II (Carraz Editions) (France)/Coloriage - Les Petits Malins II (1988)(Carraz Editions)(fr)(Side A).dsk"} },
   {0xc089f764, {"4f4d5cb27fa14840b02427efae6c81f7"}, {"Car Massacre (Tilt) (France)/Car Massacre (1986)(Tilt)(fr)[cr].dsk"} },
   {0x4e9436b2, {"c68076620e353d3feae594cc90a2f4ca"}, {"Championship Baseball (Activision)/Championship Baseball (1987)(Activision).dsk"} },
   {0x0823ac51, {"0f3ce766494c244fb3e069ee60809d95"}, {"Capitan Trueno (Dinamic Software) (Spain)/Capitan Trueno (1989)(Dinamic Software)(es).dsk"} },
   {0x1913117d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Carlos Sainz (Zigurat Software) (Spain)/Carlos Sainz (1990)(Zigurat Software)(es).dsk"} },
   {0x98f9c4e5, {"3b4253969f3a3a73f6a894926a98a0ae"}, {"Caecilia Metella (Sleepwalker PDS)/Caecilia Metella (1994)(Sleepwalker PDS)(PD)[cr].dsk"} },
// {0xe480fbec, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Cyrus II Schach (Amsoft) (de)/Cyrus II Schach (1985)(Amsoft)(de).dsk"} },
   {0xe00e41dd, {"474531fac64c84aa20625169d1ea5711"}, {"Captain Blood (Ere Informatique) (M5)/Captain Blood (1988)(Ere Informatique)(M5)[retail].dsk"} },
   {0x998fb414, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"California Games (US Gold)/California Games (1987)(US Gold)(Side A).dsk"} },
   {0xd832dd80, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Chevalier Blanc, Le (Cobra Soft) (France)/Chevalier Blanc, Le (1987)(Cobra Soft)(fr).dsk"} },
   {0x14e21aee, {"5d6c88595b777e68fc01d8971fc6e9ff"}, {"Computer Scrabble (Leisure Genius)/Computer Scrabble (1985)(Leisure Genius).dsk"} },
   {0x1aa02ae4, {"9ce5fcea97206a94cd82df16a9f611d1"}, {"Cricket-Crazy (The Dreaming Djinn)/Cricket-Crazy (1988)(The Dreaming Djinn)[cr].dsk"} },
   {0x816becd3, {"2d4af7c664698bdc1461a07225baf7e3"}, {"Coliseum (Amstar & Cpc)/Coliseum (1990)(Amstar & Cpc)[cr].dsk"} },
   {0x074ad861, {"70d5bb77c2aea6abe0b00cb84f651314"}, {"Cinco Iguales (Amstrad User Club) (Spain)/Cinco Iguales (1991)(Amstrad User Club)(es)[cr].dsk"} },
   {0x4f76cb64, {"b70c4effae0b430087bae512b6513956"}, {"Crack-Up (Atlantis Software)/Crack-Up (1989)(Atlantis Software)[tape].dsk"} },
// {0x0087cce8, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Chessmaster 2000, The (Ubi Soft)/Chessmaster 2000, The (1990)(Ubi Soft).dsk"} },
   {0xf4c4ad7b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Curro Jimenez (Zigurat) (Spain)/Curro Jimenez (1989)(Zigurat)(es).dsk"} },
   {0xcc83f97f, {"72cc258e6115a012f0e819f04f06e910"}, {"Clasic Tenis (Amstrad User Club)/Clasic Tenis (1989)(Amstrad User Club)[cr].dsk"} },
   {0x9512280f, {"a1b94abe8d5d0bd99cf83c2eeea6ffe2"}, {"Colossus Backgammon (CDS Software LTD)/Colossus Backgammon (1985)(CDS Software LTD)[cr].dsk"} },
   {0x49c1f6e0, {"b53f2a52dd215351517e50415b2d48e0"}, {"Cub Bert (Microbyte)/Cub Bert (1985)(Microbyte).dsk"} },
   {0x3fe4b8b2, {"34fdd9c33bfa16fa0061b9ff29740dbb"}, {"Cid, El (Dro Soft)/Cid, El (1988)(Dro Soft)[cr][f].dsk"} },
   {0xaaa35b34, {"0b7748f6bf99fe48cd9e6137bb6ab3ee"}, {"Chip Factory, The (Hewson)/Chip Factory, The (1984)(Hewson)[cr].dsk"} },
   {0x4dca3178, {"0f3ce766494c244fb3e069ee60809d95"}, {"Corsarios (Opera Soft)/Corsarios (1989)(Opera Soft).dsk"} },
   {0xead3004c, {"732bf8416ced6f5668c87a73f6dca69b"}, {"Corona Magica, La (OMK Software) (Spain)/Corona Magica, La (1990)(OMK Software)(es).dsk"} },
   {0x47207274, {"c7b1b1adc2e1ca0b4f6e9f4298a5cb32"}, {"Cross Chase (Caruso, Fabrizio)/Cross Chase (2018)(Caruso, Fabrizio)(PD)[cr].dsk"} },
   {0xbb0a782e, {"869d1059feac507704ec93e67553c115"}, {"Corridor Conflict (The Power House)/Corridor Conflict (1987)(The Power House)[tape].dsk"} },
   {0xd15c383d, {"8779b2817bb72ddea8247728b60423d0"}, {"Combat Zone Mentor (Alternative Software)/Combat Zone Mentor (1987)(Alternative Software)[cr].dsk"} },
   {0x8b65d51a, {"823f6002df2a325d8d6c26c71eccdfd7"}, {"Colosal Piramide (Definitive Software) (Spain)/Colosal Piramide (1994)(Definitive Software)(es)[cr].dsk"} },
   {0x3ef4d51a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Contraption (Audiogenic Software)/Contraption (1985)(Audiogenic Software).dsk"} },
   {0x9c78ae17, {"c7b5fe560598f80ca5b061c88d39a75d"}, {"Crystal Mission (Andreas Stroizcek) (M2)/Crystal Mission (1991)(Andreas Stroizcek)(PD)(M2)[cr].dsk"} },
   {0x8d5d68a2, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Computer Scrabble Deluxe (Leisure Genius)/Computer Scrabble Deluxe (1987)(Leisure Genius).dsk"} },
// {0x75e574cd, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Conspiration De L'An III (Ubi Soft) (France)/Conspiration De L'An III (1988)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xe83cdc69, {"cf525c13c659e194b072c5051bf42476"}, {"Clever & Smart (Magic Bytes) (M3)/Clever & Smart (1988)(Magic Bytes)(M3).dsk"} },
   {0x1f4e18a3, {"06f66da9127e2d43aec81008bc25abca"}, {"Centipods (Computing With The Amstrad)/Centipods (1987)(Computing With The Amstrad)[tape].dsk"} },
   {0x12354538, {"0cc24ef0e85282ea31976c4a829a6835"}, {"Chuckie Egg (A&F Software)/Chuckie Egg (1985)(A&F Software)[tape].dsk"} },
   {0xc80fc7c0, {"1186059c988bb1ab81030a0f80b8a6fe"}, {"Charly Diams (Loriciels) (France)/Charly Diams (1987)(Loriciels)(fr).dsk"} },
   {0x9a88a784, {"242e26007cbc214ef61689ffc99fb5b3"}, {"Coccinele, La (AM-Mag) (France)/Coccinele, La (1988)(AM-Mag)(fr)[cr].dsk"} },
   {0xc567eb8a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cobra (Ocean)/Cobra (1987)(Ocean).dsk"} },
   {0xeb42ce51, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cyberbig (MCM Software)/Cyberbig (1989)(MCM Software).dsk"} },
   {0xa961c9ba, {"b4d05a4b748c1bfde4f79b42c135dcc0"}, {"Con-Quest (Mastertronic)/Con-Quest (1986)(Mastertronic)[cr].dsk"} },
   {0x94903702, {"8e690e9d0f2deb641fea8aae8c23340d"}, {"Country Cottages (Sterling Software) (Spain) (Hack)/Country Cottages (1984)(Sterling Software)(es)(Hack)[cr].dsk"} },
   {0xeff6c7b7, {"f3a44de1787be14d935ef894c6793902"}, {"Catch 23 (Martech)/Catch 23 (1987)(Martech).dsk"} },
   {0x864c9951, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Custard Pie Factory (Tynesoft)/Custard Pie Factory (1985)(Tynesoft).dsk"} },
   {0x95140ead, {"02a3b6f8f3fde2644173cc70d962f967"}, {"Colour of Magic, The (Piranha)/Colour of Magic, The (1986)(Piranha)[cr].dsk"} },
   {0xe8e1c72a, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Captain America (Us Gold)/Captain America (1987)(Us Gold).dsk"} },
   {0xbe7e8c95, {"beeca7b577b138cc5ecab22013609cfa"}, {"Cross Shoot (Caruso, Fabrizio)/Cross Shoot (2020)(Caruso, Fabrizio)[cr].dsk"} },
   {0x1e7bc1c1, {"9ce5fcea97206a94cd82df16a9f611d1"}, {"Cricket Captain (Allanson Computing)/Cricket Captain (1985)(Allanson Computing)[tape].dsk"} },
   {0xce9c1fc3, {"98bc1d0aee5ba2994ce76ca6c7289c2d"}, {"Cerberus (Players)/Cerberus (1986)(Players)[tape].dsk"} },
   {0x4743863a, {"5556f9811a79533d3d325ba8ccde94fc"}, {"Chopper Squad (Interceptor Software)/Chopper Squad (1985)(Interceptor Software)[cr].dsk"} },
   {0xda2ca225, {"582a60741d9aa3882c14e465e2ba1c77"}, {"Ca Va Peter Zorglub (AM-Mag)/Ca Va Peter Zorglub (1988)(AM-Mag)[cr].dsk"} },
   {0x54d75c4a, {"55af51fa4888cd6276077be6314e8db8"}, {"Classic Trainer (GTI Software)/Classic Trainer (1989)(GTI Software)[cr].dsk"} },
   {0xd4dcd1ce, {"0956f783a52246a7187355fc4007fb34"}, {"Chimera (Firebird)/Chimera (1985)(Firebird)[tape].dsk"} },
   {0x39aae782, {"72ae57bb362fe78d2416ea1524c17d95"}, {"Cycit (Bug-Byte Software)/Cycit (1986)(Bug-Byte Software)(v2)[cr].dsk"} },
   {0xdad766c7, {"b238c7612de284f88f8f99f869fa940a"}, {"Cid, El (Dro Soft) (Spain)/Cid, El (1988)(Dro Soft)(es)[cr][f].dsk"} },
   {0x791eae64, {"508ed75d7829fbb93f78000a78575735"}, {"Commando (Elite Systems)/Commando (1985)(Elite Systems).dsk"} },
   {0x8b680531, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Cricket Master (E&J Software)/Cricket Master (1989)(E&J Software).dsk"} },
   {0x658adf06, {"049dc1fe1fe2e48a5ac1850df0713386"}, {"CPC Invaders (SIS Software)/CPC Invaders (1993)(SIS Software)(PD)[cr].dsk"} },
   {0xf80df676, {"256c405fc560a5f49166eab5a740ac98"}, {"Crazy Cars II (Titus)/Crazy Cars II (1989)(Titus)[cr][f].dsk"} },
// {0xbb2d6aff, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Clash (ERE Informatique) (France)/Clash (1987)(ERE Informatique)(fr)(Side A).dsk"} },
   {0x998ecf41, {"ce258c0c764d36a88fa6d903b03a2e8e"}, {"Colossus Chess 4 (CDS Software LTD)/Colossus Chess 4 (1986)(CDS Software LTD).dsk"} },
   {0x5c4fef97, {"dc3d50ec8fc32684e939b57e9c8f9d53"}, {"Coliseum (Topo Soft)/Coliseum (1988)(Topo Soft)[cr].dsk"} },
   {0xed5c028f, {"b0716d086f023cea4dadec95b1446558"}, {"Clever & Smart (Magic Bytes) (Spain)/Clever & Smart (1988)(Magic Bytes)(es).dsk"} },
   {0x9a3cbab6, {"ff7a0329739f63a3c6c021d0d8313d1c"}, {"Coliseum (Topo Soft) (Spain)/Coliseum (1988)(Topo Soft)(es)[cr].dsk"} },
   {0x58ba46c3, {"57aae21642983b1db50fa2678ab89115"}, {"Cluedo (Leisure Genius)/Cluedo (1985)(Leisure Genius).dsk"} },
   {0xac950a99, {"95bd10ed65126eced5673b9c52292368"}, {"Cubewars (Computing With The Amstrad)/Cubewars (1988)(Computing With The Amstrad)[cr].dsk"} },
   {0xcc4ce9a1, {"f89ef86026d20139c57418ca9e928e26"}, {"Country Cottages (Sterling Software) (de)/Country Cottages (1984)(Sterling Software)(de)[cr].dsk"} },
   {0xa2996d21, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cauldron (Palace Software) (France)/Cauldron (1985)(Palace Software)(fr).dsk"} },
   {0x32e80769, {"0b076f5733ea394635c803de5aa31659"}, {"Chicago 90 (Mircroids) (France)/Chicago 90 (1989)(Mircroids)(fr).dsk"} },
   {0xe1a074d8, {"6ee7b56a6a6b98d8dc1f354e48d79b50"}, {"Cap-Man (Hebdogiciel) (France)/Cap-Man (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0xd895249a, {"3b5ad8e7b4eafe276118d816d37f19a2"}, {"Countdown (Macsen Software)/Countdown (1987)(Macsen Software)[cr].dsk"} },
   {0x95272ba6, {"3f7dd1aabb6d128438e94f256a3b3bbd"}, {"Chiffres et des Lettres, Des (Loriciels) (France)/Chiffres et des Lettres, Des (1987)(Loriciels)(fr)(Side A)[Juin].dsk"} },
   {0x003f24cf, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Cauldron II (Palace Software)/Cauldron II (1986)(Palace Software).dsk"} },
   {0x6e991c26, {"0f3ce766494c244fb3e069ee60809d95"}, {"Classic Muncher (Bubble Bus Software)/Classic Muncher (1987)(Bubble Bus Software).dsk"} },
   {0x826c72a5, {"1c5fc72ca682633f198e8b7dc7b71059"}, {"Case of the Obscene Mural, The (Encief Routines)/Case of the Obscene Mural, The (1986)(Encief Routines)[cr].dsk"} },
   {0x0af3f96a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Cycles, The (Accolade)/Cycles, The (1989)(Accolade).dsk"} },
   {0xfd80301e, {"84892b02bf8a125f69c249e31af7be2f"}, {"Chinos, Los (Amstrad Users) (Spain)/Chinos, Los (1992)(Amstrad Users)(es)[cr].dsk"} },
   {0x03b5ab32, {"0ed06420db3336cb54d4966ba3c13661"}, {"Commando - Space Invasion (Elite Systems)/Commando - Space Invasion (1985)(Elite Systems)[cr].dsk"} },
   {0xa64dc6a3, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Crucial Test (Coktel Vision) (France)/Crucial Test (1988)(Coktel Vision)(fr)(Side A)(Q1).dsk"} },
   {0x11864f72, {"9aae6ed688f7e969cb762f8a3cf90731"}, {"Can I Cheat the Death (Amstrad Adventure PD Library)/Can I Cheat the Death (1990)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0x608ea715, {"b3a01e1d7c60ee62f13d372236ec25f8"}, {"Crazy Golf (Amsoft)/Crazy Golf (1984)(Amsoft)[tape].dsk"} },
   {0xe010f7d4, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Chicago 30's (Topo Soft)/Chicago 30's (1988)(Topo Soft).dsk"} },
   {0x4c2f8cdf, {"9df450d60830b97dba371f1cc579d206"}, {"Chicago 30's (Topo Soft) (Spain)/Chicago 30's (1988)(Topo Soft)(es)[cr][f].dsk"} },
   {0x1b6c09ae, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Captain Planet (Mindscape)/Captain Planet (1990)(Mindscape).dsk"} },
   {0x92ce11b2, {"92056f3392eb909b7dc0564b743a18fa"}, {"Corruption (Rainbird Software)/Corruption (1988)(Rainbird Software)(Side A).dsk"} },
   {0x647bb62f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"City Slicker (Hewson)/City Slicker (1986)(Hewson).dsk"} },
   {0x84396a9a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Crazy Cars 3 (1992)/Crazy Cars 3 (UK) (1992) [Original].dsk"} },
   {0x7177bf58, {"79c4e373ba3e2e9de4c47c4c37aa644f"}, {"Cross Snake (Caruso, Fabrizio)/Cross Snake (2020)(Caruso, Fabrizio)(PD)[cr].dsk"} },
   {0xc48fc661, {"1d5f0b168def1847e333a58d2f294d46"}, {"Chronos (Mastertronic)/Chronos (1987)(Mastertronic)[cr].dsk"} },
   {0xd0f4fc5f, {"732bf8416ced6f5668c87a73f6dca69b"}, {"Corona, La (System 4) (Spain)/Corona, La (1988)(System 4)(es)[cr].dsk"} },
   {0xae25ee36, {"4ab81e613e16cfa3ed4577b6a4e09e57"}, {"Campeonato Del Mundo Boxing Manager (Goliath Games) (Spain)/Campeonato Del Mundo Boxing Manager (1991)(Goliath Games)(es).dsk"} },
   {0x651eaa76, {"8f7d9350dea507f7d2a7b52df6596128"}, {"Castle Blackstar (CDS Software LTD)/Castle Blackstar (1984)(CDS Software LTD)[cr].dsk"} },
   {0x2c70c790, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Cybernoid II (Hewson)/Cybernoid II (1988)(Hewson).dsk"} },
   {0xc8a5ef6a, {"1aaf9f3a9eace6e0a2dc3d12dd70beb8"}, {"Cauldron II (Palace Software) (Spain)/Cauldron II (1986)(Palace Software)(es)[cr].dsk"} },
   {0xed61051f, {"8f4c2e15beed52e758cf3f7cfb440114"}, {"Confuzion (Incentive)/Confuzion (1985)(Incentive)[cr].dsk"} },
   {0xe418e803, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ci-U-Than Trilogy III - Chichen Itza (Aventuras AD) (Spain) (Bugs)/Ci-U-Than Trilogy III - Chichen Itza (1992)(Aventuras AD)(es)[b].dsk"} },
   {0xcb1fb4a2, {"a61ead1df423f682653dd0a3488d02de"}, {"Cubemeleon (CPC) (France)/Cubemeleon (1986)(CPC)(fr)(v3)[cr].dsk"} },
   {0x76cd8f28, {"71f7f7765e9b82e5193a5f509a175675"}, {"Crash Garrett (ERE Informatique) (France)/Crash Garrett (1987)(ERE Informatique)(fr)(Side A).dsk"} },
// {0x859433b0, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Cyrus II (Amsoft) (France)/Cyrus II (1985)(Amsoft)(fr).dsk"} },
   {0xd356f77a, {"b3a01e1d7c60ee62f13d372236ec25f8"}, {"Crazy Stamps (D. Mueller) (de)/Crazy Stamps (1986)(D. Mueller)(PD)(de)[cr].dsk"} },
   {0x74d37183, {"51c0c112e99db7d7f0ce510f7522069f"}, {"Comet Game, The (Firebird)/Comet Game, The (1986)(Firebird)[tape].dsk"} },
   {0x57eb7d63, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Crepuscule du Naja, Le (Chip) (France)/Crepuscule du Naja, Le (1987)(Chip)(fr).dsk"} },
   {0xa8a343c0, {"bfe0e941d0abe33b2e3588f046d9011e"}, {"Challenge of the Gobots (Ariolasoft)/Challenge of the Gobots (1987)(Ariolasoft).dsk"} },
   {0xa998c6ae, {"0f3ce766494c244fb3e069ee60809d95"}, {"Convoy Raider (Gremlin Graphics Software)/Convoy Raider (1987)(Gremlin Graphics Software).dsk"} },
   {0x5be24f37, {"c9e7555fe038af4b7a2df97aa4287610"}, {"Cobras Arc (Dinamic Software) (Spain)/Cobras Arc (1986)(Dinamic Software)(es)[cr][f].dsk"} },
   {0xea34c2da, {"4830b1a413cf957c283b7d853bf4b5b8"}, {"Death's Ticket (Micro Mag)/Death's Ticket (1990)(Micro Mag)[cr].dsk"} },
   {0xff9382c9, {"bb4dce69c392d163980c9e8479668d50"}, {"Dark Power (Micro Mag)/Dark Power (1989)(Micro Mag)[cr].dsk"} },
// {0x3bd70a17, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Despotik Design (ERE Informatique) (M3)/Despotik Design (1987)(ERE Informatique)(M3).dsk"} },
   {0x627d56c5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dossier G (Cobra Soft) (France)/Dossier G (1985)(Cobra Soft)(fr).dsk"} },
   {0x3a35ea93, {"d1588ea0d653e9d35ba32c482c26c61d"}, {"Dervish (The Power House)/Dervish (1989)(The Power House)[tape].dsk"} },
   {0x4ef6890a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Defcom 1 (Iber Soft) (Spain)/Defcom 1 (1989)(Iber Soft)(es).dsk"} },
   {0xd1e4eade, {"177da66b29823b7769d33528bdcc432d"}, {"Doppleganger (Alligata Software)/Doppleganger (1985)(Alligata Software)[tape].dsk"} },
// {0xebf36ee7, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Dan Silver (MBC Informatique) (France)/Dan Silver (1989)(MBC Informatique)(fr)(Side A)[cr].dsk"} },
   {0x4ac6467e, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Danger Street (Chip) (France)/Danger Street (1987)(Chip)(fr).dsk"} },
   {0x8b845864, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Defenders of the Earth (Enigma Variations)/Defenders of the Earth (1990)(Enigma Variations)(en-fr).dsk"} },
   {0x6b5b7e05, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Drakkar (Delta Software) (Spain)/Drakkar (1989)(Delta Software)(es).dsk"} },
   {0xd60d7d79, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Darkman (Ocean)/Darkman (1991)(Ocean)(Side A).dsk"} },
   {0xaa0cf74a, {"e779334af3c14788ccb25df55682c04d"}, {"Defender (Amstrad Video-Play) (Spain)/Defender (1987)(Amstrad Video-Play)(es)[cr].dsk"} },
   {0x1b671eb0, {"a27e30c4055ff6d2bf5844a9f754879c"}, {"Dash (Happy Computer)/Dash (1986)(Happy Computer)[cr].dsk"} },
   {0xc519182d, {"e51740f8767a386de2ddce8f35b5224b"}, {"Dragons of Flame (US Gold)/Dragons of Flame (1990)(US Gold)(Side A).dsk"} },
   {0x0b1fc7cc, {"3107893823a54cac60c86ca58c2e211a"}, {"Danger Mouse in Double Trouble (Creative Sparks)/Danger Mouse in Double Trouble (1985)(Creative Sparks)[tape].dsk"} },
   {0x5e19a278, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Dream Warrior (US Gold)/Dream Warrior (1988)(US Gold).dsk"} },
   {0x53ff9b48, {"c4d678b128ec4611b79fea4debb76bd3"}, {"Dernier Metro, Le (Micro Programmes 5) (France)/Dernier Metro, Le (1985)(Micro Programmes 5)(fr)[tape].dsk"} },
   {0xc29233ec, {"eb6210f4cd1fc56222c93ee9b0ace12b"}, {"D.C.A. (CPC Infos)/D.C.A. (1991)(CPC Infos)[cr].dsk"} },
   {0x76f1d396, {"63bf1e910b5f2e33aaa4fcc3168212f5"}, {"Devilry 2 (Eric Cubizolle - Emmanuel Rigot) (France)/Devilry 2 (1989)(Eric Cubizolle - Emmanuel Rigot)(fr)(Side A).dsk"} },
   {0xf30f6809, {"8872ba91af2071a108b3281ffb58af77"}, {"Digger Barnes (Cable Software)/Digger Barnes (1985)(Cable Software)[cr].dsk"} },
   {0x09b7c1f2, {"60cee405dfc2beb25380bdde999ff424"}, {"Donkey Kong (Ocean Software)/Donkey Kong (1986)(Ocean Software)[BASIC 1.0].dsk"} },
   {0xe9bc89c8, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Desperado 2 (Topo Soft) (Spain)/Desperado 2 (1989)(Topo Soft)(es).dsk"} },
   {0x9b69dabd, {"979fb5c93d4e9ad16bca06a5e22fb778"}, {"Demon Attack (Rakoko)/Demon Attack (1986)(Rakoko)[cr].dsk"} },
// {0xfce191c0, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Doomsday Blues (ERE Informatique)/Doomsday Blues (1985)(ERE Informatique).dsk"} },
   {0x60e4e33c, {"558c6813f700d9b38900ab1597fd2376"}, {"Darts (Alligata Software)/Darts (1986)(Alligata Software)[cr].dsk"} },
   {0x245d5514, {"ed729b84edf664a5589f57b0ccc891fe"}, {"Dive-Dive-Dive (Tynesoft)/Dive-Dive-Dive (1987)(Tynesoft)[cr].dsk"} },
   {0x63d1f9fe, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dynamite Dan II (Mirrorsoft)/Dynamite Dan II (1986)(Mirrorsoft).dsk"} },
   {0x4019916e, {"57cfe3bf4476288ff839dee4ae7ac0eb"}, {"Detective (Amsoft)/Detective (1984)(Amsoft)[tape].dsk"} },
   {0xb4723a22, {"c4f50994fa5b6788191826bd670f2134"}, {"Drigus und Drolan (Bollaware) (de)/Drigus und Drolan (1989)(Bollaware)(PD)(de)[cr].dsk"} },
   {0x463cc950, {"368dc2a40a5e3e4c48183dc69fec35d3"}, {"Dawnssley (Top Ten)/Dawnssley (1987)(Top Ten)[tape].dsk"} },
   {0xa20e81d5, {"c68f6bd798184376675f034c42378d92"}, {"Deep Strike (Durell Software)/Deep Strike (1986)(Durell Software)[cr].dsk"} },
// {0x1135fab1, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Druid (Firebird)/Druid (1986)(Firebird).dsk"} },
   {0x098afd20, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Double Dragon (Virgin Mastertronic)/Double Dragon (1988)(Virgin Mastertronic).dsk"} },
   {0x1ce66ea0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Daley Thompson's Supertest (Ocean)/Daley Thompson's Supertest (1985)(Ocean).dsk"} },
   {0x4b67f27a, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Defi au Tarot (Run Informatique) (France)/Defi au Tarot (1986)(Run Informatique)(fr).dsk"} },
   {0xb0dd3611, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Deathsville (Bubblebus Software)/Deathsville (1986)(Bubblebus Software).dsk"} },
   {0x79d46a26, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Dominator (Electric Dreams Software)/Dominator (1989)(Electric Dreams Software).dsk"} },
   {0x5a707d86, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dragon's Lair (Software Projects)/Dragon's Lair (1985)(Software Projects).dsk"} },
   {0xc147e40e, {"e779334af3c14788ccb25df55682c04d"}, {"Defend or Die (Alligata Software)/Defend or Die (1985)(Alligata Software)[tape].dsk"} },
   {0x0b20dfe5, {"c144997942bde8447b304573d9059ae1"}, {"Dogsbody to the Rescue (Bug-Byte Software)/Dogsbody to the Rescue (1985)(Bug-Byte Software)[tape].dsk"} },
   {0xcb00cc73, {"8b44659514c478e2486d796ed5e13597"}, {"Desperado (Topo Soft)/Desperado (1987)(Topo Soft)(Side A)[cr][f].dsk"} },
   {0x819a0d81, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Domino (Idealogic) (Spain)/Domino (1985)(Idealogic)(es)[tape].dsk"} },
   {0x0f1fcc82, {"9af113f95bc1d4d51257465dd60156ea"}, {"Druids Moon (Top Ten)/Druids Moon (1987)(Top Ten)[cr].dsk"} },
   {0xc00be31a, {"c2daca6b85c8116bcf079155dcf4afb8"}, {"Diamant de l'Ile Maudite, Le (Loriciels) (France)/Diamant de l'Ile Maudite, Le (1985)(Loriciels)(fr)(Side A).dsk"} },
   {0xa0388928, {"565d8b838dca4705b9ee132990fb4f72"}, {"Daleks (Amstrad Action)/Daleks (1989)(Amstrad Action)[tape].dsk"} },
   {0x6a441867, {"822e03974bc3e5d609259c21012bf5ef"}, {"Dwarf (Soft Hawk) (France)/Dwarf (1987)(Soft Hawk)(fr).dsk"} },
   {0xc2df6ea0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Dan Dare III - The Escape (Virgin Games)/Dan Dare III - The Escape (1990)(Virgin Games).dsk"} },
   {0x58f33108, {"b333b223226f869cfcbc45b89f3c7ef1"}, {"Doctor Who and the Mines of Terror (Micro Power)/Doctor Who and the Mines of Terror (1986)(Micro Power).dsk"} },
   {0x76fd75b1, {"61ef621d3967566abf05429f65825834"}, {"Donald & Riri (Bahia Informatique) (France)/Donald & Riri (1985)(Bahia Informatique)(fr).dsk"} },
   {0xd2fe8234, {"c68076620e353d3feae594cc90a2f4ca"}, {"Dandy (Activision)/Dandy (1987)(Activision).dsk"} },
   {0x5956333b, {"df9db7ef68db4e661c6850af8cd4f57c"}, {"Demineur (GPA)/Demineur (1993)(GPA)[cr].dsk"} },
// {0xb2f8a240, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Dakar Moto (Coktel Vision) (France)/Dakar Moto (1987)(Coktel Vision)(fr).dsk"} },
   {0x550ac9f9, {"f310b7a04f66817d8a6e17643bc50d59"}, {"Dynamite Dan (Mirrorsoft)/Dynamite Dan (1985)(Mirrorsoft)[tape].dsk"} },
   {0x02c5b434, {"8a1e2423192154620f6bf927c7c1d4de"}, {"Donde Esta Carmen Sandiego (Broderbund Software) (Spain) (Codes)/Donde Esta Carmen Sandiego (1990)(Broderbund Software)(es)(Side A)[codes].dsk"} },
   {0x2f36c5cd, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dynamic Duo (Firebird)/Dynamic Duo (1989)(Firebird).dsk"} },
   {0x5c0016ec, {"0050cfa19123c496cf974e3e32f8b545"}, {"Dungeons, Amethysts, Alchemists (Atlantis Software)/Dungeons, Amethysts, Alchemists (1987)(Atlantis Software)[tape].dsk"} },
   {0x2faa32d2, {"70cefd3e3f3067824221bac5469cda92"}, {"Dr. Dustbin (PC Schneider International) (de)/Dr. Dustbin (1988)(PC Schneider International)(de)[cr].dsk"} },
   {0xb4fe5896, {"7a51af437d81744db0836384ec8af166"}, {"Dustin (Dinamic Software) (Spain)/Dustin (1986)(Dinamic Software)(es)[tape].dsk"} },
   {0x81115ea3, {"03891c47cbbbd2e7c5e45a253ebdcccb"}, {"Duck Dodgers (Amstrad Computer User)/Duck Dodgers (1985)(Amstrad Computer User)[cr].dsk"} },
   {0xfe44dc2a, {"de19995d19f56c1755f0ba563a31d3d0"}, {"Danger Adventurer at Work Two (WoW Software)/Danger Adventurer at Work Two (1991)(WoW Software)[tape].dsk"} },
   {0xae1d8116, {"ae24b4863a438e615032e5eab52b0b06"}, {"Daley Thompson's Decathlon (Ocean)/Daley Thompson's Decathlon (1985)(Ocean)[tape].dsk"} },
   {0x0662dcbe, {"a9328fa25685d2665bc6f4df6ce94e4f"}, {"Desert Fox (US Gold)/Desert Fox (1986)(US Gold).dsk"} },
   {0xb0481e4e, {"8dc848b0c31a737fea4a147f23946293"}, {"Dark Star (Design Design)/Dark Star (1985)(Design Design)[tape].dsk"} },
   {0x656ec48f, {"cb331a0a0457e0cf4679f8fe345d8acd"}, {"Dianne (Loriciels) (France)/Dianne (1985)(Loriciels)(fr)[tape].dsk"} },
   {0x65f1ce24, {"0f3ce766494c244fb3e069ee60809d95"}, {"Dan Dare - Pilot of the Future (Virgin Games)/Dan Dare - Pilot of the Future (1986)(Virgin Games).dsk"} },
   {0x39a97e44, {"42d40b484eeb8cc27c81784fdd6f7162"}, {"Dodgy Geezers (Melbourne House)/Dodgy Geezers (1986)(Melbourne House)[D7][cr].dsk"} },
   {0xb1ca3b57, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dames 3D Champion (Cobra Soft) (France)/Dames 3D Champion (1987)(Cobra Soft)(fr).dsk"} },
   {0xc04b912b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Dan Dare II - Mekon's Revenge (Virgin Games) (Bugs)/Dan Dare II - Mekon's Revenge (1988)(Virgin Games)[b].dsk"} },
   {0x68f975d7, {"6762a2db74f072f747be68bdec1fdbc9"}, {"Duet - Commando '86 (Elite Systems)/Duet - Commando '86 (1987)(Elite Systems)[cr].dsk"} },
// {0xa82993c8, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Duel 2000 (Coktel Vision) (France)/Duel 2000 (1986)(Coktel Vision)(fr).dsk"} },
   {0xf807ae09, {"b06e1cc421118d6df39401e7872b9edb"}, {"Defcom (Quicksilva)/Defcom (1986)(Quicksilva)[cr].dsk"} },
   {0x7aa486cc, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Death or Glory (CRL Group)/Death or Glory (1987)(CRL Group).dsk"} },
   {0x2037a297, {"a671e74a7d02c5c856269d581ef108f6"}, {"Dr. Scrimes Spook School (Mastertronic)/Dr. Scrimes Spook School (1988)(Mastertronic)[tape].dsk"} },
   {0x8c5e3ea2, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Dragon Ninja (Ocean Software)/Dragon Ninja (1988)(Ocean Software).dsk"} },
   {0xaed90545, {"0f3ce766494c244fb3e069ee60809d95"}, {"Double Dragon III - The Rosetta Stone (Storm Software)/Double Dragon III - The Rosetta Stone (1991)(Storm Software)(Side A).dsk"} },
   {0x8b63fc86, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Devil's Castle (Chip) (France)/Devil's Castle (1986)(Chip)(fr).dsk"} },
   {0x8d4a1ab8, {"4934bf4011eed65a58cb88632ed93a5f"}, {"Dominoes (Blue Ribbon Software)/Dominoes (1987)(Blue Ribbon Software)[tape].dsk"} },
   {0xdc891be2, {"3bd2a961cb7fabacb341785d2d6ae813"}, {"Dizzy VII - Crystal Kingdom Dizzy (Codemasters Software)/Dizzy VII - Crystal Kingdom Dizzy (1992)(Codemasters Software)[cr].dsk"} },
   {0xc53e8be1, {"0f3ce766494c244fb3e069ee60809d95"}, {"Dragon Spirit (Domark)/Dragon Spirit (1989)(Domark)(Side A).dsk"} },
   {0x98021e34, {"7d930748499b7a585d7e39a2941d4dcf"}, {"Donald's Alphabet Chase (Disney) (M5) (Codes)/Donald's Alphabet Chase (1988)(Disney)(M5)(Side A)[codes].dsk"} },
   {0x694032c2, {"1e44e0ad45b48e739aa351c946565daa"}, {"Diamond Trap (Computing With The Amstrad)/Diamond Trap (1987)(Computing With The Amstrad)[cr].dsk"} },
   {0x2e044103, {"287abff8c052f3afd0fc18ed1e9b115c"}, {"Dr. Jackle and Mr. Wide (Bulldog)/Dr. Jackle and Mr. Wide (1987)(Bulldog)[tape].dsk"} },
   {0x3c89466f, {"89b24fdb33e3d969ccb06afcd2814afa"}, {"Diamond Mine (CDS Software LTD)/Diamond Mine (1986)(CDS Software LTD)[tape].dsk"} },
   {0x1461c372, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Dame Scanner (Chip) (France)/Dame Scanner (1988)(Chip)(fr).dsk"} },
   {0x993bb9bd, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Deep, The (US Gold)/Deep, The (1989)(US Gold).dsk"} },
   {0x2b1b70da, {"0f3ce766494c244fb3e069ee60809d95"}, {"Dieux de la Mer - Championship Water Skiing (Infogrames) (France)/Dieux de la Mer - Championship Water Skiing (1987)(Infogrames)(fr).dsk"} },
   {0x7710bc30, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Double Dragon (Dro Soft) (Spain)/Double Dragon (1988)(Dro Soft)(es).dsk"} },
   {0x3f0806cb, {"fd3a7b759c8f7ec86f5b9a807705791b"}, {"Death Pit (Durell Software)/Death Pit (1984)(Durell Software)[cr].dsk"} },
   {0xf0970e2c, {"0f3ce766494c244fb3e069ee60809d95"}, {"Dark Sceptre (Firebird Software)/Dark Sceptre (1987)(Firebird Software)[f].dsk"} },
   {0x4d4620dc, {"73eb5aa7f665824454713c2e451b658f"}, {"Deadline (Infocom)/Deadline (1982)(Infocom)[CPM].dsk"} },
   {0xc2c59a45, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dragon World (4-Mation Educational Resources)/Dragon World (1989)(4-Mation Educational Resources)(Side A)[cr].dsk"} },
   {0xc9714dda, {"13f76c85985da0e1cb2bef575a2b9f65"}, {"Don't Panic (Firebird Software)/Don't Panic (1985)(Firebird Software)[tape].dsk"} },
   {0x6b6b4872, {"145565c2dfac73dc4cca8ed9ba6cb7a9"}, {"Dripzone (Potplant Productions)/Dripzone (1987)(Potplant Productions)[cr].dsk"} },
   {0x7bb8b2c5, {"656d45d89a9f3ce5790a03338eb68536"}, {"Dora (Acocsoft)/Dora (1988)(Acocsoft)(el)[cr].dsk"} },
   {0x791127ee, {"5d9a22fd95991ca78fb1413c61c50740"}, {"Dracula (CRL Group)/Dracula (1986)(CRL Group).dsk"} },
   {0x596a99e0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Dark Side (Incentive Software)/Dark Side (1988)(Incentive Software).dsk"} },
   {0x7a816ade, {"02bd2180411ac29c188fd0ceeab93f1a"}, {"Dead or Alive (Alternative Software)/Dead or Alive (1987)(Alternative Software)[tape].dsk"} },
   {0x9b38a47e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Double Dragon II - The Revenge (Dro Soft) (Spain)/Double Dragon II - The Revenge (1989)(Dro Soft)(es).dsk"} },
   {0x5f3afbed, {"0f3ce766494c244fb3e069ee60809d95"}, {"Death Wish 3 (Gremlin Graphics Software)/Death Wish 3 (1987)(Gremlin Graphics Software).dsk"} },
   {0x1d1e61db, {"0f3ce766494c244fb3e069ee60809d95"}, {"Dark Fusion (Gremlin Graphics Software)/Dark Fusion (1988)(Gremlin Graphics Software).dsk"} },
   {0x0e1170a6, {"1ad1378c2d7e5f587e5d550d71557532"}, {"Devil's Crown, The (Probe Software)/Devil's Crown, The (1985)(Probe Software).dsk"} },
// {0xeb8ab156, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Daley Thompson's Olympic Challenge (Ocean)/Daley Thompson's Olympic Challenge (1988)(Ocean).dsk"} },
// {0x66e32c4c, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Disc (Loriciels)/Disc (1990)(Loriciels).dsk"} },
   {0x3b58b3e6, {"78945c702eb4302c634c02f5f286d110"}, {"D Day (Loriciels) (France)/D Day (1992)(Loriciels)(fr)[cr].dsk"} },
   {0x7182f979, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Dynasty Wars (US Gold)/Dynasty Wars (1990)(US Gold).dsk"} },
   {0x98fcd2a5, {"324afd2cc74332f9284a7e9f81ce1ade"}, {"Danger Mouse in Making Whoopee! (Creative Sparks)/Danger Mouse in Making Whoopee! (1985)(Creative Sparks)[tape].dsk"} },
   {0xd6e9e35b, {"8b46267329ea04c6c501e2d06de9dabc"}, {"Dragontorc (Hewson)/Dragontorc (1985)(Hewson)[tape].dsk"} },
   {0xd9dc8f56, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Dragon Breed (Activision)/Dragon Breed (1989)(Activision).dsk"} },
   {0x5e98fe2a, {"8bf70735e7943fd16103cad99d133f5f"}, {"Danger Adventurer at Work (WoW Software)/Danger Adventurer at Work (1991)(WoW Software)[tape].dsk"} },
   {0x2e5eefce, {"53143945b8c61b00bccaf70468dc458f"}, {"Doomlords (Wow Software)/Doomlords (1988)(Wow Software)[cr].dsk"} },
   {0xa3bc8bfe, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Dom Camillo (Free Game Blot) (France)/Dom Camillo (1987)(Free Game Blot)(fr)[cr].dsk"} },
   {0x4065e278, {"bb7c5ea3d9074309b82df0242687e0a0"}, {"Dizzy VI - Prince of the Yolkfolk (Codemasters Software)/Dizzy VI - Prince of the Yolkfolk (1991)(Codemasters Software)[cr].dsk"} },
// {0xbe2eb246, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Dark Century (Titus)/Dark Century (1990)(Titus).dsk"} },
   {0x3105977f, {"a4f3c54559f4ec90f50807da6b1ae63e"}, {"Devil Highway (Infomedia)/Devil Highway (1987)(Infomedia)[cr].dsk"} },
   {0x06e534dc, {"1b1ed763040c27fd075192b13fb114fd"}, {"Dragon's Lair II - Escape from Singe's Castle (Software Projects)/Dragon's Lair II - Escape from Singe's Castle (1987)(Software Projects).dsk"} },
   {0xcceea209, {"2389ac6f71160d405e2f46f91de0d1ef"}, {"Don Quijote (Dinamic Software) (Spain)/Don Quijote (1987)(Dinamic Software)(es).dsk"} },
// {0x9bed1bbf, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Detective (News by Disc) (France)/Detective (1990)(News by Disc)(fr)[cr].dsk"} },
   {0xfd300f5f, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Dogfight 2187 (Starlight Software)/Dogfight 2187 (1987)(Starlight Software).dsk"} },
   {0xc67212be, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Double Dragon II - The Revenge (Virgin Mastertronic)/Double Dragon II - The Revenge (1989)(Virgin Mastertronic).dsk"} },
   {0xd50d3b34, {"4700fa71b56a05c879a4b280e77a66f7"}, {"Deadly Evil (Players Premier Software)/Deadly Evil (1990)(Players Premier Software)(v2)[cr].dsk"} },
   {0xe041b78b, {"f8dee6777f15b3affe82bfc13db61d52"}, {"Dam Busters, The (US Gold)/Dam Busters, The (1986)(US Gold).dsk"} },
   {0xb9d58e05, {"0f3ce766494c244fb3e069ee60809d95"}, {"Dynamite Dux (Activision)/Dynamite Dux (1989)(Activision)(Side A).dsk"} },
   {0x61a1bea2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Deflektor (Gremlin Graphics Software)/Deflektor (1987)(Gremlin Graphics Software).dsk"} },
   {0x2d114ead, {"124ad6eabbc4dd7a41f15ddf6bce9d7e"}, {"Duct, The (Gremlin Graphics Software)/Duct, The (1988)(Gremlin Graphics Software)[tape].dsk"} },
   {0x3d624316, {"4be4a0e94409fe2df159d48e2e314bdb"}, {"Doomsdark's Revenge (Beyond Software)/Doomsdark's Revenge (1985)(Beyond Software)[tape].dsk"} },
   {0x73cff695, {"21f971595eb05b35d3234e06266f896a"}, {"Driller (Incentive Software)/Driller (1987)(Incentive Software)[cr].dsk"} },
   {0x260957b5, {"4a62f323a0c6d14db24e6867f1bd869d"}, {"Doodle Bug (Players Software)/Doodle Bug (1987)(Players Software)[cr].dsk"} },
   {0x24a54215, {"c68076620e353d3feae594cc90a2f4ca"}, {"Driller (Incentive Software) (Codes)/Driller (1987)(Incentive Software)[codes].dsk"} },
   {0x3443ac53, {"8e0cf02bd5cbb2038e2dbd143396577b"}, {"Dr. Doom's Revenge (Empire Software) (M4) (Codes)/Dr. Doom's Revenge (1989)(Empire Software)(M4)(Side A)[codes].dsk"} },
   {0x8ccfb58e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Dun Darach (Gargoyle Games)/Dun Darach (1985)(Gargoyle Games).dsk"} },
   {0xe9bd1055, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Dizzy II - Treasure Island Dizzy (1989)/Dizzy II - Treasure Island Dizzy (UK) (1989) [Original].dsk"} },
   {0xabab1a11, {"ee66a51ebd661ebe1185edb12e63a077"}, {"Dakar 4x4 (Coktel Vision) (France)/Dakar 4x4 (1987)(Coktel Vision)(fr)[cr].dsk"} },
// {0x6b36fb72, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Derniere Mission, La (MBC Informatique) (France)/Derniere Mission, La (1988)(MBC Informatique)(fr)(Side A).dsk"} },
   {0xa9e39d27, {"1317972e2cb00d58628edff268f9495b"}, {"Dynamix (Virgin Games)/Dynamix (1989)(Virgin Games)[tape].dsk"} },
   {0x13e32ec7, {"bb4dce69c392d163980c9e8479668d50"}, {"Darkwurlde (Top Ten)/Darkwurlde (1986)(Top Ten)[tape].dsk"} },
   {0xc9121001, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Dizzy - The Ultimate Cartoon Adventure (1988) (Bugs)/Dizzy - The Ultimate Cartoon Adventure (UK) (1988) [Original][b].dsk"} },
   {0x5bc860de, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Deactivators (Ariolasoft)/Deactivators (1986)(Ariolasoft).dsk"} },
// {0xb857f5ca, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Defender of the Crown (Cinemaware) (France)/Defender of the Crown (1987)(Cinemaware)(fr)(Side A).dsk"} },
   {0x8ab1f797, {"bcdf68469adaae28aed5a5f585d10398"}, {"Dick Tracy (Titus)/Dick Tracy (1990)(Titus).dsk"} },
   {0x2fa0073a, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Desolator (US Gold)/Desolator (1986)(US Gold).dsk"} },
   {0xed93f172, {"8314a45c075f0570cfe907e49dd98583"}, {"Dan Dare II - Mekon's Revenge (Virgin Games)/Dan Dare II - Mekon's Revenge (1988)(Virgin Games)[cr][f].dsk"} },
   {0x92a90631, {"a91e34aeb9acf97a1c750792aaa3fc16"}, {"Dragon's Gold (Amsoft)/Dragon's Gold (1985)(Amsoft)[cr].dsk"} },
   {0x2c302745, {"7161ecd4e4c3fbdbcd7a93945ac9bfcc"}, {"Dents de sa Mere, La (Transoft) (France)/Dents de sa Mere, La (1986)(Transoft)(fr)[tape].dsk"} },
   {0xdb63f848, {"3006ddc182c20a8b471d33d14876393a"}, {"Enterprise v1.0 (Data Media) (de)/Enterprise v1.0 (1985)(Data Media)(de).dsk"} },
   {0x705055f9, {"2ae8d2a211e2fd45686f47751d62d103"}, {"Enchanted (Positive) (Spain)/Enchanted (1989)(Positive)(es).dsk"} },
   {0x76f67d86, {"c68076620e353d3feae594cc90a2f4ca"}, {"Enduro Racer (Activision)/Enduro Racer (1987)(Activision).dsk"} },
   {0xe6e831d8, {"14fa5b0d2f6cb244156731d8e9f6e14b"}, {"Eidolon, The (Activision)/Eidolon, The (1986)(Activision).dsk"} },
   {0xbea63f11, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Elevator Action (Quicksilva)/Elevator Action (1987)(Quicksilva).dsk"} },
// {0x68233cd0, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Eden Blues (ERE Informatique) (France)/Eden Blues (1985)(ERE Informatique)(fr).dsk"} },
   {0x002eeb53, {"56a4fef25d0ac98e5b7e412462be4091"}, {"Escape (Entertainment & Computer Products)/Escape (1985)(Entertainment & Computer Products)[cr].dsk"} },
   {0x0cca0759, {"7d474f381b277c460fcf0df8e8faf977"}, {"Enchanter (Infocom)/Enchanter (1984)(Infocom)[CPM].dsk"} },
   {0x67c371f3, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"E-Motion (US Gold)/E-Motion (1990)(US Gold).dsk"} },
   {0x62453c06, {"5c4204eb8cd3f327c399be6248b4a40c"}, {"Er-Bert (Microbyte)/Er-Bert (1984)(Microbyte)[cr].dsk"} },
   {0x6c18db2f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Evening Star (Hewson)/Evening Star (1987)(Hewson).dsk"} },
   {0x14733dcc, {"97a2290432d363f259d5aee6af31dc91"}, {"Energy Warrior (Mastertronic)/Energy Warrior (1987)(Mastertronic)[cr].dsk"} },
   {0x16dfaedf, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Etrange Castel (Fanatic) (France)/Etrange Castel (1990)(Fanatic)(fr)(pd)[cr].dsk"} },
   {0x510fea74, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"European Superleague (CDS Software LTD) (Spain)/European Superleague (1990)(CDS Software LTD)(es).dsk"} },
   {0x327572f5, {"23762081dab77e438bd29ba648ef1e7e"}, {"Elite (Firebird)/Elite (1985)(Firebird)(Side A)[GOLD].dsk"} },
   {0x22787a91, {"c0de6c22e4544957aa221e83d5ddb8e6"}, {"Esgrima Electrico (Amstrad Computer User) (Spain)/Esgrima Electrico (1985)(Amstrad Computer User)(es)[cr].dsk"} },
   {0x69219b4f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Exolon (Hewson)/Exolon (1989)(Hewson).dsk"} },
   {0x1c4a7ef4, {"e3f5ac63852ce72457682a917945fc69"}, {"Erebus (Titus) (France)/Erebus (1987)(Titus)(fr).dsk"} },
// {0xa4bcfc77, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Electric Wonderland (ERE Informatique)/Electric Wonderland (1986)(ERE Informatique).dsk"} },
   {0xdaf5b8f7, {"12625e58e41ebc1afc898c66afc36fb0"}, {"European Superleague (CDS Software LTD) (France)/European Superleague (1990)(CDS Software LTD)(fr)[cr].dsk"} },
   {0xb4ba020b, {"1075a88a898475b18d705f9167f62306"}, {"Endzone (Alternative Software)/Endzone (1989)(Alternative Software)[tape][f].dsk"} },
   {0x98730b35, {"238f15af7ac3352913db6cf0a3fdfd27"}, {"Express Raider (US Gold)/Express Raider (1987)(US Gold).dsk"} },
   {0xdfcfd017, {"0f3ce766494c244fb3e069ee60809d95"}, {"Equinox (Mikro-Gen)/Equinox (1986)(Mikro-Gen).dsk"} },
   {0x7ba07120, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Explorer (Activision)/Explorer (1987)(Activision).dsk"} },
   {0xb66e94c0, {"56a4fef25d0ac98e5b7e412462be4091"}, {"Escape From Khoshima (Atlantis Software)/Escape From Khoshima (1986)(Atlantis Software)[cr].dsk"} },
   {0x077f567e, {"b497ab307e15154c3d86ae2c6f44fc06"}, {"Experience, The (Players)/Experience, The (1985)(Players)[tape].dsk"} },
   {0x3d86c8c2, {"56a4fef25d0ac98e5b7e412462be4091"}, {"Escape From The Planet Of Doom (Amstrad Adventure PD Library)/Escape From The Planet Of Doom (1990)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0x4995c437, {"c5598e48d611b81f1c35d26993128d75"}, {"Electric Runner (Hebdogiciel) (France)/Electric Runner (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x97a74eea, {"dd2079a7b4048b03c31aea2b0ab91896"}, {"Eva Strip Word (Amstrad Cent Pour Cent) (France)/Eva Strip Word (1988)(Amstrad Cent Pour Cent)(fr)[cr].dsk"} },
   {0xbe934e4d, {"9b541d26c3efc2a52feca1b6b1a8679a"}, {"Eagle's Rider (Microids)/Eagle's Rider (1990)(Microids)[fr].dsk"} },
   {0x773113a3, {"512f770ebe786517735c5df6892257b9"}, {"Everyone's a Wally (Mikro-Gen)/Everyone's a Wally (1985)(Mikro-Gen)[tape].dsk"} },
   {0xbefb9b11, {"17696893a4de62c35c19896749a5823b"}, {"Escoba (Marcsoft) (Spain)/Escoba (19xx)(Marcsoft)(es)[cr].dsk"} },
   {0xbc8270d3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Erbschaft, Die (Infogrames) (de)/Erbschaft, Die (1986)(Infogrames)(de).dsk"} },
   {0x9b7f3579, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Extreme (Digital Integration)/Extreme (1991)(Digital Integration).dsk"} },
   {0x90981904, {"5349031af22bff67b2e0dfaedfe39f63"}, {"Electric Fencing (Amstrad Computer User)/Electric Fencing (1985)(Amstrad Computer User)[cr].dsk"} },
   {0xbd571db5, {"b2f0bdbb2af4e22fae5e828b13d7b50a"}, {"European II - The European Cup (E&J Software)/European II - The European Cup (1989)(E&J Software)[cr].dsk"} },
   {0x525cb704, {"6bf68fd7a130c877c8cf93e64b90558f"}, {"Evasion (Alain Massoumipour) (France)/Evasion (1987)(Alain Massoumipour)(fr)(Side A)[cr].dsk"} },
   {0x3befe4ce, {"8285f668d38d378b1426099d282adcec"}, {"Elidon (Orpheus)/Elidon (1985)(Orpheus)[tape].dsk"} },
   {0x1666d286, {"747d52fabd4a8e5f4030d8354fc72012"}, {"European II - The European Cup (E&J Software) (Spain) (Hack)/European II - The European Cup (1989)(E&J Software)(es)(Hack)[cr].dsk"} },
   {0xc00d99db, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"European Superleague (CDS Software LTD)/European Superleague (1990)(CDS Software LTD).dsk"} },
   {0x14859082, {"23762081dab77e438bd29ba648ef1e7e"}, {"Elite (Firebird) (de)/Elite (1985)(Firebird)(de)[GOLD].dsk"} },
   {0xb0b9278e, {"900126226e55969355cdc56484f0b034"}, {"Ensembles, Les (Eurogiciel) (France)/Ensembles, Les (1986)(Eurogiciel)(fr)[cr].dsk"} },
   {0xef8fdc30, {"0f3ce766494c244fb3e069ee60809d95"}, {"Escape from Planet of Robot Monsters (Domark)/Escape from Planet of Robot Monsters (1990)(Domark).dsk"} },
// {0x8442d3bb, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Exit (Ubi Soft) (France)/Exit (1988)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x71dd6753, {"0f3ce766494c244fb3e069ee60809d95"}, {"Every Second Counts (Domark)/Every Second Counts (1988)(Domark).dsk"} },
   {0x368e910b, {"6bf68fd7a130c877c8cf93e64b90558f"}, {"Evasion (Entertainment & Computer Products) (France)/Evasion (1985)(Entertainment & Computer Products)(fr)[cr].dsk"} },
   {0x21b5a146, {"c68076620e353d3feae594cc90a2f4ca"}, {"Eye (Endurance Games)/Eye (1987)(Endurance Games).dsk"} },
   {0x773a2875, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Eliminator (Hewson) (Bugs)/Eliminator (1988)(Hewson)[b].dsk"} },
   {0x4f86b3c8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Emilio Butragueno Futbol (Topo Soft) (Spain)/Emilio Butragueno Futbol (1988)(Topo Soft)(es).dsk"} },
   {0xce112c59, {"7dc75c076e0a9b51374639797e234a58"}, {"Endurance (CRL Group)/Endurance (1985)(CRL Group)[tape].dsk"} },
   {0x59a3cd11, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Edd the Duck (Zeppelin Games)/Edd the Duck (1990)(Zeppelin Games).dsk"} },
// {0xacf41d84, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"E-SWAT (US Gold)/E-SWAT (1990)(US Gold).dsk"} },
   {0x25ce4a0d, {"d787d8a31e31ebe5b1571f61583a2b1e"}, {"Exploding Wall (Byte Back)/Exploding Wall (1989)(Byte Back)[tape].dsk"} },
   {0x27b6254e, {"d3990b35694de62d7363f864f21d6c42"}, {"European Champions (E&J Software)/European Champions (1990)(E&J Software)[cr].dsk"} },
   {0x1b56b252, {"f50fae3373c62d6c3c7955de39ce0eee"}, {"Emilio Butragueno Futbol II (Erbe Software) (Spain)/Emilio Butragueno Futbol II (1989)(Erbe Software)(es).dsk"} },
   {0x5795493d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Espada Sagrada, La (Topo Soft) (Spain)/Espada Sagrada, La (1990)(Topo Soft)(es).dsk"} },
   {0xc2927916, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Evil Donjon (Genesis Soft)/Evil Donjon (1989)(Genesis Soft).dsk"} },
   {0xa4f72e8d, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Echelon (US Gold)/Echelon (1988)(US Gold).dsk"} },
   {0x8aefef48, {"29d7db2dab2f88f651c0870b9c26474e"}, {"Elektra Glide (English Software)/Elektra Glide (1986)(English Software).dsk"} },
   {0x76132797, {"5c6ff6ea09124f353f0b6404dbfabcb0"}, {"Eve of Shadows (Amstrad Adventure PD Library) (Bugs)/Eve of Shadows (1991)(Amstrad Adventure PD Library)(PD)[cr][b].dsk"} },
   {0x7a74e185, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Enlightenment - Druid II (Firebird)/Enlightenment - Druid II (1988)(Firebird).dsk"} },
   {0xe31d60df, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Emilio Sanchez Vicario (Zigurat Software) (Spain)/Emilio Sanchez Vicario (1989)(Zigurat Software)(es).dsk"} },
   {0x5d87fc09, {"f3ee2dd580012ed5196d89911362e055"}, {"Emerald Isle (Level 9 Computing)/Emerald Isle (1985)(Level 9 Computing)[tape].dsk"} },
   {0x1b9045bd, {"bfd075085b155a6b08dd7897cc293d6e"}, {"Espionage (Grandslam)/Espionage (1988)(Grandslam).dsk"} },
   {0xac0091ea, {"a47df094ee57dc600967da0c0f06db5f"}, {"Excalibur Quest (Excalibur) (France)/Excalibur Quest (1988)(Excalibur)(fr)(Side A).dsk"} },
   {0xf76d2da6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Electro Freddy (Amsoft)/Electro Freddy (1984)(Amsoft).dsk"} },
// {0x6eaebfc4, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Eden Blues (ERE Informatique) (Spain)/Eden Blues (1985)(ERE Informatique)(es).dsk"} },
   {0x4897ca99, {"d9978d2bb407c2e0b15776a13ca0418a"}, {"Emlyn Hughes International Soccer (Audiogenic Software LTD)/Emlyn Hughes International Soccer (1988)(Audiogenic Software LTD).dsk"} },
   {0x21c8c7c7, {"98d7a8a75464c8c27a60988b77716f65"}, {"Exterminator (Audiogenic Software LTD)/Exterminator (1991)(Audiogenic Software LTD).dsk"} },
   {0x9187899c, {"e41bc9dddc1e4a6ff3a561a7ff6371d0"}, {"Exchange (Cascade Games)/Exchange (1986)(Cascade Games)[cr].dsk"} },
   {0x893a5fc8, {"56a4fef25d0ac98e5b7e412462be4091"}, {"Escape from Wacci (Potplant Production)/Escape from Wacci (1989)(Potplant Production)(PD)[cr].dsk"} },
   {0xfa9a2d49, {"23762081dab77e438bd29ba648ef1e7e"}, {"Elite (Firebird) (France)/Elite (1985)(Firebird)(fr)[cr][GOLD].dsk"} },
   {0x577cf898, {"d39a2e03c010538bebf9149cba4f29da"}, {"Fres Man (Bollaware) (de)/Fres Man (1990)(Bollaware)(de)[cr].dsk"} },
   {0x3094c97e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Firelord (Hewson)/Firelord (1986)(Hewson).dsk"} },
   {0x28f0fc6e, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Final Fight (US Gold)/Final Fight (1991)(US Gold).dsk"} },
   {0x3978c90e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Flimbo's Quest (System 3)/Flimbo's Quest (1990)(System 3)(Side A).dsk"} },
   {0xc2bc35c3, {"46f3c7e135a3aeedfb3c0aaaafecd832"}, {"Five A Side Soccer (Mastertronic)/Five A Side Soccer (1986)(Mastertronic)[cr].dsk"} },
   {0x55d399c6, {"e02ed8d075a805a491f2ed7e1eb1ae4d"}, {"Formula 1 Simulator (Mastertronic)/Formula 1 Simulator (1985)(Mastertronic)[cr][f].dsk"} },
   {0x08f2f58f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Frost Byte (Mikrogen)/Frost Byte (1986)(Mikrogen).dsk"} },
   {0xff2a8f73, {"a0f344051c0f493b9af2ea19cfc024c2"}, {"Fusion II (Loriciels) (France)/Fusion II (1988)(Loriciels)(fr).dsk"} },
   {0x43e60a93, {"eb592bf2e8af750d024643694e091b66"}, {"Football Manager 2 (Addictive Games) (France)/Football Manager 2 (1988)(Addictive Games)(fr)[cr].dsk"} },
   {0xfe89ad78, {"563551102e0d58a296fdbcf524cedba3"}, {"Further Adventures of Fred, The (Sean McManus)/Further Adventures of Fred, The (2020)(Sean McManus)(PD)[cr].dsk"} },
   {0x95a5888b, {"84f38460b73b3f1629bb60374fac80fd"}, {"Friday The 13th - Viernes 13 (Domark)/Friday The 13th - Viernes 13 (1986)(Domark).dsk"} },
   {0x17726e14, {"af1c271a2b72191a5f70e723680e8a19"}, {"Forestland (Supersoft)/Forestland (1986)(Supersoft).dsk"} },
   {0xf8c38616, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"F1 Tornado Simulator (Zeppelin Games)/F1 Tornado Simulator (1991)(Zeppelin Games).dsk"} },
   {0xe3ade0bf, {"890aadd87564f0a3f80e929ab045912e"}, {"Froggy (R&B Marketing)/Froggy (1985)(R&B Marketing)[cr].dsk"} },
   {0xce13f5d2, {"89a40b86eea7b6e2203d28ab298d4e4f"}, {"Fleche (Micro Mag)/Fleche (1989)(Micro Mag)[cr].dsk"} },
   {0xe3f26c39, {"0a161f2e5ac87aace8bc2511b1f0f296"}, {"Flight Simulation (Myrddin Software)/Flight Simulation (1984)(Myrddin Software)[cr].dsk"} },
   {0x01dd7b07, {"d790cb7fdaed39406bc7a8b3371addfb"}, {"Fruit Machine Simulator (Codemasters Software)/Fruit Machine Simulator (1988)(Codemasters Software)[cr].dsk"} },
   {0xc79a0c4f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Flying Shark (Firebird Software)/Flying Shark (1987)(Firebird Software).dsk"} },
   {0xb7609628, {"0fa147197f1a565d0ab1daba69ece7e3"}, {"Fairlight - A Trail Of Darkness (The Edge)/Fairlight - A Trail Of Darkness (1986)(The Edge)[cr][f].dsk"} },
   {0x2a6a6691, {"8ae646adf86dfbcd0d1bfdcb71cfa457"}, {"ForceField (David Hall)/ForceField (19xx)(David Hall)(PD)[cr].dsk"} },
   {0x45d91d85, {"2a1ef67e37cc2041145265ec5ee80e26"}, {"F-15 Strike Eagle (Microprose Software)/F-15 Strike Eagle (1986)(Microprose Software)[cr].dsk"} },
   {0xec6a5258, {"0870e8e6d722aac9a627a74df618c8d1"}, {"Fairlight - A Prelude (The Edge)/Fairlight - A Prelude (1985)(The Edge).dsk"} },
   {0xc9a350f6, {"eb592bf2e8af750d024643694e091b66"}, {"Football Manager 2 (Addictive Games)/Football Manager 2 (1988)(Addictive Games).dsk"} },
   {0xc3997a3d, {"874e92df0e796baee03e9938357be577"}, {"Fred (Zigurat) (Spain)/Fred (1984)(Zigurat)(es)[cr][f].dsk"} },
// {0xdd86f049, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Fantome City (Coktel Vision) (France)/Fantome City (1986)(Coktel Vision)(fr).dsk"} },
   {0xf9ac5798, {"0f3ce766494c244fb3e069ee60809d95"}, {"Fire (New Deal Productions)/Fire (1990)(New Deal Productions).dsk"} },
   {0x45b5d65d, {"1edd60ad6e5e3d324f6b3f5bc5f724d1"}, {"Fantomas (Hebdogiciel) (France)/Fantomas (1986)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x70756ff6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Flintstones, The (Grandslam)/Flintstones, The (1988)(Grandslam).dsk"} },
   {0x887d173f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Freddy Hardest in South Manhattan (Dinamic Software) (Spain)/Freddy Hardest in South Manhattan (1989)(Dinamic Software)(es).dsk"} },
   {0x65528221, {"6788f21b2556a15ecd9b89e985e11625"}, {"Froggit (Happy Computer)/Froggit (1987)(Happy Computer)[cr].dsk"} },
   {0x24736392, {"ede1af0aec4bbf173e3f2b436ef4e312"}, {"Flash Gordon (Mastertronic) (Bugs)/Flash Gordon (1988)(Mastertronic)[cr][b].dsk"} },
   {0x47dce9b2, {"567b6ca5459dc434044ad5aaf909dd68"}, {"Forces (PC Schneider International)/Forces (1987)(PC Schneider International)[cr].dsk"} },
   {0x3eea51e6, {"7976a991a55791ba5b2887a6d7b2d15c"}, {"Football Frenzy (Alternative Software)/Football Frenzy (1987)(Alternative Software)[cr].dsk"} },
   {0xff560a03, {"0f3ce766494c244fb3e069ee60809d95"}, {"Final Matrix, The (Gremlin Graphics Software)/Final Matrix, The (1987)(Gremlin Graphics Software).dsk"} },
   {0xea67f87e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Frankenstein (CRL Group)/Frankenstein (1987)(CRL Group).dsk"} },
   {0x81ec6b2e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Fighting Soccer (Activision)/Fighting Soccer (1989)(Activision).dsk"} },
   {0xdd846c34, {"b76b634701bbf80bfc3bffe9b8475e0b"}, {"Firefox (Home Computing Weekly)/Firefox (1985)(Home Computing Weekly)[cr].dsk"} },
   {0x71016c13, {"220b5497f1b64fdec897fc8d09671dee"}, {"Fruity Frank (Kuma Computers) (Spain)/Fruity Frank (1984)(Kuma Computers)(es)[cr].dsk"} },
   {0x8317c75a, {"fae8862ee07e084d470b12de0558b1ca"}, {"Fantasia Diamond (Hewson)/Fantasia Diamond (1984)(Hewson)[cr].dsk"} },
   {0x778bc097, {"246a839be67e04c840da6eded2092085"}, {"Frestris v1.1 (Bollaware)/Frestris v1.1 (1995)(Bollaware)(PD).dsk"} },
   {0x1aabb041, {"5300f9588fc305f624a26865f2b2c91a"}, {"Fantasy Land (Cascade Games)/Fantasy Land (1986)(Cascade Games)[cr].dsk"} },
   {0x411d6548, {"68e4b04acfd96108089d031c7f6dbc11"}, {"Fourtris (CPC Computing)/Fourtris (1988)(CPC Computing)[cr].dsk"} },
   {0x18b560ea, {"f4eedfe270b7fdb000c65c58c52f3a76"}, {"Freedom Fighter (The Power House)/Freedom Fighter (1988)(The Power House)[cr].dsk"} },
   {0xc73dd7e4, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Fruit Machine (Amsoft)/Fruit Machine (1984)(Amsoft)[tape].dsk"} },
   {0x2ebe34c9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Future Knight (Gremlin Graphics Software)/Future Knight (1986)(Gremlin Graphics Software).dsk"} },
   {0x45eb3208, {"cf3ed8c662107d470c16ebbfe7a17e06"}, {"Future Shock (Tynesoft Computer System)/Future Shock (1987)(Tynesoft Computer System)[cr].dsk"} },
   {0x48cdf786, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Famous Five On Treasure Island, The (Enigma Variations)/Famous Five On Treasure Island, The (1990)(Enigma Variations).dsk"} },
   {0x7b648261, {"b76b634701bbf80bfc3bffe9b8475e0b"}, {"Firefox 2 (Yie Ar Soft)/Firefox 2 (1987)(Yie Ar Soft)[cr].dsk"} },
   {0xef6a6ff5, {"4c30f1c2784833689b4fbc58f43ecc1b"}, {"Fighting Warrior (Melbourne House)/Fighting Warrior (1985)(Melbourne House)[cr].dsk"} },
   {0x993226d2, {"3cdbf808f4d49befff7f114f80a6d206"}, {"Fighter Command (Cascade Games)/Fighter Command (1986)(Cascade Games)[cr].dsk"} },
   {0x7f03a79b, {"deda8d73ded07682bb4760bdee7471ef"}, {"F-15 Strike Eagle (Microprose Software) (Codes)/F-15 Strike Eagle (1986)(Microprose Software)[codes].dsk"} },
   {0x573d30b4, {"78937f37c9d64cbc947c330568307307"}, {"Futur Racer (Amstar & Cpc) (France)/Futur Racer (1989)(Amstar & Cpc)(fr)[cr].dsk"} },
   {0x0e55de6f, {"7f1ee9d2236fc55e90afb4d780def9f0"}, {"Firestone, The (Amstrad Adventure PD Library)/Firestone, The (1990)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0x2c2599ba, {"ca82f5ae45fefc653db9dbb89e0456ee"}, {"Football Manager World Cup Edition (Addictive Games) (France)/Football Manager World Cup Edition (1990)(Addictive Games)(fr)[cr].dsk"} },
   {0x114dce4a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Fruity Frank (Kuma Computers)/Fruity Frank (1984)(Kuma Computers).dsk"} },
   {0x9ea39068, {"2025ca4249901bb6370781a549660aeb"}, {"Force Quatre (Cobra Soft) (France)/Force Quatre (1985)(Cobra Soft)(fr)[cr].dsk"} },
   {0x6ca6e53d, {"f0245160a9298d17e3c73cc3506b6dac"}, {"Fucki Demo (CPC Infos) (France)/Fucki Demo (1990)(CPC Infos)(fr)[cr].dsk"} },
   {0xdf940198, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Fu-Kung in Las Vegas (Amsoft)/Fu-Kung in Las Vegas (1985)(Amsoft).dsk"} },
// {0xbc7b47c3, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Fer & Flamme (Ubi Soft) (France)/Fer & Flamme (1986)(Ubi Soft)(fr)(Disk 1 Side A).dsk"} },
   {0xc07ee7b1, {"aeb4845163aa18ec401cb6244c3e2210"}, {"Fallout (Amstrad Action Magazine)/Fallout (1987)(Amstrad Action Magazine)[cr].dsk"} },
   {0xb46403ae, {"eb592bf2e8af750d024643694e091b66"}, {"Football Manager 2 (Addictive Games) (Spain)/Football Manager 2 (1988)(Addictive Games)(es).dsk"} },
   {0xd6361b0e, {"81825855c2b49e1e3bac2501fb3f4991"}, {"Formula One (CRL Group)/Formula One (1985)(CRL Group)[cr].dsk"} },
   {0x8079a844, {"85f78509903f350923c3881965c66cb2"}, {"Fire and Forget II (Titus)/Fire and Forget II (1990)(Titus)[cr].dsk"} },
   {0x708351db, {"2dccff60b2e7dbcb7e5171607d2d79db"}, {"Fernando Martin Basket Master (Dinamic Software) (Spain)/Fernando Martin Basket Master (1987)(Dinamic Software)(es).dsk"} },
   {0x5f933903, {"39709430d0e5067c5866ac24ed8d49f0"}, {"Fighter Pilot (Digital Integration) (M3)/Fighter Pilot (1985)(Digital Integration)(M3).dsk"} },
   {0x0b296a53, {"0b3591de7c38b051f4106c895960589d"}, {"Fourtron (Rafael Garcia Gonzales) (Spain)/Fourtron (1986)(Rafael Garcia Gonzales)(es)[cr].dsk"} },
   {0x43d4b751, {"cfb26d71fd40aaef1c292a9edd094440"}, {"Fire and Forget (Titus)/Fire and Forget (1988)(Titus).dsk"} },
   {0x9c474afb, {"0f3ce766494c244fb3e069ee60809d95"}, {"Footballer of the Year (Gremlin Graphics Software)/Footballer of the Year (1986)(Gremlin Graphics Software).dsk"} },
   {0xaed93596, {"4350d2bffdfd23a848776ddf30bce65a"}, {"Fruit Machine 2 Simulator (Codemasters Software)/Fruit Machine 2 Simulator (1990)(Codemasters Software)[cr].dsk"} },
// {0xbca5acb2, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Faial (Excalibur) (France)/Faial (1986)(Excalibur)(fr)(Side A).dsk"} },
   {0xe03a48b5, {"a91e34aeb9acf97a1c750792aaa3fc16"}, {"Foso Del Dragon, El (Geasa) (Spain)/Foso Del Dragon, El (1986)(Geasa)(es)[cr].dsk"} },
   {0x0b09c221, {"76f6088a2a507acddac2832c34665a87"}, {"Feud (Mastertronic)/Feud (1987)(Mastertronic)[cr].dsk"} },
   {0x9b10bce1, {"f2e733a6506424eda2b6bf9c180a20e4"}, {"Finders Keepers (Mastertronic)/Finders Keepers (1985)(Mastertronic)[cr].dsk"} },
   {0xbe873eae, {"292085dced24874c8452556dce761f9f"}, {"Forest at World's End, The (Interceptor Software)/Forest at World's End, The (1985)(Interceptor Software)[cr].dsk"} },
   {0x4524af85, {"7865e03c3aac94de3b7d062ffed347c4"}, {"Fire Land (CPC Infos)/Fire Land (1991)(CPC Infos)(v2)[cr].dsk"} },
   {0x7a8fe41d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Freddy Hardest (Dinamic Software)/Freddy Hardest (1987)(Dinamic Software).dsk"} },
   {0x9e80ee3a, {"6c6b3a1c857710196899eec9bebc594b"}, {"Friss Man (Amsoft)/Friss Man (1985)(Amsoft)[cr].dsk"} },
   {0xa47e0e62, {"220b5497f1b64fdec897fc8d09671dee"}, {"Fruity (Amstar & CPC) (France)/Fruity (1988)(Amstar & CPC)(fr)[cr].dsk"} },
   {0xa526ba0e, {"56860e923ee91a4edac5cce0d3d81f5a"}, {"Frankie Goes to Hollywood (Ocean Software)/Frankie Goes to Hollywood (1986)(Ocean Software)[cr].dsk"} },
   {0x508f2885, {"c68076620e353d3feae594cc90a2f4ca"}, {"Firetrap (Activision)/Firetrap (1987)(Activision).dsk"} },
   {0x874e9bb6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Freddy Hardest (Dinamic Software) (Spain)/Freddy Hardest (1987)(Dinamic Software)(es).dsk"} },
   {0xcc93182d, {"e3dbc5ab58c97a698ab06fd2b505577b"}, {"For Gold or Glory (Alternative Software)/For Gold or Glory (1988)(Alternative Software)[cr][f].dsk"} },
   {0xeb63b31b, {"1727c8fa64332ad13e5ab7fb640f62b7"}, {"Fres Fighter II Turbo v1.5 (Bollaware)/Fres Fighter II Turbo v1.5 (1999)(Bollaware)(PD)(Disk 1 Side A)[cr].dsk"} },
   {0x53f452e0, {"7b0243e66d74db6c9e09562a11341d61"}, {"Frank Bruno's Boxing (Elite Systems)/Frank Bruno's Boxing (1985)(Elite Systems).dsk"} },
   {0x2c1e44ad, {"80f4bae506cb0cf095cad0fc151f9dec"}, {"Football Manager (Addictive Games)/Football Manager (1984)(Addictive Games)[cr].dsk"} },
   {0x9b449b3b, {"b590dd7044620e4945e5135712131f18"}, {"Freedom (Coktel Vision) (France)/Freedom (1988)(Coktel Vision)(fr)(Side A).dsk"} },
   {0xe5facd84, {"36a009b1d2de0d8ebd1033f17372e16c"}, {"Flight Path 737 (Anirog Software) (M5)/Flight Path 737 (1984)(Anirog Software)(M5)[cr].dsk"} },
   {0xb685fd1d, {"02b06debdd4410f4c526e01382193b13"}, {"Fortune En Mer Du Nord (Kuma Computers) (France)/Fortune En Mer Du Nord (1985)(Kuma Computers)(fr)[cr].dsk"} },
   {0x900e99b6, {"c4141a6a85107ee829060b3b0414fdca"}, {"Flight Simulator (Amstrad Magazine) (France)/Flight Simulator (1987)(Amstrad Magazine)(fr)[cr].dsk"} },
   {0x96e2374e, {"6531e4e5cf62d54aaa26cfa523ba49bb"}, {"Fres Attack (Bollaware) (de)/Fres Attack (1991)(Bollaware)(de)(PD)[cr].dsk"} },
   {0xfbdf3208, {"0f3ce766494c244fb3e069ee60809d95"}, {"Football Manager 3 (Addictive Games)/Football Manager 3 (1992)(Addictive Games).dsk"} },
   {0x04ef1030, {"b91aaa458188b1c828c4c4747caec27a"}, {"Fire Ant (Mogul)/Fire Ant (1984)(Mogul)[cr].dsk"} },
   {0x165bf3ea, {"6ebd8c0fffa6cfa824c3764642ff7627"}, {"Frankie Crashed on Jupiter (Kingsoft)/Frankie Crashed on Jupiter (1985)(Kingsoft)(Side A).dsk"} },
   {0xca3cb7df, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Fast Food Dizzy (Codemasters Software)/Fast Food Dizzy (1989)(Codemasters Software).dsk"} },
   {0x0669d006, {"220b5497f1b64fdec897fc8d09671dee"}, {"Fruity Frank (Kuma Computers) (de)/Fruity Frank (1984)(Kuma Computers)(de)[cr].dsk"} },
   {0x93dfda13, {"67c63313b688a505335bc964875d46c4"}, {"Foret Infernale, La (Strategy Software) (France)/Foret Infernale, La (1985)(Strategy Software)(fr)[cr].dsk"} },
   {0xc61ff80e, {"86ac174f4447fe738dfb2bc7e44fc3e9"}, {"Frank N Stein (Amsoft)/Frank N Stein (1985)(Amsoft)[cr].dsk"} },
   {0xd2671f44, {"87d3e6ebb383bd63890006ce186642e1"}, {"Foso, El (Jasap Software) (Spain)/Foso, El (1985)(Jasap Software)(es)[cr].dsk"} },
   {0x36618f61, {"d91dddc7b3dedce091af9aeddd1073b4"}, {"F-16 Combat Pilot (Digital Integration) (M3) (Codes)/F-16 Combat Pilot (1991)(Digital Integration)(M3)[codes].dsk"} },
   {0xb74e5f17, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Forgotten Worlds (US Gold)/Forgotten Worlds (1989)(US Gold).dsk"} },
   {0xdf73e59f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Fiendish Freddy's Big Top O' Fun (Mindscape) (Codes)/Fiendish Freddy's Big Top O' Fun (1990)(Mindscape)(Side A)[codes].dsk"} },
   {0x0cc8bc65, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Football Manager World Cup Edition (Addictive Games) (de)/Football Manager World Cup Edition (1990)(Addictive Games)(de).dsk"} },
   {0xb145f198, {"b9f1bf95b1764d770688abd7dd6d67c6"}, {"Fumiga (Indescomp)/Fumiga (1985)(Indescomp)[cr].dsk"} },
   {0xecf5c310, {"973c16c287c846add02cb0bf909ffbab"}, {"Firescape (FIL) (France)/Firescape (1987)(FIL)(fr).dsk"} },
   {0x35f2a29e, {"644313c638a9913e05629a4af2bd78a8"}, {"Flash (Loriciels)/Flash (1987)(Loriciels).dsk"} },
   {0x27d02694, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Fantastic Voyage, The (Amsoft)/Fantastic Voyage, The (1985)(Amsoft).dsk"} },
   {0xb64fe91d, {"c68076620e353d3feae594cc90a2f4ca"}, {"Fernandez Must Die (Image Works)/Fernandez Must Die (1988)(Image Works).dsk"} },
   {0x1b366599, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Frontiers (Zafiro Software Division) (Spain)/Frontiers (1988)(Zafiro Software Division)(es).dsk"} },
   {0x66ac0bb2, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Fighter Bomber (Activision)/Fighter Bomber (1990)(Activision)(Side A).dsk"} },
   {0xa5ef45ae, {"e521c6860677896d9af3ffe7fbeddfd7"}, {"Fox (Hebdogiciel) (France)/Fox (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0xac7604a3, {"c2b53d42232c91c3eae8b7a544982b99"}, {"Football Manager World Cup Edition (Addictive Games) (Spain)/Football Manager World Cup Edition (1990)(Addictive Games)(es)[cr].dsk"} },
   {0x7af79096, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Footballer of the Year 2 (Gremlin Graphics Software)/Footballer of the Year 2 (1989)(Gremlin Graphics Software).dsk"} },
   {0xbf8a83cf, {"72dcdffb90639e8786f52b4ccbe91631"}, {"Flunky (Piranha) (M5)/Flunky (1987)(Piranha)(M5).dsk"} },
   {0x2cdc32b5, {"a8c88b2e01b93ca69ddca3324a31261b"}, {"Fury, The (Martech Games)/Fury, The (1988)(Martech Games).dsk"} },
   {0x52f0add7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Football Manager World Cup Edition (Addictive Games)/Football Manager World Cup Edition (1990)(Addictive Games).dsk"} },
   {0x12a1efea, {"b9ba7ab147276c962035adfd9530bdbd"}, {"Griffes de la Nuit, Les (Bruno Fonters) (France)/Griffes de la Nuit, Les (1993)(Bruno Fonters)(fr)(Side A)[cr].dsk"} },
   {0x674fbced, {"7477f0e82f9b173fad52f22173bc9183"}, {"Galactic Plague, The (Amsoft)/Galactic Plague, The (1984)(Amsoft)[cr].dsk"} },
   {0xbae9bb8f, {"db2a21c5e9c9ee2da3a5d3fdf2c6aaa3"}, {"Green Beret (Ocean Software)/Green Beret (1986)(Ocean Software).dsk"} },
   {0x080c97e6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Golden Basket (Opera Soft) (Spain) (Codes)/Golden Basket (1990)(Opera Soft)(es)[codes].dsk"} },
   {0xed14021d, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Games, The - Winter Edition (US Gold)/Games, The - Winter Edition (1988)(US Gold)(Side A).dsk"} },
   {0x20dcbf76, {"fe7f98785e5d4fcc3bd7bca881bdaef8"}, {"Gabrielle (Ubi Soft) (France)/Gabrielle (1987)(Ubi Soft)(fr).dsk"} },
   {0x81459018, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gary Lineker's Super Star Soccer (Gremlin Graphics Software) (France)/Gary Lineker's Super Star Soccer (1987)(Gremlin Graphics Software)(fr).dsk"} },
   {0xd3ce1181, {"2dccff60b2e7dbcb7e5171607d2d79db"}, {"Golden Basket (Opera Soft) (Spain)/Golden Basket (1990)(Opera Soft)(es)[cr].dsk"} },
   {0x363985d0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Gremlins 2 (Topo Soft) (Spain)/Gremlins 2 (1990)(Topo Soft)(es).dsk"} },
   {0xb0a79287, {"78e5f3c7b3f804c2068c0b272de9d026"}, {"Gnome Ranger (Level 9 Computing)/Gnome Ranger (1987)(Level 9 Computing)(Side A).dsk"} },
   {0x1f01e07c, {"39b956297053f4ac9e5533978b7a81d9"}, {"Gob (TJC)/Gob (1987)(TJC)[cr].dsk"} },
   {0x0edae7dd, {"3c9acdbd8a175a901a390d52fbd15296"}, {"Grand Prix 500cc (Microids) (France)/Grand Prix 500cc (1986)(Microids)(fr).dsk"} },
   {0xc978c90f, {"58fbdd09aa60a88cb618a0d404f521ef"}, {"Gun Dogs (Andromeda Software)/Gun Dogs (1985)(Andromeda Software)[cr].dsk"} },
   {0x5d00c766, {"6cb7a4f5481620f1387e71388aa85b48"}, {"Gilbert - Escape from Drill (Alternative Software)/Gilbert - Escape from Drill (1989)(Alternative Software)[tape].dsk"} },
   {0xb78bd384, {"ca9f05583cfa4f2e9205ea50316c7bc8"}, {"Great Giana Sisters, The (Rainbow Arts)/Great Giana Sisters, The (1988)(Rainbow Arts) (Prototype)[cr][f].dsk"} },
   {0xb6e80000, {"a93de3d0e859e968c00d83cc361ccf49"}, {"Goonies, The (US Gold)/Goonies, The (1986)(US Gold)[cr].dsk"} },
   {0xfdaf20b2, {"8b465a319164059ad19cb5f63fb05c94"}, {"Goldrush (PC Amstrad International)/Goldrush (1989)(PC Amstrad International)[cr].dsk"} },
   {0x6d45f398, {"11149d2878ee22edbc52605c67d42c0b"}, {"Galivan (Ocean)/Galivan (1986)(Ocean).dsk"} },
// {0x51e77955, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Garfield - Big, Fat, Hairy Deal (The Edge Software)/Garfield - Big, Fat, Hairy Deal (1988)(The Edge Software).dsk"} },
   {0x79777618, {"392e7b99f5b6900d2245896d4afc978b"}, {"Gazza's Super Soccer (Empire Software) (Spain)/Gazza's Super Soccer (1990)(Empire Software)(es).dsk"} },
   {0x8d8e3122, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Game Over (Dinamic Software)/Game Over (1987)(Dinamic Software).dsk"} },
   {0x31b561e4, {"397d12a922488a8264228c56916d445a"}, {"Get Dexter 2 (ERE Informatique)/Get Dexter 2 (1988)(ERE Informatique).dsk"} },
   {0x36c70444, {"0f3ce766494c244fb3e069ee60809d95"}, {"Grand Prix Master (Dinamic Software)/Grand Prix Master (1988)(Dinamic Software).dsk"} },
   {0x5b5bb1bf, {"0fe710167e624507efd05cad2580df6c"}, {"Goliath (Rainbow Productions) (France)/Goliath (1986)(Rainbow Productions)(fr)[tape].dsk"} },
   {0x0d7c84b0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Gazza II (Empire Software)/Gazza II (1990)(Empire Software).dsk"} },
   {0x429f78f6, {"92056f3392eb909b7dc0564b743a18fa"}, {"Guild of Thieves, The (Rainbird Software)/Guild of Thieves, The (1988)(Rainbird Software)(v2)(Side A).dsk"} },
   {0xd853a63d, {"52c18325e14b97580c83c6a6e929ab3b"}, {"Gridrider (PC Amstrad International)/Gridrider (1990)(PC Amstrad International)[cr].dsk"} },
   {0x8960a2c9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gauntlet - Deeper Dungeon (US Gold)/Gauntlet - Deeper Dungeon (1987)(US Gold)(Extension).dsk"} },
   {0xc8149ef6, {"c39d544e39ca1a21865de7b1aee60612"}, {"Ghostbusters (Activision)/Ghostbusters (1986)(Activision).dsk"} },
   {0xc057aaa8, {"2028b2f79fbc3b0ee10626f409f19a2f"}, {"Guzzler (Players)/Guzzler (1986)(Players)[cr].dsk"} },
   {0x801b1081, {"8ffdce6ffcd51599d05020a23d33118a"}, {"Ghouls (Micro Power)/Ghouls (1985)(Micro Power)[cr].dsk"} },
   {0xf10ee3fc, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Games, The - Summer Edition (US Gold)/Games, The - Summer Edition (1989)(US Gold)(Side A).dsk"} },
   {0xbbc67708, {"20d991e183ab6598a25d3bc7269a3d68"}, {"Glen Hoddle Soccer (Amsoft) (Spain)/Glen Hoddle Soccer (1985)(Amsoft)(es).dsk"} },
   {0x83eb38d4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Guerra de las Vajillas, La (Dinamic Software) (Spain)/Guerra de las Vajillas, La (1988)(Dinamic Software)(es).dsk"} },
   {0x746d9652, {"0f3ce766494c244fb3e069ee60809d95"}, {"Game Over II (Dinamic Software)/Game Over II (1988)(Dinamic Software).dsk"} },
   {0xe4c3cfce, {"392e7b99f5b6900d2245896d4afc978b"}, {"Gazza's Super Soccer (Empire Software) (France)/Gazza's Super Soccer (1990)(Empire Software)(fr).dsk"} },
   {0xeebc403d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Great Courts (Ubi Soft) (Codes)/Great Courts (1989)(Ubi Soft)[AZERTY][codes].dsk"} },
   {0xd5e3e43f, {"969bf46eda4048d948aea4306efa3dd0"}, {"Galaxian's Revenge (Amstrad Computer User)/Galaxian's Revenge (1984)(Amstrad Computer User)[cr].dsk"} },
   {0x287abc03, {"d0f5b3f2779b103b325f8eb4fe5b13eb"}, {"Guardian (Your Computer) (Spain)/Guardian (1986)(Your Computer)(es)[cr].dsk"} },
   {0xf89cc225, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gauntlet II (US Gold)/Gauntlet II (1988)(US Gold).dsk"} },
   {0xa4bc521a, {"153e287b044cd66fbf8377ae7edead44"}, {"Gorbaf el Vikingo (Software Center) (Spain)/Gorbaf el Vikingo (1987)(Software Center)(es)[cr].dsk"} },
   {0xd2bff6bd, {"79fa3e1898a153452f3619832adc62dd"}, {"Gems of Stradus (Amsoft)/Gems of Stradus (1984)(Amsoft)[tape].dsk"} },
   {0xde622d6e, {"3ac5ce4afab21b82536661e40e2899e7"}, {"Gutter (ERE Informatique)/Gutter (1985)(ERE Informatique)[tape].dsk"} },
   {0x8d478d60, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Great Escape, The (Ocean)/Great Escape, The (1986)(Ocean).dsk"} },
   {0xa2b01221, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Gryzor (Ocean)/Gryzor (1987)(Ocean).dsk"} },
   {0x39dbbb77, {"c68076620e353d3feae594cc90a2f4ca"}, {"Guadalcanal (Activision)/Guadalcanal (1987)(Activision).dsk"} },
   {0xd649f19f, {"65f6a2de6244da4e19f61d572d9e2539"}, {"Gold Hunter (Schneider Magazin)/Gold Hunter (1987)(Schneider Magazin)[cr].dsk"} },
   {0x1eb29361, {"6f941d504259a5fba1646d7636adc2aa"}, {"GI Hero (Firebird)/GI Hero (1988)(Firebird).dsk"} },
   {0x5f83fbdd, {"8dc72f4611c513b6ced1f6121cecf439"}, {"Grange Hill (Grandslam) (Spain)/Grange Hill (1987)(Grandslam)(es)[cr].dsk"} },
   {0xe963b88f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Galactic Games (Activision)/Galactic Games (1987)(Activision)(Side A).dsk"} },
   {0x35cbfeb9, {"c2f7628d52a11e2953114c20f44b29ab"}, {"Galaxias (Delta 4 Software)/Galaxias (1986)(Delta 4 Software)[cr].dsk"} },
   {0xbc911bd9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Goody (Opera Soft) (Spain)/Goody (1987)(Opera Soft)(es)[cr][f].dsk"} },
   {0xf74fc16d, {"f52932d8ba50d9f9a0a2518483bd50e2"}, {"Grand Prix Simulator (Codemasters Software)/Grand Prix Simulator (1987)(Codemasters Software)[cr][f].dsk"} },
   {0x6c191159, {"f735ffacd19fe824c24f8098486a826c"}, {"Garfield - Winter's Tail (The Edge Software)/Garfield - Winter's Tail (1990)(The Edge Software).dsk"} },
   {0xd050c94e, {"4c61930ee9a2c8473010d02b77d344e2"}, {"Ghosts (Cascade Games)/Ghosts (1985)(Cascade Games)[cr].dsk"} },
   {0xdad8d078, {"93f33a921ba895ccc93ec097e18df2e3"}, {"Grand Prix 500cc (Microids) (Spain)/Grand Prix 500cc (1986)(Microids)(es)[cr].dsk"} },
   {0xc8d7f575, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Ghouls 'n' Ghosts (US Gold)/Ghouls 'n' Ghosts (1989)(US Gold).dsk"} },
   {0x4d723f39, {"67c59e2d5086ad86808bfc4c61823293"}, {"Game Over (Dinamic Software) (Spain)/Game Over (1987)(Dinamic Software)(es).dsk"} },
   {0xe3ffbe7b, {"cd74ce9d9d0e2f793d2e422b2a18bcc5"}, {"Geoff Capes Strong Man (Martech)/Geoff Capes Strong Man (1985)(Martech)[tape].dsk"} },
   {0x2e4a23b2, {"10dbc93b89eb2769b9b5e20846a7b736"}, {"Galachip (Chip) (France)/Galachip (1985)(Chip)(fr)[cr].dsk"} },
   {0x880c2a34, {"6b36391ee4520a784ab3dd205d6ace23"}, {"Gremlins (Adventure International)/Gremlins (1985)(Adventure International)[cr].dsk"} },
   {0x8ceb4fa3, {"23762081dab77e438bd29ba648ef1e7e"}, {"Ghost 'n Goblins (Elite Systems)/Ghost 'n Goblins (1986)(Elite Systems)(v2).dsk"} },
   {0xd4279f25, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Galaxy Force (Activision)/Galaxy Force (1989)(Activision).dsk"} },
   {0x8e1d4e1d, {"482e6018441913a6bcdaf5ad6e31f05a"}, {"Guardian Angel, The (Dinamic Software)/Guardian Angel, The (1987)(Dinamic Software)[cr].dsk"} },
   {0x35e77f98, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Gremlins 2 (Topo Soft)/Gremlins 2 (1990)(Topo Soft).dsk"} },
   {0x7f1e18b6, {"f6178c27ae5cedbfa199a79f8f50689c"}, {"Gunship (Microprose Software)/Gunship (1988)(Microprose Software)(Side A).dsk"} },
   {0x1309e3e5, {"0e63b1ba0e54e4aba85cead7f21a9243"}, {"Gladiator (Domark)/Gladiator (1986)(Domark)[tape].dsk"} },
   {0xe3350811, {"db40108f209145c7c03580548d8c7530"}, {"Gunslinger (D. Walsh)/Gunslinger (1989)(D. Walsh)[cr].dsk"} },
   {0x9d449456, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gary Lineker's Super Star Soccer (Gremlin Graphics Software)/Gary Lineker's Super Star Soccer (1987)(Gremlin Graphics Software).dsk"} },
   {0x80d513f4, {"2566e57e3b6a50b3ff841803892d3977"}, {"Grumpy Gumphrey - Super Sleuth (Gremlin Graphics Software)/Grumpy Gumphrey - Super Sleuth (1986)(Gremlin Graphics Software)[cr].dsk"} },
   {0x82f434d2, {"40aba3adde227f7cc17b9bd7c210c53a"}, {"Glass (Quicksilva)/Glass (1986)(Quicksilva)[tape].dsk"} },
// {0xb10f45ff, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Get Dexter (ERE Informatique)/Get Dexter (1986)(ERE Informatique).dsk"} },
   {0x2ed04f45, {"d0f5b3f2779b103b325f8eb4fe5b13eb"}, {"Guardians (Loriciels)/Guardians (1991)(Loriciels).dsk"} },
   {0x83236163, {"cbcdc06930d2930aa114e9dd10649699"}, {"Grand Prix Tennis (Mastertronic)/Grand Prix Tennis (1988)(Mastertronic)[tape].dsk"} },
   {0x6a74fc40, {"1bf396462be9a86cc42e50491882b9d1"}, {"Gallitron (Mastertronic)/Gallitron (1987)(Mastertronic)[cr].dsk"} },
   {0x33365db0, {"1ae98d8a75add797d6f1d63f8049275a"}, {"Gyroscope (Melbourne House)/Gyroscope (1985)(Melbourne House)[cr].dsk"} },
   {0x2a17ecd1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Great Barrier Reef, The (The Power House)/Great Barrier Reef, The (1987)(The Power House)[cr].dsk"} },
   {0x6e0e3657, {"3c9acdbd8a175a901a390d52fbd15296"}, {"Grand Prix 500cc (Microids)/Grand Prix 500cc (1986)(Microids)[cr].dsk"} },
   {0xce1233f5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Gogly (Ace Software) (Spain)/Gogly (1986)(Ace Software)(es).dsk"} },
   {0x7a636b5b, {"5eff89e1dd92862531b3c3461358af7a"}, {"Good Moon (Micro Mag)/Good Moon (1990)(Micro Mag)[cr].dsk"} },
   {0x9ee0e36b, {"bab13dea89386349257055ae98fe0bb2"}, {"Galaxia (Kuma Computers)/Galaxia (1984)(Kuma Computers)[cr].dsk"} },
   {0x8c2dacf2, {"94f6ecd9da8fd4f664a428d7b90b29c1"}, {"Great Gurianos (Elite Systems)/Great Gurianos (1987)(Elite Systems)[cr].dsk"} },
   {0xe3862c26, {"6f399d6f1ce123a2d1a78aba2565b36b"}, {"Gauntlet (Micro Power)/Gauntlet (1985)(Micro Power)[cr].dsk"} },
   {0x860c4bbb, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Greyfell (Starlight Software) (Bugs)/Greyfell (1987)(Starlight Software)[b].dsk"} },
   {0x4f4ed2ca, {"a9e548a4e1537e65dd24c100ccb53fc2"}, {"Grid Trap (LiveWire Software)/Grid Trap (1985)(LiveWire Software)[tape].dsk"} },
   {0xa6483dd7, {"7dccfbc8a449265d5a93d10bd9ba5f47"}, {"Gravity (Schneider Magazin)/Gravity (1988)(Schneider Magazin)[cr].dsk"} },
// {0xc8d40fe6, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Globe-Trotter (Excalibur) (France)/Globe-Trotter (1986)(Excalibur)(fr)(Disk 1 Side A).dsk"} },
   {0xd75d55f7, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Gunsmoke (Topo Soft)/Gunsmoke (1987)(Topo Soft)(Side A).dsk"} },
   {0xf4ee9de8, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Ghostbusters II (Activision)/Ghostbusters II (1989)(Activision)(v2).dsk"} },
   {0x651b2e79, {"5d5181888a3b18a1221a659f489e3806"}, {"Gregory Loses his Clock (Mastertronic)/Gregory Loses his Clock (1985)(Mastertronic)[tape].dsk"} },
   {0xca159214, {"f6178c27ae5cedbfa199a79f8f50689c"}, {"Gunship (Microprose Software) (France)/Gunship (1988)(Microprose Software)(fr)(v3)(Side A).dsk"} },
   {0x47d2ab2c, {"53d23b4499982a5fd31efdaccee5aa5f"}, {"Grell and Falla (Codemasters Software)/Grell and Falla (1992)(Codemasters Software)[cr].dsk"} },
   {0x20786cf2, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Game of Dragons, The (Amsoft)/Game of Dragons, The (1985)(Amsoft).dsk"} },
   {0xad37a08f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Golden Axe (Virgin Games)/Golden Axe (1990)(Virgin Games)(Side A).dsk"} },
   {0xe819bc33, {"8f60ba20a06889164ca092a090ec268c"}, {"Growing Pains of Adrian Mole, The (Virgin Games)/Growing Pains of Adrian Mole, The (1987)(Virgin Games)[tape].dsk"} },
   {0x8bd6cfef, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Glider Rider (Quicksilva)/Glider Rider (1987)(Quicksilva).dsk"} },
   {0x8f51de4c, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"G-Log R360 (US Gold)/G-Log R360 (1991)(US Gold).dsk"} },
   {0xb131ce39, {"98f14b823df67a38bda32c63923c92b3"}, {"Ghost Hunters (Codemasters Software)/Ghost Hunters (1987)(Codemasters Software)[tape].dsk"} },
   {0x38a6771e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Guillermo Tell (Opera Soft) (Spain) (LightGun)/Guillermo Tell (1989)(Opera Soft)(es)(LightGun).dsk"} },
   {0xf020ee31, {"11336946033b26be4efa8f44302b41af"}, {"Grand Prix Simulator 2 (Codemasters Software)/Grand Prix Simulator 2 (1989)(Codemasters Software)[cr].dsk"} },
   {0x2071ce74, {"c68076620e353d3feae594cc90a2f4ca"}, {"GBA Championship Basketball (Activision)/GBA Championship Basketball (1987)(Activision).dsk"} },
   {0xdc1f7bd4, {"c68076620e353d3feae594cc90a2f4ca"}, {"GFL Championship Football (Activision)/GFL Championship Football (1987)(Activision).dsk"} },
   {0x795638dc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Goody (Opera Soft) (Spain) (Bugs)/Goody (1987)(Opera Soft)(es)[b].dsk"} },
   {0x7b14ade8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Golden Path (Amsoft)/Golden Path (1986)(Amsoft)(Side A).dsk"} },
   {0xc6d8fd83, {"3c9acdbd8a175a901a390d52fbd15296"}, {"Grand Prix Driver (Amsoft)/Grand Prix Driver (1984)(Amsoft)[tape].dsk"} },
   {0x067924d3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gary Lineker's Super Skills (Gremlin Graphics Software)/Gary Lineker's Super Skills (1988)(Gremlin Graphics Software).dsk"} },
   {0x966760b8, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Gauntlet III - The Final Quest (US Gold)/Gauntlet III - The Final Quest (1991)(US Gold)(Side A).dsk"} },
   {0xe7c2bbbb, {"aa1d84e682cf367ac4a53f93f958143c"}, {"Gremlins (Adventure International) (de)/Gremlins (1985)(Adventure International)(de)[cr].dsk"} },
// {0xb49849a5, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Glen Hoddle Soccer (Amsoft)/Glen Hoddle Soccer (1985)(Amsoft).dsk"} },
   {0x79911402, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Gothik (Firebird)/Gothik (1987)(Firebird).dsk"} },
   {0x37d695f7, {"9ebb582b071facdc334cd5acee9d8dcf"}, {"Gusanin (Your Computer) (Spain)/Gusanin (1985)(Your Computer)(es)[cr].dsk"} },
   {0xa1d8563c, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Gary Lineker's Hot-Shot! (Gremlin Graphics Software)/Gary Lineker's Hot-Shot! (1988)(Gremlin Graphics Software).dsk"} },
   {0xb458d701, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gonzzalezz (Opera Soft) (Spain)/Gonzzalezz (1989)(Opera Soft)(es)(v2).dsk"} },
   {0x6d128285, {"a34b9b34a0356c6232d6da02e83d3965"}, {"Grand Prix 500cc 2 (Microids)/Grand Prix 500cc 2 (1991)(Microids).dsk"} },
   {0xfe56bf61, {"08316e0566cd5d8fc4329d676808b379"}, {"Gunfright (Ultimate Play The Game)/Gunfright (1985)(Ultimate Play The Game)[tape].dsk"} },
   {0x1b99bbeb, {"bc96136f5b111df312c7cba96147c0eb"}, {"Goblin Towers (Supersoft)/Goblin Towers (1986)(Supersoft)[cr].dsk"} },
   {0x0900cf93, {"9ce5fcea97206a94cd82df16a9f611d1"}, {"Graham Gooch's Test Cricket (Audiogenic Software LTD)/Graham Gooch's Test Cricket (1985)(Audiogenic Software LTD).dsk"} },
   {0x12851664, {"abb7a174fb497d6854f2f8a59c5f2340"}, {"Gilligan's Gold (Ocean)/Gilligan's Gold (1984)(Ocean)[tape].dsk"} },
   {0xc0c97733, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Gemini Wing (Virgin Games)/Gemini Wing (1989)(Virgin Games).dsk"} },
   {0x18d12379, {"f098c7b231624243f81c5adadb7cf010"}, {"Galactic Conqueror (Titus)/Galactic Conqueror (1988)(Titus).dsk"} },
   {0x751d7ef6, {"f88faf699ebb36d9023074a7b43dd871"}, {"Genghis Khan (Positive)/Genghis Khan (1991)(Positive)[tape].dsk"} },
   {0x7c16d340, {"0f3ce766494c244fb3e069ee60809d95"}, {"Gauntlet (US Gold)/Gauntlet (1986)(US Gold)[f].dsk"} },
   {0x2cb38fd9, {"aa1d84e682cf367ac4a53f93f958143c"}, {"Gremlins (Adventure International) (Spain)/Gremlins (1985)(Adventure International)(es)[cr].dsk"} },
   {0x17258623, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Guerrilla War (Ocean Software)/Guerrilla War (1988)(Ocean Software).dsk"} },
   {0x193505d0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Grand Prix Circuit (Accolade)/Grand Prix Circuit (1990)(Accolade).dsk"} },
   {0x6e5c49bc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Heritage, 'L (Infogrames) (France)/Heritage, 'L (1986)(Infogrames)(fr).dsk"} },
   {0xb6fcedc6, {"7b60496907b61010ea1a96cd5254443b"}, {"Highlander (Ocean Software)/Highlander (1986)(Ocean Software)[cr].dsk"} },
   {0x5d038c8e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Heroes of the Lance (US Gold) (Codes)/Heroes of the Lance (1988)(US Gold)(Side A)[codes].dsk"} },
   {0x4e6c1074, {"a9cde91fcd8c0ac0a3f888b7befff54b"}, {"Hawk Storm (Players Premier)/Hawk Storm (1990)(Players Premier)[cr].dsk"} },
   {0x40c18e7e, {"ab3acbcdc880577ea2759abf436dcdff"}, {"Hyper Sports (Ocean Software)/Hyper Sports (1985)(Ocean Software).dsk"} },
   {0x10283d11, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hydrofool (FTL)/Hydrofool (1987)(FTL).dsk"} },
   {0xefa922a7, {"a77b1e8f6fb1f45bad8debc67ae9e1dd"}, {"Hive (Firebird)/Hive (1987)(Firebird).dsk"} },
   {0xffd6fb47, {"29fa12c6765ce5a4eb109669a5741868"}, {"Harricana (Loriciels) (France)/Harricana (1990)(Loriciels)(fr).dsk"} },
   {0x2aa3ef0f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hammerfist (Activision)/Hammerfist (1990)(Activision).dsk"} },
   {0x555335b1, {"be722c6e2915f1e56c890cf700f0c7bf"}, {"Hunt for Red October, The - Based on the Movie (Grandslam Entertainments)/Hunt for Red October, The - Based on the Movie (1991)(Grandslam Entertainments)(Side A).dsk"} },
   {0x522cb62f, {"c68076620e353d3feae594cc90a2f4ca"}, {"Howard the Duck (Activision)/Howard the Duck (1987)(Activision).dsk"} },
   {0x2eee44c4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hostages - Operation Jupiter (Infogrames)/Hostages - Operation Jupiter (1990)(Infogrames)(v2)(Side A).dsk"} },
   {0x6f3f1177, {"973c16c287c846add02cb0bf909ffbab"}, {"High Epidemy (FIL) (France)/High Epidemy (1988)(FIL)(fr).dsk"} },
   {0x5256fc2f, {"64469ba75134da338251d3967abd5717"}, {"Highway Patrol II (Microids)/Highway Patrol II (1989)(Microids).dsk"} },
   {0xca1ccfa9, {"bbbf40679d019c955fa0bc68ffbcbd3a"}, {"Hair Boy (cpcretrodev.byterealms)/Hair Boy (2016)(cpcretrodev.byterealms)[cr].dsk"} },
   {0x134e83f6, {"c68076620e353d3feae594cc90a2f4ca"}, {"Hibernated 1 This Place Is Death - Directors Cut (Puddle Soft)/Hibernated 1 This Place Is Death - Directors Cut (2022)(Puddle Soft).dsk"} },
// {0xdc7e4115, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Hustler (Bubblebus Software)/Hustler (1985)(Bubblebus Software).dsk"} },
   {0xb9126a6e, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Human Killing Machine (US Gold)/Human Killing Machine (1989)(US Gold).dsk"} },
   {0x881760cc, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Heilige Rustung Des Antiriad, Die (Palace Software) (de)/Heilige Rustung Des Antiriad, Die (1986)(Palace Software)(de).dsk"} },
   {0x61e8492a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hexenkueche - Cauldron (Palace Software) (de)/Hexenkueche - Cauldron (1985)(Palace Software)(de).dsk"} },
   {0x1551412e, {"ec4ff681d2fd8f0e5b5360ec1d5b6e95"}, {"Han d'Islande (Loriciels) (France)/Han d'Islande (1988)(Loriciels)(fr)(Side A).dsk"} },
   {0xbda5bdfa, {"cef1a0ddb953f63dd46a67cc72474acb"}, {"Harvey Headbanger (Firebird)/Harvey Headbanger (1986)(Firebird)(v5-86)[cr].dsk"} },
   {0x9f193c0a, {"e63b020d6a459fe66bda54bb3f7a0766"}, {"Holiday, The (Amstrad Adventure PD Library)/Holiday, The (19xx)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0x1dbdfde0, {"8f18354124369343ad35c016d2cc10be"}, {"Hounds of Hell (Wow Software)/Hounds of Hell (19xx)(Wow Software)[cr].dsk"} },
   {0xc01f31d7, {"e431e7d9e7ba0cd0ac8629eefda09fe5"}, {"Halls of the Things (Design Design)/Halls of the Things (1985)(Design Design)[cr].dsk"} },
   {0x57c09d73, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hirise (Bubble Bus Software)/Hirise (1986)(Bubble Bus Software).dsk"} },
   {0xe32fb98b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hot-Rod (Activision)/Hot-Rod (1990)(Activision).dsk"} },
   {0x0b6efce2, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Heavy On the Magick (Gargoyle Games)/Heavy On the Magick (1986)(Gargoyle Games).dsk"} },
   {0x0b157fed, {"303f87d2186b296f316bd81c70bdf582"}, {"High Epidemy (FIL)/High Epidemy (1988)(FIL)[cr].dsk"} },
   {0x744472d3, {"dedb596bc2de23c4424590d53287103e"}, {"Heroes of Karn (Interceptor Software)/Heroes of Karn (1984)(Interceptor Software)[cr].dsk"} },
   {0x3f6dbd27, {"397d12a922488a8264228c56916d445a"}, {"Harry & Harry - Mission Torpedo (ERE Informatique) (France)/Harry & Harry - Mission Torpedo (1986)(ERE Informatique)(fr)(Side A).dsk"} },
   {0xa59bc588, {"284b8e3bce273b72097cc98ecbb45ddc"}, {"Holocauste (MBC Informatique) (France)/Holocauste (1988)(MBC Informatique)(fr)(Side A).dsk"} },
   {0x5b80efe4, {"a1784192e2e0282582af6e8a178cedc0"}, {"Hero of the Golden Talisman (Mastertronic)/Hero of the Golden Talisman (1986)(Mastertronic)[cr].dsk"} },
   {0xa27228c7, {"7d7351221a614782ddb6442c0c50791e"}, {"Hundra (Dinamic Software)/Hundra (1987)(Dinamic Software)[cr][f].dsk"} },
   {0x32461d45, {"08faa953a15fe7fea33f7afecc0c8902"}, {"Horloger 2, L' (Amsoft)/Horloger 2, L' (1984)(Amsoft)[cr].dsk"} },
   {0x8f438125, {"f99cd9c74030ab08611ce6ca09210368"}, {"Herbert's Dummy Run (Mikrogen) (Spain)/Herbert's Dummy Run (1986)(Mikrogen)(es)[cr].dsk"} },
   {0xb789e864, {"621fa6a1e4f36d51410b74f9e08efc11"}, {"Heli-Bomber (Pan Books)/Heli-Bomber (1984)(Pan Books)[cr].dsk"} },
   {0x11ba9fce, {"c68076620e353d3feae594cc90a2f4ca"}, {"Hotshot (Addictive Games)/Hotshot (1988)(Addictive Games).dsk"} },
   {0x57fec6ae, {"5d20c873d41210a706314ad2af1817e7"}, {"High Noon (Locomotive Soft)/High Noon (1984)(Locomotive Soft)[cr].dsk"} },
   {0x5c1309e4, {"f99cd9c74030ab08611ce6ca09210368"}, {"Herbert's Dummy Run (Mikrogen)/Herbert's Dummy Run (1986)(Mikrogen)[cr].dsk"} },
   {0xac7d53f0, {"bdf19afc00a6e3ca141458d58838566d"}, {"Hyperspace (Cobra Soft) (France)/Hyperspace (1985)(Cobra Soft)(fr)[cr].dsk"} },
   {0x1a97c01b, {"b03b17af7098f48c8c0006e7cc6b11f5"}, {"Hacker (Activision)/Hacker (1985)(Activision).dsk"} },
   {0x154002ca, {"635d5194811989fa42696d7b6fc9c86c"}, {"Hi Q Quiz (CDS Software LTD)/Hi Q Quiz (1989)(CDS Software LTD)[cr].dsk"} },
   {0x4d10c25d, {"c68076620e353d3feae594cc90a2f4ca"}, {"High Frontier (Activision)/High Frontier (1987)(Activision).dsk"} },
// {0x47f7f71f, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Hamsters en Folie (Generation 5) (France)/Hamsters en Folie (1989)(Generation 5)(fr).dsk"} },
   {0xafe22434, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hero Quest (Gremlin Graphics Software) (France)/Hero Quest (1991)(Gremlin Graphics Software)(fr).dsk"} },
   {0xb956fda4, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Hybrid (Starlight Software)/Hybrid (1987)(Starlight Software).dsk"} },
   {0x52f69491, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hero Quest - Return of the Witchlord (Gremlin Graphics Software) (France)/Hero Quest - Return of the Witchlord (1991)(Gremlin Graphics Software)(fr)(extension).dsk"} },
   {0x55e8ece1, {"c574c0a51586c385793a456f6303d186"}, {"Horloger 2, L' (Amsoft) (France)/Horloger 2, L' (1984)(Amsoft)(fr)[cr].dsk"} },
   {0xa523527c, {"b6fbb954e21604ec087938bd2238fcb2"}, {"Hitchhiker's Guide to the Galaxy, The (Infocom)/Hitchhiker's Guide to the Galaxy, The (1984)(Infocom)[CPM].dsk"} },
   {0x0762a657, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Harrier Attack! (Amsoft)/Harrier Attack! (1984)(Amsoft).dsk"} },
   {0x3f3dd360, {"bdf19afc00a6e3ca141458d58838566d"}, {"Hyperbowl (Mastertronic)/Hyperbowl (1986)(Mastertronic)[cr].dsk"} },
   {0xa8a6bfd6, {"c68076620e353d3feae594cc90a2f4ca"}, {"Hammer Boy (Dinamic Software)/Hammer Boy (1991)(Dinamic Software)[f].dsk"} },
   {0x74452b0e, {"23762081dab77e438bd29ba648ef1e7e"}, {"Hopping Mad (Elite Systems)/Hopping Mad (1988)(Elite Systems).dsk"} },
   {0x6552a91a, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Hate (Gremlin Graphics Software)/Hate (1989)(Gremlin Graphics Software).dsk"} },
   {0x386ab47d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hero Quest - Return of the Witchlord (Gremlin Graphics Software) (Spain)/Hero Quest - Return of the Witchlord (1991)(Gremlin Graphics Software)(es)(extension).dsk"} },
   {0x9594c53f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hudson Hawk (Ocean)/Hudson Hawk (1991)(Ocean).dsk"} },
   {0xb3882b69, {"3e4844229d002feae877bfa9e44e3b2f"}, {"Hagar (Micro Mag)/Hagar (1989)(Micro Mag)[cr].dsk"} },
   {0x045c9620, {"3719172eab2107cd647af5f1b7ea11c5"}, {"Hollywood Hijinx (Infocom)/Hollywood Hijinx (1986)(Infocom)[CPM].dsk"} },
   {0xf8652e9e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hypsys (Dro Soft)/Hypsys (1989)(Dro Soft).dsk"} },
   {0x0cfb850e, {"a8ee15fe257242412aee8e559cbb866b"}, {"House of Usher (Anirog Software)/House of Usher (1984)(Anirog Software)[cr].dsk"} },
   {0xc613efa0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Head over Heels (Ocean Software)/Head over Heels (1987)(Ocean Software).dsk"} },
   {0x1bee658e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hunt for Red October, The (Grandslam)/Hunt for Red October, The (1987)(Grandslam).dsk"} },
   {0xc7b23244, {"5843e85f9db9f4cb395fe5baea2fab38"}, {"Hunchback - The Adventure (Ocean Software)/Hunchback - The Adventure (1986)(Ocean Software).dsk"} },
   {0x6863c03f, {"1edbe21d9ecff623cddb859a37980e87"}, {"Horloger 1, L' (Amsoft) (France)/Horloger 1, L' (1984)(Amsoft)(fr)[cr].dsk"} },
   {0x8c03c2c1, {"c68076620e353d3feae594cc90a2f4ca"}, {"Hacker (Activision) (de)/Hacker (1985)(Activision)(de).dsk"} },
   {0xc7f2552b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hundra (Dinamic Software) (Spain)/Hundra (1987)(Dinamic Software)(es).dsk"} },
   {0xa20e5157, {"1682dcd1b630f00a9a13d55e09aaf6a0"}, {"Hal (CPC Infos) (France)/Hal (1992)(CPC Infos)(fr)[cr].dsk"} },
   {0xf1fff06c, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hero Quest - Return of the Witchlord (Gremlin Graphics Software)/Hero Quest - Return of the Witchlord (1991)(Gremlin Graphics Software)(extension).dsk"} },
   {0x13210179, {"1b9c0fd73e3c40b5becc7050a4dd1318"}, {"Halls of Gold (Rainbow Arts)/Halls of Gold (1986)(Rainbow Arts).dsk"} },
   {0xbbbf68bb, {"a34fef79155cced1e31f5461a962fe86"}, {"How to be a Hero (Mastertronic)/How to be a Hero (1987)(Mastertronic)[cr].dsk"} },
   {0x74b874e2, {"d966181e47673bfc2189be56e4e4b130"}, {"Hawaii (Excalibur) (France)/Hawaii (1987)(Excalibur)(fr)(Side A)[cr].dsk"} },
   {0x6f9312fa, {"bdf19afc00a6e3ca141458d58838566d"}, {"Hyperspace - Time-Space Adventures (Cobra Soft) (Hack)/Hyperspace - Time-Space Adventures (2019)(Cobra Soft)(Hack)[cr].dsk"} },
   {0xe468e3e7, {"b7edf0618596f93ca3de7c39a8f2e448"}, {"Haunted Hedges (Amsoft)/Haunted Hedges (1984)(Amsoft)[cr].dsk"} },
   {0x257af370, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hero Quest (Gremlin Graphics Software) (Spain) (Bugs)/Hero Quest (1991)(Gremlin Graphics Software)(es)[b].dsk"} },
   {0x86f6acfb, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hydra (Domark)/Hydra (1991)(Domark)(Side A).dsk"} },
   {0x18173be7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hard Drivin' (Domark)/Hard Drivin' (1989)(Domark).dsk"} },
   {0xbb282a41, {"016920389600e72c8520027dea5aa3c4"}, {"Hobbit, The (Melbourne House)/Hobbit, The (1985)(Melbourne House).dsk"} },
   {0xdc0c5b25, {"00e50fe9c41faee727cfc791a1ad71a1"}, {"Herobotix (Hewson)/Herobotix (1988)(Hewson)[cr].dsk"} },
   {0x3d8657f8, {"3bfbcfc678513a3912b5ee8e62b453aa"}, {"House Of Spiders (Computing With The Amstrad)/House Of Spiders (1988)(Computing With The Amstrad)[cr].dsk"} },
   {0x1828a382, {"7b92fec41e8b7c2199294365d135225b"}, {"How to be a Complete Bastard (Virgin Games)/How to be a Complete Bastard (1987)(Virgin Games)[cr].dsk"} },
   {0x89713649, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hijack (Activision)/Hijack (1986)(Activision).dsk"} },
   {0xb73aff3e, {"a5f792bd73318d2c1fd2ccd1c0d71b12"}, {"Hold Up (ERE Informatique) (France)/Hold Up (1984)(ERE Informatique)(fr)[cr].dsk"} },
   {0xeaefa043, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hunt for Red October, The (Grandslam) (de)/Hunt for Red October, The (1987)(Grandslam)(de).dsk"} },
   {0xd4e66999, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hamil (Jonathan Partington)/Hamil (1987)(Jonathan Partington)[cr].dsk"} },
   {0xc48ea9ad, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Hexenkueche II - Cauldron II (Palace Software) (de)/Hexenkueche II - Cauldron II (1986)(Palace Software)(de).dsk"} },
   {0xb8798b87, {"d14e5ec3c830711b411ef9c7271bef94"}, {"Hard Hat Mack (Electronic Arts)/Hard Hat Mack (1983)(Electronic Arts)[cr].dsk"} },
   {0x2e5e1912, {"64469ba75134da338251d3967abd5717"}, {"Highway Patrol (Microids)/Highway Patrol (1989)(Microids).dsk"} },
// {0x083c9554, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Helter Skelter (Audiogenic Software)/Helter Skelter (1990)(Audiogenic Software)(Side A).dsk"} },
   {0x60d38d8a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Highway Encounter (Vortex Software)/Highway Encounter (1985)(Vortex Software).dsk"} },
   {0x37376eba, {"2ab451fc74587caf0e0adcbb4f41dbf7"}, {"Hurlements (Ubi Soft) (France)/Hurlements (1988)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xe842ba0a, {"bdf19afc00a6e3ca141458d58838566d"}, {"Hyperspace - Aventures Spatio-Temporelles (Cobra Soft) (Spain) (Hack)/Hyperspace - Aventures Spatio-Temporelles (2018)(Cobra Soft)(es)(Hack)[cr].dsk"} },
   {0xaa82fa6c, {"f209b1f5b111e1430eefc56603a96e8e"}, {"Helicoptero 2000 (Interceptor Software)/Helicoptero 2000 (1985)(Interceptor Software)[cr].dsk"} },
   {0xec279622, {"0f3ce766494c244fb3e069ee60809d95"}, {"Hero Quest (Gremlin Graphics Software)/Hero Quest (1991)(Gremlin Graphics Software).dsk"} },
   {0x542c8788, {"9d7c344c214928deb2f923d728681631"}, {"Histo Quizz (Cobra Soft) (France)/Histo Quizz (1985)(Cobra Soft)(fr)[cr].dsk"} },
   {0xa4e3d8ff, {"124f95a77ed42084a767d1d8081382c9"}, {"Havoc (Players)/Havoc (1990)(Players)[cr].dsk"} },
   {0x53fdb930, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Histoire d'Or (Cobra Soft) (France)/Histoire d'Or (1987)(Cobra Soft)(fr)(Side A).dsk"} },
   {0x45b84584, {"397d12a922488a8264228c56916d445a"}, {"Harry & Harry - La Boite De Rajmahal (ERE Informatique) (France)/Harry & Harry - La Boite De Rajmahal (1986)(ERE Informatique)(fr)(Side A).dsk"} },
   {0xb165c326, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Hercules - Slayer of the Damned (Gremlin Graphics Software)/Hercules - Slayer of the Damned (1988)(Gremlin Graphics Software).dsk"} },
   {0x357e7b6e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hardball (Accolade)/Hardball (1986)(Accolade)(Side A).dsk"} },
   {0xfa3063d0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hunter-Killer (Amsoft)/Hunter-Killer (1984)(Amsoft).dsk"} },
   {0x3abecdc4, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Hunchback (Amsoft)/Hunchback (1985)(Amsoft).dsk"} },
// {0xc34b7449, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Heartland (Odin Computer Graphics)/Heartland (1986)(Odin Computer Graphics).dsk"} },
   {0x759c1c27, {"233075ee8b240d272263e3cbbfef3dd1"}, {"Horloger 1, L' (Amsoft)/Horloger 1, L' (1984)(Amsoft)[cr].dsk"} },
   {0xe211e4bc, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"High Steel (Screen 7)/High Steel (1989)(Screen 7).dsk"} },
   {0x90668523, {"216d133fa911e780dbd46958933fca88"}, {"Hopital Danger (B. & J. Dissoubret) (France)/Hopital Danger (1989)(B. & J. Dissoubret)(fr)(Side A)(PD)[cr].dsk"} },
   {0x66ebc2c6, {"4f9a234cdd76f96a3e03f529ff03bcd1"}, {"Humphrey (Zigurat Software) (Spain)/Humphrey (1988)(Zigurat Software)(es)[cr].dsk"} },
   {0x3005eb3a, {"4737dfdf7697165c3ad353c8bf8758fe"}, {"Inside Outing (The Edge)/Inside Outing (1987)(The Edge).dsk"} },
   {0x52149225, {"d12a7243265d4700f63ea1f48852f4d0"}, {"Impact (Audiogenic Software LTD)/Impact (1988)(Audiogenic Software LTD).dsk"} },
   {0xfecc5418, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Impossible Mission (Epyx)/Impossible Mission (1986)(Epyx).dsk"} },
   {0x56780bdd, {"2452ab44e5bbfce980d1668a7d5be693"}, {"Interieur (Sprites) (France)/Interieur (1985)(Sprites)(fr).dsk"} },
   {0x2367f5fa, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Italy 1990 (US Gold)/Italy 1990 (1990)(US Gold).dsk"} },
   {0x280ba9a9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Impossamole (Gremlin Graphics Software)/Impossamole (1990)(Gremlin Graphics Software).dsk"} },
   {0x9106f3ee, {"b69ba782898717b6f59c9cb7e79ac5ac"}, {"Interdictor Pilot (Supersoft)/Interdictor Pilot (1985)(Supersoft).dsk"} },
   {0x6c640566, {"07426f4977cbf962dc0989fc98339429"}, {"Indoor Bowling (Alligata Software)/Indoor Bowling (1987)(Alligata Software)[cr].dsk"} },
   {0xaae46015, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Italia '90 - World Cup Soccer (Virgin Games)/Italia '90 - World Cup Soccer (1990)(Virgin Games).dsk"} },
   {0x6caa4a16, {"143a1d6ee3127e6466f497a8c709e6a3"}, {"International Rugby (Artic Computing)/International Rugby (1985)(Artic Computing)[cr].dsk"} },
   {0xed170c44, {"799abe7c51adcf48d8e40220e6a5b1cf"}, {"Infiltrator (US Gold)/Infiltrator (1986)(US Gold).dsk"} },
   {0x2c7b0274, {"40e38032bb00d6767837d8ae237f5684"}, {"Ishido (Fraggle)/Ishido (1991)(Fraggle)[cr].dsk"} },
   {0x2ccbca1d, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Ingrid's Back (Level 9 Computing)/Ingrid's Back (1988)(Level 9 Computing)(Side A).dsk"} },
   {0xcacc038a, {"d81072cee3493c977401645683473fa7"}, {"Into Oblivion (Mastertronic)/Into Oblivion (1986)(Mastertronic)[cr].dsk"} },
   {0xc3ce5121, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Ivan 'Ironman' Stewart's Super Off Road (Virgin Games)/Ivan 'Ironman' Stewart's Super Off Road (1990)(Virgin Games).dsk"} },
   {0xdc3c19fc, {"57b0862132c2f649cebca495c6d7681f"}, {"Infidel (Infocom)/Infidel (1986)(Infocom)[CPM].dsk"} },
   {0x453b613c, {"65d5a632dcd9ca36b1d49237a26c1de3"}, {"Ice Guardian, The (Strategy Software)/Ice Guardian, The (1991)(Strategy Software)(Side A)[cr].dsk"} },
// {0x1ac09f99, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Infernal House (Lankhor) (France)/Infernal House (1991)(Lankhor)(fr)(Side A).dsk"} },
   {0x36d943ea, {"91a3fdd14eccb6be84ef177ae6592fcc"}, {"Ikari Warriors (Elite Systems)/Ikari Warriors (1988)(Elite Systems)(v2).dsk"} },
   {0xb3e18f77, {"39f1c366dfce197f28fbc65d979f90c5"}, {"It's a Knockout (Ocean Software)/It's a Knockout (1986)(Ocean Software)[cr].dsk"} },
   {0x779bf2ae, {"dc8ccc965a203ead5cadadddc36de8d6"}, {"Indoor Soccer (Codemasters Software)/Indoor Soccer (1989)(Codemasters Software)[cr].dsk"} },
   {0x586c9898, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Indiana Jones and the Last Crusade (US Gold) (Codes)/Indiana Jones and the Last Crusade (1989)(US Gold)(v3)[codes].dsk"} },
   {0x8e6f3981, {"3628660577c4c6e792ddc2e79708c86c"}, {"Indoor Soccer (Magnificent 7)/Indoor Soccer (1986)(Magnificent 7)[cr].dsk"} },
   {0xe6183529, {"9aba99418900e6538e785f5e62e1a057"}, {"Infernal Runner (Loriciels) (France)/Infernal Runner (1985)(Loriciels)(fr).dsk"} },
   {0x55b67795, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Ice Breaker (Topo Soft) (Spain)/Ice Breaker (1990)(Topo Soft)(es).dsk"} },
   {0x67048019, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Iron Trackers (Microids)/Iron Trackers (1989)(Microids)(Side A).dsk"} },
   {0xcee8a8bd, {"ad1447bb5018153880d2d245dfb5f7f5"}, {"Infection (Virgin Mastertronic)/Infection (1989)(Virgin Mastertronic)(Prototype)[cr].dsk"} },
   {0x3ea95ce1, {"26fff3fdaee0edacc1782b9d851abbf2"}, {"Incantation (Softhawk) (France)/Incantation (1987)(Softhawk)(fr)(Side A).dsk"} },
   {0xbf064b59, {"0f3ce766494c244fb3e069ee60809d95"}, {"Iznogoud (Infogrames) (France)/Iznogoud (1987)(Infogrames)(fr).dsk"} },
   {0x51a3e14d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Impossaball (Hewson)/Impossaball (1987)(Hewson).dsk"} },
   {0x111ad278, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Inhumanos, Los (Delta Software) (Spain)/Inhumanos, Los (1990)(Delta Software)(es).dsk"} },
   {0xf6eda395, {"a7cbb8cb68ff21d17cba051e38898087"}, {"Imagination (Firebird)/Imagination (1987)(Firebird)[cr].dsk"} },
   {0x6cdf1485, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Impossible Mission II (Epyx)/Impossible Mission II (1988)(Epyx).dsk"} },
   {0x3febcdf8, {"6f941d504259a5fba1646d7636adc2aa"}, {"Ile Oubliee, L' (Bruno Fonters) (France)/Ile Oubliee, L' (1993)(Bruno Fonters)(fr)(Side A).dsk"} },
   {0x7b3fe8d4, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Icon Jon (Mirrorsoft)/Icon Jon (1986)(Mirrorsoft).dsk"} },
   {0xd189e414, {"3efaadf72aec501c339244aa47e37cb9"}, {"Ice Temple, The (CDS Software LTD)/Ice Temple, The (1989)(CDS Software LTD)[cr].dsk"} },
   {0x298e8919, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Inquisitor - Shade of Swords (Chip) (France)/Inquisitor - Shade of Swords (1988)(Chip)(fr).dsk"} },
   {0xf08c5b1c, {"a856fff631de66b366e807994c38779c"}, {"Italian Supercar (Codemasters Software)/Italian Supercar (1990)(Codemasters Software)[tape].dsk"} },
   {0x730747d5, {"58d4cb80d2d835c48198774eac288daa"}, {"Il Etait Une Fois (Carraz Editions) (France)/Il Etait Une Fois (1989)(Carraz Editions)(fr).dsk"} },
   {0xce9761b5, {"c68076620e353d3feae594cc90a2f4ca"}, {"International Karate+ (System 3)/International Karate+ (1988)(System 3).dsk"} },
   {0xfb7739c8, {"89ad6890d48495ec660b83dd04b5a36c"}, {"Iron Lord (Ubi Soft) (France)/Iron Lord (1990)(Ubi Soft)(fr)(Disk 1 Side A).dsk"} },
   {0x7d127037, {"c68076620e353d3feae594cc90a2f4ca"}, {"ISS - Incredible Shrinking Sphere (Activision)/ISS - Incredible Shrinking Sphere (1989)(Activision).dsk"} },
   {0x036182ae, {"fcd88017c6c63b85d714f4e3edf03034"}, {"Island (WiteKB)/Island (2002)(WiteKB)(PD)[cr].dsk"} },
   {0x6794c6c6, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Into the Eagle's Nest (Pandora)/Into the Eagle's Nest (1987)(Pandora).dsk"} },
   {0xc5b314e4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Inheritance, The (Infogrames)/Inheritance, The (1987)(Infogrames).dsk"} },
   {0xfb866692, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Indiana Jones and the Temple of Doom (US Gold)/Indiana Jones and the Temple of Doom (1987)(US Gold).dsk"} },
   {0x6ffd24c3, {"bbe1fad09e559d043ea5a423f73b4182"}, {"Ian Botham's Test Match (Tynesoft)/Ian Botham's Test Match (1985)(Tynesoft)[cr].dsk"} },
   {0xe3bb11ec, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Infodroid (Beyond Software)/Infodroid (1986)(Beyond Software).dsk"} },
   {0xadb50c58, {"765385c08f5db40359f6f602ed9ce98f"}, {"I, Ball II - Quest for the Past (Firebird)/I, Ball II - Quest for the Past (1987)(Firebird)[cr].dsk"} },
   {0xe5c9f091, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"International 3D Tennis (Palace Software)/International 3D Tennis (1990)(Palace Software)(v2).dsk"} },
   {0x5084e823, {"fe7f98785e5d4fcc3bd7bca881bdaef8"}, {"Inertie (Ubi Soft) (France)/Inertie (1987)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xdaaa48ae, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"International Karate (Endurance Games)/International Karate (1986)(Endurance Games).dsk"} },
   {0xaf33badf, {"ed4681be035fcc886ab226118b3d00af"}, {"Island of Dr. Destructo, The (Mastertronic)/Island of Dr. Destructo, The (1987)(Mastertronic)[cr].dsk"} },
   {0x77d9ca8d, {"cec2b53dfccf090653ce330aac71b831"}, {"Isoleur (Sprites) (France)/Isoleur (1985)(Sprites)(fr)[cr].dsk"} },
   {0x0c735354, {"0f3ce766494c244fb3e069ee60809d95"}, {"Island, The (The Adventure Workshop)/Island, The (1985)(The Adventure Workshop).dsk"} },
   {0x56af7f27, {"382ca8fe549743e3499588b61a52fa2a"}, {"Indoor Sports (Design Star Consultants)/Indoor Sports (1987)(Design Star Consultants).dsk"} },
   {0x8fb048a1, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Indiana Jones and the Fate of Atlantis (US Gold)/Indiana Jones and the Fate of Atlantis (1993)(US Gold)(Side A).dsk"} },
   {0x13823a00, {"50c82db4c7860901382d445f245b57a5"}, {"I, Ball (Firebird)/I, Ball (1987)(Firebird)[cr][f].dsk"} },
   {0xf578d894, {"be52d8035af41404fce0d72bfead4630"}, {"Isotopes (Amstrad Action)/Isotopes (1988)(Amstrad Action)[cr].dsk"} },
   {0x96423d08, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"International Rugby Simulator (Codemasters Software) (Bugs)/International Rugby Simulator (1988)(Codemasters Software)[b].dsk"} },
   {0x034de766, {"a50e2756b25efddb2332d05b930b47ef"}, {"Joe Blade 3 (Players Premier)/Joe Blade 3 (1989)(Players Premier)[cr][f].dsk"} },
// {0x21de51e7, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"James Debug - Mystere de l'Ile Perdue (Coktel Vision)/James Debug - Mystere de l'Ile Perdue (1986)(Coktel Vision).dsk"} },
   {0x23dcdb6b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Jetsons, The (Hi-Tec Software)/Jetsons, The (1992)(Hi-Tec Software).dsk"} },
   {0xff3ada47, {"4d25f348f66fbd986070d62b9b5a63c3"}, {"Jungle Jane (Bug-Byte)/Jungle Jane (1986)(Bug-Byte)[cr][464].dsk"} },
   {0xe76f838a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Jai Alai (Opera Soft) (Spain) (Codes)/Jai Alai (1991)(Opera Soft)(es)[codes].dsk"} },
   {0xc0fb0b5b, {"23981a52854f0b8f2dad242a5572b966"}, {"Joe Blade 2 (Players)/Joe Blade 2 (1988)(Players)[cr].dsk"} },
   {0x7d18254a, {"4341b514ecd38d6fe6ce6699a5a7d7d7"}, {"Jewels of Babylon, The (Interceptor Software)/Jewels of Babylon, The (1984)(Interceptor Software)[cr].dsk"} },
   {0xcc600d0b, {"4b67b0162113dd5034169caf933c0174"}, {"Jocky Wilson's Compendium of Darts (Zeppelin Games)/Jocky Wilson's Compendium of Darts (1990)(Zeppelin Games)[cr].dsk"} },
   {0x9ac75672, {"eeae63e96bb267cd52e263e8658ece4b"}, {"Jack the Ripper (CRL Group)/Jack the Ripper (1988)(CRL Group)[cr].dsk"} },
   {0x269f0d8a, {"6a01d7a08ddb20e4d41697f67f95c841"}, {"Jet Set Willy (Software Projects)/Jet Set Willy (1985)(Software Projects)[cr].dsk"} },
   {0xe0da82c4, {"6f941d504259a5fba1646d7636adc2aa"}, {"Jet Bike Simulator (Codemasters Software)/Jet Bike Simulator (1988)(Codemasters Software).dsk"} },
   {0x9f177d9b, {"92056f3392eb909b7dc0564b743a18fa"}, {"Jinxter (Rainbird Software)/Jinxter (1988)(Rainbird Software)(Side A).dsk"} },
   {0xccc3a70b, {"5de52f2c7dd9863b6a2630692a19e7cc"}, {"Jungle Book (Coktel Vision)/Jungle Book (1989)(Coktel Vision)(Side A).dsk"} },
   {0xf4548f27, {"0f3ce766494c244fb3e069ee60809d95"}, {"Jahangir Khan World Championship Squash (Krisalis Software) (M3)/Jahangir Khan World Championship Squash (1991)(Krisalis Software)(M3)(Side A)[Club].dsk"} },
   {0xcc18789c, {"f0586393de78c41494d5b32633a7c74a"}, {"Jet-Boot Jack (Amsoft)/Jet-Boot Jack (1984)(Amsoft)[tape].dsk"} },
   {0x1b5a700f, {"b007a141476d62d22549ca28e1e51bb5"}, {"Joust (Quality Software)/Joust (1986)(Quality Software)[cr].dsk"} },
   {0xf0da3efc, {"e0c4f544b58a4ab274557f0f284b46b2"}, {"Jet Set Willy - The Final Frontier (Software Projects)/Jet Set Willy - The Final Frontier (1985)(Software Projects)[cr].dsk"} },
   {0x02bec9bd, {"0f3ce766494c244fb3e069ee60809d95"}, {"Jack the Nipper II - In Coconut Capers (Gremlin Graphics Software)/Jack the Nipper II - In Coconut Capers (1987)(Gremlin Graphics Software).dsk"} },
   {0x92057eaf, {"b696c3c660449963773198109f4d2318"}, {"Jail Break (Konami)/Jail Break (1986)(Konami).dsk"} },
// {0xfaa04721, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"James Debug - El Misterio De La Isla Perdida (Coktel Vision) (Spain)/James Debug - El Misterio De La Isla Perdida (1986)(Coktel Vision)(es)[cr].dsk"} },
   {0x89ecce07, {"930c9da712acd871aa1b20ea232d222c"}, {"Jumpman (Blaby Computer Games)/Jumpman (1986)(Blaby Computer Games)[cr].dsk"} },
   {0x5e9c938b, {"020caec336970a12eb8e4024002956ae"}, {"Jump Jet (Anirog Software)/Jump Jet (1985)(Anirog Software).dsk"} },
   {0x9039209f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Juego de la Oca, El (Zafiro Software) (Spain)/Juego de la Oca, El (1989)(Zafiro Software)(es).dsk"} },
   {0xd772dd9e, {"841f92d4d6487b8062f9f22f8f59562e"}, {"Jack and the Beanstalk (Thor Software)/Jack and the Beanstalk (1985)(Thor Software)[cr].dsk"} },
   {0x91b72895, {"b16294954ba58064a05c878307efc190"}, {"Johnny Reb (MC Lothlorien)/Johnny Reb (1984)(MC Lothlorien)[cr].dsk"} },
   {0x350f5b1a, {"c68076620e353d3feae594cc90a2f4ca"}, {"Jewels of Darkness - Colossal Trilogy (Rainbird Software)/Jewels of Darkness - Colossal Trilogy (1986)(Rainbird Software).dsk"} },
   {0xd1b6e326, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"James Clavell's Shogun (Virgin Games)/James Clavell's Shogun (1986)(Virgin Games).dsk"} },
// {0xb21fb6b0, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Jaws - Le Dernier Etalon (MBC Informatique) (France)/Jaws - Le Dernier Etalon (1988)(MBC Informatique)(fr)(Side A).dsk"} },
   {0xade65d61, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Jinks (Rainbow Arts)/Jinks (1988)(Rainbow Arts).dsk"} },
   {0x23e7dd40, {"e3ed493ffb29afdd138e5d4d87249452"}, {"Joe Blade (Players)/Joe Blade (1987)(Players)[cr].dsk"} },
   {0xb06159a2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Jack the Nipper (Gremlin Graphics Software)/Jack the Nipper (1986)(Gremlin Graphics Software).dsk"} },
   {0xafd4245e, {"6034ae7a8b3582fa45e793ee72d6510c"}, {"Jason of the Argonauts (The Guild)/Jason of the Argonauts (1990)(The Guild)(PD)[cr].dsk"} },
   {0x8cb5b3fd, {"c684723409ad4b8bb8360219bec6f632"}, {"Jonah Barrington's Squash (Mastertronic)/Jonah Barrington's Squash (1987)(Mastertronic)[tape].dsk"} },
   {0x4a3e1d19, {"97ae3057e11c4db653c5639fd8d79c1b"}, {"Jim Power in Mutant Planet (Loriciels)/Jim Power in Mutant Planet (1992)(Loriciels)(Side A).dsk"} },
   {0x3db4af9c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Jack Nicklaus Golf (Accolade)/Jack Nicklaus Golf (1989)(Accolade)(v2)(Disk 1 Side A)[Program].dsk"} },
   {0x6d5e1931, {"6af02a2853bc6bd2e5064398d2a10337"}, {"Joyaux De Babylone, Les (Interceptor Software)/Joyaux De Babylone, Les (1985)(Interceptor Software)(v1.2)[cr].dsk"} },
   {0xd0d1542c, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Jackal (Konami)/Jackal (1986)(Konami).dsk"} },
   {0xb6553a69, {"aedd3f2c129b476d2318392840368adc"}, {"Jungle Warfare (Virgin Mastertronic)/Jungle Warfare (1989)(Virgin Mastertronic)[cr].dsk"} },
// {0xa1b3336e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"J.T 37 (Amstar & Cpc)/J.T 37 (1990)(Amstar & Cpc)[cr].dsk"} },
   {0xa888572f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Jaws (Screen 7)/Jaws (1989)(Screen 7).dsk"} },
   {0x2f2cc873, {"48ac185329d97d133c518f051c53f895"}, {"Jugando al Ajedrez (Mexico Floppy) (Spain)/Jugando al Ajedrez (1991)(Mexico Floppy)(es)[cr].dsk"} },
   {0x85010e9d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Johnny Reb II (MC Lothlorien)/Johnny Reb II (1986)(MC Lothlorien).dsk"} },
   {0xa169df18, {"61777e9a07179fd9077b40bbf0ae9e7f"}, {"Jigsaw (Skyline Software)/Jigsaw (1986)(Skyline Software)[cr].dsk"} },
   {0xf0926ae7, {"0f3ce766494c244fb3e069ee60809d95"}, {"Jabato (Aventuras AD) (Spain)/Jabato (1989)(Aventuras AD)(es).dsk"} },
   {0xb5d6a0d6, {"d8dd75fd3617688aec0eb79acc9a055e"}, {"Jeux Sans Frontieres - Intervilles (Ocean Software)/Jeux Sans Frontieres - Intervilles (1986)(Ocean Software)[cr].dsk"} },
   {0x43665e0d, {"3068633881421afa410718259da844e1"}, {"Juggernaut (CRL Group)/Juggernaut (1985)(CRL Group)[cr].dsk"} },
   {0x0bac47f1, {"b8cf76535be3c60be63a1144c49c159d"}, {"Jeu du Roy, Le (FIL) (France) (Bugs)/Jeu du Roy, Le (1988)(FIL)(fr)[b].dsk"} },
   {0xbe7f2e78, {"ded535ff661fa50b75ccb46122a5665a"}, {"Juego del Ahorcado (-) (M5)/Juego del Ahorcado (19xx)(-)(PD)(M5)[cr].dsk"} },
   {0x420cd6ec, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Jammin (Amsoft)/Jammin (1985)(Amsoft).dsk"} },
   {0x7a9f7d53, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Jungle Warrior (Zigurat Software) (Spain)/Jungle Warrior (1990)(Zigurat Software)(es).dsk"} },
   {0x551d921f, {"04df986c2c06cdd2e7a5cde2ada469ea"}, {"Killer Ring (Ariolasoft)/Killer Ring (1987)(Ariolasoft)[cr].dsk"} },
   {0xb73c418b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Karateka (Broderbund Software) (Spain)/Karateka (1986)(Broderbund Software)(es)(Side A).dsk"} },
   {0xb8c30fe5, {"7e522527196cdc122c43f0cace919686"}, {"K.Y.A. (Loriciels) (France)/K.Y.A. (1987)(Loriciels)(fr).dsk"} },
   {0x4d2044c4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Krypton Factor, The (Domark)/Krypton Factor, The (1987)(Domark)(Side A)[f].dsk"} },
   {0xf9b8eb95, {"c68076620e353d3feae594cc90a2f4ca"}, {"KTris (Richard Wilson)/KTris (2003)(Richard Wilson).dsk"} },
   {0x6f0e5a7a, {"1d61d5393fae53763a179e18849524a8"}, {"Killapede (Players)/Killapede (1986)(Players)[cr].dsk"} },
   {0x36c62e3a, {"29ef562d7aac00463f8637622d7d69a7"}, {"Knight Games (English Software)/Knight Games (1986)(English Software)(v2)(Side A).dsk"} },
   {0xaf878a5f, {"c68076620e353d3feae594cc90a2f4ca"}, {"Kiloroid (Richard Wilson)/Kiloroid (2002)(Richard Wilson).dsk"} },
   {0xe0987148, {"eff9a6cf5a239c8a15873493c5e0ccee"}, {"Knight Games (English Software) (Spain) (Hack)/Knight Games (1986)(English Software)(es)(Hack)(Side A)[cr].dsk"} },
   {0xab58ecd4, {"7e522527196cdc122c43f0cace919686"}, {"K.Y.A. (Loriciels) (Spain)/K.Y.A. (1987)(Loriciels)(es).dsk"} },
   {0xd33e0313, {"3315a15dd3fb52456a7a1bdc029ff138"}, {"Kessin (PD) (France)/Kessin (1992)(PD)(fr)[cr].dsk"} },
   {0xee16d403, {"a9a44e53133c02b5b504c374a5f6d7c8"}, {"King Leonard (Mind Games España) (Spain)/King Leonard (1986)(Mind Games España)(es)[cr].dsk"} },
   {0x96b53a41, {"0f3ce766494c244fb3e069ee60809d95"}, {"Klax (Domark)/Klax (1990)(Domark).dsk"} },
   {0xcf97d092, {"d8722a42f992198bad277bd67af9dcea"}, {"Karl's Treasure Hunt (Software Project)/Karl's Treasure Hunt (1984)(Software Project)[cr].dsk"} },
   {0xddd09042, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ke Rulen los Petas (Iber Soft) (Spain)/Ke Rulen los Petas (1989)(Iber Soft)(es).dsk"} },
   {0xbc83b163, {"cd7084d73e0075fd9bf769196e4de266"}, {"Konami's Golf (Ocean Software)/Konami's Golf (1986)(Ocean Software).dsk"} },
   {0x0200e7b4, {"49e00b2737d9cc8d8c750952450fbb90"}, {"Koronis Rift (Activision)/Koronis Rift (1987)(Activision)(v2).dsk"} },
   {0x66f60bf3, {"db2fc310f957b3bc8a80bdc816bd7099"}, {"Knight Tyme (Mastertronic)/Knight Tyme (1986)(Mastertronic)[cr].dsk"} },
   {0x0934c463, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Knight Orc (Level 9 Computing)/Knight Orc (1987)(Level 9 Computing)(Side A).dsk"} },
   {0x64619305, {"9b7862b4adc9a767973d8bb8442506c3"}, {"Kinetik (Firebird)/Kinetik (1987)(Firebird).dsk"} },
   {0x8b2ddad1, {"d73c332fb4e1088307f5d65318339f3b"}, {"Konami's Ping Pong (Ocean Software)/Konami's Ping Pong (1986)(Ocean Software).dsk"} },
   {0x7a097c69, {"071476209ce9cf81e02ca05f0edde1be"}, {"Kenny Dalglish Soccer Match (Impressions)/Kenny Dalglish Soccer Match (1990)(Impressions)[tape].dsk"} },
   {0x47f50e26, {"b681f15f7ad68050e156df334c825f75"}, {"Kobyashi Naru (Mastertronic)/Kobyashi Naru (1987)(Mastertronic)[cr].dsk"} },
   {0xdc4f94ca, {"0f3ce766494c244fb3e069ee60809d95"}, {"Killer Star (Loisitech) (France) (Bugs)/Killer Star (1986)(Loisitech)(fr)(Side A)[b].dsk"} },
   {0xeed8ee05, {"aaf16d5efa589d3ce86207c0137864e3"}, {"Kong Strikes Back (Ocean Software)/Kong Strikes Back (1984)(Ocean Software)[cr].dsk"} },
   {0x5804d4f1, {"27afa6e8ff0cc6043596102f6e06b334"}, {"Kokotoni Wilf (Elite Systems)/Kokotoni Wilf (1984)(Elite Systems)[cr].dsk"} },
   {0xc6737857, {"fd6218ab26332a9a088b8249cea6c73f"}, {"Kick Off 2 (Anco Software) (Spain)/Kick Off 2 (1990)(Anco Software)(es)[cr].dsk"} },
   {0xb9e22201, {"f0feb1a60e398f4d2130311afae5c7e4"}, {"Karateka (Broderbund Software) (France)/Karateka (1986)(Broderbund Software)(fr).dsk"} },
   {0xaee30fe7, {"fa420c38d04c8b292344ce8f5e456f3e"}, {"Killer Cobra (Mastertronic)/Killer Cobra (1987)(Mastertronic)[cr].dsk"} },
   {0xc6628383, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Killed Until Dead (US Gold)/Killed Until Dead (1987)(US Gold)(Side A).dsk"} },
// {0x0e81f696, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Knight Force (Titus)/Knight Force (1989)(Titus)(Side A).dsk"} },
   {0x1c4f62da, {"071476209ce9cf81e02ca05f0edde1be"}, {"Kenny Dalglish Soccer Manager (Cognito)/Kenny Dalglish Soccer Manager (1989)(Cognito)[cr].dsk"} },
   {0x33220da8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Kat Trap (Domark)/Kat Trap (1987)(Domark).dsk"} },
   {0x624b9342, {"2ae8d2a211e2fd45686f47751d62d103"}, {"Kong's Revenge (Zigurat Software) (Spain)/Kong's Revenge (1991)(Zigurat Software)(es).dsk"} },
   {0xec2efccb, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Kwik Snax Dizzy (Codemasters Software)/Kwik Snax Dizzy (1990)(Codemasters Software).dsk"} },
   {0xe4b64206, {"c07f7eb4bc9b457a7ed386dbc3523257"}, {"Kane (Mastertronic)/Kane (1986)(Mastertronic)[cr].dsk"} },
   {0xa2d5c9db, {"db2fc310f957b3bc8a80bdc816bd7099"}, {"Knight Lore (Ultimate Play The Game)/Knight Lore (1984)(Ultimate Play The Game)[cr].dsk"} },
   {0x89cba118, {"0108065fcfb208e5b34f0d4ee104abed"}, {"Kentucky Racing (Alternative Software)/Kentucky Racing (1991)(Alternative Software)[cr].dsk"} },
   {0x555ba7ba, {"6114cb24c8bc9a23a3fbc7e464e7f85e"}, {"Kung-Fu (Bug-Byte)/Kung-Fu (1986)(Bug-Byte)[cr].dsk"} },
   {0x5708f28a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Krakout (Gremlin Graphics Software)/Krakout (1987)(Gremlin Graphics Software).dsk"} },
   {0x267dbdff, {"8ebd7a23c227d87feb34c2b3cefb32fc"}, {"Key Factor, The (Amsoft)/Key Factor, The (1985)(Amsoft)[cr].dsk"} },
   {0xa2a1a0fa, {"6ca13e9e8d45f645ac1078bd2516848b"}, {"Kettle (Alligata Software)/Kettle (1986)(Alligata Software).dsk"} },
   {0xe874a3ae, {"980e876acba36ba0433a840fd32c9492"}, {"Kung-Fu Master (US Gold)/Kung-Fu Master (1986)(US Gold).dsk"} },
   {0xe2dbc3c3, {"1b415355da13fe89419520517cb62b1e"}, {"Killer Ball (Microids) (M2)/Killer Ball (1991)(Microids)(M2).dsk"} },
   {0xbc4f103d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Kick Off 2 (Anco Software) (France)/Kick Off 2 (1990)(Anco Software)(fr)(Side A).dsk"} },
   {0x734bb556, {"57f05ccced67a0e1a633085428193e6f"}, {"Knight Rider (Ocean Software)/Knight Rider (1986)(Ocean Software).dsk"} },
   {0xfa322061, {"3d094a32b78af57028ff8edf24b09885"}, {"Kentilla (Mastertronic)/Kentilla (1986)(Mastertronic)[cr].dsk"} },
   {0xf4990d9e, {"c68076620e353d3feae594cc90a2f4ca"}, {"Knightmare (Activision)/Knightmare (1987)(Activision).dsk"} },
   {0x68ede3f2, {"2e43e36ae433a075c2c83feb96b4c874"}, {"Killer Gorilla (Micro Power)/Killer Gorilla (1984)(Micro Power)[cr].dsk"} },
   {0x81cf1945, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Kick Off (Anco Software) (M5)/Kick Off (1990)(Anco Software)(M5).dsk"} },
   {0xa83f0253, {"dde7962e3d390fb88593df18ab19db85"}, {"Kristax (Deca Software)/Kristax (1989)(Deca Software)[cr].dsk"} },
   {0x6ca93012, {"c68076620e353d3feae594cc90a2f4ca"}, {"Karnov (Activision)/Karnov (1988)(Activision)(Side A).dsk"} },
   {0xb88541f9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Kristal (Core)/Kristal (1984)(Core).dsk"} },
   {0x79b9b585, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Kick Off 2 (Anco Software)/Kick Off 2 (1990)(Anco Software)(Side A).dsk"} },
   {0x5f05890e, {"7eea1c07727e0cd9bf51c2aab5512bc9"}, {"Leviathan (English Software)/Leviathan (1987)(English Software).dsk"} },
   {0x1d39d2e7, {"85c7667950e6a3072364dbe9752ee45d"}, {"Leaderboard (US Gold)/Leaderboard (1986)(US Gold).dsk"} },
   {0x29e5876c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Lotus Esprit Turbo Challenge (Gremlin Graphics Software)/Lotus Esprit Turbo Challenge (1990)(Gremlin Graphics Software).dsk"} },
   {0xf172183f, {"d03825989114c908018a6f2e87e3ec27"}, {"Link (Amstrad Action)/Link (1992)(Amstrad Action)[cr].dsk"} },
   {0xe12e6e01, {"69e0283fc6575cdddc4dac9d8aabf180"}, {"Lion (Amstrad Action)/Lion (1991)(Amstrad Action)[cr].dsk"} },
   {0x7dd16bd1, {"0726ca182dc414104a693f0158069902"}, {"Labyrinth Hall (Amstrad Adventure PD Library)/Labyrinth Hall (1987)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0xf6943a86, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Labyrinthe aux Mille Calculs, Le - College (Retz) (France)/Labyrinthe aux Mille Calculs, Le - College (1989)(Retz)(fr)(Disk 1 Side A)[CPM].dsk"} },
   {0xb2837f6d, {"c3aee0447cc02913cac2f7b3709bfa9c"}, {"Lifeterm (Alternative Software)/Lifeterm (1987)(Alternative Software)[cr].dsk"} },
   {0xf2d8dffa, {"6a262b0f61c8f846292d562b6a44aa81"}, {"Lights Out (Rudiger) (France)/Lights Out (1997)(Rudiger)(fr)(PD)[cr].dsk"} },
   {0xa4f28175, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Labyrinthe d'Errare, Le - College (Retz) (France)/Labyrinthe d'Errare, Le - College (1989)(Retz)(fr)(Disk 1 Side A)[CPM].dsk"} },
   {0x4e7fd8a2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Lurking Horror, The (Infocom)/Lurking Horror, The (1987)(Infocom)[cr].dsk"} },
   {0x92b6a819, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Labyrinthe aux Cent Calculs, Le - Ecole (Retz) (France)/Labyrinthe aux Cent Calculs, Le - Ecole (1989)(Retz)(fr)(Disk 1 Side A)[CPM].dsk"} },
   {0xd7aa74be, {"0f3ce766494c244fb3e069ee60809d95"}, {"Livingstone Supongo (Opera Soft) (Spain)/Livingstone Supongo (1986)(Opera Soft)(es).dsk"} },
   {0xc5ad3e3e, {"78e5f3c7b3f804c2068c0b272de9d026"}, {"Lancelot (Level 9 Computing)/Lancelot (1988)(Level 9 Computing)(Side A).dsk"} },
   {0xe0fd670d, {"bf6921fecbcb3f68d0fa1811d588eb89"}, {"Legions of Death (MC Lothlorien) (Spain)/Legions of Death (1987)(MC Lothlorien)(es)[cr].dsk"} },
   {0xcf01470c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Laser Squad - Kit 1 (Blade Software) (M2)/Laser Squad - Kit 1 (1989)(Blade Software)(M2).dsk"} },
   {0x11b7b081, {"c60812b8a46d3e66bd37feea654a6b75"}, {"Legend of Kage (Ocean Software)/Legend of Kage (1986)(Ocean Software).dsk"} },
   {0x42e5f481, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Lords of Midnight, The (Beyond Software)/Lords of Midnight, The (1985)(Beyond Software).dsk"} },
   {0x0dc39b44, {"0f3ce766494c244fb3e069ee60809d95"}, {"Last Mission, The (Opera Soft) (France)/Last Mission, The (1987)(Opera Soft)(fr).dsk"} },
   {0x4eec7616, {"c68076620e353d3feae594cc90a2f4ca"}, {"Liberator (Proein Soft Line)/Liberator (1989)(Proein Soft Line).dsk"} },
   {0x1f8ce03a, {"c68076620e353d3feae594cc90a2f4ca"}, {"Lucky Luke - Nitroglycerine (Coktel Vision) (Spain)/Lucky Luke - Nitroglycerine (1987)(Coktel Vision)(es)(Side A).dsk"} },
   {0x66ecb73b, {"446af083da702f322d9d1e0dc4055b53"}, {"Laser Squad (Blade Software) (M2)/Laser Squad (1989)(Blade Software)(M2).dsk"} },
   {0xdecbd246, {"fdbd093850d8d11f3a828fda152731d3"}, {"Los Angeles SWAT (Mastertronic)/Los Angeles SWAT (1987)(Mastertronic)[cr].dsk"} },
   {0x59802f2a, {"104faa83f7a01f356200ae702f894582"}, {"Loom (Arkos)/Loom (1996)(Arkos)(PD)[cr].dsk"} },
   {0x6fe2ef82, {"b5c6f305ae89ba12305c0fb5dc08219f"}, {"Laberinto Sultan, El (Amsoft) (Spain)/Laberinto Sultan, El (1984)(Amsoft)(es)[cr].dsk"} },
   {0xeb127e47, {"3ba7e27f4b8afb2ed880144aa8ba39b8"}, {"Leather Goddesses of Phobos (Infocom)/Leather Goddesses of Phobos (1986)(Infocom)[CPM].dsk"} },
   {0x695b81d3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Labyrinthe des Pharaons, Le (Retz) (France)/Labyrinthe des Pharaons, Le (1990)(Retz)(fr)(Disk 1 Side A).dsk"} },
   {0xc319fe69, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Light Force (FTL)/Light Force (1986)(FTL).dsk"} },
   {0xd2a48c7d, {"c01ae1a5f122f25ce5675f86028b536a"}, {"Lords Of Chaos - Expansion Kit One (Blade Software) (M2)/Lords Of Chaos - Expansion Kit One (1990)(Blade Software)(M2).dsk"} },
   {0x7e0090aa, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Last Ninja 2 Remix (System 3)/Last Ninja 2 Remix (1990)(System 3)(Side A).dsk"} },
   {0x342c720e, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Labyrinthe d'Orthophus, Le - Ecole (Retz) (France)/Labyrinthe d'Orthophus, Le - Ecole (1989)(Retz)(fr)(Disk 1 Side A)[CPM].dsk"} },
   {0x5f963c09, {"0f3ce766494c244fb3e069ee60809d95"}, {"Labyrinthe D'Anglomania 1, Le (Retz) (France)/Labyrinthe D'Anglomania 1, Le (1990)(Retz)(fr)(Side A).dsk"} },
   {0x01dab581, {"14160b09f0ce40db6425e47439eeeb98"}, {"Lucky Luke - Nitroglycerine (Coktel Vision) (France)/Lucky Luke - Nitroglycerine (1987)(Coktel Vision)(fr)(Side A)[CPM].dsk"} },
   {0xd4bc3547, {"a9d9116c23f17837021bd98ce44bd0f9"}, {"Lisa Strip Pot (Ludo's Software Distribution) (France)/Lisa Strip Pot (1985)(Ludo's Software Distribution)(PD)(fr)[cr].dsk"} },
   {0x35cf7ef3, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Last Duel (US Gold)/Last Duel (1989)(US Gold).dsk"} },
   {0xdf4abfd8, {"5db19ae0069e670ae8a20d0ad1279138"}, {"Lubix (AM-Mag) (France)/Lubix (1988)(AM-Mag)(fr)[cr].dsk"} },
   {0xef801dfc, {"02ace624e18946579e0219aee36dcb8f"}, {"Loogaroo (Top Ten)/Loogaroo (1988)(Top Ten)[cr].dsk"} },
   {0x4ccd5ef3, {"d413f088494c926c98818f2af3c2cf34"}, {"Life Expectancy Zero (Blaby Computer Games)/Life Expectancy Zero (1985)(Blaby Computer Games)[cr].dsk"} },
   {0xa5f991ad, {"958ade8e7ef79c351e21fb63394b880b"}, {"Lone Wolf (Audiogenic Software LTD)/Lone Wolf (1991)(Audiogenic Software LTD).dsk"} },
// {0xb0a1e816, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Labyrinthe D'Anglomania 2, Le (Retz) (France)/Labyrinthe D'Anglomania 2, Le (1990)(Retz)(fr)(Side A).dsk"} },
   {0x63e7466d, {"eb7d4f798d4b39465c7181775cdee1bc"}, {"Labynotaure (Amstrad Magazine) (France)/Labynotaure (1985)(Amstrad Magazine)(fr)[cr].dsk"} },
   {0xc5714f20, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Lemmings (Psygnosis)/Lemmings (1992)(Psygnosis)(Side A).dsk"} },
   {0xae273ff5, {"0b2c496712415a644d6abed81d432527"}, {"Lost Caves (Players Premier)/Lost Caves (1989)(Players Premier)[cr].dsk"} },
   {0xab95d498, {"196f11f84782bd82c161e82c6ea7ea31"}, {"La Boule Infernale (Hebdogiciel) (France)/La Boule Infernale (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x7f951a1c, {"c1de011f6e595c79599a5bb7c51889f5"}, {"Lost Crown, The (S. Sawdy)/Lost Crown, The (1985)(S. Sawdy)[cr].dsk"} },
   {0xb58d3ed5, {"0f3ce766494c244fb3e069ee60809d95"}, {"Lee Enfield - An Amazon Adventure (Infogrames)/Lee Enfield - An Amazon Adventure (1987)(Infogrames).dsk"} },
   {0x8014ac9c, {"0f3ce766494c244fb3e069ee60809d95"}, {"Livingstone I Presume (Opera Soft)/Livingstone I Presume (1987)(Opera Soft).dsk"} },
   {0x74c68ce8, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Line of Fire (US Gold)/Line of Fire (1990)(US Gold).dsk"} },
   {0xe93f03d2, {"3fc197d9d613c5b1e1efc1a4b40bc9fc"}, {"Loopz (Audiogenic Software)/Loopz (1991)(Audiogenic Software).dsk"} },
   {0x9fa57d50, {"0f3ce766494c244fb3e069ee60809d95"}, {"Lee Enfield - Space Ace (Infogrames)/Lee Enfield - Space Ace (1987)(Infogrames).dsk"} },
   {0x2ff0cc27, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Lost Phirious, The (Wow Software)/Lost Phirious, The (19xx)(Wow Software)[cr].dsk"} },
   {0x3e8a43fd, {"74ff7ec6fbd36e8935f1c84c4913a157"}, {"Last Race, The (Amstar & Cpc)/Last Race, The (1989)(Amstar & Cpc)[cr].dsk"} },
   {0x3804f990, {"e01b03beb3b3cf0000eff9f49351f08f"}, {"Laser Base (Computing With The Amstrad)/Laser Base (1986)(Computing With The Amstrad)[cr].dsk"} },
   {0x1da0dcd4, {"bc94ed95eae788273a99b4149da51e9b"}, {"Last V8, The (Mastertronic)/Last V8, The (1986)(Mastertronic)[cr].dsk"} },
   {0x410d2254, {"2d3bde3cb2ab82a082e0987d20eb3020"}, {"Legions of Death (MC Lothlorien)/Legions of Death (1987)(MC Lothlorien)[cr].dsk"} },
   {0xc685e1b3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Livingstone (Opera Soft) (France)/Livingstone (1987)(Opera Soft)(fr).dsk"} },
   {0x0d65ed5e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Legend (Delta Software) (Spain)/Legend (1990)(Delta Software)(es)(v2)(Side A).dsk"} },
   {0x708f31d5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Lorna (Topo Soft) (Spain)/Lorna (1990)(Topo Soft)(es).dsk"} },
   {0x7c2489ec, {"0f3ce766494c244fb3e069ee60809d95"}, {"Lord of the Rings - Game One (Melbourne House)/Lord of the Rings - Game One (1986)(Melbourne House)(Side A).dsk"} },
   {0xd9dec288, {"653a418d346ceb7aaf85de2eeefeaeca"}, {"Lords of Chaos (Blade Software) (M2)/Lords of Chaos (1990)(Blade Software)(M2).dsk"} },
   {0x33a4f4d3, {"57417a6ffcfb7db26edf96e85f6963ac"}, {"Laserwarp (Amsoft)/Laserwarp (1985)(Amsoft)[tape].dsk"} },
   {0x2ebe385f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Livingstone Supongo II (Opera Soft)/Livingstone Supongo II (1989)(Opera Soft).dsk"} },
   {0xf81c4337, {"c14f8af81fe25db3012fa42a16a5783c"}, {"La Pulga (Indescomp)/La Pulga (1984)(Indescomp)[cr].dsk"} },
   {0xb5dd9b44, {"0f3ce766494c244fb3e069ee60809d95"}, {"Light Corridor, The (Infogrames)/Light Corridor, The (1990)(Infogrames).dsk"} },
   {0xfac29692, {"259e4d85800409b4d70c2d890b3a4f05"}, {"Lode Runner (Broderbund Software) (France)/Lode Runner (1989)(Broderbund Software)(fr).dsk"} },
   {0xff869f60, {"960101fd1614ae564377572477cc7c71"}, {"Last of the Smileys (Amstrad Action)/Last of the Smileys (1995)(Amstrad Action)(PD)[cr].dsk"} },
   {0x2e386ba7, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Last Ninja 2 (System 3)/Last Ninja 2 (1988)(System 3)(Side A).dsk"} },
   {0xd21c33a6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Labyrinthe de Lexicos, Le (Retz) (France)/Labyrinthe de Lexicos, Le (1990)(Retz)(fr)(Side A).dsk"} },
   {0x3669b69f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Leaderboard Tournament (US Gold)/Leaderboard Tournament (1987)(US Gold).dsk"} },
   {0x9a2bd0a6, {"464f9321e19bc8bc4cfa8ad58235d04b"}, {"Little Game (Lojze Dolenc)/Little Game (1987)(Lojze Dolenc)(PD)[cr].dsk"} },
   {0x99acff55, {"973c16c287c846add02cb0bf909ffbab"}, {"Legende (FIL) (France)/Legende (1987)(FIL)(fr)(Side A).dsk"} },
   {0xe89e115e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Lee Enfield - The Tournament Of Death (Infogrames)/Lee Enfield - The Tournament Of Death (1988)(Infogrames).dsk"} },
   {0xbbe80a27, {"14b48b220eede7400715637e640cb193"}, {"Legend of Apache Gold, The (Incentive) (Hack)/Legend of Apache Gold, The (1986)(Incentive)(Hack)[cr].dsk"} },
   {0xe31090f5, {"f7015e80368870705c6aace0c016b1b4"}, {"Lord of the Rings - Game Two - Shadows of Mordor (Melbourne House)/Lord of the Rings - Game Two - Shadows of Mordor (1987)(Melbourne House)[cr].dsk"} },
   {0x92f208ca, {"7d4f4e21665b8cb5df6c401322de3b4d"}, {"La Mansion Encantada (Anirog Software) (Spain)/La Mansion Encantada (1984)(Anirog Software)(es)[cr].dsk"} },
   {0x504e2a3f, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Little Puff in Dragonland (Codemasters Software)/Little Puff in Dragonland (1990)(Codemasters Software).dsk"} },
   {0x0cde6333, {"0f3ce766494c244fb3e069ee60809d95"}, {"Last Mission, The (Opera Soft) (Spain)/Last Mission, The (1987)(Opera Soft)(es).dsk"} },
   {0xa07d3bdf, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"LED Storm (Us Gold)/LED Storm (1988)(Us Gold).dsk"} },
   {0x1a7d1a90, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Lazer Tag (US Gold)/Lazer Tag (1987)(US Gold).dsk"} },
   {0x9cff63e2, {"cccf043cfde72848281183852ecd4dc0"}, {"Long-Way (Amstrad Cent Pour Cent)/Long-Way (1988)(Amstrad Cent Pour Cent)[cr].dsk"} },
   {0x04aa3b1e, {"506f7ee6a021a06b1a56cc441873e5c7"}, {"Molecule (Computing With The Amstrad)/Molecule (1990)(Computing With The Amstrad)[cr].dsk"} },
   {0x51210f22, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Marque Jaune, La (Cobra Soft) (France)/Marque Jaune, La (1988)(Cobra Soft)(fr)(Side A).dsk"} },
   {0x0754859e, {"278fdfa034a2f8b0ba6fc83bbbe594ea"}, {"Movie (Ocean Software)/Movie (1986)(Ocean Software).dsk"} },
   {0x7cd49cdc, {"d6b01ba91c88bc701e68596bb1b7620b"}, {"Meynaupede (Hebdogiciel) (France)/Meynaupede (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0xcd2e8018, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Malediction de Thaar, La (Coktel Vision) (France)/Malediction de Thaar, La (1985)(Coktel Vision)(fr).dsk"} },
   {0x77b4db9c, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Mystere de Kikekankoi, Le (Loriciels) (France)/Mystere de Kikekankoi, Le (1985)(Loriciels)(fr)[cr].dsk"} },
   {0x73ac7fd4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Manchester United Europe (Krisalis Software) (M5)/Manchester United Europe (1991)(Krisalis Software)(M5).dsk"} },
   {0x2bb9ce08, {"334e81b2ea4561bb202cf1774d3768f3"}, {"MLM 3D - Evasion de la Lune (Chip Avril) (France)/MLM 3D - Evasion de la Lune (1986)(Chip Avril)(fr).dsk"} },
// {0x57f4d790, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Mountie Mick's Death Ride (Reaktor)/Mountie Mick's Death Ride (1987)(Reaktor).dsk"} },
   {0x0083cdf8, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Marsport (Gargoyle Games)/Marsport (1985)(Gargoyle Games).dsk"} },
   {0x6abcc9b6, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Moon Cresta (Incentive)/Moon Cresta (1986)(Incentive).dsk"} },
   {0x6b8d3058, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Mondes Paralleles, Les (Mchtml) (France)/Mondes Paralleles, Les (1993)(Mchtml)(fr)(Side A)[cr].dsk"} },
   {0xb55f3eec, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Maze Mania (Hewson)/Maze Mania (1989)(Hewson).dsk"} },
   {0x9957a7c3, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Masters of Space, The (Radical Software)/Masters of Space, The (1994)(Radical Software)[cr].dsk"} },
   {0xf353927d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Mutant Monty (Artic Computing)/Mutant Monty (1984)(Artic Computing).dsk"} },
   {0x05339e1d, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Mewilo (Coktel Vision) (de)/Mewilo (1987)(Coktel Vision)(de)(Side A)[CPM].dsk"} },
   {0xfac6531d, {"c68076620e353d3feae594cc90a2f4ca"}, {"Munsters, The (Again Again)/Munsters, The (1989)(Again Again).dsk"} },
   {0xcc7e6ce8, {"2efaae7190d8136c6bbbe798075b7e53"}, {"Madmazes (Pipeline Software)/Madmazes (1992)(Pipeline Software)[cr].dsk"} },
   {0xd77ef6ed, {"95b1a01bcc2ea15f1aaefdcbc2b02cf5"}, {"Moto Cross Simulator (Codemasters Software)/Moto Cross Simulator (1989)(Codemasters Software)[cr].dsk"} },
   {0x11868bff, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Momie Blue (Coktel Vision) (France)/Momie Blue (1986)(Coktel Vision)(fr).dsk"} },
   {0x8e59d16a, {"026df8624f2c9e328db2c001d00f4604"}, {"Moulinsar (Bretagne Edit presse) (France)/Moulinsar (1987)(Bretagne Edit presse)(fr)[cr].dsk"} },
   {0xfd20468f, {"2250ad966589552a2e780876063b56cb"}, {"Mega-Bucks (Firebird)/Mega-Bucks (1986)(Firebird)[cr].dsk"} },
   {0xfd3423b5, {"f5b874ebabad882e658b07caa7f248f1"}, {"Mission 2 (Gasoline Software)/Mission 2 (1987)(Gasoline Software)[cr].dsk"} },
   {0x148447dc, {"28d57459898dbeb3cca3d6cdd7e2df53"}, {"Motos (Mastertronic)/Motos (1987)(Mastertronic)[cr].dsk"} },
   {0xfd2001f3, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Mercs (US Gold)/Mercs (1991)(US Gold).dsk"} },
   {0x7c096b33, {"45b56fcc4b91fe8023ce345f26210b4b"}, {"Miss Input 2 (cpcretrodev.byterealms)/Miss Input 2 (2020)(cpcretrodev.byterealms)[tape].dsk"} },
   {0x907b8195, {"bd6e93cb8b16e98abdbfb5e03443eb48"}, {"Miami Vice (Ocean Software)/Miami Vice (1986)(Ocean Software).dsk"} },
   {0x18dcb1b4, {"502fe2ca97f6320e84299814bf5fd2f2"}, {"Mega-Apocalypse (Martech)/Mega-Apocalypse (1988)(Martech).dsk"} },
   {0x95def41f, {"059f18e353096df6a8823f2b990a1321"}, {"Metal Army (Players)/Metal Army (1988)(Players)[cr].dsk"} },
   {0xb88a5919, {"e01f984e0d70e019442e07d02f87cbaa"}, {"Mission Jupiter (Codemasters Software)/Mission Jupiter (1987)(Codemasters Software)[cr].dsk"} },
   {0xc321d3b5, {"57f39e7899dc0624f21897319c291ba3"}, {"Mr Freeze (Firebird)/Mr Freeze (1984)(Firebird)[cr].dsk"} },
   {0xff082b39, {"5c85c111522cfc4042130598f003792e"}, {"Munch-it (Tynesoft)/Munch-it (1984)(Tynesoft)[cr].dsk"} },
   {0x77a58bee, {"066220f847ca95cfb8ee18e36a4e83ea"}, {"Meltdown (Alligata Software)/Meltdown (1986)(Alligata Software).dsk"} },
// {0x3edfb68f, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Mission Delta (ERE Informatique) (France)/Mission Delta (1985)(ERE Informatique)(fr).dsk"} },
   {0x797cd283, {"548a4d331165899f560f167ad5dbfd18"}, {"Maddog (Titus) (France)/Maddog (1987)(Titus)(fr).dsk"} },
   {0x4d8464d3, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Myth - History in the Making (System 3)/Myth - History in the Making (1989)(System 3)(Side A).dsk"} },
   {0x174743db, {"2f0b4fcfea1feed5a348281ceec07a90"}, {"Mission (Loriciels) (France)/Mission (1987)(Loriciels)(fr).dsk"} },
   {0xcd7c294d, {"bc48c29e92d0ed954fac0a42512254b4"}, {"Minette (Edmund Spicer)/Minette (19xx)(Edmund Spicer)[cr].dsk"} },
   {0xfe03f194, {"e12d49ff81aaabd85e2e6c34f61a3e6c"}, {"Master Rubik's Cube (Hebdogiciel) (France)/Master Rubik's Cube (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x5237c2e6, {"1ba886efd01a8c77e6a93f9e2611d3cc"}, {"Monopolic (Free Game Blot) (France)/Monopolic (1985)(Free Game Blot)(fr).dsk"} },
   {0x73044172, {"abff189f49be8991fe039efbbe78801d"}, {"Monopoly (Leisure Genius)/Monopoly (1986)(Leisure Genius).dsk"} },
   {0x5d037c5c, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mandragore (Infogrames)/Mandragore (1985)(Infogrames)(Side A).dsk"} },
   {0x43aa21e6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mickey Mouse (Gremlin Graphics Software)/Mickey Mouse (1988)(Gremlin Graphics Software).dsk"} },
   {0xc70118be, {"284b8e3bce273b72097cc98ecbb45ddc"}, {"Mike & Moko (MBC Informatique)/Mike & Moko (1988)(MBC Informatique)(Side A).dsk"} },
   {0xdadfca99, {"9fc8aa456778bf28bcc81f7921319e7e"}, {"Mission en Rafale (FIL) (M2)/Mission en Rafale (1987)(FIL)(M2).dsk"} },
   {0x281b7099, {"d9211d7756e554806c47a7cbe65a9d7f"}, {"MGT - Magnetik Tank (Loriciels)/MGT - Magnetik Tank (1986)(Loriciels).dsk"} },
   {0xf43e00bd, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Mag Max (Imagine Software)/Mag Max (1987)(Imagine Software).dsk"} },
   {0x08530c6e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mot (Opera Soft) (M2)/Mot (1989)(Opera Soft)(M2)(Side A).dsk"} },
   {0xe698443a, {"0f6b84f80d6ce35800b295a49eb98f4d"}, {"Memotron (Magazin Players Dream) (de)/Memotron (1987)(Magazin Players Dream)(de)[cr].dsk"} },
   {0xf59da67d, {"948b4bed0517343610a1b29132d2bcc7"}, {"Master of the Lamps (Activision)/Master of the Lamps (1985)(Activision)[cr].dsk"} },
   {0x706d0ef3, {"6ef77b2e1d4b1f0721dcc594bdc15e01"}, {"Maggot Splat (Your Computer)/Maggot Splat (1985)(Your Computer)[cr].dsk"} },
// {0xaa35d5c2, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Macadam Bumper (PSS) (Spain)/Macadam Bumper (1985)(PSS)(es)[cr].dsk"} },
   {0x998919cf, {"ca06bd8ecca4ed602fab3c2462854e24"}, {"Mystery of the Java Star, The (Shards Software)/Mystery of the Java Star, The (1985)(Shards Software)[cr].dsk"} },
   {0xce4e6c6e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mask (Gremlin Graphics Software)/Mask (1987)(Gremlin Graphics Software).dsk"} },
   {0x90f7f707, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Monte Cristo (Coktel Vision) (France)/Monte Cristo (1988)(Coktel Vision)(fr)(Side A)[CPM].dsk"} },
   {0x745434d1, {"07fa82dba2dfb09218c843f91be55f70"}, {"Mad Ball (CPC Infos) (France)/Mad Ball (1993)(CPC Infos)(fr)[cr].dsk"} },
   {0x48cfba3d, {"5af9cc1980e0c2e1b823699ac2fcfe45"}, {"Missile Ground Zero (Virgin Games) (LightGun)/Missile Ground Zero (1989)(Virgin Games)(LightGun)[cr].dsk"} },
   {0x5745a375, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Mario Bros (Ocean Software)/Mario Bros (1987)(Ocean Software).dsk"} },
   {0xa5c8df4b, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Mig 29 Soviet Fighter (Codemasters Software) (Bugs)/Mig 29 Soviet Fighter (1989)(Codemasters Software)[b].dsk"} },
   {0x04d0e00d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Monopoly (Leisure Genius) (France)/Monopoly (1986)(Leisure Genius)(fr).dsk"} },
   {0x90fdb297, {"24e5eda8764a66c95a601eb548a33f4b"}, {"Manhattan 95 (Ubi Soft) (France)/Manhattan 95 (1986)(Ubi Soft)(fr).dsk"} },
   {0xbc2e3016, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mystical (Infogrames)/Mystical (1990)(Infogrames).dsk"} },
   {0x4596115b, {"04b9045c73b2344092edeaefd53f6349"}, {"Megamix (LLC)/Megamix (1992)(LLC)(PD)[cr].dsk"} },
   {0xd0880eb7, {"0f3ce766494c244fb3e069ee60809d95"}, {"Marius Tresor Foot (Loriciels) (France)/Marius Tresor Foot (1985)(Loriciels)(fr).dsk"} },
   {0x32ca151b, {"2e15a2dcfc6dde8c48ca978a38a69379"}, {"Menace sur l'Arctique (Chip) (France)/Menace sur l'Arctique (1987)(Chip)(fr)[cr].dsk"} },
   {0xa7baa480, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Midnight Resistance (Ocean Software)/Midnight Resistance (1990)(Ocean Software)(Side A).dsk"} },
// {0x82f0d494, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Mindfighter (Activision)/Mindfighter (1988)(Activision).dsk"} },
   {0x9f367a77, {"b753b76bf502e519edcdb9284dd83451"}, {"Monument (Zeppelin Games)/Monument (1991)(Zeppelin Games)[cr].dsk"} },
   {0x20a0989b, {"7de527c910583e946b029a9c5a3733eb"}, {"Manager (ERE Informatique) (France) (Bugs)/Manager (1985)(ERE Informatique)(fr)[b].dsk"} },
   {0xaf3d9c8f, {"c9199f55c55d4669c1486823191d6984"}, {"Mac 2 (Scull PD Library)/Mac 2 (1990)(Scull PD Library)(PD)[cr].dsk"} },
   {0x416d5acd, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Mascotte (Coktel Vision) (France)/Mascotte (1988)(Coktel Vision)(fr)(Side A)[CPM].dsk"} },
   {0x815c762b, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Mewilo (Coktel Vision) (France)/Mewilo (1987)(Coktel Vision)(fr)(Side A)[CPM].dsk"} },
   {0x58ecb546, {"c12768900f22eec944f988d07c4a177d"}, {"Malediction, La (Lankhor) (France)/Malediction, La (1991)(Lankhor)(fr)(Side A).dsk"} },
   {0x63ba006b, {"8c0761b55ad924f2ba561fcb0ac981d2"}, {"Morris Meets the Biker (Automata UK)/Morris Meets the Biker (1984)(Automata UK)[cr].dsk"} },
   {0x48684cf4, {"130402548f7a3f88cb60fc213a276bed"}, {"Mikie (Ocean Software)/Mikie (1986)(Ocean Software)[cr].dsk"} },
   {0x8349da70, {"1b7ceb4bdf05aabde88a82b82c427dec"}, {"Maracaibo (Loriciels) (France)/Maracaibo (1986)(Loriciels)(fr).dsk"} },
// {0x061fb016, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Moon Blaster (Loriciels)/Moon Blaster (1990)(Loriciels).dsk"} },
// {0x532f7930, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Molecule Man (Mastertronic)/Molecule Man (1986)(Mastertronic)[cr].dsk"} },
   {0x35c029d5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Match Day II (Ocean Software)/Match Day II (1987)(Ocean Software).dsk"} },
   {0x53f3d54c, {"758ed9585e2057880cc306ba073d03d9"}, {"Marble Madness Deluxe Edition (Melbourne House)/Marble Madness Deluxe Edition (1987)(Melbourne House)[cr][f].dsk"} },
   {0xab3ea0dc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mask II (Gremlin Graphics Software)/Mask II (1988)(Gremlin Graphics Software).dsk"} },
   {0x037b1c79, {"4c016002446d9e32c542af008421dde9"}, {"Mille Bornes (Free Games Blot) (France)/Mille Bornes (1985)(Free Games Blot)(fr).dsk"} },
   {0x7e1deece, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Mineur (Cobra Soft) (France)/Mineur (1987)(Cobra Soft)(fr)[cr].dsk"} },
   {0x40a3cfd4, {"38f1192ddbdf440bc008682a01d3a2b9"}, {"Misterio del Nilo, El (Zigurat) (Spain)/Misterio del Nilo, El (1987)(Zigurat)(es)[cr].dsk"} },
   {0x976e97c3, {"9aca9d62b44c0f0ed906103fa1c83525"}, {"Microball (Alternative Software)/Microball (1987)(Alternative Software)[cr].dsk"} },
   {0xdf728125, {"605357de188783590f6ed06e61239c17"}, {"Mange Cailloux (Ubi Soft) (France)/Mange Cailloux (1987)(Ubi Soft)(fr).dsk"} },
   {0x79799b5a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Microprose Soccer (Microprose Software)/Microprose Soccer (1989)(Microprose Software)(Side A)[Soccer].dsk"} },
   {0x54b79dfb, {"61ca763a9acdb74fd7fd86b630cf345e"}, {"Martianoids (Ultimate Play The Game)/Martianoids (1987)(Ultimate Play The Game)[cr].dsk"} },
   {0x7f2003c3, {"26d92bbc9cfb3ac29258a7c109cf55cc"}, {"Magic Clock (Players)/Magic Clock (1986)(Players)[cr].dsk"} },
   {0x62a4deae, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mutan Zone (Opera Soft) (Spain)/Mutan Zone (1989)(Opera Soft)(es).dsk"} },
   {0x85408c9d, {"5d6c88595b777e68fc01d8971fc6e9ff"}, {"Micro Scrabble (Leisure Genius) (France)/Micro Scrabble (1985)(Leisure Genius)(fr).dsk"} },
   {0x5b9b2926, {"d1bcdbfb448574235973e3a312b15091"}, {"Mata Hari (Loriciels)/Mata Hari (1988)(Loriciels)[cr].dsk"} },
   {0x9995ddbe, {"ce258c0c764d36a88fa6d903b03a2e8e"}, {"Master Chess (Mastertronic)/Master Chess (1987)(Mastertronic)[cr].dsk"} },
   {0x1210c20f, {"a58fed50fd2f9db2c786bde7b8185002"}, {"Mindshadow (Activision)/Mindshadow (1986)(Activision).dsk"} },
   {0x0f071249, {"f801d674d1282e78ed244aec388f2a71"}, {"Moving Target (Players Premier)/Moving Target (1989)(Players Premier)[cr].dsk"} },
   {0xbd6ed47c, {"e120762a59d857337daf8eef7cb7daba"}, {"Mr Pingo (Rainbow Arts)/Mr Pingo (1986)(Rainbow Arts)[cr].dsk"} },
   {0x8deb606e, {"0000cd892466e6b34b879cab27ec3217"}, {"Mission Genocide (Firebird)/Mission Genocide (1987)(Firebird)[cr].dsk"} },
   {0xffc8baaf, {"2f0b4fcfea1feed5a348281ceec07a90"}, {"Mission (Loriciels)/Mission (1987)(Loriciels).dsk"} },
   {0xe9d9f77e, {"60df39d8a25f75da2aa64601b19f4335"}, {"Mazie (Zeppelin Games)/Mazie (1988)(Zeppelin Games)[cr].dsk"} },
   {0xdc036664, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Motor Massacre (Gremlin Graphics Software)/Motor Massacre (1988)(Gremlin Graphics Software).dsk"} },
   {0x4882c41a, {"f2756379aded668a756762145b1e13df"}, {"Mercenary (Novagen Software) (de)/Mercenary (1987)(Novagen Software)(de).dsk"} },
   {0x0b45fb5b, {"f55754e53a9aa433efbc590234fea169"}, {"Mokowe (Lankhor) (France)/Mokowe (1991)(Lankhor)(fr)(Side A).dsk"} },
   {0xa673019e, {"457a848b6e0b84c6d8c3579107f09e72"}, {"Metropolis (The Power House)/Metropolis (1988)(The Power House)[cr].dsk"} },
   {0xad5f8b5b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mandragore (Infogrames) (France)/Mandragore (1985)(Infogrames)(fr)(Side A).dsk"} },
   {0xb043f026, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Mission Elevator (Eurogold)/Mission Elevator (1988)(Eurogold).dsk"} },
   {0x159ed0f1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Meurtre a Grande Vitesse (Cobra Soft) (France)/Meurtre a Grande Vitesse (1985)(Cobra Soft)(fr).dsk"} },
   {0xc36d1efd, {"ff6274a4746fdcaf40b526b35fa58162"}, {"Mad Mix Game (Topo Soft) (Spain)/Mad Mix Game (1988)(Topo Soft)(es)[cr].dsk"} },
   {0x697d2d31, {"c622ce1785c738ec87d36a85bf5918eb"}, {"Manoir de Mortvielle, Le (Lankhor) (France)/Manoir de Mortvielle, Le (1988)(Lankhor)(fr)(Side A).dsk"} },
   {0x0c5444f8, {"96b96dde9b4cf48749e5a185e4eb01ab"}, {"Magic Sword, The (Database Educational Software)/Magic Sword, The (1984)(Database Educational Software).dsk"} },
   {0xf3dcb034, {"85ee27cbf0f3b86104a83dd531bb2b28"}, {"Match Day (Ocean Software)/Match Day (1985)(Ocean Software)[cr].dsk"} },
   {0xb13a3365, {"f9375fd652d103728598f02ac6b9fdb4"}, {"Meurtres a Venise (Cobra Soft) (France)/Meurtres a Venise (1988)(Cobra Soft)(fr)(Side A).dsk"} },
   {0xed1262ad, {"83bc2112c35a93b65bd485db8ec021e7"}, {"Mini-Centipede (PD)/Mini-Centipede (2001)(PD)[cr].dsk"} },
   {0x209fa05d, {"8f38b09a938bab3f128b943df8af82f1"}, {"Mr Pingo (Rainbow Arts) (M2)/Mr Pingo (1986)(Rainbow Arts)(M2)[cr].dsk"} },
   {0xdaf163ba, {"0f3ce766494c244fb3e069ee60809d95"}, {"Masters of the Universe (Gremlin Graphics Software) (France)/Masters of the Universe (1987)(Gremlin Graphics Software)(fr).dsk"} },
   {0x55dc54ee, {"0f909790a4337363c7edd236a97138f5"}, {"Mahjong (Liffsoft)/Mahjong (1986)(Liffsoft)[cr].dsk"} },
   {0x4486bb08, {"9628fddeb333a865502f6f6bf347ea3e"}, {"Mountains of Ket (Incentive)/Mountains of Ket (1987)(Incentive)[cr].dsk"} },
// {0x75a53bec, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Megablasters (Radical Software)/Megablasters (1994)(Radical Software)(Disk 1 Side A).dsk"} },
// {0xf9bc30df, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Molecularr (Amstrad Cent Pour Cent)/Molecularr (1990)(Amstrad Cent Pour Cent)[cr].dsk"} },
   {0x11f43936, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mr Heli (Firebird)/Mr Heli (1989)(Firebird).dsk"} },
   {0x789e6383, {"386c60bd462bb53d13112cda8ec7f283"}, {"Mines (CRCT)/Mines (1994)(CRCT)(PD)[cr].dsk"} },
// {0x34dc1faa, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"M'enfin - Gaston (Ubi Soft) (France)/M'enfin - Gaston (1987)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x71f4ff32, {"457a848b6e0b84c6d8c3579107f09e72"}, {"Metro 2018 (Initiel) (France)/Metro 2018 (1985)(Initiel)(fr).dsk"} },
   {0x41332486, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Moontorc (Atlantis Software)/Moontorc (1991)(Atlantis Software)[cr][f].dsk"} },
   {0xc0334b8e, {"d248b6e0c6f3b7c5ebc3eabe519e6337"}, {"Mantis 2 (MCM Software) (Spain)/Mantis 2 (1990)(MCM Software)(es)[cr].dsk"} },
   {0xeed2b2e6, {"c4b33bca7959da788a01bb69f841c56b"}, {"Minisenso (JM)/Minisenso (1992)(JM)(PD)[cr].dsk"} },
   {0x5e917c38, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Meurtres en Serie (Cobra Soft) (France)/Meurtres en Serie (1987)(Cobra Soft)(fr)(Side A).dsk"} },
   {0xcbc0e70f, {"664b79d0e5b74bdfe8cd73f219f76b08"}, {"Mach 3 (Loriciels)/Mach 3 (1987)(Loriciels).dsk"} },
   {0x6f132709, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mundial de Futbol (Opera Soft) (Spain)/Mundial de Futbol (1990)(Opera Soft)(es).dsk"} },
   {0x1f07cc81, {"0f3ce766494c244fb3e069ee60809d95"}, {"Manchester United (Krisalis Software) (Spain)/Manchester United (1990)(Krisalis Software)(es).dsk"} },
   {0x29f601f4, {"d9211d7756e554806c47a7cbe65a9d7f"}, {"MGT - Magnetik Tank (Loriciels) (France)/MGT - Magnetik Tank (1986)(Loriciels)(fr).dsk"} },
   {0x5a5f6699, {"cfbcd7b6f876f783056061d6a536fe73"}, {"Moors Challenge, The (Timeslip Software)/Moors Challenge, The (1984)(Timeslip Software)[cr].dsk"} },
   {0xc3e4ab94, {"f0be23720d824ad637abcb370169c47e"}, {"Mr Wong's Loopy Laundry (Amsoft)/Mr Wong's Loopy Laundry (1984)(Amsoft)[cr].dsk"} },
   {0x2dce1a57, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Monty Pythons Flying Circus (Virgin Games) (Codes)/Monty Pythons Flying Circus (1990)(Virgin Games)[codes].dsk"} },
   {0xec4ec694, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Malefice des Atlantes, Le (Chip) (France)/Malefice des Atlantes, Le (1987)(Chip)(fr).dsk"} },
// {0x23af9eb4, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Maitre Absolu, Le (Ubi Soft) (France)/Maitre Absolu, Le (1989)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xe8d15029, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Miss Input (cpcretrodev.byterealms)/Miss Input (2019)(cpcretrodev.byterealms)[tape].dsk"} },
   {0xdfcc4b07, {"5f1897618e844aac1e74f3fb0e7aa6d8"}, {"Morpions (Depinoy Daniel) (France)/Morpions (1985)(Depinoy Daniel)(fr)[cr].dsk"} },
   {0xb279d4c8, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Mad Mix 2 - En el Castillo de los Fantasmas (Topo Soft) (Spain)/Mad Mix 2 - En el Castillo de los Fantasmas (1990)(Topo Soft)(es).dsk"} },
   {0x48adf9cf, {"9ae7dd918ea21914619a2ae5319410c2"}, {"Molecularr 2 (Amstrad Cent Pour Cent)/Molecularr 2 (1991)(Amstrad Cent Pour Cent)[cr].dsk"} },
   {0xf5751383, {"c147dcdab6df30eac5c35a4231994af7"}, {"Match Point (Psion)/Match Point (1985)(Psion)[cr].dsk"} },
   {0xb70a9759, {"f2756379aded668a756762145b1e13df"}, {"Mercenary (Novagen Software)/Mercenary (1987)(Novagen Software).dsk"} },
   {0x7f16b4bd, {"ae023ddd95a162d7fc9002398faeaf48"}, {"Magic Maths (Players)/Magic Maths (1986)(Players)[cr].dsk"} },
   {0xcd9dbf9c, {"d10388b395966e3dc49bfcfa837cfbfb"}, {"Manic Miner (Software Projects)/Manic Miner (1984)(Software Projects)[tape][BASIC 1.0].dsk"} },
   {0x54339699, {"f2756379aded668a756762145b1e13df"}, {"Mercenary (Novagen Software) (France)/Mercenary (1987)(Novagen Software)(fr).dsk"} },
   {0x0eeae24a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Mortadelo y Filemon II (Dro Soft)/Mortadelo y Filemon II (1989)(Dro Soft).dsk"} },
   {0x82acc11e, {"aa2ed9cb1f42bd6f149f1ae471e16894"}, {"Mega-Corp (Dinamic Software) (Spain)/Mega-Corp (1987)(Dinamic Software)(es)[cr].dsk"} },
   {0xdbc29c10, {"664b79d0e5b74bdfe8cd73f219f76b08"}, {"Mach 3 (Loriciels) (France)/Mach 3 (1987)(Loriciels)(fr).dsk"} },
   {0xa5302940, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mandragore (Infogrames) (de)/Mandragore (1986)(Infogrames)(de)(Side A).dsk"} },
   {0xf4dfdb4a, {"1059281249eb4ea14f0b0aaaad79ef07"}, {"Mystery of Arkham Manor, The (Melbourne House)/Mystery of Arkham Manor, The (1987)(Melbourne House)[cr].dsk"} },
   {0xb69c3207, {"bdb1fa233f4396bbe3f56f93dd2e5a6f"}, {"Mano Negra (Micro Mag) (France)/Mano Negra (1990)(Micro Mag)(fr)[cr].dsk"} },
   {0xcad04368, {"595bf9a5a956cd85e4c24fe19f73868a"}, {"Military School (AM-Mag)/Military School (1989)(AM-Mag)[cr].dsk"} },
   {0x398be600, {"2aa194021f5081a56d29cebbaf268698"}, {"Moonmist (Infocom)/Moonmist (1986)(Infocom)[CPM].dsk"} },
   {0x15d53d43, {"25e6b10afddbe47050e09498fcd3efea"}, {"Mac 1 (Scull PD Library)/Mac 1 (19xx)(Scull PD Library)(PD)[cr].dsk"} },
   {0xdfeb8592, {"6315a07d371f0ce94ac5181d5b8fc7ba"}, {"Mega Chess (CP Software) (Spain)/Mega Chess (1988)(CP Software)(es)[cr].dsk"} },
   {0xbd48490a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mega Phoenix (Dinamic Software)/Mega Phoenix (1991)(Dinamic Software).dsk"} },
   {0xcfc732ab, {"0f3ce766494c244fb3e069ee60809d95"}, {"Masters of the Universe (Gremlin Graphics Software)/Masters of the Universe (1987)(Gremlin Graphics Software).dsk"} },
   {0xccc7f59a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Megawar (Genesis Software)/Megawar (1990)(Genesis Software)[cr].dsk"} },
   {0x3309d69e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mike Gunner (Dinamic Software) (Spain) (LightGun)/Mike Gunner (1988)(Dinamic Software)(es)(LightGun).dsk"} },
   {0x24af346e, {"b93da24bed2f6fd995c25eff6a8045b3"}, {"Maquina del Tiempo, La (Noel Llopis Artime) (Spain)/Maquina del Tiempo, La (1989)(Noel Llopis Artime)(es)[cr].dsk"} },
   {0xe002cf9c, {"5999d941d4fd5c938641bb5166720982"}, {"Mille et un Voyages, Les (Carraz Editions) (France)/Mille et un Voyages, Les (1989)(Carraz Editions)(fr)(Side A).dsk"} },
   {0x3e51adc0, {"c68076620e353d3feae594cc90a2f4ca"}, {"Metaplex (Addictive Games)/Metaplex (1988)(Addictive Games).dsk"} },
   {0x71e4f836, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Mr Weems and the She Vampires (Piranha)/Mr Weems and the She Vampires (1987)(Piranha).dsk"} },
   {0x056040fa, {"4fdd0ac2d139eb0a2112392669eec97a"}, {"Max Headroom (Quicksilva)/Max Headroom (1986)(Quicksilva)[cr].dsk"} },
   {0xe12ac3b6, {"5fd8088a21f2797fc1936f109846a487"}, {"Mordon's Quest (Melbourne House)/Mordon's Quest (1985)(Melbourne House)[tape].dsk"} },
   {0x62c0e892, {"4572268b1bac3d55494d8d5ef156a27d"}, {"Message from Andromeda (Interceptor Software)/Message from Andromeda (1986)(Interceptor Software)[cr].dsk"} },
   {0x671e3957, {"d35cd85404f540258dade17ba5e6e0b1"}, {"Moto Driver (Loriciels) (France)/Moto Driver (1986)(Loriciels)(fr)[cr].dsk"} },
   {0x97b8b3a9, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Mad Mix Game - The Pepsi Challenge (Topo Soft)/Mad Mix Game - The Pepsi Challenge (1988)(Topo Soft).dsk"} },
   {0xfb354864, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Mutants (Ocean Software)/Mutants (1987)(Ocean Software).dsk"} },
   {0x0eae7e77, {"b8ef82204ddbeb5dd033598c0d34e9b2"}, {"Milk Race (Mastertronic)/Milk Race (1987)(Mastertronic)[cr].dsk"} },
   {0xdc93ff81, {"e120762a59d857337daf8eef7cb7daba"}, {"Mr Pingo (Rainbow Arts) (France)/Mr Pingo (1986)(Rainbow Arts)(fr)[cr].dsk"} },
   {0x4518ef00, {"68f3c499271e425c54a3df1e560d5ee0"}, {"Mystery of the Nile, The (Zigurat)/Mystery of the Nile, The (1987)(Zigurat).dsk"} },
   {0xd1fbd4c6, {"dcaa6541e40ed27d9f8fe59c1338541f"}, {"Murder Off Miami (CRL Group)/Murder Off Miami (1986)(CRL Group)[cr].dsk"} },
   {0xbd99351f, {"aa78264b25e078c691042795d220a3a3"}, {"Mission 1 - Project Volcano (Mission Software)/Mission 1 - Project Volcano (1985)(Mission Software)[cr].dsk"} },
   {0x70da91c0, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mot (Opera Soft) (Spain)/Mot (1989)(Opera Soft)(es)(Side A).dsk"} },
   {0xca7f19e3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Magic Johnson's Basketball (Dro Soft) (Spain)/Magic Johnson's Basketball (1990)(Dro Soft)(es).dsk"} },
   {0x01938d46, {"5eb85b7150212462323ac62c7e956f9f"}, {"Manoir de Rochebrune, Le (CPC) (France)/Manoir de Rochebrune, Le (1985)(CPC)(fr)[cr][f].dsk"} },
   {0xa0469898, {"386c60bd462bb53d13112cda8ec7f283"}, {"Minesweeper (Dream Soft)/Minesweeper (1992)(Dream Soft)(PD)[cr].dsk"} },
   {0x950f5102, {"758ed9585e2057880cc306ba073d03d9"}, {"Marble Madness Construction Set (Melbourne House)/Marble Madness Construction Set (1986)(Melbourne House)[cr].dsk"} },
   {0x3b567f38, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Marauder (Hewson)/Marauder (1988)(Hewson).dsk"} },
   {0x834d2a48, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Mermaid Madness (Activision)/Mermaid Madness (1986)(Activision).dsk"} },
   {0x858b7ddf, {"28873cbb646e036d051b8471c8a746e4"}, {"Meganova - The Weapon (Dinamic Software)/Meganova - The Weapon (1988)(Dinamic Software)[cr][f].dsk"} },
   {0x31bddd66, {"3f437954b8e2699b9cc4f4ad835e282e"}, {"Moon Buggy (1985)/Moon Buggy (UK) (1985)[cr].dsk"} },
   {0xe5d0fff0, {"0b60eb22b885cd187f8dcdcfe2b8ab58"}, {"Maggot Splat (Your Computer) (Spain)/Maggot Splat (1985)(Your Computer)(es)[cr].dsk"} },
   {0x9567d632, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Mobile Man (Loriciels) (France)/Mobile Man (1989)(Loriciels)(fr).dsk"} },
// {0x65bdaadd, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Macadam Bumper (PSS)/Macadam Bumper (1985)(PSS).dsk"} },
   {0x7a30b534, {"1115be24255b04792f69c577ea118b58"}, {"Monty on the Run (Gremlin Graphics Software)/Monty on the Run (1986)(Gremlin Graphics Software).dsk"} },
   {0xb7f1a1c7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Metropolis (Topo Soft) (Spain)/Metropolis (1989)(Topo Soft)(es).dsk"} },
// {0x888d910d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Macrocosmica (Datacom Publications)/Macrocosmica (1986)(Datacom Publications).dsk"} },
   {0xc82e3009, {"6fab15c2902608cf488dc3cfbea89a56"}, {"Masters of Space, The - X Levels (Radical Software)/Masters of Space, The - X Levels (1994)(Radical Software)[cr].dsk"} },
   {0x764ab702, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mask III - Venom Strikes Back (Gremlin Graphics Software)/Mask III - Venom Strikes Back (1988)(Gremlin Graphics Software).dsk"} },
   {0x735be17b, {"284b8e3bce273b72097cc98ecbb45ddc"}, {"Marmelade (MBC Informatique) (France)/Marmelade (1987)(MBC Informatique)(fr)[cr].dsk"} },
   {0x3c7b9432, {"478db42058740a36d79728a2baf2fe05"}, {"Mercenaire (Rainbow Productions)/Mercenaire (1986)(Rainbow Productions)[cr].dsk"} },
   {0x917f5380, {"0f3ce766494c244fb3e069ee60809d95"}, {"Meganova (Dinamic Software) (Spain)/Meganova (1988)(Dinamic Software)(es).dsk"} },
   {0x9e91c2c9, {"0c9b63109740eb200355455ab6b51df6"}, {"Mister Gas (Proein Soft Line) (Spain)/Mister Gas (1990)(Proein Soft Line)(es).dsk"} },
   {0xdaf34394, {"a1ec40f78074bf3d6385b355d788339a"}, {"Mata Hari (Loriciels) (France)/Mata Hari (1988)(Loriciels)(fr).dsk"} },
   {0x1e6eb6ce, {"df94f81e4cf4ad0fc1de4f2204ae2b1f"}, {"Manager (ERE Informatique) (Spain)/Manager (1985)(ERE Informatique)(es)(hack)[cr].dsk"} },
// {0xfeb65eff, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Masque (Ubi Soft) (France)/Masque (1986)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x42646875, {"24e5eda8764a66c95a601eb548a33f4b"}, {"Manhattan 95 (Ubi Soft)/Manhattan 95 (1986)(Ubi Soft).dsk"} },
   {0xb40c5cb2, {"3fb09e9960cb3c539e8dc370fdc53291"}, {"Murder on the Atlantic (Cobra Soft)/Murder on the Atlantic (1985)(Cobra Soft)(Side A).dsk"} },
   {0x80f7e58a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Masterchess (Amsoft)/Masterchess (1984)(Amsoft).dsk"} },
   {0xc14e1245, {"4eb77cee99810ca4019a09e3bc60405a"}, {"Mambo (Positive) (Spain)/Mambo (1989)(Positive)(es).dsk"} },
   {0x5ca84322, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Madballs (Ocean Software)/Madballs (1988)(Ocean Software).dsk"} },
   {0xd3c12dc7, {"b5c6f305ae89ba12305c0fb5dc08219f"}, {"Maze (CPC)/Maze (1985)(CPC)[cr].dsk"} },
   {0x29eb1f2a, {"42e6b7e3acdce48a334b0a240fe73446"}, {"Montsegur (Norsoft) (France)/Montsegur (1985)(Norsoft)(fr)[cr].dsk"} },
   {0xaeeb7e36, {"66c3fc0618301d03485e0658dcb2f957"}, {"Muri (Happy Computer)/Muri (1987)(Happy Computer)[cr].dsk"} },
   {0x76225bd5, {"0f3ce766494c244fb3e069ee60809d95"}, {"Manchester United (Krisalis Software) (M5)/Manchester United (1990)(Krisalis Software)(M5)(Side A).dsk"} },
   {0x677a184f, {"e78aca6cf7a3804d4d288c40c2f8e587"}, {"Manoir du Comte Frozarda, Le (MBC Informatique) (France)/Manoir du Comte Frozarda, Le (1988)(MBC Informatique)(fr)[cr].dsk"} },
   {0x3b29d8fe, {"4d7e7ab324cc84b3be1adff48e50d8b1"}, {"Mystery of the Indus Valleys (Alternative Software)/Mystery of the Indus Valleys (1987)(Alternative Software)[cr].dsk"} },
   {0x901e677f, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Meurtre sur LAtlantique (Cobra Soft) (France)/Meurtre sur LAtlantique (1985)(Cobra Soft)(fr)(Side A)[cr].dsk"} },
   {0x055e2b83, {"0f3ce766494c244fb3e069ee60809d95"}, {"Mythos (Opera Soft)/Mythos (1990)(Opera Soft).dsk"} },
   {0x73d376a3, {"9a7962cb481a9a4358ad1826ec1dfebd"}, {"Malefices (Nicolas Cocaign) (France)/Malefices (1992)(Nicolas Cocaign)(fr)(Side A)[cr].dsk"} },
   {0x2d8d5877, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Metro Cross (US Gold)/Metro Cross (1987)(US Gold).dsk"} },
   {0x2483557e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Metropol (Zafiro Software) (Spain)/Metropol (1988)(Zafiro Software)(es).dsk"} },
// {0x16c28934, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Macadam Bumper (PSS) (de)/Macadam Bumper (1985)(PSS)(de)[cr].dsk"} },
   {0x6eafbd80, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Moonwalker (US Gold)/Moonwalker (1989)(US Gold).dsk"} },
   {0x00163387, {"b59501c73a8d7445034380af07e248c9"}, {"Mantis 1 (MCM Software) (Spain)/Mantis 1 (1990)(MCM Software)(es)[cr].dsk"} },
   {0x2a5b9b60, {"548a4d331165899f560f167ad5dbfd18"}, {"Maddog (Titus)/Maddog (1987)(Titus)[cr].dsk"} },
   {0xa1c366b6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Nexus (Nexus)/Nexus (1986)(Nexus).dsk"} },
   {0x363b6a03, {"0f3ce766494c244fb3e069ee60809d95"}, {"Narco Police (Dinamic Software)/Narco Police (1990)(Dinamic Software)[f].dsk"} },
   {0xf048d226, {"5446a9e69d938210ca782dd301f8abbc"}, {"Nonamed (Dinamic Software) (Spain)/Nonamed (1986)(Dinamic Software)(es)[cr].dsk"} },
   {0xbf564629, {"0f3ce766494c244fb3e069ee60809d95"}, {"North & South (Infogrames) (M3)/North & South (1989)(Infogrames)(M3)(Side A).dsk"} },
   {0xebd801cd, {"09ac41aff4b6a6b659dd5d444e9af6f9"}, {"Nigromante, El (Ubi Soft) (Spain) (Hack)/Nigromante, El (2019)(Ubi Soft)(es)(Hack)(Side A)[cr].dsk"} },
   {0x9299697c, {"0f3ce766494c244fb3e069ee60809d95"}, {"Navy Moves (Dinamic Software)/Navy Moves (1988)(Dinamic Software).dsk"} },
   {0x89c0c313, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Nocturne (Alpha Omega Software)/Nocturne (1986)(Alpha Omega Software)[cr].dsk"} },
// {0x5579ba92, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Nosferatu the Vampyre (Piranha) (Bugs)/Nosferatu the Vampyre (1986)(Piranha)[b].dsk"} },
   {0xaecc8465, {"232cd51f685f5ca56c3c22e8c74985a8"}, {"Nigel Mansell's Grand Prix (Martech)/Nigel Mansell's Grand Prix (1988)(Martech).dsk"} },
   {0x06cdf929, {"929576542f86c1a29cb84bf4d5c3de7e"}, {"Ninja Scooter Simulator (Silverbird)/Ninja Scooter Simulator (1988)(Silverbird)[cr].dsk"} },
   {0x38c99e42, {"8b2fe9f5d66fd2118a7dd10ba01830c3"}, {"Nonterraqueous (Mastertronic)/Nonterraqueous (1985)(Mastertronic)[cr].dsk"} },
   {0xdc356958, {"5fbe28f66bfc5f910fdeb69e91c4ffee"}, {"Nemesis IV (Cascade Games)/Nemesis IV (1986)(Cascade Games)[cr].dsk"} },
   {0x47cd9774, {"905eb46dd909af9fa7424cdca5cb0b2a"}, {"Nonamed (Dinamic Software)/Nonamed (1986)(Dinamic Software)[cr][f].dsk"} },
   {0x480e33f5, {"52756bdde72d55f8a171066ed6ff40ce"}, {"Newmarket (Computing With The Amstrad)/Newmarket (1988)(Computing With The Amstrad)[cr].dsk"} },
   {0x7807f952, {"74b35a40130958a25af2f4aaa20c9e27"}, {"Nervous Break Down (Hebdogiciel) (France)/Nervous Break Down (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x5867c8e4, {"51368674244645ac3edaec4391889f09"}, {"Night Gunner (Digital Integration) (M3) (Codes)/Night Gunner (1989)(Digital Integration)(M3)[codes].dsk"} },
   {0x93743dc7, {"68334f3ad749f19fac1a8c4badbed936"}, {"Necris Dome (Codemasters Software)/Necris Dome (1987)(Codemasters Software)[cr].dsk"} },
   {0xf5b719cc, {"c68076620e353d3feae594cc90a2f4ca"}, {"Nemesis the Warlock (Martech Games)/Nemesis the Warlock (1987)(Martech Games).dsk"} },
   {0xbda05d27, {"929576542f86c1a29cb84bf4d5c3de7e"}, {"Ninja Massacre (Codemasters Software)/Ninja Massacre (1989)(Codemasters Software)[cr].dsk"} },
   {0x8f0b963f, {"61264589ec31142aaf119429ec1b2df0"}, {"Nightshade (Ultimate Play The Game)/Nightshade (1985)(Ultimate Play The Game)[cr].dsk"} },
// {0x3d981755, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Necromancien, Le (Ubi Soft) (France)/Necromancien, Le (1987)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xadc86f57, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Narc (Ocean Software)/Narc (1990)(Ocean Software)(Side A).dsk"} },
   {0xa084af0d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Netherworld (Hewson)/Netherworld (1988)(Hewson).dsk"} },
   {0x99dcfd1b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"New Zealand Story, The (Ocean Software)/New Zealand Story, The (1989)(Ocean Software)(Side A).dsk"} },
   {0x7db9cd99, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Nebulus (Hewson Consultants)/Nebulus (1988)(Hewson Consultants)[f].dsk"} },
   {0x5ebefb4b, {"e27412929cf42cf73e02a9ef315b4397"}, {"Not a Penny More, Not a Penny Less (Domark)/Not a Penny More, Not a Penny Less (1987)(Domark)(Side A).dsk"} },
   {0xa26962d6, {"8fa92c5cd70876edb5090a7c543553f2"}, {"Ninja Commando (Zeppelin Games)/Ninja Commando (1989)(Zeppelin Games)[cr].dsk"} },
   {0xd9fe8817, {"929576542f86c1a29cb84bf4d5c3de7e"}, {"Ninja (Micro Mag)/Ninja (1990)(Micro Mag)[cr].dsk"} },
   {0x358fc009, {"a1f4dea89360e1133d5efdbee21b8655"}, {"Neil (Alternative Software)/Neil (1988)(Alternative Software)[cr].dsk"} },
   {0x5c06632f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Night Raider (Gremlin Graphics Software)/Night Raider (1988)(Gremlin Graphics Software).dsk"} },
   {0xa816b717, {"0f3ce766494c244fb3e069ee60809d95"}, {"Nigel Mansell's World Championship (Gremlin Graphics Software)/Nigel Mansell's World Championship (1992)(Gremlin Graphics Software)(Side A).dsk"} },
   {0x722c18aa, {"a24ade2746085db8374614797a5fdc55"}, {"NeverEnding Story, The (Ocean Software)/NeverEnding Story, The (1985)(Ocean Software).dsk"} },
   {0xe4ce7e73, {"c656e1c17f87bebd6e701896fae8026a"}, {"Nodes of Yesod (Odin Computer Graphics)/Nodes of Yesod (1986)(Odin Computer Graphics).dsk"} },
   {0x380c424f, {"b3ce80a1dd7dc7dee2d294240cc7b682"}, {"Nibbler (Mosaik Software)/Nibbler (1984)(Mosaik Software)[cr].dsk"} },
   {0x2d67b1d6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Nick Faldo Plays the Open (Mind Games)/Nick Faldo Plays the Open (1985)(Mind Games).dsk"} },
   {0x6c2cdcea, {"84f4f6bcee21dc2b6d472b9b9db46c12"}, {"Nanako Descends To Hell (The Mojon Twins)/Nanako Descends To Hell (2019)(The Mojon Twins).dsk"} },
   {0xb5396b62, {"8fa92c5cd70876edb5090a7c543553f2"}, {"Ninja (Mastertronic)/Ninja (1987)(Mastertronic)[cr].dsk"} },
   {0xf2f19689, {"0f3ce766494c244fb3e069ee60809d95"}, {"Night Breed (Ocean Software)/Night Breed (1990)(Ocean Software)(Side A).dsk"} },
   {0x1312d1b3, {"406f4af2143829acd4b7634d6f7d7017"}, {"Number 1 (Bug-Byte)/Number 1 (1986)(Bug-Byte)[cr].dsk"} },
   {0x10e96c91, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Nythyhel - Files of the Occult (50-50 Club Software)/Nythyhel - Files of the Occult (1986)(50-50 Club Software)[cr].dsk"} },
   {0xfa3a4ad5, {"c68076620e353d3feae594cc90a2f4ca"}, {"Ninja Warriors, The (Virgin Games)/Ninja Warriors, The (1989)(Virgin Games).dsk"} },
   {0xacf62400, {"0f3ce766494c244fb3e069ee60809d95"}, {"Navy Moves (Dinamic Software) (Spain) (Hack)/Navy Moves (1988)(Dinamic Software)(es)(Hack)[cr].dsk"} },
   {0x0b35ed50, {"017b1d601b1c0d111042cecfdefc2d31"}, {"Nemesis (Konami)/Nemesis (1987)(Konami).dsk"} },
   {0xc8ae3fad, {"0f3ce766494c244fb3e069ee60809d95"}, {"North Star (Gremlin Graphics Software)/North Star (1988)(Gremlin Graphics Software).dsk"} },
   {0x62573108, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Ninja Hamster (CRL Group)/Ninja Hamster (1987)(CRL Group).dsk"} },
   {0x63916ce0, {"1e720e450479b229ee2d27e1599f4347"}, {"Nightmare Park (Strategy Software)/Nightmare Park (1985)(Strategy Software)[cr].dsk"} },
   {0xe920b1e1, {"f9bbae48f52a8bee75498b01b275154d"}, {"Night Booster (Cobra Soft) (France)/Night Booster (1985)(Cobra Soft)(fr)[cr].dsk"} },
   {0xa43eb279, {"9f6e240837fc648cc4ade57fece91f5c"}, {"Night Gunner (Digital Integration) (M3)/Night Gunner (1989)(Digital Integration)(M3)[cr].dsk"} },
   {0x1e1b4feb, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Nakamoto (Alpha Omega Software)/Nakamoto (1987)(Alpha Omega Software)[cr].dsk"} },
   {0xfc53cce8, {"929576542f86c1a29cb84bf4d5c3de7e"}, {"Ninja Master (Firebird)/Ninja Master (1986)(Firebird)[cr].dsk"} },
   {0x6761ee78, {"f56a76cfeaa10a2479f1422081603f94"}, {"Night Hunter (Ubi Soft) (Spain)/Night Hunter (1990)(Ubi Soft)(es)(Side A).dsk"} },
   {0xdfaa4154, {"f4e47bb0dd94f97d5f88143ce2fee50d"}, {"Nuclear Heist (Players)/Nuclear Heist (1986)(Players)[cr].dsk"} },
   {0xd53f9fdb, {"5215a15e199811e0845ea5a2a88782aa"}, {"No Exit (Coktel Vision)/No Exit (1990)(Coktel Vision).dsk"} },
   {0x803fc2a2, {"0f3ce766494c244fb3e069ee60809d95"}, {"N.E.X.O.R. (Design Design Software)/N.E.X.O.R. (1986)(Design Design Software)[Custom, 64sectors].dsk"} },
   {0xeae0e80f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Night Shift (US Gold)/Night Shift (1991)(US Gold).dsk"} },
   {0xb3f243a2, {"1e720e450479b229ee2d27e1599f4347"}, {"Nightmare Maze (CDS Software)/Nightmare Maze (1986)(CDS Software)[cr].dsk"} },
   {0x159d5a2c, {"61264589ec31142aaf119429ec1b2df0"}, {"Night Hunter (Ubi Soft) (France)/Night Hunter (1990)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x2ff420da, {"49d572df5506b590e60046c992c3056d"}, {"Oh Mummy! (Amsoft)/Oh Mummy! (1984)(Amsoft)[cr].dsk"} },
   {0x3c1c3d56, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Olaf (Amstrad Cent pour Cent) (France)/Olaf (1992)(Amstrad Cent pour Cent)(fr)[cr].dsk"} },
   {0x317e04e9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Oriental Games (Micro Style)/Oriental Games (1990)(Micro Style)(Side A).dsk"} },
   {0xb8b1db15, {"ab37ce9061a49290f50b9f69767e3a26"}, {"Omega Dimension (Positive) (Spain)/Omega Dimension (1989)(Positive)(es)[cr].dsk"} },
   {0x505e5041, {"95eb6dde3b018395f4f216f64556ec0e"}, {"Olympiad '86 (Atlantis Software)/Olympiad '86 (1986)(Atlantis Software)[cr].dsk"} },
   {0x28dfb62b, {"4d8b935dc371cbaa0d657fc750b5ce0a"}, {"Ormuz (Iber Soft) (Spain)/Ormuz (1988)(Iber Soft)(es)[tape].dsk"} },
   {0x20de516d, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Out Run Europa (US Gold)/Out Run Europa (1991)(US Gold)(Side A).dsk"} },
   {0x2083b8b5, {"e14e520da5dfede9fc04ecb3c6066557"}, {"On the Run (Design Design Software)/On the Run (1985)(Design Design Software)[cr].dsk"} },
   {0x8099581a, {"b82c460537533d762ab335d1cc628e8b"}, {"Omeyad (Ubi Soft) (France)/Omeyad (1989)(Ubi Soft)(fr).dsk"} },
   {0x2ce75743, {"aa150c0ae3ed01423c7d856cff1fb27c"}, {"One Man and his Droid (Mastertronic)/One Man and his Droid (1985)(Mastertronic)[cr].dsk"} },
   {0x5d77d588, {"a45f62e340f55fa123ef00f0a780195b"}, {"Othello Master (Power Master) (France)/Othello Master (1985)(Power Master)(fr)[cr].dsk"} },
// {0x2519a761, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Octoplex (Mastertronic)/Octoplex (1989)(Mastertronic)[cr].dsk"} },
   {0x4be97fcf, {"d2f0f2a9b03bbd43a1b4d5c53c89b720"}, {"Orion (Spain)/Orion (Jasap Software)(Spain)[cr].dsk"} },
   {0x549dfa0a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Overlander (Elite Systems)/Overlander (1988)(Elite Systems).dsk"} },
   {0x525d1275, {"a33aeb6a1574bc53b6dcbdb93576bce1"}, {"Official Father Christmas Game, The (Alternative Software)/Official Father Christmas Game, The (1989)(Alternative Software)[cr].dsk"} },
   {0x0d7df404, {"b7dd7cae94846fe5c9ae0d16ffcdab31"}, {"Obsidian (Artic Computing)/Obsidian (1985)(Artic Computing)[cr].dsk"} },
   {0x46d2775d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Obliterator (Melbourne House)/Obliterator (1989)(Melbourne House).dsk"} },
   {0xf334ff41, {"2b40eff8655511f96a21f6c7b76a3105"}, {"Out Of This World (Boxsoft)/Out Of This World (2016)(Boxsoft)[cr].dsk"} },
   {0x2b92d514, {"d7304650b787fa76cda745424c05b84a"}, {"Ocean Conqueror (Hewson)/Ocean Conqueror (1988)(Hewson)[cr].dsk"} },
   {0x6abd6ce2, {"84c9d1c175d44eeb824e35984cc87702"}, {"Oh Mummy! (Amsoft) (Spain)/Oh Mummy! (1984)(Amsoft)(es)[cr].dsk"} },
   {0x5a1d7d59, {"0f3ce766494c244fb3e069ee60809d95"}, {"Omega Planete Invisible (Infogrames) (France)/Omega Planete Invisible (1987)(Infogrames)(fr)(Side A).dsk"} },
   {0x2317e673, {"928f83e21edb9a1d5d73c8c8321e3ad9"}, {"Orphee (Loriciels) (France)/Orphee (1985)(Loriciels)(fr)(Side A).dsk"} },
   {0x0940d89a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Operation Wolf (Ocean Software) (LightGun)/Operation Wolf (1988)(Ocean Software)(LightGun).dsk"} },
   {0x523e055e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Operation Thunderbolt (Ocean Software)/Operation Thunderbolt (1989)(Ocean Software)(Side A).dsk"} },
   {0x6d119419, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Out Run (US Gold)/Out Run (1988)(US Gold)(Side A).dsk"} },
   {0xffd9594e, {"c189cb0f4bdeeeb4c7a8d7a51a731d51"}, {"On the Oche (Artic Computing)/On the Oche (1984)(Artic Computing)[cr].dsk"} },
   {0xb9d5e5e3, {"98ce7cbd419f5fa2fbd49dec9443a92a"}, {"Operation Gunship (Codemasters Software)/Operation Gunship (1989)(Codemasters Software)[cr].dsk"} },
   {0xe9cd997f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Outboard (Loriciels) (France)/Outboard (1990)(Loriciels)(fr).dsk"} },
   {0xfce7fa16, {"283ae18de4e9bcc39a857f3751838061"}, {"On Cue (Mastertronic)/On Cue (1987)(Mastertronic)[cr].dsk"} },
   {0x4d91810b, {"2d6cfc6b03a656bc330e9f80fb805b58"}, {"Oxyda (CPC) (France)/Oxyda (1987)(CPC)(fr)[cr].dsk"} },
   {0xd77dde4b, {"8ace28155fc0be2fa08daddd36086c60"}, {"Off Shore Warrior (Titus)/Off Shore Warrior (1989)(Titus).dsk"} },
// {0x365d9220, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Oxphar (ERE Informatique) (France)/Oxphar (1987)(ERE Informatique)(fr)(Side A).dsk"} },
   {0x7c6c1e2e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Operation Wolf (Ocean Software)/Operation Wolf (1988)(Ocean Software).dsk"} },
// {0x1959a428, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"One (D3M)/One (1986)(D3M).dsk"} },
   {0xc61bddb3, {"0511c1f017fa689ac3cd309c629911f3"}, {"Orifice from Outer Space (Plasma Touch)/Orifice from Outer Space (19xx)(Plasma Touch)[cr].dsk"} },
   {0x951a0c7d, {"7f117cfbf4703d9ad2e973814d2de435"}, {"Oeil de Set, L' (Ubi Soft) (France)/Oeil de Set, L' (1987)(Ubi Soft)(fr)(v2)(Side A).dsk"} },
   {0xe45fa8de, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Out of This World (Ariolasoft)/Out of This World (1987)(Ariolasoft).dsk"} },
   {0xf1f7aa40, {"e746037a3b53e8655b3b5747428bf876"}, {"Pac-Ball 2 (CPC Infos) (France)/Pac-Ball 2 (1991)(CPC Infos)(fr)[cr].dsk"} },
   {0xc071d82b, {"214a2b2f59e8838de40962ae067d15ba"}, {"Panza Kick Boxing (Loriciels) (France)/Panza Kick Boxing (1990)(Loriciels)(fr).dsk"} },
   {0x21dc2abb, {"3bba6e1db772de5e48aa28a09b2ef638"}, {"Pub Trivia (Codemasters Software)/Pub Trivia (1989)(Codemasters Software)[cr].dsk"} },
// {0x7789187a, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Prehistorik (Titus)/Prehistorik (1991)(Titus).dsk"} },
   {0xbe5ec8f7, {"11ccedfa459e34384eb509af2308adaa"}, {"Python (Chip) (France)/Python (1986)(Chip)(fr)[cr].dsk"} },
   {0xfcefc3b9, {"0211704f2729f9db6ffaea1f5096e370"}, {"Paranoia Complex, The (Magic Bytes)/Paranoia Complex, The (1989)(Magic Bytes)[cr].dsk"} },
   {0x7d6aa040, {"0f3ce766494c244fb3e069ee60809d95"}, {"Pac-Mania (Grandslam Entertainments)/Pac-Mania (1988)(Grandslam Entertainments).dsk"} },
   {0x25af0923, {"3a1a504f4ee2ee4a0c9b07474f0760fc"}, {"Pro Tennis (Loriciels)/Pro Tennis (1986)(Loriciels).dsk"} },
   {0x3b9f7b83, {"2e9bfb7953ebc8b3eb65c16cc4fd9d2d"}, {"Pac-Man (T and T)/Pac-Man (1986)(T and T)(PD)[cr].dsk"} },
   {0xe13a3cc9, {"3e175a3d385bebf284b394c6fb326920"}, {"Porky (PC Schneider International)/Porky (1987)(PC Schneider International)[cr].dsk"} },
   {0x3bf55cb1, {"0b16bb2133aa722d6185296b824ae08e"}, {"Pac Girl v1.2 (CPC Infos)/Pac Girl v1.2 (1993)(CPC Infos)[cr].dsk"} },
   {0xc4190bb5, {"9cae57c9e93d2bb710f50feb7e62fda6"}, {"Pyramides d'Atlantys, Les (Microids) (France)/Pyramides d'Atlantys, Les (1986)(Microids)(fr).dsk"} },
   {0x8af478eb, {"5fd122f7ab9a29dd8ba4f0945dabcf4c"}, {"Pit-Fighter (Domark) (Bugs)/Pit-Fighter (1991)(Domark)(Side A)[b].dsk"} },
   {0xf1e21224, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Paperboy 2 (Mindscape)/Paperboy 2 (1991)(Mindscape).dsk"} },
   {0xee11df0f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pinball Wizard (CP Software) (Spain)/Pinball Wizard (1985)(CP Software)(es).dsk"} },
   {0xaaf3476a, {"ddc05e04dd736b4207c2c5826696d029"}, {"Parabola (Firebird)/Parabola (1987)(Firebird)[cr].dsk"} },
   {0xd6318ce3, {"74187cbe3702879db653a430b001dee8"}, {"Pipeline (PC Amstrad International) (France)/Pipeline (1991)(PC Amstrad International)(fr)[cr].dsk"} },
   {0xd4680ee7, {"0f3ce766494c244fb3e069ee60809d95"}, {"Passagers du Vent (Infogrames) (France)/Passagers du Vent (1986)(Infogrames)(fr)(Side A).dsk"} },
   {0x1d80f5ee, {"c71db403bb67e2d861a80a28e4299db3"}, {"Pirate (Black System)/Pirate (1990)(Black System)[cr].dsk"} },
   {0x194e6cf4, {"f0a3d20f68b7378f15da52073cd276f0"}, {"Psycho Hopper (Mastertronic)/Psycho Hopper (1989)(Mastertronic)[cr].dsk"} },
   {0x000fc745, {"12fd53af3a5c0adda0b2d940107b529d"}, {"Peasants Tale, A (Crysys Software)/Peasants Tale, A (1988)(Crysys Software)[cr].dsk"} },
   {0x5f1a49d4, {"c68076620e353d3feae594cc90a2f4ca"}, {"Prehistorik 2 (Titus) (M3)/Prehistorik 2 (1993)(Titus)(M3).dsk"} },
   {0x4cfeb8db, {"916a262cc0a58829b71037a57e89d087"}, {"Pousnik (CPC Infos) (France)/Pousnik (1991)(CPC Infos)(fr)[cr].dsk"} },
   {0x2c878107, {"0f3ce766494c244fb3e069ee60809d95"}, {"Plundered Hearts (Infocom)/Plundered Hearts (1987)(Infocom)[cr].dsk"} },
   {0xe2c87660, {"7aa803d0ec6579bdaced6a099c0dc46e"}, {"Postman Pat 3 - To the Rescue (Alternative Software)/Postman Pat 3 - To the Rescue (1992)(Alternative Software)[cr].dsk"} },
   {0x0cc6a3f5, {"9620bc85cd6f0b133ce73ec692d216a2"}, {"Pacte, Le (Loriciels) (France)/Pacte, Le (1986)(Loriciels)(fr)(Side A).dsk"} },
   {0xec6fbe67, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"P-47 Thunderbolt - The Freedom Fighter (Firebird Software)/P-47 Thunderbolt - The Freedom Fighter (1990)(Firebird Software).dsk"} },
   {0x0735fecf, {"8c4a2947719e134c8a134fbafb469f26"}, {"Playbox (Norsoft) (France)/Playbox (1985)(Norsoft)(fr)[cr].dsk"} },
   {0xc1831828, {"5592d3216edcc5ecbf2bcf04cd514c79"}, {"Pipeline Plumber (Amstrad Computer User)/Pipeline Plumber (1987)(Amstrad Computer User)[cr].dsk"} },
// {0x0d4da0fb, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Puffy's Saga (Ubi Soft)/Puffy's Saga (1989)(Ubi Soft)(Side A).dsk"} },
   {0xa4c910f5, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Plate-Forme (MBC Informatique) (France)/Plate-Forme (1988)(MBC Informatique)(fr)[cr].dsk"} },
   {0x457d9475, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Philosopher's Quest (Topologika)/Philosopher's Quest (1987)(Topologika)[cr].dsk"} },
   {0x4ebc8925, {"bf0ee5ee90a668762e0a79045a8161fd"}, {"Profanation 2 - Escape from Abu Simbel (4Mhz)/Profanation 2 - Escape from Abu Simbel (2017)(4Mhz).dsk"} },
   {0xe0107438, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Poussy (Fanatic) (France)/Poussy (1991)(Fanatic)(fr).dsk"} },
   {0xf49d6612, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Powerplay - Game of the Gods (Arcana Software Design)/Powerplay - Game of the Gods (1986)(Arcana Software Design)[cr].dsk"} },
   {0xad884f7d, {"9b9a7bb1d23e4f86c3621eaad999847f"}, {"Park Patrol (Firebird)/Park Patrol (1986)(Firebird)[cr].dsk"} },
   {0x70af3425, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pro Tennis Tour (Ubi Soft) (Codes)/Pro Tennis Tour (1990)(Ubi Soft)[codes].dsk"} },
   {0x903781fe, {"15444f000aca8116ce1e148f7ae2d492"}, {"Pro Golf Simulator (Codemasters Software)/Pro Golf Simulator (1990)(Codemasters Software)[cr].dsk"} },
   {0xda8c298f, {"cdef918c54f5eb59f1109c730d4d11a4"}, {"Perestroika 2 - Le Retour (BLB Soft) (France)/Perestroika 2 - Le Retour (1991)(BLB Soft)(fr)[cr].dsk"} },
   {0xe3f0e142, {"a99f26e5c42d32e5c7b2418872688abc"}, {"Psyborg (Loriciels)/Psyborg (1992)(Loriciels).dsk"} },
   {0x200c4423, {"0f3ce766494c244fb3e069ee60809d95"}, {"Passagers du Vent 2 (Infogrames) (France)/Passagers du Vent 2 (1987)(Infogrames)(fr)(Side A).dsk"} },
   {0xcd719517, {"afb0b2ecf87b63ca42ad25ef90f0d08e"}, {"Postman's Destiny (PC Amstrad International)/Postman's Destiny (1989)(PC Amstrad International)[cr].dsk"} },
   {0xb5c6ff7c, {"11ccedfa459e34384eb509af2308adaa"}, {"Python (Chip) (Spain)/Python (1986)(Chip)(es)[cr].dsk"} },
   {0x866335da, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Poule Position (Firebird) (France)/Poule Position (1985)(Firebird)(fr)[cr].dsk"} },
   {0x4257037d, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Profanation (Chip)/Profanation (1987)(Chip).dsk"} },
   {0xaf1988fe, {"9a061f2218b34a6c8370484aa0d35716"}, {"Pheonix Mission, The (Entertainment & Computer Products)/Pheonix Mission, The (1987)(Entertainment & Computer Products)[cr].dsk"} },
   {0x9af2061b, {"1ef6d31d5f1a5e001abb422e36617217"}, {"Planetfall (Infocom)/Planetfall (1983)(Infocom)[CPM].dsk"} },
// {0xc09cd00c, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Peur Sur Amityville (Ubi Soft) (Spain) (Hack)/Peur Sur Amityville (2019)(Ubi Soft)(es)(Hack)(Side A)[cr].dsk"} },
   {0x71d99b9e, {"214a2b2f59e8838de40962ae067d15ba"}, {"Panza Kick Boxing (Loriciels)/Panza Kick Boxing (1990)(Loriciels).dsk"} },
   {0x259559b5, {"419e173bad428fc8de09e8354c6bae5c"}, {"Pinball Power (Mastertronic Plus)/Pinball Power (1989)(Mastertronic Plus).dsk"} },
   {0x89d771f2, {"6942c1053a4d669e2e3d2433c3b26c51"}, {"Pang (Schneider Magazin)/Pang (1990)(Schneider Magazin)[cr].dsk"} },
// {0x72046022, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Peur Sur Amityville (Ubi Soft) (France)/Peur Sur Amityville (1987)(Ubi Soft)(fr)(Side A).dsk"} },
   {0xc84aced2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Poli Diaz Boxeo (Opera Soft) (Codes)/Poli Diaz Boxeo (1991)(Opera Soft)[o][codes].dsk"} },
   {0xd290885b, {"c2a02b28bdbc789d2dd66640d1f24b75"}, {"Pulsator (Martech)/Pulsator (1988)(Martech).dsk"} },
   {0x3baa8f66, {"ac3bedc00eb5ab89d36b68884be55fba"}, {"Paragliding Simulation (Loriciels) (France)/Paragliding Simulation (1991)(Loriciels)(fr).dsk"} },
   {0x6677ce1f, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Psycho Pig UXB (US Gold)/Psycho Pig UXB (1988)(US Gold).dsk"} },
   {0xbfa602b8, {"3f2da9126887545c05687e70bcb53746"}, {"Play Your Cards Right (Britannia Software)/Play Your Cards Right (1986)(Britannia Software)[cr].dsk"} },
   {0x98b87c3b, {"ff8015517cfa92c7ccd6ce9fb8429654"}, {"Plasmatron (CRL Group)/Plasmatron (1988)(CRL Group).dsk"} },
   {0x797c7ff4, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Platoon (Ocean Software)/Platoon (1988)(Ocean Software).dsk"} },
// {0xad4e58e2, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Pepe Bequilles (Softhawk) (France)/Pepe Bequilles (1987)(Softhawk)(fr).dsk"} },
   {0x0c0ba704, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pyjamarama (Mikrogen)/Pyjamarama (1984)(Mikrogen).dsk"} },
   {0xa60eba03, {"0f3ce766494c244fb3e069ee60809d95"}, {"Phantis (Dinamic Software) (Spain)/Phantis (1987)(Dinamic Software)(es).dsk"} },
   {0x525dd4fb, {"7477f0e82f9b173fad52f22173bc9183"}, {"Plaga Galactica, La (Amsoft) (Spain)/Plaga Galactica, La (1984)(Amsoft)(es)[tape].dsk"} },
   {0x961c3ab4, {"7dfa5eeeae2493c7be428100deba0dc5"}, {"Patience (Computing With The Amstrad)/Patience (1987)(Computing With The Amstrad)[cr].dsk"} },
   {0x793e37f5, {"66b4dcb15d9312284841b5bb705439df"}, {"Pirates (Microprose Software) (France)/Pirates (1987)(Microprose Software)(fr)(Side A).dsk"} },
   {0x0adcd87e, {"0597db6b2cc7cf0e3326f01534b024bb"}, {"Prokyon (Pride Soft) (de)/Prokyon (1986)(Pride Soft)(de)[cr].dsk"} },
   {0x3cc3f2a5, {"0b16bb2133aa722d6185296b824ae08e"}, {"Pacman (AM-Mag)/Pacman (1989)(AM-Mag)[cr].dsk"} },
   {0x1580b2b3, {"74187cbe3702879db653a430b001dee8"}, {"Pipe Crazy! (Micro Mag) (France)/Pipe Crazy! (1990)(Micro Mag)(fr)[cr].dsk"} },
   {0x26d85124, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pictionary (Domark) (France)/Pictionary (1989)(Domark)(fr).dsk"} },
   {0x872b7d18, {"7b5ef8f94b89647d0d181b54c34bf5d4"}, {"Pawn, The (Rainbird Software)/Pawn, The (1987)(Rainbird Software)(Side A).dsk"} },
   {0x185f6085, {"aa433458ea35664c3e80ae7d05812270"}, {"Puzznix (CPC Amstrad International)/Puzznix (1992)(CPC Amstrad International)[cr].dsk"} },
// {0x35d2ed86, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Palitron (The Edge Software)/Palitron (1986)(The Edge Software).dsk"} },
   {0x3618dcda, {"2dad281168508e1c4377888c2e0458d8"}, {"Potsworth & Co. (Hi-Tec Software)/Potsworth & Co. (1992)(Hi-Tec Software).dsk"} },
   {0x655fbeea, {"13f76c85985da0e1cb2bef575a2b9f65"}, {"Panic Dizzy (Codemasters Software)/Panic Dizzy (1991)(Codemasters Software)[cr].dsk"} },
// {0x06f28d8f, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Pepe Bequilles (Softhawk) (Spain)/Pepe Bequilles (1987)(Softhawk)(es).dsk"} },
   {0xe874e175, {"6fee42377b90ed46f326099433707ffb"}, {"Pac-Boy (Micro Mag)/Pac-Boy (1989)(Micro Mag)[cr].dsk"} },
   {0x615f4ff1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pick'N Pile (Ubi Soft)/Pick'N Pile (1990)(Ubi Soft).dsk"} },
   {0x33615414, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Punchy (Amsoft)/Punchy (1984)(Amsoft).dsk"} },
   {0xd1c258d1, {"0f3ce766494c244fb3e069ee60809d95"}, {"Passagers du Vent 2 (Infogrames)/Passagers du Vent 2 (1987)(Infogrames)(Side A).dsk"} },
   {0xadd097a0, {"dec5a4d0f21fb686b61d6fd8ecc3fa4e"}, {"Pilots (Bollaware) (de)/Pilots (1990)(Bollaware)(de)(PD)[cr].dsk"} },
   {0x19071d88, {"23762081dab77e438bd29ba648ef1e7e"}, {"Paperboy (Elite Systems)/Paperboy (1987)(Elite Systems).dsk"} },
   {0x752e93aa, {"fe435c627756c736c7bcf2f57261da90"}, {"Periscope Up (Atlantis Software)/Periscope Up (1989)(Atlantis Software)[cr].dsk"} },
   {0x1df0ab01, {"01526b361467a552f0c6e10071b475fe"}, {"Pool (Micro Mag)/Pool (1989)(Micro Mag)[cr].dsk"} },
   {0x12b949cc, {"cbe2db3772d4b10bbe804562c9d3c907"}, {"Psycho City (Players)/Psycho City (1989)(Players)[cr].dsk"} },
   {0x65ee3dbb, {"d9031806912f2f4ccf10f260adc1c257"}, {"Pro Golf - Pebble Beach (Atlantis Software)/Pro Golf - Pebble Beach (1987)(Atlantis Software)[cr].dsk"} },
   {0x4d86be11, {"5e48cc88720b6e3d5a610531593ef800"}, {"Paranoia Complex, The (Magic Bytes) (France)/Paranoia Complex, The (1989)(Magic Bytes)(fr).dsk"} },
   {0xccaf43e1, {"4c6810c0dc8b662f10a933c3799e3ba8"}, {"Poogaboo (Opera Soft) (Spain)/Poogaboo (1991)(Opera Soft)(es)[cr].dsk"} },
   {0x4f838837, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Phenix Noir (Chip) (France)/Phenix Noir (1987)(Chip)(fr).dsk"} },
   {0x5b1e7942, {"c76bf57629221764a7578d85924a7701"}, {"Packy (CPC) (France)/Packy (1987)(CPC)(fr)[cr].dsk"} },
   {0xe0fc510b, {"a4928627021b42e9ab18f1c520fcdf5e"}, {"Pharaon (Loriciels) (Spain) (Hack)/Pharaon (2012)(Loriciels)(es)(Hack)(Side A)[cr].dsk"} },
   {0x5864697e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Phantom Club (Ocean)/Phantom Club (1988)(Ocean).dsk"} },
   {0x9178822a, {"d5a8e6c5dcdb7bee03b158192d1648cb"}, {"Project Future (Gremlin Graphics Software)/Project Future (1985)(Gremlin Graphics Software)[cr].dsk"} },
   {0xb877fe2c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pictionary (Domark) (Spain)/Pictionary (1989)(Domark)(es).dsk"} },
   {0x42b3f15d, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Poseidon (Coktel Vision) (France)/Poseidon (1985)(Coktel Vision)(fr).dsk"} },
   {0x9298d89e, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Power and Magic (Zigurat Software) (Spain)/Power and Magic (1990)(Zigurat Software)(es).dsk"} },
   {0xca45ab7d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Prodigy (Activision)/Prodigy (1986)(Activision).dsk"} },
   {0xf964db5d, {"1dece7b2e9a8061da901c3e13f716fb1"}, {"Prince of Persia (Broderbund Software)/Prince of Persia (1990)(Broderbund Software).dsk"} },
   {0x815924e5, {"31338797c27ed3aa55c2c573c04b9b85"}, {"Peter Shilton's Handball Maradona (Grandslam)/Peter Shilton's Handball Maradona (1986)(Grandslam)[cr].dsk"} },
   {0xd9282631, {"3bde201911bcf323187f8271c65bb014"}, {"Panzadrome (Ariolasoft)/Panzadrome (1985)(Ariolasoft)[cr].dsk"} },
   {0xb7296fc1, {"0f3ce766494c244fb3e069ee60809d95"}, {"Paladin (Bubblebus Software)/Paladin (1987)(Bubblebus Software).dsk"} },
   {0xf9c8d1ad, {"8a729ba18594f46fe10ad2ec48a6608f"}, {"Power Tetris (PC Amstrad International)/Power Tetris (1991)(PC Amstrad International)[cr].dsk"} },
   {0xcbab7a0d, {"d12462a1ae4ecda0937d67cb5ae0192d"}, {"Play Bac (Microids) (France)/Play Bac (1987)(Microids)(fr)(Side A).dsk"} },
   {0xf73e3c45, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Puzznic (Ocean Software)/Puzznic (1990)(Ocean Software).dsk"} },
   {0xadc89071, {"7331f97a5c9903cff95335411dba86a6"}, {"Penggy (Chip) (France)/Penggy (1987)(Chip)(fr)[cr].dsk"} },
   {0xe7f8c6e2, {"07a4612465ea542d86d8ee02e51b0e30"}, {"Pac Punk (Bretagne Edit presse) (France)/Pac Punk (1987)(Bretagne Edit presse)(fr)[cr].dsk"} },
   {0x09f1d651, {"0f3ce766494c244fb3e069ee60809d95"}, {"Pac-Land (Grandslam)/Pac-Land (1989)(Grandslam).dsk"} },
// {0xcb8ae96e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"PFC - PFS (MEBC) (France)/PFC - PFS (19xx)(MEBC)(fr)(PD)[cr].dsk"} },
   {0x03d3a496, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Power Drift (Activision)/Power Drift (1989)(Activision).dsk"} },
   {0xef4e2cae, {"0f3ce766494c244fb3e069ee60809d95"}, {"Prohibition (Infogrames) (M4)/Prohibition (1987)(Infogrames)(M4).dsk"} },
   {0x4c690319, {"0bb22c138f9d39e598996566bb522229"}, {"Piclos (Micro Mag)/Piclos (1989)(Micro Mag)[cr].dsk"} },
   {0xf1684e55, {"66b4dcb15d9312284841b5bb705439df"}, {"Pirates (Microprose Software)/Pirates (1987)(Microprose Software)(Side A).dsk"} },
   {0x7fec6523, {"d9031806912f2f4ccf10f260adc1c257"}, {"Pro Golf - Sunningdale (Atlantis Software)/Pro Golf - Sunningdale (1987)(Atlantis Software)[cr].dsk"} },
   {0x2f3d91e7, {"204a75a3c2907401f2133a09376895cc"}, {"Popeye (Piranha)/Popeye (1986)(Piranha).dsk"} },
   {0x4a848c11, {"397d12a922488a8264228c56916d445a"}, {"Purple Saturn Day (Ere Informatique)/Purple Saturn Day (1989)(Ere Informatique).dsk"} },
   {0xd8b60327, {"a8f86fd52e9dacd6a73bd61f39dcef51"}, {"Penguins (Amstrad Action)/Penguins (1992)(Amstrad Action)[cr].dsk"} },
   {0x55f1325d, {"baa34b9ddc3b93eae479a7c4d8d18a7f"}, {"Peter Pack Rat (Silverbird Software)/Peter Pack Rat (1989)(Silverbird Software)[cr][f].dsk"} },
   {0x24b0497a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Passengers On The Wind (Infogrames)/Passengers On The Wind (1987) (Infogrames)(Side A).dsk"} },
   {0x9aae636e, {"396cd13df26c95ddd5e6b037a4e8167c"}, {"Professional BMX Simulator (Codemasters Software)/Professional BMX Simulator (1988)(Codemasters Software)(Side A)[cr].dsk"} },
   {0x84539cdc, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pipe Mania (Empire)/Pipe Mania (1990)(Empire).dsk"} },
// {0x3e3fc1c3, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Powerplay - Game of the Gods (Arcana Software Design) (France)/Powerplay - Game of the Gods (1986)(Arcana Software Design)(fr).dsk"} },
   {0xd4892cab, {"1974f2cd78295a6494e600e6f010caaf"}, {"Pogostick Olympics (Firebird)/Pogostick Olympics (1987)(Firebird)[cr].dsk"} },
   {0x33bfdb3a, {"f11d1471320467b55a81c9123bf974be"}, {"Perestroika (CPC)/Perestroika (1988)(CPC)[cr].dsk"} },
   {0xa811651d, {"18c6687d7b2972be9b36bc79c99aa2c5"}, {"Pharaon (Loriciels) (France)/Pharaon (1987)(Loriciels)(fr)(Side A).dsk"} },
   {0xdfaea603, {"dd0317ad0110090ad725ce832ac4973d"}, {"Pacplant (Potplant Productions)/Pacplant (1988)(Potplant Productions)[cr].dsk"} },
   {0x6c595eda, {"0a59f8212b37cf280d8299cfff6462bf"}, {"Penalty Soccer (Gamebusters)/Penalty Soccer (1990)(Gamebusters)[cr].dsk"} },
   {0xae4a38ad, {"7c8f3d4cd5c71b442c98ced5585ae217"}, {"Plumpy (CPC Infos) (France)/Plumpy (1990)(CPC Infos)(fr)(Side A)[cr].dsk"} },
   {0x4c89d3dd, {"0f3ce766494c244fb3e069ee60809d95"}, {"Passing Shot (Image Works)/Passing Shot (1989)(Image Works).dsk"} },
   {0xd1c1a8f8, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Perico Delgado Maillot Amarillo (Topo Soft) (Spain)/Perico Delgado Maillot Amarillo (1989)(Topo Soft)(es).dsk"} },
   {0x9a8b051f, {"fe4c31f042ab95d041c557aefd439d4f"}, {"Paws (Artic Computing)/Paws (1985)(Artic Computing)[cr].dsk"} },
// {0x3ea9bb91, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Powerplay - Game of the Gods (Arcana Software Design) (Spain)/Powerplay - Game of the Gods (1986)(Arcana Software Design)(es).dsk"} },
   {0xe18ec52b, {"0aef1d3f8b8075eeb3ff6b774360b1fd"}, {"Push (Eliot)/Push (1995)(Eliot)(PD)[cr].dsk"} },
   {0xfe13d596, {"2682a0a4d838c0d7137c43be86ae7baa"}, {"Punk Star (Iber Soft) (Spain)/Punk Star (1988)(Iber Soft)(es)[cr].dsk"} },
   {0x9d2a8c1a, {"f439275600df18de1c2e1b51b166a6b6"}, {"Plot, The (Firebird)/Plot, The (1987)(Firebird)[cr].dsk"} },
   {0xd4888386, {"35c7f37f1dab78e7b7cb964e38f171fa"}, {"Paranoia (Power System)/Paranoia (1994)(Power System)[cr].dsk"} },
   {0xc599b2d0, {"cfb0ec8be215233b5d150a4a7d2b8e57"}, {"Pipeline (PC Amstrad International)/Pipeline (1991)(PC Amstrad International)[cr].dsk"} },
   {0x7a74d9fd, {"ef644d6ac9abcc2b217e0f3ee0065d39"}, {"Pro Tennis Tour (Ubi Soft)/Pro Tennis Tour (1990)(Ubi Soft)[cr].dsk"} },
   {0x33d6eaad, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Poder Oscuro, El (Zigurat Software) (Spain)/Poder Oscuro, El (1988)(Zigurat Software)(es).dsk"} },
   {0x0ddda48d, {"a58979b1202b106bb405e279d2649ee2"}, {"Profanation 2 - Escape from Abu Simbel (4Mhz) (Spain)/Profanation 2 - Escape from Abu Simbel (2017)(4Mhz)(es).dsk"} },
   {0xf8f9dda6, {"c6c102f2ab8b5fe68af77d89c1e8936c"}, {"Pinaut (Minsoft)/Pinaut (1986)(Minsoft)[cr].dsk"} },
   {0x5f58268a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Pink Panther (Magic Bytes)/Pink Panther (1988)(Magic Bytes).dsk"} },
   {0x693b9445, {"0f3ce766494c244fb3e069ee60809d95"}, {"Pajaros de Bangkok, Los (Dinamic Software) (Spain)/Pajaros de Bangkok, Los (1988)(Dinamic Software)(es).dsk"} },
   {0x181ddcde, {"c68076620e353d3feae594cc90a2f4ca"}, {"Predator (Activision)/Predator (1988)(Activision).dsk"} },
   {0xc5a3ce66, {"f97e28b94d1abe53c7e5b1d701a3c50c"}, {"Project-X - The Microman (Global Software)/Project-X - The Microman (1986)(Global Software)[cr].dsk"} },
   {0xb6c59177, {"397d12a922488a8264228c56916d445a"}, {"Pacific (ERE Informatique) (M3)/Pacific (1986)(ERE Informatique)(M3).dsk"} },
   {0x4a3b42c0, {"0f3ce766494c244fb3e069ee60809d95"}, {"Peter Beardsley's Soccer (Grandslam)/Peter Beardsley's Soccer (1989)(Grandslam).dsk"} },
   {0x5dce5c79, {"419e173bad428fc8de09e8354c6bae5c"}, {"Pinball Magic (Loriciels) (M2)/Pinball Magic (1990)(Loriciels)(M2)(v2)(Side A).dsk"} },
   {0xfc391fd4, {"397d12a922488a8264228c56916d445a"}, {"Passager du Temps, Le (ERE Informatique) (France)/Passager du Temps, Le (1987)(ERE Informatique)(fr)(Side A).dsk"} },
   {0x10548a7a, {"b6d1ee6d1e5b73e00e9f0487ae6c29f0"}, {"Peter Pan (Coktel Vision)/Peter Pan (1988)(Coktel Vision)(Side A)[CPM].dsk"} },
   {0x60d2e10f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Poogaboo (Opera Soft) (Spain) (Codes)/Poogaboo (1991)(Opera Soft)(es)[o][codes].dsk"} },
   {0xc93eb89b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Pop-Up (Loriciels) (France)/Pop-Up (1990)(Loriciels)(fr)(Side A).dsk"} },
   {0x8b343b89, {"36c17fa18f70f373f6c3b8dbcbcbf665"}, {"Postman Pat (Alternative Software)/Postman Pat (1988)(Alternative Software)[cr].dsk"} },
   {0x7b084af7, {"ccd2417662547c35ff04e1e4727966df"}, {"PHM Pegasus (Electronics Arts)/PHM Pegasus (1986)(Electronics Arts).dsk"} },
   {0x5ce924ba, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Professional Ski Simulator (Codemasters Software)/Professional Ski Simulator (1987)(Codemasters Software)[o].dsk"} },
   {0x5b9973af, {"57419832fea175fec0eecc099463eae5"}, {"Prize, The (Amsoft)/Prize, The (1985)(Amsoft)[tape].dsk"} },
   {0xb84d97ea, {"968e203690d58f98049feb2110328284"}, {"Pulsoid (Mastertronic)/Pulsoid (1988)(Mastertronic)[tape].dsk"} },
   {0xcaf968a1, {"896aa4d2cc999cebc77e4c240108425f"}, {"Pinball Wizard (CP Software)/Pinball Wizard (1985)(CP Software)[cr].dsk"} },
   {0x4294d4b2, {"6ed583db4ea3d04ae4048096280d4cd9"}, {"Party Machine (Computing With The Amstrad)/Party Machine (1987)(Computing With The Amstrad)[cr].dsk"} },
   {0xc8c547d0, {"1dece7b2e9a8061da901c3e13f716fb1"}, {"Prince de Perse (Broderbund Software) (France) (Codes)/Prince de Perse (1990)(Broderbund Software)(fr)[codes].dsk"} },
   {0x0a96fed4, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Predator 2 (Image Works)/Predator 2 (1991)(Image Works).dsk"} },
   {0x66e9ffbf, {"047375a4ed2df268ace6da1ad5f32e30"}, {"Pneumatic Hammers (Firebird)/Pneumatic Hammers (1987)(Firebird)[cr].dsk"} },
   {0x4e185974, {"822f5e0224885f32045c2daf2f163e1e"}, {"Quest for the Golden Eggcup, The (Mastertronic)/Quest for the Golden Eggcup, The (1988)(Mastertronic)[cr].dsk"} },
   {0xab988af2, {"6b8a9625e25ea0dd15bfeb2bb98b21b3"}, {"Quad-X II (Edmund Spicer)/Quad-X II (1991) (Edmund Spicer)[cr].dsk"} },
   {0xb8a5d5c8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Quack a Jack (Amsoft)/Quack a Jack (1984)(Amsoft).dsk"} },
   {0x03c2e55b, {"630c8a58bcbcc532330c3f5a9d18597a"}, {"Quad (Microids) (France)/Quad (1987)(Microids)(fr).dsk"} },
// {0xf9521465, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Qin (ERE Informatique) (France)/Qin (1987)(ERE Informatique)(fr)(Disk 1 Side A).dsk"} },
// {0x93b95448, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Quiwi (Kingsoft) (de)/Quiwi (1986)(Kingsoft)(de)(Side A)[BASIC 1.0].dsk"} },
   {0x4015d81d, {"50ec49feadf7cff860f5542541f68366"}, {"Quaterne (Sprites) (France)/Quaterne (1985)(Sprites)(fr)[cr].dsk"} },
   {0x8122f603, {"6679228c86a49bfbd2167542ddc1801a"}, {"Quadrant (Sleepwalker PDS)/Quadrant (1993)(Sleepwalker PDS)[cr].dsk"} },
   {0x3a0e0661, {"0402c5f159d4085142eb29e74244c915"}, {"Quete De La Pierre Mindstone (The Edge) (France)/Quete De La Pierre Mindstone (1987)(The Edge)(fr)[cr].dsk"} },
   {0x1c3811c5, {"b9b206c1a854d9f789713b2b68a4ff56"}, {"Quadrel (Loriciels) (France)/Quadrel (1991)(Loriciels)(fr).dsk"} },
   {0x0e58dcf4, {"c9820309a17e38073a1b412d42e08d6d"}, {"Quick Draw McGraw (Hi-Tec Software)/Quick Draw McGraw (1991)(Hi-Tec Software)[cr].dsk"} },
   {0x254b5168, {"eb4ca0c180c527970b493f3f51c179da"}, {"Quad-X (Edmund SPICER)/Quad-X (1991)(Edmund SPICER)[cr].dsk"} },
   {0x7f1fca7d, {"ea4ab0b6a2810855342c14d57f2743c8"}, {"Quarters (Computing With The Amstrad)/Quarters (1987)(Computing With The Amstrad)[cr].dsk"} },
   {0x80d595c7, {"11ee36eecb493c0b9952a14cd847a0e7"}, {"Qor (Maltdale)/Qor (1986)(Maltdale)[cr].dsk"} },
   {0xf91b4aae, {"f4f7c3e27ea9c40b3ca86ad8bd1af3c0"}, {"Questprobe 3 - Fantastic Four (US Gold)/Questprobe 3 - Fantastic Four (1985)(US Gold)[cr].dsk"} },
   {0xacf00a30, {"2afd82d58ea585bb795012f1697c76a7"}, {"Quest for the Mindstone (The Edge)/Quest for the Mindstone (1986)(The Edge)[cr].dsk"} },
   {0x855a0d40, {"932e28e7e2149043fc174e0fafb896a7"}, {"Q10 Tank Buster (Zeppelin Games)/Q10 Tank Buster (1991)(Zeppelin Games).dsk"} },
   {0x3e40eb55, {"5113317b27ab9128b67318ec0a5e66b6"}, {"Qabbalah (Amsoft)/Qabbalah (1986)(Amsoft)[cr].dsk"} },
   {0x313915c9, {"92056f3392eb909b7dc0564b743a18fa"}, {"Questor (Cascade Games)/Questor (1986)(Cascade Games).dsk"} },
   {0xee8f9219, {"0c1b5672f2761a23a23bb8b8a60e15cf"}, {"Question of Sport, A (Elite Systems)/Question of Sport, A (1988)(Elite Systems).dsk"} },
   {0x4f55e966, {"670bf25f71f957a72ef7416605cf7bb1"}, {"Quartet (Activision) (Bugs)/Quartet (1987)(Activision)[b].dsk"} },
// {0xeebfb943, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Raid Over Moscow (US Gold)/Raid Over Moscow (1985)(US Gold).dsk"} },
// {0x229083cc, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Ripoux, Les (Cobra Soft) (France)/Ripoux, Les (1987)(Cobra Soft)(fr)(Side A).dsk"} },
   {0xb6017864, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Robocop (Ocean Software)/Robocop (1989)(Ocean Software).dsk"} },
   {0xd7dd6963, {"5da2a3481efee90f33490abd1039b048"}, {"Renegade (Kuma Computers)/Renegade (1985)(Kuma Computers)[cr].dsk"} },
   {0xc42bdd32, {"1411f4b83bc8171ec700e518c5f605b6"}, {"Romba (Micro Mag) (France)/Romba (1990)(Micro Mag)(fr)[cr].dsk"} },
   {0xa0eb703d, {"ee0870f8ff3e08a1944a1540343ada88"}, {"Rebel Planet (US Gold)/Rebel Planet (1986)(US Gold)[cr].dsk"} },
   {0x4948162e, {"fe42557678c40a94ee428439a995211e"}, {"Robot Ron (A-Team)/Robot Ron (1985)(A-Team)[cr].dsk"} },
// {0x72e302b8, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Reisende im Wind 2 (Infogrames) (de)/Reisende im Wind 2 (1987)(Infogrames)(de)(Side A).dsk"} },
   {0x33cb07bc, {"ad5b8fff32fcb976fb5cec72a18a32e8"}, {"Robot Ron (A-Team) (Spain)/Robot Ron (1985)(A-Team)(es)[cr].dsk"} },
   {0x0324cfc6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Roland on the Ropes (Zigurat)/Roland on the Ropes (1984)(Zigurat).dsk"} },
   {0x8953a047, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Robozone (Image Works)/Robozone (1991)(Image Works).dsk"} },
   {0x71101441, {"16636937f635a9856914637b8df5c02c"}, {"Rambo - First Blood Part II (Ocean Software)/Rambo - First Blood Part II (1986)(Ocean Software)[tape].dsk"} },
// {0x75ac076d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Rana (PC Amstrad International) (de)/Rana (1990)(PC Amstrad International)(de)[cr].dsk"} },
   {0x2556636c, {"648ae7d0d98fcf30bfbc0154d0cab5c1"}, {"Rock Run (Swift Software)/Rock Run (1989)(Swift Software)[cr].dsk"} },
   {0xd93567e6, {"ab52a354789a412b3e48bdd7b68bb3f2"}, {"Riding the Rapids (Players)/Riding the Rapids (1987)(Players)[cr].dsk"} },
   {0x07e5bc58, {"b1fc8f79d3f9b51f55109865e96df958"}, {"Rock Hopper (Amstrad Computer User) (France)/Rock Hopper (1985)(Amstrad Computer User)(fr)[cr].dsk"} },
   {0xcdc84017, {"b3cbec0587d9d45e48685401bc43d3f6"}, {"Ricochet (Firebird)/Ricochet (1987)(Firebird)[tape].dsk"} },
   {0xe8a597cf, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Reward (JLMD) (France)/Reward (1991)(JLMD)(fr)(PD)[cr].dsk"} },
   {0x04e8e31c, {"6382c383e59b69b3577e9b42cdca7bdf"}, {"Reflector (AM-Mag) (France)/Reflector (1988)(AM-Mag)(fr)[cr].dsk"} },
   {0xd6870307, {"56b3b67a334826529808c7e71da03a68"}, {"Rasterscan (Mastertronic)/Rasterscan (1987)(Mastertronic)[cr].dsk"} },
   {0xd0f6eaf5, {"f5ad7b9425658c9a76922a3d0620f007"}, {"Ralf (CPC)/Ralf (1990)(CPC)[cr].dsk"} },
   {0xf121ebe5, {"5f133217c58041494f5abd9fd5d4be25"}, {"Reversi Champion (Loriciels) (France)/Reversi Champion (1986)(Loriciels)(fr).dsk"} },
   {0x349f4dcd, {"4637e634aa8c5bf4de433c409e5816ce"}, {"Ruff and Reddy in The Space Adventure (Hi-Tec Software)/Ruff and Reddy in The Space Adventure (1990)(Hi-Tec Software)[cr].dsk"} },
// {0x928f12b2, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Renaud (Infogrames) (France)/Renaud (1987)(Infogrames)(fr).dsk"} },
   {0x2b82aab6, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Red L.E.D. (Starlight Software)/Red L.E.D. (1987)(Starlight Software).dsk"} },
   {0x5c2c4ee3, {"b1ef35eadbebecd339a9b91add7f03d3"}, {"Revolver (Alternative Software)/Revolver (1988)(Alternative Software)[cr].dsk"} },
   {0x920d4d8e, {"59c780678225f55be03127d196bab3f5"}, {"Rig Attack (Tynesoft)/Rig Attack (1985)(Tynesoft)[cr].dsk"} },
   {0xf851e598, {"56df5f557a4f6e18e8dd9555a9cf75ea"}, {"Roland Goes Square Bashing (Amsoft)/Roland Goes Square Bashing (1984)(Amsoft)[tape].dsk"} },
   {0x74ea3cb1, {"1a86973177a5479bff05a8e5953a2288"}, {"Rock Raid (Kuma Computers) (Spain)/Rock Raid (1985)(Kuma Computers)(es)[cr].dsk"} },
   {0x5755688c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rick Dangerous (Firebird)/Rick Dangerous (1989)(Firebird).dsk"} },
   {0xbff172a0, {"6b45ea7d0c0cb8d9c53fd6399efe2416"}, {"Rock 'n Wrestle (Melbourne House)/Rock 'n Wrestle (1985)(Melbourne House)[tape].dsk"} },
   {0x8690ff53, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Rolling Thunder (US Gold)/Rolling Thunder (1988)(US Gold).dsk"} },
   {0x29acc063, {"a7cebbf4767af864fc47155b2c202302"}, {"Rody & Mastico (Lankhor) (France)/Rody & Mastico (1988)(Lankhor)(fr)(Side A).dsk"} },
   {0xbd62835d, {"e1b7cd66691b2509180437bca341c028"}, {"Rollaround (Mastertronic)/Rollaround (1988)(Mastertronic)[cr].dsk"} },
   {0x266bb86d, {"cdc43cca209a449303ed80f0e1b4b9c7"}, {"Redhawk (Melbourne House)/Redhawk (1986)(Melbourne House)[cr].dsk"} },
   {0x906f3991, {"bcdbc8573eb19580295a1dd854d84d4e"}, {"Rally Driver (Hill MacGibbon)/Rally Driver (1986)(Hill MacGibbon)[cr].dsk"} },
   {0x234854ab, {"7172d1ab618339be32ca9dac61359a1d"}, {"Reflex (Players)/Reflex (1987)(Players)[cr].dsk"} },
   {0xd66297b4, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Running Man, The (Grandslam)/Running Man, The (1989)(Grandslam)(Side A).dsk"} },
   {0x23b750e8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rogue (Mastertronic)/Rogue (1987)(Mastertronic)[tape].dsk"} },
   {0x66848ef1, {"570c0d6a76037243a0fe2049d342eb73"}, {"Revolution (US Gold)/Revolution (1986)(US Gold).dsk"} },
   {0xef892c7f, {"90c589c23b155319c9448fe5f8227498"}, {"Renaud - Sidewalk (Infogrames)/Renaud - Sidewalk (1987)(Infogrames)[cr].dsk"} },
   {0x6fb15934, {"bcdbc8573eb19580295a1dd854d84d4e"}, {"Rally Simulator (Zeppelin Games)/Rally Simulator (1988)(Zeppelin Games)[cr].dsk"} },
   {0x108bd162, {"b91524479c5ff7cc46e4c2e0215c5974"}, {"Rock 'n Roller (Topo Soft) (Spain)/Rock 'n Roller (1988)(Topo Soft)(es)[tape].dsk"} },
   {0xad3702d1, {"73174034df6626908dd256240ef1a16f"}, {"Return to Oz (US Gold)/Return to Oz (1986)(US Gold)[tape].dsk"} },
   {0xa6f175bf, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Rambo III (Ocean)/Rambo III (1988)(Ocean)[f].dsk"} },
   {0x3f72c8bf, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rock 'n Roll (Rainbow Arts)/Rock 'n Roll (1989)(Rainbow Arts)(Side A).dsk"} },
   {0x20df0713, {"75966f020f5039b0dba0b911fd8bdaa5"}, {"Renaud - Sidewalk (Infogrames) (Spain) (Hack)/Renaud - Sidewalk (2021)(Infogrames)(es)(Hack)[cr].dsk"} },
   {0xd4144a8b, {"e38adc505b3e1e0defdd087cb9c594cd"}, {"Race Against Time, The (Codemasters Software)/Race Against Time, The (1988)(Codemasters Software)[cr].dsk"} },
   {0x99baf9f9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Roland Ahoy! (Amsoft)/Roland Ahoy! (1984)(Amsoft).dsk"} },
   {0xe4057c25, {"c68076620e353d3feae594cc90a2f4ca"}, {"Rampage (Activision)/Rampage (1987)(Activision).dsk"} },
// {0x86f87f1d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Recherche Miss X Deseperement (Fanatic) (France)/Recherche Miss X Deseperement (1989)(Fanatic)(fr).dsk"} },
   {0x7789c21e, {"0286e044ddb7ec79ff9ba9008ad3d09e"}, {"Radzone (Mastertronic)/Radzone (1986)(Mastertronic)[cr].dsk"} },
   {0xf01c4e6d, {"0066424be7d5cae14164d7684f386ea9"}, {"Rocky - Rocco (Dinamic Software)/Rocky - Rocco (1985)(Dinamic Software)[cr].dsk"} },
   {0x11d42e74, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ravening (Sylvain Guehl) (France)/Ravening (1992)(Sylvain Guehl)(PD)(fr)[cr].dsk"} },
   {0xf70eee66, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Robocop (Ocean Software) (France)/Robocop (1989)(Ocean Software)(fr).dsk"} },
   {0x0985c1ea, {"31a0cbf7e6ec06b285956debe71b06f8"}, {"Robin of Sherwood - The Touchstones of Rhiannon (Adventure International)/Robin of Sherwood - The Touchstones of Rhiannon (1985)(Adventure International)[cr].dsk"} },
   {0x2706e957, {"c33491a6b015db1c8d0c944bdaec626f"}, {"RFX (CPC Infos) (France)/RFX (1993)(CPC Infos)(fr)[cr].dsk"} },
// {0x6fbe410c, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Rex (Martech)/Rex (1988)(Martech).dsk"} },
   {0x843d62ca, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rock Raid (Kuma Computers)/Rock Raid (1985)(Kuma Computers).dsk"} },
   {0x268fff6a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Rastan (Ocean Software)/Rastan (1987)(Ocean Software)(Side A).dsk"} },
   {0xd171a650, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Roland in Space (Amsoft) (Spain)/Roland in Space (1984)(Amsoft)(es).dsk"} },
   {0x2238a34f, {"0f3ce766494c244fb3e069ee60809d95"}, {"Reisende im Wind (Infogrames) (de)/Reisende im Wind (1986)(Infogrames)(de)(Side A).dsk"} },
   {0xed8cbab5, {"b067271c818d380b5b4c310ee50c9bf4"}, {"Ring des Lichts, Der (Frank Senft) (de)/Ring des Lichts, Der (1997)(Frank Senft)(PD)(de).dsk"} },
   {0x400bab11, {"94e391ec3d1ac0a454ac13efe7baffce"}, {"Revenge of the C5 (Atlantis Software)/Revenge of the C5 (1986)(Atlantis Software)[cr].dsk"} },
   {0xffa14122, {"0f3ce766494c244fb3e069ee60809d95"}, {"Rex Hard (Mister Chip) (Spain)/Rex Hard (1987)(Mister Chip)(es).dsk"} },
   {0xaaa86825, {"bab4910d61fdaed848d3303c7cccc327"}, {"River Race (PC Amstrad International)/River Race (1990)(PC Amstrad International)[cr].dsk"} },
   {0xd4e464e0, {"3ba274c9e3f0d39cf3bb3de87bad2672"}, {"Realm (Firebird)/Realm (1987)(Firebird)[tape].dsk"} },
   {0xb3a24dbf, {"7c44a66148bb96f8f8af1058a58bfdcd"}, {"Road Blasters (US Gold)/Road Blasters (1988)(US Gold).dsk"} },
   {0x617f615b, {"78c3a267215fa64d5786a1c2eb4c4ec9"}, {"Ranarama (Hewson Consultants)/Ranarama (1987)(Hewson Consultants).dsk"} },
   {0x39e92a63, {"0f3ce766494c244fb3e069ee60809d95"}, {"Rescate Atlantida (Dinamic Software) (Spain)/Rescate Atlantida (1989)(Dinamic Software)(es).dsk"} },
   {0x827cdf1e, {"ec8fa044cba2b5dec88acad94b9ca12d"}, {"Raster Runner (Mastertronic)/Raster Runner (1990)(Mastertronic)[cr].dsk"} },
// {0x4bb21249, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Rock Hopper (Amstrad Computer User)/Rock Hopper (1985)(Amstrad Computer User)[cr].dsk"} },
   {0x2f376c17, {"dd774a08dbddd2e11c996279866e5597"}, {"Rugby Boss (Alternative Software)/Rugby Boss (1989)(Alternative Software)[tape].dsk"} },
   {0x404937ef, {"c7914e417efabf536e1660de1f33eaaa"}, {"Runestone (Firebird)/Runestone (1985)(Firebird)[tape].dsk"} },
   {0x658cbef1, {"ae2389037b18a68afab3ad833cf77f80"}, {"Rocky Horror Show, The (CRL Group)/Rocky Horror Show, The (1985)(CRL Group)(v1.1).dsk"} },
   {0x239a14e3, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Road Runner (US Gold)/Road Runner (1985)(US Gold)(v2).dsk"} },
   {0xad893638, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"RAM (Topo Soft) (Spain)/RAM (1990)(Topo Soft)(es).dsk"} },
   {0x3d857ff5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Roland in Space (Amsoft)/Roland in Space (1984)(Amsoft).dsk"} },
   {0xd1a63dcf, {"c947febcc24001e807506f077b470625"}, {"Room Ten (CRL Group) (M3)/Room Ten (1986)(CRL Group)(M3).dsk"} },
   {0xf2d804ab, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Red Heat (Ocean Software)/Red Heat (1989)(Ocean Software).dsk"} },
   {0xf468aa03, {"359b6ab8d1d264df1e39e4d291bd9fac"}, {"Roland in the Haunted House (Amstrad Computer User) (Spain)/Roland in the Haunted House (1985)(Amstrad Computer User)(es)[cr].dsk"} },
   {0xac08ec57, {"0bbf124afa951602bb51cb0a4ee02180"}, {"Rigel's Revenge (Mastertronic)/Rigel's Revenge (1987)(Mastertronic)[cr].dsk"} },
   {0x0c0124f1, {"0cd80d35e752b87e88ffcaf3569ab73d"}, {"Run for Gold (Five Ways Software)/Run for Gold (1985)(Five Ways Software)[tape].dsk"} },
   {0x3d52ff08, {"1b7a564310963ecf091dbab7a4669d2c"}, {"Rescue on Fractalus (Activision) (Bugs)/Rescue on Fractalus (1986)(Activision)[b].dsk"} },
   {0xe85fafd6, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Reversi - Challenger (Cobra Soft) (M2)/Reversi - Challenger (1985)(Cobra Soft)(M2).dsk"} },
   {0x93962139, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rally II (Loriciels)/Rally II (1985)(Loriciels).dsk"} },
   {0x4a61c20c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rod-Land (Storm Software)/Rod-Land (1991)(Storm Software)(Side A).dsk"} },
   {0x6e33d7e5, {"0f549d11a9762e08825ed69ae8f67933"}, {"Robocide (Asclepios Software)/Robocide (19xx)(Asclepios Software)(PD)[cr].dsk"} },
   {0xbbf59693, {"00a69e6f2bc946da92e0911aa4dd4ced"}, {"Ralf II (CPC Infos)/Ralf II (1993)(CPC Infos)[cr].dsk"} },
   {0xbbf3d2c6, {"71a0d014d24a67105d93a220d96d9344"}, {"Rath-Tha (Positive) (Spain)/Rath-Tha (1989)(Positive)(es)[cr].dsk"} },
   {0x9e1ce74a, {"92199aa31bb3afc0ab113acd490f9a6f"}, {"Royal Quest, The (Timeslip Software)/Royal Quest, The (1984)(Timeslip Software)[cr].dsk"} },
   {0xfff25344, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"R.B.I. 2 Baseball (Domark)/R.B.I. 2 Baseball (1991)(Domark).dsk"} },
   {0x32bb9762, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Roland Goes Digging (Amsoft)/Roland Goes Digging (1984)(Amsoft).dsk"} },
   {0xd7e834b9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Roland on the Run (Amsoft)/Roland on the Run (1984)(Amsoft).dsk"} },
   {0xc6c84484, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"R-Type (Easter Egg)/R-Type (2012)(Easter Egg).dsk"} },
   {0x953353f4, {"2a06cb32c18d173b8a912d4462856bab"}, {"Rad Ramp Racer (Mastertronic)/Rad Ramp Racer (1990)(Mastertronic)[cr].dsk"} },
   {0x42fb20b8, {"fef3181affc8d686bb67cde9180e5362"}, {"Real Ghostbusters, The (Activision)/Real Ghostbusters, The (1989)(Activision)(v2)(Side A).dsk"} },
   {0xf79e9e5d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Rescate en el Golfo (Opera Soft) (M2) (Codes)/Rescate en el Golfo (1990)(Opera Soft)(M2)[codes].dsk"} },
   {0xf8b63b53, {"4bf10bed082c883eeb30ee84239d3b15"}, {"Rat Connection (MBC Informatique) (France)/Rat Connection (1988)(MBC Informatique)(fr)[cr].dsk"} },
   {0x558abe44, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Rygar (US Gold)/Rygar (1987)(US Gold)(v2).dsk"} },
   {0x31f0ac5b, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Ramparts (US Gold)/Ramparts (1987)(US Gold).dsk"} },
   {0x3f3f84de, {"5246f5ea5b17beb68031ed10e3c3936a"}, {"Red Arrows, The (Database Educational Software)/Red Arrows, The (1985)(Database Educational Software).dsk"} },
   {0x50c8b233, {"c02dce41f5416c870f6577316d7c3228"}, {"Relief Action (Loriciels) (France)/Relief Action (1987)(Loriciels)(fr).dsk"} },
   {0x02bde426, {"4166591acaded771769838da882761ad"}, {"Reveal (Mastertronic)/Reveal (1988)(Mastertronic)[tape].dsk"} },
   {0x6fc53a3a, {"9c5f45ad1ebdc0aa94fedbd0e735c874"}, {"Road Toad (Popular Computing Weekly)/Road Toad (1986)(Popular Computing Weekly)[cr].dsk"} },
   {0x2f40ccd7, {"7bd96356a6c47c9a1a7f7c425215e301"}, {"Race, The (Amstrad Adventure PD Library)/Race, The (1990)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0xc40ae9b4, {"5c5310e141130d53b5c456a5e350bf94"}, {"Roog (Amstrad Adventure PD Library)/Roog (1990)(Amstrad Adventure PD Library)[cr].dsk"} },
// {0xd6a9cd52, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Robbbot (ERE Informatique) (Spain)/Robbbot (1986)(ERE Informatique)(es)(Side A).dsk"} },
   {0xd961f6bb, {"0f3ce766494c244fb3e069ee60809d95"}, {"Run the Gauntlet (Ocean Software)/Run the Gauntlet (1989)(Ocean Software).dsk"} },
   {0xa4e6b5e8, {"3d3ff975410833168d8dd67b4ff02f12"}, {"Redhawk II - Kwah! (Melbourne House)/Redhawk II - Kwah! (1986)(Melbourne House)[cr].dsk"} },
   {0xd11aa568, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Rainbow Islands (Ocean Software)/Rainbow Islands (1989)(Ocean Software).dsk"} },
   {0xfc540661, {"c3474027671aa53ff1af0b5efb3ab1fa"}, {"Ring of Darkness, The (Wintersoft)/Ring of Darkness, The (1985)(Wintersoft)[cr].dsk"} },
   {0xe17f30fb, {"02cd997644a3451e0f893f8087182f7e"}, {"Rebotes (Amstrad Computer User) (Spain)/Rebotes (1984)(Amstrad Computer User)(es)[cr].dsk"} },
   {0x47d6fe0a, {"73b2d14a89b0677487dd3676d13fdcd5"}, {"Rally (CPC) (France)/Rally (1986)(CPC)(fr)[cr].dsk"} },
   {0x465c7238, {"1d433f7cf46c19a97ee8f61ce4c825be"}, {"RC Quest (Moving Pixels)/RC Quest (1993)(Moving Pixels)[cr].dsk"} },
// {0x04ae8758, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Rodeo (Microids) (France)/Rodeo (1986)(Microids)(fr).dsk"} },
   {0xc3273263, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Robinson Crusoe (Coktel Vision) (France)/Robinson Crusoe (1987)(Coktel Vision)(fr)(Side A).dsk"} },
   {0xb1e19b14, {"0f3ce766494c244fb3e069ee60809d95"}, {"Rally II (Loriciels) (France)/Rally II (1985)(Loriciels)(fr).dsk"} },
   {0xc2445018, {"6c21e60132c175e53044ad2cc1cf1b58"}, {"Ricochet (Blaby Computer Games)/Ricochet (1986)(Blaby Computer Games)[tape].dsk"} },
   {0x6e9aadca, {"dc526f014522d56681a55f86537f250f"}, {"Raffles - Inside Outing (The Edge)/Raffles - Inside Outing (1987)(The Edge).dsk"} },
   {0x0aca0e0f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Roland in Time (Amsoft)/Roland in Time (1986)(Amsoft).dsk"} },
   {0x371eaac1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Roland in the Caves (Indescomp)/Roland in the Caves (1984)(Indescomp).dsk"} },
   {0xa7eabae7, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Rally Cross (Anco Software)/Rally Cross (1989)(Anco Software).dsk"} },
   {0x0edf0b5f, {"d9ad902a68ec8832cf71bd2971a342e4"}, {"Roulette (Computing With The Amstrad)/Roulette (1987)(Computing With The Amstrad)[cr].dsk"} },
// {0x1068d4af, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"R-Type (Activision)/R-Type (1988)(Activision).dsk"} },
   {0xa53ffbf8, {"397d12a922488a8264228c56916d445a"}, {"Robbbot (ERE Informatique) (M3)/Robbbot (1986)(ERE Informatique)(M3).dsk"} },
   {0x10712a0c, {"b099e6816a4157915fb4b44a631c9c61"}, {"Rescue Atlantis (Dinamic Software)/Rescue Atlantis (1988)(Dinamic Software)[cr][f].dsk"} },
   {0xdf16b5d3, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Renegade (Ocean Software)/Renegade (1987)(Ocean Software)[f].dsk"} },
   {0x89cc6b51, {"c68076620e353d3feae594cc90a2f4ca"}, {"Rogue Trooper (Piranha)/Rogue Trooper (1986)(Piranha).dsk"} },
   {0x7a07199a, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Raid Sur Tenere (Coktel Vision) (France)/Raid Sur Tenere (1985)(Coktel Vision)(fr).dsk"} },
   {0x371023fd, {"0f3ce766494c244fb3e069ee60809d95"}, {"Rick Dangerous II (Micro Style)/Rick Dangerous II (1990)(Micro Style).dsk"} },
   {0x3b61fc45, {"6500278011a2b4afaa30939e39589f40"}, {"Radius (Players)/Radius (1987)(Players)[cr].dsk"} },
   {0x804acec4, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Renegade III - The Final Chapter (Imagine Software)/Renegade III - The Final Chapter (1989)(Imagine Software).dsk"} },
   {0x0f7abcdf, {"ccfa608c4f262a2f39f48ef902cb9d1e"}, {"Retour d'Ali Gator, Le (Micro Mag) (France)/Retour d'Ali Gator, Le (1989)(Micro Mag)(fr)[tape].dsk"} },
   {0xa67ddad0, {"8837686bce879406ce8590eec9f5c411"}, {"RX 220 (Microids) (France)/RX 220 (1987)(Microids)(fr)[cr].dsk"} },
   {0x9854f2ff, {"d60c62a5af8ab2e3fc69b2ec37a51333"}, {"Reckless Rufus (Alternative Software)/Reckless Rufus (1992)(Alternative Software)[cr].dsk"} },
   {0xf4e63364, {"d0e56cc1a7ef3b6088da3d2adb273a1c"}, {"Rik the Roadie (Alternative Software)/Rik the Roadie (1988)(Alternative Software)[tape].dsk"} },
// {0x1e4269a4, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Robin of Sherlock (CRL Group)/Robin of Sherlock (1986)(CRL Group)[cr].dsk"} },
   {0xe6a652f5, {"36fe0ebf8608a3acef5c208c36f948ac"}, {"Ramblas - El Caso Vega (Mind Games Espana) (Spain)/Ramblas - El Caso Vega (1986)(Mind Games Espana)(es)[cr].dsk"} },
   {0x07cafada, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sweevo's World (Gargoyle Games)/Sweevo's World (1986)(Gargoyle Games).dsk"} },
   {0xe97478db, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Slap Fight (Ocean Software)/Slap Fight (1987)(Ocean Software).dsk"} },
   {0x86cd863f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Saint Dragon (Storm Software)/Saint Dragon (1990)(Storm Software).dsk"} },
   {0x41703c02, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Summer Games II (Epyx)/Summer Games II (1989)(Epyx)(Side A).dsk"} },
   {0x62dd3a2b, {"8376cde775dfe3f0b859fe77ec77385f"}, {"Stress (Cobra Soft) (France)/Stress (1985)(Cobra Soft)(fr)[cr].dsk"} },
   {0x7963c719, {"b89155cde73f538190e351452bdb4bc4"}, {"Scalextric (Leisure Genius)/Scalextric (1987)(Leisure Genius)[cr].dsk"} },
   {0x9f46b8f7, {"0f3ce766494c244fb3e069ee60809d95"}, {"Sydney Affair, The (Infogrames)/Sydney Affair, The (1986)(Infogrames).dsk"} },
   {0xb9625be5, {"88bfdae639e7c2ed8f3e6770aedd247f"}, {"Starbyte (Mister Chip) (Spain)/Starbyte (1987)(Mister Chip)(es)[tape].dsk"} },
   {0x6e1d7ad5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Skate or Die (Electronic Arts)/Skate or Die (1989)(Electronic Arts)(Side A).dsk"} },
   {0x31b7091c, {"5bccbf05f723463d7b020d45fb81aa0c"}, {"Sir Lancelot (Melbourne House)/Sir Lancelot (1984)(Melbourne House)[tape].dsk"} },
   {0xb26585d2, {"5668fbfcc57ae3e0c41dfb14347fcb21"}, {"Super Ali (CPC Infos) (France)/Super Ali (1990)(CPC Infos)(fr)[cr].dsk"} },
   {0x3343b8d7, {"c87a98f8cc363ed129a320da6a59a8a3"}, {"Sparse Invaders (FUK)/Sparse Invaders (1986)(FUK)[cr].dsk"} },
   {0xfd79cead, {"63fe5738a72582a3d1f5ea662a9bc2b7"}, {"Space Harrier (Elite Systems)/Space Harrier (1986)(Elite Systems).dsk"} },
   {0x4675e22e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Simulador Profesional de Tenis (Dinamic Software) (Spain)/Simulador Profesional de Tenis (1990)(Dinamic Software)(es).dsk"} },
   {0x95b94081, {"c23d2fa751b771790e3d421385e52200"}, {"Secte Noire, La (Lankhor) (France)/Secte Noire, La (1990)(Lankhor)(fr)(Side A).dsk"} },
   {0x5483ddb7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Split Personalities (Domark)/Split Personalities (1986)(Domark).dsk"} },
   {0xd3de0256, {"cbaaffc7ea3580033750a5861f4ef4fd"}, {"Super Chess (CP Software)/Super Chess (1984)(CP Software)[cr].dsk"} },
   {0x910dbea7, {"f4a0a489a6c1de39d02b514c42222d61"}, {"Stunt Man Seymour (Codemasters Software)/Stunt Man Seymour (1992)(Codemasters Software)[cr].dsk"} },
   {0xa45e6806, {"10609e7932ae57f2e48c1b43b9503dfa"}, {"Secret Diary of Adrian Mole, The (Mosaic Publishing)/Secret Diary of Adrian Mole, The (1985)(Mosaic Publishing)[tape].dsk"} },
   {0x4aa7b255, {"0f3ce766494c244fb3e069ee60809d95"}, {"Star Wars - The Empire Strikes Back (Domark)/Star Wars - The Empire Strikes Back (1988)(Domark).dsk"} },
   {0xd4fe12b1, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Shockway Rider (FTL)/Shockway Rider (1986)(FTL).dsk"} },
   {0xbdfbd2d0, {"8a451bb3afb17c10698c3f504debb2fb"}, {"Simon (Amstrad Action)/Simon (1990)(Amstrad Action)[cr].dsk"} },
   {0xed2d0b83, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Street Fighter (Us Gold)/Street Fighter (1988)(Us Gold).dsk"} },
   {0x9547c0eb, {"44593361b513b7c2d70cfaf8bf00e37a"}, {"Shove a Sledge (Gremlin Graphics Software)/Shove a Sledge (1987)(Gremlin Graphics Software)[tape].dsk"} },
   {0xb0540671, {"0f3ce766494c244fb3e069ee60809d95"}, {"Sol Negro (Opera Soft) (Spain)/Sol Negro (1989)(Opera Soft)(es).dsk"} },
   {0xa02ee4f7, {"92056f3392eb909b7dc0564b743a18fa"}, {"Shark (Players Premier)/Shark (1989)(Players Premier)[tape].dsk"} },
   {0x29348c34, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Street Gang (Players)/Street Gang (1988)(Players)[f].dsk"} },
   {0x30ea42d7, {"820373d126ec4b561d522042164e3d54"}, {"Star Commando (Terminal software)/Star Commando (1984)(Terminal software)[tape].dsk"} },
   {0x1e15c4c1, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sapiens (Loriciels) (France)/Sapiens (1986)(Loriciels)(fr)(v2).dsk"} },
   {0x2652e26e, {"b6ced4990f02394c35b02292396e0a6b"}, {"Strip Takin (Eric Hiller) (France)/Strip Takin (19xx)(Eric Hiller)(fr)[cr].dsk"} },
   {0x9018ae68, {"b888cb44db99daea6caa451333ad0ac9"}, {"Spy vs Spy III - Arctic Antics (Databyte)/Spy vs Spy III - Arctic Antics (1988)(Databyte).dsk"} },
   {0xb115061b, {"397d12a922488a8264228c56916d445a"}, {"Sky Hunter (ERE Informatique) (France)/Sky Hunter (1988)(ERE Informatique)(fr).dsk"} },
   {0x46f46c53, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Skull & Crossbones (Domark)/Skull & Crossbones (1991)(Domark).dsk"} },
   {0xc1754e9e, {"b84cd4631ef90fc17ad35919cadeb79d"}, {"Subtera Puzlo (Egotrip, Redbox)/Subtera Puzlo (2013)(Egotrip, Redbox).dsk"} },
   {0xe04c8351, {"34854bb9810e5933b63a1c65771d377a"}, {"Space Froggy 2 (Glenco)/Space Froggy 2 (19xx)(Glenco)[cr].dsk"} },
   {0xe84c1b56, {"090dfa9dfbdd67b907ec578a234ff4b1"}, {"Samantha Fox Strip Poker (React Software)/Samantha Fox Strip Poker (1986)(React Software).dsk"} },
   {0xae559ca9, {"b1ef35eadbebecd339a9b91add7f03d3"}, {"Super Ski (Microids)/Super Ski (1987)(Microids)[f].dsk"} },
   {0x745df326, {"c68076620e353d3feae594cc90a2f4ca"}, {"Sailing (Activision)/Sailing (1987)(Activision).dsk"} },
   {0xc25543ff, {"551cee8f0db652808fef8c504b466704"}, {"Speed King (Mastertronic)/Speed King (1986)(Mastertronic)[cr].dsk"} },
   {0x32baf3a8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Silent Shadow (Topo Soft) (Spain)/Silent Shadow (1988)(Topo Soft)(es).dsk"} },
   {0x6bc6492b, {"e3ae33a605b7701fa46bc2d0bb375af8"}, {"Super Sam (Budgie)/Super Sam (1985)(Budgie)[cr].dsk"} },
   {0x0bd6c0af, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Shinobi - Remaster (Fmtrx) (Hack)/Shinobi - Remaster (1989)(Fmtrx)(v1.02)(Hack)[cr][f].dsk"} },
   {0xa035e15b, {"99da5681226bce61e70976445d4bb1d5"}, {"Short's Fuse (Firebird)/Short's Fuse (1984)(Firebird)[tape].dsk"} },
   {0x702b10da, {"dc7cb83ef6d70e271c753d0eaa6b6dc2"}, {"Starion (Melbourne House)/Starion (1985)(Melbourne House)[cr].dsk"} },
   {0xe2f225a3, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Shadow Warriors (Ocean Software)/Shadow Warriors (1990)(Ocean Software).dsk"} },
   {0x0ad8c6d7, {"fe4fcf5c3bdebd0e4b8091d0d5b5d1b7"}, {"Smash (PC Amstrad International)/Smash (1988)(PC Amstrad International)[cr].dsk"} },
   {0xfcb65dde, {"0bfa77229697c85dce54445a35746cde"}, {"Solar Invasion (Mastertronic) (LightGun)/Solar Invasion (1989)(Mastertronic)(LightGun)[cr].dsk"} },
   {0x9f9f22e3, {"50175030a09ccae8e64232460dc90054"}, {"Sharpes Deeds (Incentive) (Hack)/Sharpes Deeds (1987)(Incentive)(Hack)[cr].dsk"} },
   {0xe4c85712, {"14c8f78901a3ace01714556f0478e123"}, {"Swords & Sorcery (PSS)/Swords & Sorcery (1985)(PSS).dsk"} },
// {0x3f4b2026, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"SRAM (ERE Informatique) (M3)/SRAM (1986)(ERE Informatique)(M3)(Side A).dsk"} },
// {0xabd24f9a, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Sport (Amstar & Cpc)/Sport (1989)(Amstar & Cpc)[cr].dsk"} },
   {0x8f69c29e, {"0d85ed44415ef882b1f8c2c86dc58cd7"}, {"Souls of Darkon (Taskset)/Souls of Darkon (1985)(Taskset).dsk"} },
   {0x16bbd7b9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Super Pipeline II (Amsoft)/Super Pipeline II (1985)(Amsoft).dsk"} },
   {0xb1801fa7, {"28f094ab5c03e27cab8577605ec97cc8"}, {"Secrets of Ur, The (Amstrad Adventure PD Library)/Secrets of Ur, The (19xx)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0xe103b180, {"fb2a68453bb9baadf7e7478e5c9edaff"}, {"Super Tetris (Frequency)/Super Tetris (1997)(Frequency)(PD)[cr].dsk"} },
   {0xcb3f9396, {"1b3be23e8e94188645b27c70ea67000f"}, {"Stationfall (Infocom)/Stationfall (1987)(Infocom)[CPM].dsk"} },
   {0x335b8c5e, {"c68076620e353d3feae594cc90a2f4ca"}, {"Starstrike II (Firebird)/Starstrike II (1986)(Firebird).dsk"} },
   {0xcc9a8724, {"20b0c37a39b9bed1275e773d50e50ba3"}, {"Snoball in Hell (Atlantis Software)/Snoball in Hell (1989)(Atlantis Software)[tape].dsk"} },
   {0x766a1630, {"a66c465f3e333a96a729f34fd4facfbe"}, {"Skywar (CPC Infos)/Skywar (1992)(CPC Infos)[cr].dsk"} },
   {0x2314f143, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Stifflip & Co (Palace Software) (de)/Stifflip & Co (1987)(Palace Software)(de)(Side A).dsk"} },
   {0x2a17a0be, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Silicon Dreams (Level 9 Computing)/Silicon Dreams (1986)(Level 9 Computing)(v2).dsk"} },
   {0xbae01a82, {"6dff7995c3ee5d490dd137797f166470"}, {"Silent Service (Microprose Software)/Silent Service (1986)(Microprose Software).dsk"} },
   {0x1c2bc5e6, {"397d12a922488a8264228c56916d445a"}, {"Stryfe - The Everlasting Battle (ERE Informatique) (France)/Stryfe - The Everlasting Battle (1986)(ERE Informatique)(fr).dsk"} },
   {0xf279a823, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Screwball (CDS Software LTD)/Screwball (1985)(CDS Software LTD)[cr].dsk"} },
   {0xc22c04c0, {"a1cc1b060515a28702cd76c786f98d7a"}, {"Sport of Kings (Mastertronic)/Sport of Kings (1986)(Mastertronic)[tape].dsk"} },
   {0x086e337d, {"0192d9978d19ea01e1f535ce8049f08c"}, {"Sherman M4 (Loriciels) (France)/Sherman M4 (1990)(Loriciels)(fr)(v2).dsk"} },
// {0xdf6b3ee6, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Spitfire 40 (Mirrorsoft)/Spitfire 40 (1985)(Mirrorsoft).dsk"} },
   {0xfe604da8, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Salamander (Konami)/Salamander (1988)(Konami).dsk"} },
   {0xaeba8e2d, {"63669eb25c4f606d57774857d669a69c"}, {"Soko-Ban (Schneider Computer Partner) (de)/Soko-Ban (1989)(Schneider Computer Partner)(de)[cr].dsk"} },
   {0xda93dcb2, {"faac37858b5eddb15c0d12b7b1a873d3"}, {"Spots (Jaysoft)/Spots (1993)(Jaysoft)(PD)[cr].dsk"} },
   {0x95204f0b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Soldier of Light (ACE) (Spain)/Soldier of Light (1989)(ACE)(es).dsk"} },
   {0xa97a4c9b, {"2331d69ee21cf92cf7090716a369aeaf"}, {"Skyfox (Electronics Arts)/Skyfox (1985)(Electronics Arts).dsk"} },
   {0x6c33a78e, {"551cee8f0db652808fef8c504b466704"}, {"Speed King (Mastertronic) (Spain)/Speed King (1986)(Mastertronic)(es)[cr].dsk"} },
   {0xe629f5aa, {"ca6d3de5d59a7dcb075cb3046bae3618"}, {"Superman - The Game (First Star Software)/Superman - The Game (1985)(First Star Software)[cr].dsk"} },
   {0xdf1fbc63, {"b9d80528777a906c3aac05cda56c304b"}, {"Satelit (CPC) (France)/Satelit (1988)(CPC)(fr)[cr].dsk"} },
   {0x583ff05a, {"0f3ce766494c244fb3e069ee60809d95"}, {"Stainless Steel (Mikrogen)/Stainless Steel (1986)(Mikrogen).dsk"} },
   {0xedf6e15d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Sirwood (Opera Soft)/Sirwood (1990)(Opera Soft).dsk"} },
   {0xe72d55be, {"71d42431adae1ddd32c84cc84b001d69"}, {"Spaced Out (Amstrad Adventure PD Library)/Spaced Out (1990)(Amstrad Adventure PD Library)[tape].dsk"} },
   {0x1b3bf900, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Supertripper (Indescomp) (Spain)/Supertripper (1985)(Indescomp)(es).dsk"} },
   {0xf54901d3, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Star Control (Accolade)/Star Control (1991)(Accolade).dsk"} },
   {0xfbd21696, {"0f3ce766494c244fb3e069ee60809d95"}, {"Samurai Warrior - The Battles of Usaji Yojimbo (Firebird)/Samurai Warrior - The Battles of Usaji Yojimbo (1988)(Firebird).dsk"} },
   {0xc50b67b4, {"9c2d41782ad3d9f0f18ad849de5925c9"}, {"Subway Vigilante (Players Premier)/Subway Vigilante (1989)(Players Premier)[tape].dsk"} },
   {0xe3fbe93f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Scalextric (Leisure Genius) (France)/Scalextric (1987)(Leisure Genius)(fr)(v2).dsk"} },
   {0x7dd3f5cf, {"0f3ce766494c244fb3e069ee60809d95"}, {"Scramble Spirits (Grandslam)/Scramble Spirits (1990)(Grandslam).dsk"} },
   {0x0e9b2124, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Stunt Car Racer (Micro Style)/Stunt Car Racer (1990)(Micro Style).dsk"} },
   {0x927f9670, {"0f3ce766494c244fb3e069ee60809d95"}, {"Soleil Noir (Opera Soft) (France)/Soleil Noir (1989)(Opera Soft)(fr).dsk"} },
   {0x7f758031, {"f8dbc5df1706f537eafccdd9b6591b2b"}, {"Star Trap (Loriciels) (France)/Star Trap (1989)(Loriciels)(fr)(Side A)[cr].dsk"} },
   {0x1993c727, {"e3ae33a605b7701fa46bc2d0bb375af8"}, {"Super Skweek (Loriciels) (Bugs)/Super Skweek (1990)(Loriciels)[b].dsk"} },
   {0x85597be5, {"40959bf2b5b209de9862719940ee8f6d"}, {"Slightly Magic (Codemasters Software)/Slightly Magic (1992)(Codemasters Software)[cr].dsk"} },
   {0x91a8d403, {"06ab23a77845b8330ceca4e793c69668"}, {"Space Base (Computer Gamer)/Space Base (1986)(Computer Gamer)[cr].dsk"} },
   {0xe7e51b18, {"8a451bb3afb17c10698c3f504debb2fb"}, {"Simon (Computing With The Amstrad)/Simon (1988)(Computing With The Amstrad)[cr].dsk"} },
   {0xc83f6f3b, {"b1491c883b3f8cc20d3dc7131df7ec44"}, {"Storm Warrior (Elite Systems)/Storm Warrior (1989)(Elite Systems)[cr].dsk"} },
   {0x2a4e9503, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Saboteur 2 (Durell Software)/Saboteur 2 (1987)(Durell Software)[f].dsk"} },
   {0x6c98f5be, {"b6841abd56fd0f530fe0181f38f09170"}, {"Sexy Words (H. Monchatre) (France)/Sexy Words (1988)(H. Monchatre)(PD)(fr)[cr].dsk"} },
   {0x1ba876a5, {"a1973958869b15e35a50cd9443c819de"}, {"Strip Ball (Digital Dream) (France)/Strip Ball (1995)(Digital Dream)(fr)[cr].dsk"} },
   {0x1ee9ee39, {"666c0745f7241de8b1269936c55f7e7c"}, {"Sub-Marine (Amstrad Cent Pour Cent) (France)/Sub-Marine (1989)(Amstrad Cent Pour Cent)(fr)[cr].dsk"} },
   {0x73736e58, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Spitting Image (Domark)/Spitting Image (1988)(Domark).dsk"} },
   {0xbca83ee8, {"5ece7026973117284998c0e7aa4c6111"}, {"Storm II - The Fear (Mastertronic)/Storm II - The Fear (1987)(Mastertronic)[cr].dsk"} },
   {0x72d0dc7d, {"0b784ddc69fe051787258658867d02c1"}, {"Showdown In Tombstone City (Magazin Players Dream)/Showdown In Tombstone City (1985)(Magazin Players Dream)(PD)[cr].dsk"} },
   {0xf773074b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Samurai Trilogy (Gremlin Graphics Software) (M4)/Samurai Trilogy (1987)(Gremlin Graphics Software)(M4)(Side A).dsk"} },
   {0x248f2c16, {"0f3ce766494c244fb3e069ee60809d95"}, {"Solo (Opera Soft) (Spain) (LightGun)/Solo (1989)(Opera Soft)(es)(LightGun).dsk"} },
// {0xce5c2785, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Saga (Lankhor) (France)/Saga (1990)(Lankhor)(fr)(Side A).dsk"} },
   {0xd2d336bd, {"d2db1661c53ee95331df4023104006c5"}, {"Space Shuttle Simulateur (Loriciels) (France)/Space Shuttle Simulateur (1985)(Loriciels)(fr)[cr].dsk"} },
   {0x7fe4abc2, {"fefeb2ed3fe9f32f65ee6a8cb4256f3e"}, {"Survivant, Le (PSS) (France)/Survivant, Le (1985)(PSS)(fr)[cr][f].dsk"} },
   {0xc58820bf, {"51790f1152b592f82545a2d929ee46fd"}, {"Sdaw (Lankhor) (France)/Sdaw (1990)(Lankhor)(fr)(Side A).dsk"} },
   {0xb9c39b3d, {"c1561b120842fabe1310417083827590"}, {"Star-Bores (Neutrino Software)/Star-Bores (1988)(Neutrino Software)[cr][CPM].dsk"} },
   {0xef453a52, {"639a5e2d45ca7419e5161f32e83c1c0f"}, {"Sliders (Microids)/Sliders (1991)(Microids).dsk"} },
   {0x3f07d809, {"099707279213ac43ffff96f2fcba5776"}, {"Survivors (Atlantis Software)/Survivors (1988)(Atlantis Software)[tape].dsk"} },
   {0x4b96f419, {"f5c83c6ba83bfa9af4ffc5335a728404"}, {"Star Trooper (Players)/Star Trooper (1988)(Players)[tape].dsk"} },
   {0x35db55a2, {"551cee8f0db652808fef8c504b466704"}, {"Speedzone (Mastertronic)/Speedzone (1988)(Mastertronic)[tape].dsk"} },
   {0x20fca483, {"a983e93fa833915364b255098af648e1"}, {"Space Duel, The (Andreas Stroiczek) (de)/Space Duel, The (1990)(Andreas Stroiczek)(PD)(de)[cr].dsk"} },
   {0x1984568a, {"31f51fb9995fca03a663b41c0d46d352"}, {"Suicide Squad (Magazin Players Dream)/Suicide Squad (1987)(Magazin Players Dream)(PD)[cr].dsk"} },
   {0x4e289ff4, {"efe2314959e59f493afa02e318f90b52"}, {"Space Mission (Cascade Games)/Space Mission (1986)(Cascade Games)[cr].dsk"} },
   {0x456874d4, {"e3b2d2af33a7146d16e2aa77cc3c7554"}, {"Spy Trek Adventure (Americana Software Ltd)/Spy Trek Adventure (1987)(Americana Software Ltd)[cr].dsk"} },
   {0x4ec6fcf8, {"7c91f08dc1c3659e87a362d526541336"}, {"Skaal (Softhawk) (France)/Skaal (1987)(Softhawk)(fr)(Side A).dsk"} },
   {0x1aa1cbe7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Stockmarket (Amsoft)/Stockmarket (1985)(Amsoft).dsk"} },
   {0xb715105e, {"4fa3da497f05dc7944256ceadfbd1478"}, {"Subsunk (CPC Schneider International) (France)/Subsunk (1988)(CPC Schneider International)(fr)[cr].dsk"} },
   {0xc9f96b87, {"5028d15ccd2c21489060d84044caf590"}, {"Solar Empire (Players Premier)/Solar Empire (1990)(Players Premier)[tape].dsk"} },
// {0x167ea88a, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Soccer 86 (Loriciels)/Soccer 86 (1985)(Loriciels).dsk"} },
   {0x06edc711, {"4fa3da497f05dc7944256ceadfbd1478"}, {"Subsunk (CPC Schneider International) (de)/Subsunk (1988)(CPC Schneider International)(de)[cr].dsk"} },
   {0xf3e8bd31, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Subterranean Stryker (Amsoft)/Subterranean Stryker (1985)(Amsoft).dsk"} },
   {0xfcf7fc5d, {"06ab23a77845b8330ceca4e793c69668"}, {"Space Rider - Jet Pack Co. (Hi-Tec Software)/Space Rider - Jet Pack Co. (1990)(Hi-Tec Software)[cr].dsk"} },
   {0x9364824b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Super Wonderboy in Monster Land (Activision)/Super Wonderboy in Monster Land (1989)(Activision)(Side A).dsk"} },
   {0xe1fcec53, {"a3ad30cfe5b674f3fff30a11192562c4"}, {"Shanghai (-)/Shanghai (1988)(-)(PD)[cr].dsk"} },
   {0x300c27db, {"a556ba3086b143bd0694152c9ce69692"}, {"Salva las Letras (-) (Spain)/Salva las Letras (19xx)(-)(PD)(es)[cr].dsk"} },
   {0xd05a21f3, {"d539b78db7f748f4a95f062e0da97434"}, {"Stomp (DK' Tronics)/Stomp (1984)(DK' Tronics)[cr].dsk"} },
   {0x284a343c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Score 3020 (Topo Soft) (Spain)/Score 3020 (1988)(Topo Soft)(es).dsk"} },
   {0xfab74dca, {"83cf1a6fab81c1fb1f89ba8c4083c2bc"}, {"Space Invaders Arcade Emulator (-)/Space Invaders Arcade Emulator (2017)(-)(PD)(v1.02)[cr].dsk"} },
   {0x953bf28b, {"adecc05bfdb5ab3de1740b46b182eb92"}, {"SOS 100% (Amstrad Cent Pour Cent) (France)/SOS 100% (1988)(Amstrad Cent Pour Cent)(fr)[cr].dsk"} },
   {0x4971cc63, {"c0fdb01642566572669aa0aac6f89eef"}, {"Saga of Erik the Viking, The (Level 9 Computing)/Saga of Erik the Viking, The (1984)(Level 9 Computing)[tape].dsk"} },
   {0x0ba1e0de, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Spherical (Rainbow Arts)/Spherical (1989)(Rainbow Arts)(Side A).dsk"} },
   {0x7830a74e, {"a1ab329cc71f9a87e56c2b6cc80e8509"}, {"Sai Combat (Mirrorsoft)/Sai Combat (1986)(Mirrorsoft).dsk"} },
   {0xaf81d0ad, {"41342997cecafc1987de262fda2706af"}, {"Seas of Blood (Adventure International)/Seas of Blood (1985)(Adventure International)(v2)[cr].dsk"} },
   {0x2792ba58, {"351ac977ef782f53d4252c4f721dce49"}, {"Submarino Experimental Neptuno (Ediciones Manali) (Spain)/Submarino Experimental Neptuno (19xx)(Ediciones Manali)(es)[cr][d7].dsk"} },
   {0x49b24afd, {"039928c9c1cbc652de79538c3945edac"}, {"Scramble (Computing With The Amstrad)/Scramble (1988)(Computing With The Amstrad)[cr].dsk"} },
   {0x376c862a, {"06ab23a77845b8330ceca4e793c69668"}, {"Space Racer (Loriciels)/Space Racer (1988)(Loriciels).dsk"} },
   {0xcb87873b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Starfox (Ariolasoft)/Starfox (1987)(Ariolasoft).dsk"} },
   {0xd4586894, {"2aa650dfc70cb9e3237dc3db85ae7ac0"}, {"Sharkey's Moll (Zeppelin Games)/Sharkey's Moll (1991)(Zeppelin Games)[cr].dsk"} },
   {0x7434b021, {"0f3ce766494c244fb3e069ee60809d95"}, {"Star Wars - Return Of The Jedi (Domark)/Star Wars - Return Of The Jedi (1989)(Domark).dsk"} },
   {0x6085a8be, {"5028d15ccd2c21489060d84044caf590"}, {"Solar Coaster (Optyx Software)/Solar Coaster (1987)(Optyx Software)[tape].dsk"} },
   {0x79b8bbcd, {"c622ce1785c738ec87d36a85bf5918eb"}, {"Secret of Bastow Manor, The (Gameworx Software)/Secret of Bastow Manor, The (1984)(Gameworx Software).dsk"} },
   {0xc40d22cb, {"3a8ccb0d5781c9b5b9ad25cead2b4714"}, {"S.T.U.N. Runner (Domark)/S.T.U.N. Runner (1991)(Domark).dsk"} },
   {0xe4ca7266, {"a4f8c48bd44e10d44038033ac6ca7e7a"}, {"Stack 'n' Smile (Nicholas Campbell)/Stack 'n' Smile (2003)(Nicholas Campbell).dsk"} },
   {0xd474d246, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Side Arms (US Gold)/Side Arms (1988)(US Gold).dsk"} },
   {0xaa7f2a56, {"5c01411687e064ae41572035d8527c7e"}, {"SDI - Strategic Defence Initiative (Activision)/SDI - Strategic Defence Initiative (1988)(Activision)[tape].dsk"} },
   {0x4c5cd626, {"0f3ce766494c244fb3e069ee60809d95"}, {"Space Crusade (Gremlin Graphics Software) (Spain)/Space Crusade (1992)(Gremlin Graphics Software)(es).dsk"} },
   {0x00c8282b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Space Harrier II (Grandslam)/Space Harrier II (1990)(Grandslam)(Side A).dsk"} },
   {0xce0180d5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Stifflip & Co (Palace Software) (France)/Stifflip & Co (1987)(Palace Software)(fr)(Side A).dsk"} },
   {0xdea061fc, {"dd53469eee692d53548c3838a92220cf"}, {"Simplex 3D (Micro Mag) (France)/Simplex 3D (1990)(Micro Mag)(fr)[cr].dsk"} },
   {0x44d6bf89, {"38cacb59b43bc05ff2f718a06abc92a6"}, {"Scooby Doo and Scrappy Doo (Hi-Tec Software)/Scooby Doo and Scrappy Doo (1991)(Hi-Tec Software)[cr][f].dsk"} },
   {0x80b4d1de, {"acb5d9cc68f5133e472a7cb28cf749a4"}, {"Strip Poker Animado (Knight Soft) (Spain) (Hack)/Strip Poker Animado (1987)(Knight Soft)(es)(Hack)[cr].dsk"} },
   {0x39d956c4, {"877f42964cc8bc757944bcff57734e51"}, {"Scoop Junior (Generation 5) (France)/Scoop Junior (1990)(Generation 5)(fr)(Side A).dsk"} },
   {0xaffce575, {"ba142c22c73a1cb70aaca7fce71eebd1"}, {"Super Pac (PC Schneider International)/Super Pac (1987)(PC Schneider International)[cr].dsk"} },
   {0x00653097, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sideral War (Delta Software) (Spain)/Sideral War (1990)(Delta Software)(es).dsk"} },
   {0x6e83fa1f, {"a54dd8f1d810532b94ed307c5ea06bc7"}, {"Septieme Continent, Le (L. Dplanque) (France)/Septieme Continent, Le (1987)(L. Dplanque)(fr)(Side A).dsk"} },
   {0xb984201b, {"8c933fa2bbb08bb9017e1a7f1a3ceb83"}, {"Smiley Affair, The (M. Dowse)/Smiley Affair, The (1993)(M. Dowse)(PD)[cr].dsk"} },
   {0x160ee8e9, {"a3fde1905f0f9df7876d950895450d1b"}, {"Seastalker (Infocom)/Seastalker (1984)(Infocom)[CPM].dsk"} },
   {0xe5d8e7e9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Splat! (Amsoft)/Splat! (1985)(Amsoft).dsk"} },
   {0x11b73896, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ship Pilot (System 4) (Spain)/Ship Pilot (1986)(System 4)(es).dsk"} },
   {0xef7871dc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Skate Crazy (Gremlin Graphics Software)/Skate Crazy (1988)(Gremlin Graphics Software)(Side A).dsk"} },
   {0x43a174ac, {"42120e572939b214d445cdb9cc6862c2"}, {"Sigma 7 (Durell Software)/Sigma 7 (1987)(Durell Software).dsk"} },
   {0x687a0668, {"c3888a36091dc28ce3bb7648a24cf0bf"}, {"Scary Tales (The Power House)/Scary Tales (1985)(The Power House)[tape].dsk"} },
   {0x20e80d12, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Shadow Dancer (US Gold)/Shadow Dancer (1991)(US Gold).dsk"} },
   {0x482fe514, {"375b3818072bd1077a0e94f4081ce43c"}, {"Smugglers Cove (CRL Group)/Smugglers Cove (1985)(CRL Group)[cr][BASIC 1.0].dsk"} },
   {0x75b52a3b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Silkworm (Virgin Games)/Silkworm (1988)(Virgin Games).dsk"} },
   {0xdde58c80, {"b1491c883b3f8cc20d3dc7131df7ec44"}, {"Stormbringer (Mastertronic)/Stormbringer (1987)(Mastertronic)[tape].dsk"} },
// {0xd611e454, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"SRAM 2 (ERE Informatique) (France)/SRAM 2 (1986)(ERE Informatique)(fr)(Side A).dsk"} },
   {0x2e01e637, {"3ed6e305936e3b69be3e18cf7ea7e705"}, {"Serpentino (AM-Mag) (France)/Serpentino (1988)(AM-Mag)(fr)[cr].dsk"} },
   {0xf88a48bd, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Strip Poker II+ (Anco Software)/Strip Poker II+ (1988)(Anco Software).dsk"} },
   {0xfaa10dd6, {"d47a0735b8c62204fdacabe406c1a428"}, {"Saboteur (Durell Software)/Saboteur (1986)(Durell Software)[f].dsk"} },
   {0x29c80cbd, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Star Avenger (Kuma Computers)/Star Avenger (1984)(Kuma Computers).dsk"} },
   {0x37ee404f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Shinobu (cpcretrodev.byterealms)/Shinobu (2019)(cpcretrodev.byterealms)[cr].dsk"} },
   {0x3726c2cf, {"5d528fda701686f3898560f35938821a"}, {"Super Stock Car (Mastertronic)/Super Stock Car (1990)(Mastertronic)[tape].dsk"} },
   {0x5f89b89d, {"71f4d1560bcaf42071859840cc325d8a"}, {"Syntax (CDS Software LTD)/Syntax (1988)(CDS Software LTD)[cr].dsk"} },
   {0x04090355, {"2b21f7c184bd3c79fd6606a6b3a80d47"}, {"Strip Poker Anime, Le (Knight Soft) (France)/Strip Poker Anime, Le (1985)(Knight Soft)(fr)[cr].dsk"} },
   {0xae64ea1d, {"0f3ce766494c244fb3e069ee60809d95"}, {"Satan (Dinamic Software)/Satan (1989)(Dinamic Software).dsk"} },
   {0x825e0177, {"990bed2e77708f68567bce811e501a31"}, {"Sudoku (Cronosoft)/Sudoku (2008)(Cronosoft).dsk"} },
// {0x84e5676e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Skateball (Ubi Soft)/Skateball (1989)(Ubi Soft).dsk"} },
   {0xb2c6c7cd, {"397d12a922488a8264228c56916d445a"}, {"Scott Winder Reporter (ERE Informatique) (France)/Scott Winder Reporter (1987)(ERE Informatique)(fr)(Side A).dsk"} },
   {0x0e387f66, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Snowstrike (US Gold)/Snowstrike (1991)(US Gold).dsk"} },
   {0x5dbf9970, {"7216f1b724b3cf8e9d3f6e54e4a25015"}, {"Striker In The Crypts Of Trogan (Codemasters Software)/Striker In The Crypts Of Trogan (1992)(Codemasters Software)[cr][CPC+].dsk"} },
   {0xc331b18d, {"8a451bb3afb17c10698c3f504debb2fb"}, {"Simon Dice (Amstrad Action) (Spain)/Simon Dice (19xx)(Amstrad Action)(PD)(es)[cr].dsk"} },
   {0x81ad6524, {"d8b4d9e3a75010b273d1640fa51eb32f"}, {"Solitaire (CPC) (France)/Solitaire (1986)(CPC)(fr)[464].dsk"} },
   {0x9181fe3c, {"3aadd9955198404e8372d204b82f7cc7"}, {"Steve Davis Snooker (CDS Software LTD)/Steve Davis Snooker (1985)(CDS Software LTD).dsk"} },
   {0x1115c8c8, {"1f250345474ec052ddb3523211644514"}, {"Super Stuntman (Codemasters Software)/Super Stuntman (1988)(Codemasters Software)[cr].dsk"} },
   {0x2c1804c8, {"fccdb8008e08dfee5ae57550027b817c"}, {"Space Racer (Loriciels) (France)/Space Racer (1988)(Loriciels)(fr).dsk"} },
   {0x0417c5aa, {"8b17bc4ce24ee0db34a4f27ea751481f"}, {"Slaine (Martech)/Slaine (1988)(Martech).dsk"} },
   {0xdaa9cc5e, {"e03b603b1095ff230f060f09ee4e1c5b"}, {"Scooby Doo (Elite Systems)/Scooby Doo (1986)(Elite Systems).dsk"} },
   {0xee17125a, {"5bfc73f72f8cc857644abc3f0998e6f5"}, {"Stardust (Topo Soft) (Spain)/Stardust (1987)(Topo Soft)(es)[cr].dsk"} },
   {0xae01ef0e, {"b4b2ae24be1b5843d084f051be6ba6f2"}, {"Swap (Fraggle)/Swap (1992)(Fraggle)(PD)[cr].dsk"} },
// {0x1e51e321, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Skweek (Loriciels)/Skweek (1989)(Loriciels).dsk"} },
   {0x1733c833, {"0f3ce766494c244fb3e069ee60809d95"}, {"Skyx (Legend Software) (France)/Skyx (1988)(Legend Software)(fr)(Side A).dsk"} },
   {0x6d63f48a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Shadows Of Sergoth, The (PD) (M3)/Shadows Of Sergoth, The (2018)(PD)(M3)(v1.0)(Side A).dsk"} },
   {0xaf6de481, {"ff156cefae9d0506c4e938c6249f4d6f"}, {"Santa's Christmas Capers (Zeppelin Games)/Santa's Christmas Capers (1991)(Zeppelin Games)[cr].dsk"} },
   {0xd8f8a7e9, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Survivor (Topo Soft)/Survivor (1987)(Topo Soft).dsk"} },
   {0x192a42fa, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Summer Games (Epyx)/Summer Games (1988)(Epyx)(Side A).dsk"} },
   {0xeeb6bb92, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Snoopy and Peanuts (The Edge)/Snoopy and Peanuts (1989)(The Edge).dsk"} },
   {0x21332735, {"3ed6e305936e3b69be3e18cf7ea7e705"}, {"Serpent Madness (CPC) (France)/Serpent Madness (1986)(CPC)(fr)[cr].dsk"} },
   {0xa06446cf, {"374126674366329e370bc0a63d992c1e"}, {"Sentinel, The (Firebird) (France)/Sentinel, The (1987)(Firebird)(fr).dsk"} },
   {0xed5a1c75, {"0f3ce766494c244fb3e069ee60809d95"}, {"Suspect (Infocom)/Suspect (1986)(Infocom).dsk"} },
   {0xbcd370e0, {"b49014bfa47b8a4f6cb8365e20537cc2"}, {"Strip Poker (Logipresse) (France)/Strip Poker (1987)(Logipresse)(fr)[cr].dsk"} },
   {0x9a4bca1c, {"3d139d35d336c80333d0853b1dfafa51"}, {"Soko Bam (CPC Infos) (M2)/Soko Bam (1992)(CPC Infos)(M2)[cr].dsk"} },
   {0xd39ebb1d, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Shackled (US Gold) (Bugs)/Shackled (1988)(US Gold)[b].dsk"} },
   {0x5c4b84cc, {"78b5d197361f8271fbeb9d8ee22570f9"}, {"Starcross (Infocom)/Starcross (1982)(Infocom)[cr][CPM].dsk"} },
   {0xd41826f1, {"f5d7acbbf0e8064020793e8a141a034a"}, {"Stop Ball (Dro Soft) (Spain)/Stop Ball (1987)(Dro Soft)(es)[cr].dsk"} },
   {0xa4bc9aab, {"74eb48df739c5840a94ad6d39b04fd8e"}, {"Strangeloop (Virgin Games)/Strangeloop (1985)(Virgin Games)[tape].dsk"} },
   {0x819d6ed7, {"5e45c8dfc8a55593bc3fd3e0efe04f0e"}, {"Suspended (Infocom)/Suspended (1983)(Infocom)[CPM].dsk"} },
// {0xeea7a690, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Sai Combat (Mirrorsoft) (France)/Sai Combat (1986)(Mirrorsoft)(fr).dsk"} },
   {0xd519f3ce, {"a5ab50b98db4eff018253b3b67222870"}, {"Spellbreaker (Infocom)/Spellbreaker (1985)(Infocom)[CPM].dsk"} },
   {0x7ca067e2, {"4e3a81207e82af0f998e374d67f7b4f0"}, {"Space Shuttle - A Journey into Space (Activision)/Space Shuttle - A Journey into Space (1986)(Activision).dsk"} },
   {0xd7e09b3d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Scramble (PuzCPC)/Scramble (2019)(PuzCPC)(PD)[cr].dsk"} },
// {0xfd464030, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Subbuteo - The Computer Game (Electronic Zoo) (Spain)/Subbuteo - The Computer Game (1990)(Electronic Zoo)(es).dsk"} },
   {0xfe3eb13a, {"06ab23a77845b8330ceca4e793c69668"}, {"Space Thief (Micro Mag)/Space Thief (1990)(Micro Mag)[cr].dsk"} },
   {0xcccc6eea, {"5f3abf1fd84fe0633eb7d47397652ac9"}, {"Special Operations (MC Lothlorien)/Special Operations (1984)(MC Lothlorien)[tape].dsk"} },
// {0x99821ea9, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Space Smugglers (MHT Ingenieros) (Spain)/Space Smugglers (1989)(MHT Ingenieros)(es)[gunstick].dsk"} },
   {0x36596d2c, {"09ce692dca58b781e4a47f061c478f99"}, {"Sabre Wulf (Ultimate Play The Game)/Sabre Wulf (1984)(Ultimate Play The Game)[tape].dsk"} },
   {0x8c8a37bd, {"8d8cb0ff49969a3c4b3814db7dd57717"}, {"Sgrizam (Dinamic Software) (Spain)/Sgrizam (1986)(Dinamic Software)(es)[cr].dsk"} },
// {0xe20b9533, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Subbuteo - The Computer Game (Electronic Zoo)/Subbuteo - The Computer Game (1990)(Electronic Zoo).dsk"} },
   {0xdd3b4296, {"368181f85ec0c626738683061f6b4603"}, {"Stifflip & Co (Palace Software) (Spain)/Stifflip & Co (1987)(Palace Software)(es)[cr].dsk"} },
   {0x8090224b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Super Trux (Elite Systems)/Super Trux (1988)(Elite Systems).dsk"} },
   {0x3a2ea285, {"831f03468c23b5ab8150ea0c3bdd42b1"}, {"Soccer Challenge (Alternative Software)/Soccer Challenge (1990)(Alternative Software)[tape].dsk"} },
   {0x365aba64, {"88d2391eebeb360778bd71ef6becb28c"}, {"Space Attack (Cascade Games)/Space Attack (1986)(Cascade Games)[cr].dsk"} },
   {0xe271c145, {"8a2b56e17ba7206deb2b63a10157962c"}, {"Sceptre d'Anubis, Le (Micro Programmes 5) (France)/Sceptre d'Anubis, Le (1985)(Micro Programmes 5)(fr)[cr].dsk"} },
   {0x829a71ce, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Star Wars (Domark)/Star Wars (1987)(Domark).dsk"} },
   {0xb8b2a919, {"e3ae33a605b7701fa46bc2d0bb375af8"}, {"Super Soccer (Ocean Software)/Super Soccer (1987)(Ocean Software)[cr].dsk"} },
   {0xbfe7ed34, {"e4955d163aeff24e11873bdb960f8121"}, {"Solomon's Key 3 v1.0 (Acid Team)/Solomon's Key 3 v1.0 (1994)(Acid Team)(PD)[cr].dsk"} },
   {0xc18a84f9, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Smash TV (Ocean Software)/Smash TV (1991)(Ocean Software).dsk"} },
   {0x6a653770, {"0f3ce766494c244fb3e069ee60809d95"}, {"Super Cars (Gremlin Graphics Software)/Super Cars (1990)(Gremlin Graphics Software).dsk"} },
   {0xca6ffd7a, {"71b3302975d01d8870f4eef1d5bb194e"}, {"Savage (Firebird)/Savage (1988)(Firebird)(Side A).dsk"} },
   {0x6cfb64e0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Spirits (Topo Soft) (Spain)/Spirits (1987)(Topo Soft)(es).dsk"} },
// {0x25723968, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Scoop Senior (Generation 5) (France)/Scoop Senior (1990)(Generation 5)(fr)(Side A).dsk"} },
   {0x3a970d1c, {"c68076620e353d3feae594cc90a2f4ca"}, {"Shufflepuck Cafe (Broderbund Software) (France)/Shufflepuck Cafe (1989)(Broderbund Software)(fr).dsk"} },
   {0xa454e2b3, {"2b6fd711fc3cbbcabd1a708611046636"}, {"Space Mazes (Amstrad Cent Pour Cent)/Space Mazes (1991)(Amstrad Cent Pour Cent)[cr].dsk"} },
   {0xe99c43c4, {"820373d126ec4b561d522042164e3d54"}, {"Star Fight (Hebdogiciel) (France)/Star Fight (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x36f23396, {"73a2ac47aebfb562fe0d8385b240d256"}, {"Search for Largo Grann, The (Amstrad Adventure PD Library)/Search for Largo Grann, The (1987)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0x22459515, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Saint Valentin (Sebastien Leloutre) (France)/Saint Valentin (1990)(Sebastien Leloutre)(fr)[cr].dsk"} },
   {0x881245c7, {"06ab23a77845b8330ceca4e793c69668"}, {"Space (Fanatic) (France)/Space (1990)(Fanatic)(fr)[cr].dsk"} },
   {0xbaab941c, {"2d83f732d3ea72189462e6535d7c0f5d"}, {"Super Cycle (Epyx)/Super Cycle (1987)(Epyx)[D3M].dsk"} },
   {0x83bce66c, {"c97614fe1a794e578df0b2b3d28df9c3"}, {"Storm (Mastertronic)/Storm (1986)(Mastertronic)[cr].dsk"} },
   {0xa02fd402, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Sootland (Zafiro Software Division) (Spain)/Sootland (1988)(Zafiro Software Division)(es).dsk"} },
   {0x43157458, {"b5c6f305ae89ba12305c0fb5dc08219f"}, {"Sultans Maze (Amsoft)/Sultans Maze (1984)(Amsoft)[cr][f][BASIC 1.1].dsk"} },
   {0xc4769db6, {"0c9516e0baa831831595516f6072d449"}, {"Scrounch (Hebdogiciel) (France)/Scrounch (1985)(Hebdogiciel)(fr)[cr].dsk"} },
   {0x595d8f94, {"368181f85ec0c626738683061f6b4603"}, {"Stifflip & Co (Palace Software)/Stifflip & Co (1987)(Palace Software)[cr].dsk"} },
   {0xca68e112, {"049dc1fe1fe2e48a5ac1850df0713386"}, {"Space Invaders (Auntie John)/Space Invaders (19xx)(Auntie John)(PD)[cr].dsk"} },
// {0x600fad6d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Scientific (Chip) (France)/Scientific (1987)(Chip)(fr).dsk"} },
   {0x8ea6b3fd, {"31e4497311ca76996c001b7f13e25d9f"}, {"Super Robin Hood (Codemasters Software)/Super Robin Hood (1986)(Codemasters Software)[cr].dsk"} },
   {0x26e35fea, {"c85598d34aee2634375a0e5f040f18c2"}, {"Scarabaeus (Ariolasoft) (Spain)/Scarabaeus (1985)(Ariolasoft)(es)[cr].dsk"} },
   {0x96c5402c, {"481fc6e603d60ff5dd41aa8dd8369c77"}, {"Southern Belle (Hewson)/Southern Belle (1985)(Hewson)[cr].dsk"} },
   {0x62641a3b, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sly Spy - Secret Agent (Ocean Software)/Sly Spy - Secret Agent (1990)(Ocean Software)(Side A).dsk"} },
   {0x7787b485, {"3183f1bdaa8f17d0e5dc283c68d5775e"}, {"Strike Force S.A.S. (Mikrogen)/Strike Force S.A.S. (1987)(Mikrogen)[cr].dsk"} },
   {0x443c7682, {"27cfbda7bc68f66e65beef1d16d7b06b"}, {"SOS Ovoides (Andromeda Software)/SOS Ovoides (1986)(Andromeda Software)[cr].dsk"} },
   {0xa68f4d96, {"2c6ed8fe1cfc3d23374e08fe2b20b583"}, {"Super Seymour Saves the Planet (Codemasters Software)/Super Seymour Saves the Planet (1991)(Codemasters Software)[cr].dsk"} },
   {0xf03ad98a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Shao Lin's Road (The Edge)/Shao Lin's Road (1987)(The Edge).dsk"} },
   {0x96426e54, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Strip Poker (CORE) (France)/Strip Poker (1985)(CORE)(fr).dsk"} },
   {0x0d84c1bc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Space Crusade (Gremlin Graphics Software) (France)/Space Crusade (1992)(Gremlin Graphics Software)(fr).dsk"} },
   {0x7af9e63d, {"3f101d3dc7f24611bdf88689859d8953"}, {"Streaker (Mastertronic)/Streaker (1987)(Mastertronic)[tape].dsk"} },
   {0x238d8926, {"0b16bb2133aa722d6185296b824ae08e"}, {"Super Pac (Loisitech) (France)/Super Pac (1985)(Loisitech)(fr).dsk"} },
   {0x4ba81057, {"670a364e87b6c44428db5732d4308711"}, {"Stock Exchange (Top Ten)/Stock Exchange (1987)(Top Ten)[cr].dsk"} },
   {0xa4d354a5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Sun Star (CRL Group)/Sun Star (1987)(CRL Group).dsk"} },
   {0x0997de36, {"7bb2b50c16d93d44c8e623c6f1628a23"}, {"Synchronous (Bretagne Edit Press) (France)/Synchronous (1987)(Bretagne Edit Press)(fr)[cr].dsk"} },
   {0x92345cde, {"2ae8d2a211e2fd45686f47751d62d103"}, {"Sir Fred (Zigurat) (Spain)/Sir Fred (1986)(Zigurat)(es).dsk"} },
   {0x761d9413, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Sootland (Zafiro Software Division) (Spain) (LightGun)/Sootland (1988)(Zafiro Software Division)(es)(LightGun).dsk"} },
   {0x1473cc7e, {"c68076620e353d3feae594cc90a2f4ca"}, {"Super Sapiens (Proein Soft Line) (Spain)/Super Sapiens (1989)(Proein Soft Line)(es).dsk"} },
// {0xf2a3ca3e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Sorcery+ (Amsoft) (de)/Sorcery+ (1985)(Amsoft)(de).dsk"} },
   {0x863ee312, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Spy vs Spy II - The Island Caper (Databyte)/Spy vs Spy II - The Island Caper (1987)(Databyte).dsk"} },
   {0x1482816b, {"42bf91e49d86d1c0cfb81fd1504f670a"}, {"SMASHED (Alternative Software)/SMASHED (1987)(Alternative Software)[tape].dsk"} },
   {0x5a1a3f9b, {"9f5644ba2c24c1f2c8947793ed20150f"}, {"Starglider (Rainbird Software)/Starglider (1987)(Rainbird Software).dsk"} },
   {0xd404b5df, {"c68076620e353d3feae594cc90a2f4ca"}, {"Super Sprint (Activision)/Super Sprint (1987)(Activision)(v3).dsk"} },
   {0x0a1d8e00, {"e964c7911c4bf02af261a781793df6b9"}, {"Spindrone (Atlantis Software)/Spindrone (1988)(Atlantis Software)[tape].dsk"} },
   {0xf122e580, {"b49014bfa47b8a4f6cb8365e20537cc2"}, {"Streap-Poker (Denis Mezenge) (France)/Streap-Poker (1987)(Denis Mezenge)(PD)(fr)[cr].dsk"} },
   {0x860b5808, {"cdc06bb2e5c62f6d74deda1cd7433877"}, {"Sabrina (Iber Soft) (Spain)/Sabrina (1989)(Iber Soft)(es)[cr][f].dsk"} },
   {0x0813f0c1, {"f186e3d6079c951723f6b141e5015d7e"}, {"Spiky Harold (Firebird)/Spiky Harold (1986)(Firebird)[cr].dsk"} },
   {0xcf0d5cff, {"b888cb44db99daea6caa451333ad0ac9"}, {"Spy Hunter (Amsoft)/Spy Hunter (1986)(Amsoft)[cr][f].dsk"} },
// {0xe94c9501, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Skweek (Loriciels) (France)/Skweek (1989)(Loriciels)(fr).dsk"} },
   {0xde543883, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Sorcery+ (Amsoft)/Sorcery+ (1985)(Amsoft).dsk"} },
   {0x7fa49d6e, {"0f3ce766494c244fb3e069ee60809d95"}, {"Star Bowls (Zigurat Software) (Spain)/Star Bowls (1991)(Zigurat Software)(es).dsk"} },
   {0xa2c253de, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Sorcery (Virgin Games)/Sorcery (1985)(Virgin Games).dsk"} },
   {0x196a3c08, {"ff927c8ca831c06b752209b5ffb97bb0"}, {"Starboy (Gasoline Software) (France)/Starboy (1986)(Gasoline Software)(fr)[cr].dsk"} },
   {0x01257f77, {"0f3ce766494c244fb3e069ee60809d95"}, {"Super Sports - The Olympic Challenge (Gremlin Graphics Software)/Super Sports - The Olympic Challenge (1988)(Gremlin Graphics Software)(Side A).dsk"} },
   {0xfbad0848, {"7bbcd849f72302d68bcd52ee4bedb691"}, {"Samurai (Amstar & Cpc)/Samurai (1990)(Amstar & Cpc)[cr].dsk"} },
   {0x5a5b588a, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Strider (US Gold)/Strider (1989)(US Gold).dsk"} },
   {0xa1b54138, {"18931c2ba995b757f501909f65910b13"}, {"Shoot (CPC)/Shoot (1990)(CPC)[cr].dsk"} },
   {0x61de3bf1, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Short Circuit (Ocean Software)/Short Circuit (1987)(Ocean Software).dsk"} },
   {0x24bbc94b, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"SAS Combat Simulator (Codemasters Software) (Bugs)/SAS Combat Simulator (1988)(Codemasters Software)[b].dsk"} },
   {0xf0a67f40, {"6f941d504259a5fba1646d7636adc2aa"}, {"Superman - The Man of Steel (Tynesoft)/Superman - The Man of Steel (1989)(Tynesoft)(Side A).dsk"} },
   {0xf391fade, {"b4b2ae24be1b5843d084f051be6ba6f2"}, {"Swap (Microids) (M2)/Swap (1990)(Microids)(M2)(v2).dsk"} },
   {0x30f6e0fb, {"cc473dc7db8e2e5e4a3304a7cff83354"}, {"Superkid (Atlantis Software)/Superkid (1990)(Atlantis Software)[cr].dsk"} },
   {0x8a436a1b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Strangeloop+ (Virgin Games)/Strangeloop+ (1986)(Virgin Games).dsk"} },
   {0xe2b5b1f5, {"fb3f9ea8aa0aa1c721d4c395728d45ca"}, {"Sandman, The (TGS) (de)/Sandman, The (1995)(TGS)(PD)(de)(Disk 1 Side A).dsk"} },
   {0xa5d86a23, {"44c5f855f2f6e78febfd9e373a402717"}, {"Space Pod Rescue (Cascade Games)/Space Pod Rescue (1986)(Cascade Games)[cr].dsk"} },
   {0x5873228b, {"b33f11ed4a3cd429074954e6b5bd270a"}, {"Space Taxi (Elmsoft Game Service)/Space Taxi (1987)(Elmsoft Game Service)(PD)[cr].dsk"} },
   {0x9d746e4e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Spindizzy (Activision)/Spindizzy (1986)(Activision).dsk"} },
   {0x03d6720c, {"0f3ce766494c244fb3e069ee60809d95"}, {"Stir Crazy Featuring Bobo (Infogrames)/Stir Crazy Featuring Bobo (1988)(Infogrames)(Side A).dsk"} },
   {0xfac5bdac, {"0f3ce766494c244fb3e069ee60809d95"}, {"Starquake (Bubble Bus Software)/Starquake (1986)(Bubble Bus Software).dsk"} },
   {0x135f1fc7, {"0f3ce766494c244fb3e069ee60809d95"}, {"SWIV (Storm Software)/SWIV (1991)(Storm Software).dsk"} },
   {0x2117bd08, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Switchblade (Gremlin Graphics Software)/Switchblade (1991)(Gremlin Graphics Software).dsk"} },
   {0x98ec5c36, {"b1ef35eadbebecd339a9b91add7f03d3"}, {"Super Ski (Microids) (France)/Super Ski (1987)(Microids)(fr)[f].dsk"} },
   {0x42f1778f, {"51604cbc3e0c2d179c52c0ca70e5618c"}, {"Spots 94 (Jaysoft)/Spots 94 (1994)(Jaysoft)[cr].dsk"} },
   {0xda1d3e90, {"0a1b8bcf63614210ae274c10024c300d"}, {"Star Wars Droids (Mastertronic)/Star Wars Droids (1988)(Mastertronic)[tape].dsk"} },
   {0xbc8e8f76, {"4011398b756036412200e09c0488da6e"}, {"Slapshot (Indescomp)/Slapshot (1985)(Indescomp).dsk"} },
   {0xf3163ff3, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Super Space Invaders (Domark)/Super Space Invaders (1991)(Domark)(Side A).dsk"} },
   {0x6e1f628e, {"766e2a1ff69524423d752471af3d245e"}, {"Star-Wreck (Alternative Software)/Star-Wreck (1987)(Alternative Software)[tape].dsk"} },
   {0x776cd65e, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Shovel Adventure (Pat Morita Team)/Shovel Adventure (2021)(Pat Morita Team)(JGN Edition).DSK"} },
   {0x0ab6f33f, {"d25a74818150d52ee2cb597a04ed958c"}, {"Spaced Out (Firebird)/Spaced Out (1987)(Firebird)[tape].dsk"} },
   {0x4ec69c25, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Super Monaco GP (US Gold)/Super Monaco GP (1991)(US Gold).dsk"} },
   {0xd8b1d3e4, {"230d4ac20768751396637fccf24a8693"}, {"Sabotage (Zeppelin Games)/Sabotage (1988)(Zeppelin Games)[tape].dsk"} },
   {0x1b9371d2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Saint and Greavsie (Grandslam)/Saint and Greavsie (1989)(Grandslam).dsk"} },
   {0xb0c72be6, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Shadowfire (Beyond Software)/Shadowfire (1986)(Beyond Software).dsk"} },
   {0x92842960, {"0f3ce766494c244fb3e069ee60809d95"}, {"Soviet (Opera Soft)/Soviet (1990)(Opera Soft).dsk"} },
   {0x6e328762, {"7efd000a96aaa91d13582181d57a540d"}, {"Spheric (Amstrad Cent Pour Cent) (France)/Spheric (1989)(Amstrad Cent Pour Cent)(fr)[cr].dsk"} },
   {0xb49383c1, {"16beccd5d9962eabc3f89d60e540a033"}, {"Sandman, The (TGS)/Sandman, The (1995)(TGS)(PD)(Disk 1 Side A).dsk"} },
   {0x5a32bd0d, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Strider II (US Gold)/Strider II (1990)(US Gold).dsk"} },
   {0xd867cd03, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Stormlord (Hewson)/Stormlord (1989)(Hewson).dsk"} },
   {0xef32e345, {"dd04727ad5b09e60531340d9dec6cbcc"}, {"Serie Noire (Micro Application) (France)/Serie Noire (1985)(Micro Application)(fr)[cr].dsk"} },
   {0x6307eb75, {"1b4ba50386ba122a962a3482b8556ea9"}, {"Silva (Lankhor) (France)/Silva (1985)(Lankhor)(fr)(Side A).dsk"} },
   {0x133e8046, {"23b1b893fcdb11b3346d0e406942871f"}, {"Steve Mc Queen Westphaser (Loriciels) (Phaser)/Steve Mc Queen Westphaser (1992)(Loriciels)(West Phaser)(Side A).dsk"} },
   {0x635dbb5b, {"f7fec3552bcebd6d8f9bd6077d4f9132"}, {"Street Hawk (Ocean Software)/Street Hawk (1986)(Ocean Software).dsk"} },
   {0x3391e8a8, {"17ca68846e423a05294996bbd859ca98"}, {"Syndrome, Le (Alligata Software) (France)/Syndrome, Le (1986)(Alligata Software)(fr).dsk"} },
   {0xb4ca9087, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Shadow Skimmer (The Edge)/Shadow Skimmer (1987)(The Edge).dsk"} },
   {0x802695e9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Superpix (Crack'n'Rom)/Superpix (2014)(Crack'n'Rom)(Side A)[f].dsk"} },
   {0xd66de504, {"0f3ce766494c244fb3e069ee60809d95"}, {"Satan (Dinamic Software) (Spain)/Satan (1989)(Dinamic Software)(es).dsk"} },
   {0x2a959d64, {"0460ad7fe133940176098ea7e1d3ff2c"}, {"Secret du Tombeau, Le (Loriciels) (France)/Secret du Tombeau, Le (1986)(Loriciels)(fr).dsk"} },
   {0xd6968fb8, {"c68076620e353d3feae594cc90a2f4ca"}, {"Star Raiders II (Activision)/Star Raiders II (1987)(Activision).dsk"} },
   {0x2382e5ec, {"9de0634c8e079ce479543c249758856b"}, {"Super Puzzle (Logipresse) (France)/Super Puzzle (1987)(Logipresse)(fr)[cr].dsk"} },
   {0x39fdcbd1, {"fcdb76cf0a0dc832cdddf830ab27b5ea"}, {"Smirking Horror, The (WoW Software)/Smirking Horror, The (1991)(WoW Software)[cr].dsk"} },
   {0x4cd46327, {"c5cbd13a572c31dd5f4cde6469c3a931"}, {"Soccer Director (GTI Software)/Soccer Director (1990)(GTI Software)[tape].dsk"} },
   {0x636a30d8, {"c248771e16da61605e3841a0a4045f03"}, {"Sorcerer (Infocom)/Sorcerer (1984)(Infocom)[CPM].dsk"} },
   {0x375d4353, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Stormlord II - Deliverance (Hewson)/Stormlord II - Deliverance (1990)(Hewson).dsk"} },
   {0x1bab7a1c, {"2331d69ee21cf92cf7090716a369aeaf"}, {"Skyfox (Electronics Arts) (Spain)/Skyfox (1985)(Electronics Arts)(es)[cr].dsk"} },
   {0x61cc737a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Super Hang-On (Activision)/Super Hang-On (1986)(Activision).dsk"} },
   {0x75de79e6, {"099707279213ac43ffff96f2fcba5776"}, {"Survivor (Topo Soft) (Spain)/Survivor (1987)(Topo Soft)(es)[cr].dsk"} },
   {0x7990d859, {"83dfbf175226f35065cef6900b7ae73c"}, {"Skate Wars (Ubi Soft)/Skate Wars (1990)(Ubi Soft).dsk"} },
   {0xa1754ab2, {"890aadd87564f0a3f80e929ab045912e"}, {"Space Froggy (Glenco Software)/Space Froggy (1990)(Glenco Software)[cr].dsk"} },
   {0x74c0c019, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Spannerman (Amsoft)/Spannerman (1984)(Amsoft).dsk"} },
   {0x06225f9f, {"193c1574a6c362e8acfa8dbf592816af"}, {"Super Hero (Codemasters Software)/Super Hero (1988)(Codemasters Software)[cr][f].dsk"} },
   {0xfff6b37b, {"0f3ce766494c244fb3e069ee60809d95"}, {"Shadow of the Beast (Gremlin Graphics Software)/Shadow of the Beast (1990)(Gremlin Graphics Software)(Side A).dsk"} },
   {0x65986be4, {"988673fb0b61d9395c578712a6c99a56"}, {"Spellbound (Mastertronic)/Spellbound (1985)(Mastertronic)[tape].dsk"} },
   {0xa6a27132, {"4fa3da497f05dc7944256ceadfbd1478"}, {"Subsunk Adventure (Firebird)/Subsunk Adventure (1985)(Firebird)[tape].dsk"} },
   {0xc275e43a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sonic Boom (Activision)/Sonic Boom (1990)(Activision).dsk"} },
   {0x72929b47, {"374126674366329e370bc0a63d992c1e"}, {"Sentinel, The (Firebird)/Sentinel, The (1987)(Firebird)(v2).dsk"} },
// {0xdf48e423, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Star Driver (Radical Software)/Star Driver (1994)(Radical Software).dsk"} },
   {0xbe401909, {"d23dfd1019106a87818fec8963140350"}, {"Strike Force Cobra (Piranha)/Strike Force Cobra (1986)(Piranha).dsk"} },
   {0xc411455f, {"5ed376be02e5ecad48250aca320830c7"}, {"Secret Defense (Loriciels) (France)/Secret Defense (1988)(Loriciels)(fr).dsk"} },
   {0x2fded49c, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sacred Armour of Antiriad, The (Palace Software)/Sacred Armour of Antiriad, The (1986)(Palace Software).dsk"} },
   {0x53c6e5d0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Super Cauldron (Titus) (M3)/Super Cauldron (1992)(Titus)(M3).dsk"} },
   {0x2cc66470, {"92056f3392eb909b7dc0564b743a18fa"}, {"Survivre (Lankhor) (France)/Survivre (1991)(Lankhor)(fr)(Side A).dsk"} },
   {0x29671a87, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Solomon's Key (US Gold)/Solomon's Key (1987)(US Gold).dsk"} },
   {0xce1c4766, {"e843cbcb97825f1650b68394569dbf00"}, {"Street Gang Football (Codemasters Software)/Street Gang Football (1989)(Codemasters Software)[tape].dsk"} },
   {0x37549059, {"cb0b98f493459b8b7738164f40f47ac0"}, {"Seabase Delta (Firebird)/Seabase Delta (1985)(Firebird)[cr].dsk"} },
// {0xddc50888, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Scapeghost (Level 9 Computing)/Scapeghost (1989)(Level 9 Computing)(Side A).dsk"} },
   {0x2674fdf1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Stairway to Hell (Software invasion)/Stairway to Hell (1986)(Software invasion).dsk"} },
   {0xa266c7d9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Sphaira (Ubi Soft) (France)/Sphaira (1989)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x49586e15, {"c806133cdbcdb7b714307dbf436eacfc"}, {"Space Moves (Retrobytes Productions)/Space Moves (2020)(Retrobytes Productions)(v2.2).dsk"} },
   {0x94159db0, {"765c2c3185802daad6f54fb45876b4d9"}, {"Stretcher (Pipeline Software)/Stretcher (1992)(Pipeline Software)[cr].dsk"} },
   {0x1c2787f3, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sim City (Infogrames)/Sim City (1989)(Infogrames)(Side A).dsk"} },
   {0x9a407cf0, {"d12abc098a93d00540984e97d9eb3a55"}, {"Space Mania (Amstrad Computer User)/Space Mania (1986)(Amstrad Computer User)[cr].dsk"} },
   {0x6f1e3eb0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Shinobi (Virgin Games)/Shinobi (1989)(Virgin Games).dsk"} },
   {0xd3267a79, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Snooker (Amsoft)/Snooker (1984)(Amsoft).dsk"} },
   {0xe0c76ce1, {"e258cba243021ee96fd1cd3f480bd96d"}, {"Saracen (US Gold)/Saracen (1987)(US Gold).dsk"} },
   {0x27489824, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Scout Steps Out, The (Amsoft)/Scout Steps Out, The (1985)(Amsoft).dsk"} },
   {0x9469fe98, {"2e63cb6b78850da2575e8015739ce3b7"}, {"Sherman M4 (Loriciels)/Sherman M4 (1990)(Loriciels).dsk"} },
   {0xcd5ede5a, {"17475955053679ded883e6108dbffef2"}, {"Shadow of the Bear, The (Kuma Computers)/Shadow of the Bear, The (1985)(Kuma Computers)[cr].dsk"} },
   {0x69927831, {"a2cc82d78c5d6efa06d0cae4f2691f69"}, {"Secreto De La Tumba, El (Loriciels) (Spain)/Secreto De La Tumba, El (1987)(Loriciels)(es)[cr][f].dsk"} },
   {0xc65a5218, {"41a953d7921e648ae0733e6366ac3072"}, {"Seymour - Take One (Codemasters Software)/Seymour - Take One (1991)(Codemasters Software)(PD)[cr].dsk"} },
   {0x18e04d4c, {"06ab23a77845b8330ceca4e793c69668"}, {"Space Moves (cpcretrodev.byterealms) (Spain)/Space Moves (2015)(cpcretrodev.byterealms)(es)[tape].dsk"} },
   {0x625b38d8, {"dfb52b33f45c0646354f0a4e3036730f"}, {"Star Ranger (Tynesoft)/Star Ranger (1986)(Tynesoft)[cr].dsk"} },
   {0x602b16e5, {"6f941d504259a5fba1646d7636adc2aa"}, {"Skatin' USA (Atlantis Software)/Skatin' USA (1990)(Atlantis Software).dsk"} },
   {0xa9f5fbd4, {"099707279213ac43ffff96f2fcba5776"}, {"Survivor, The (Anirog Software)/Survivor, The (1984)(Anirog Software)[cr].dsk"} },
// {0x8cecd42c, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Super Flippard (Free Game Blot) (France)/Super Flippard (1987)(Free Game Blot)(fr).dsk"} },
   {0x1149f9d0, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Street Machine (Software Invasion) (Spain)/Street Machine (1986)(Software Invasion)(es).dsk"} },
   {0x85d18e60, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Sooty and Sweep (Alternative Software)/Sooty and Sweep (1990)(Alternative Software).dsk"} },
   {0xb7b1a995, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Strike Force Harrier (Mirrorsoft)/Strike Force Harrier (1986)(Mirrorsoft)(v2).dsk"} },
   {0x245093fe, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Super Scramble Simulator (Gremlin Graphics Software)/Super Scramble Simulator (1989)(Gremlin Graphics Software).dsk"} },
   {0xcc5f46b2, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Simpsons - Bart vs the Space Mutants (Ocean Software)/Simpsons - Bart vs the Space Mutants (1991)(Ocean Software)(v2)(Side A).dsk"} },
   {0x0630c1a6, {"855f4886aa152c69d1b60f8d183e52da"}, {"Snakes and Hazards (Gremlin Graphics Software)/Snakes and Hazards (1987)(Gremlin Graphics Software)[cr].dsk"} },
// {0xd5e3633d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Satellite Warrior (Amsoft)/Satellite Warrior (1985)(Amsoft).dsk"} },
// {0xe0111415, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Sorcery+ (Amsoft) (France)/Sorcery+ (1985)(Amsoft)(fr).dsk"} },
   {0x74901f54, {"06ab23a77845b8330ceca4e793c69668"}, {"Space Invaders (-)/Space Invaders (19xx)(-)(PD)[cr].dsk"} },
   {0x0e430e36, {"70bf9c003178df26acd8404d5f1e13e1"}, {"Space Ace (Players)/Space Ace (1987)(Players)[tape].dsk"} },
   {0xca1c7f49, {"54b816414224d398fdf5d47f94588503"}, {"Stretcher 2 - Mr. Line's Revenge (Pipeline Software)/Stretcher 2 - Mr. Line's Revenge (1992)(Pipeline Software)[cr].dsk"} },
   {0x268bba28, {"3a624de626bc0cc157492249c7fbcc28"}, {"Sapiens (Loriciels)/Sapiens (1986)(Loriciels).dsk"} },
   {0x396d27ed, {"2057640d70ad9e618a9b9a2f8c05030c"}, {"Star Firebirds (Insight)/Star Firebirds (1986)(Insight)[cr].dsk"} },
   {0x07a97eed, {"e3ae33a605b7701fa46bc2d0bb375af8"}, {"Super Skweek (Loriciels) (France)/Super Skweek (1990)(Loriciels)(fr).dsk"} },
   {0x8385f78f, {"b888cb44db99daea6caa451333ad0ac9"}, {"Spy vs Spy (Beyond Software)/Spy vs Spy (1985)(Beyond Software).dsk"} },
   {0x45c69639, {"dc8ccc965a203ead5cadadddc36de8d6"}, {"Super Soccer (Ocean Software) (France)/Super Soccer (1987)(Ocean Software)(fr)[cr].dsk"} },
   {0x641dcd51, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Sito Pons 500cc Grand Prix (Zigurat) (Spain)/Sito Pons 500cc Grand Prix (1990)(Zigurat)(es).dsk"} },
   {0xfdaf7cd2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Space Crusade (Gremlin Graphics Software)/Space Crusade (1992)(Gremlin Graphics Software).dsk"} },
   {0xfefca5e7, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Sepulcri (Ariolasoft)/Sepulcri (1986)(Ariolasoft).dsk"} },
   {0x62a6e45d, {"030e85dd3244283f1bb4d82a1e5a24b2"}, {"Snodgits (Thorn Emi Computer Software)/Snodgits (1985)(Thorn Emi Computer Software)[tape].dsk"} },
   {0xa041e903, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Space Hawks - Aguilas Del Espacio (Amsoft)/Space Hawks - Aguilas Del Espacio (1984)(Amsoft).dsk"} },
   {0xff92c5e5, {"9a44c179b857a37623fde968328fe3f9"}, {"Shard of Inovar (Mastertronic)/Shard of Inovar (1987)(Mastertronic)[tape].dsk"} },
// {0xc46c46de, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Trivial Pursuit II - A New Beginning (Domark)/Trivial Pursuit II - A New Beginning (1988)(Domark)(Side A).dsk"} },
   {0xfa94714b, {"50fc22fd629a794c9b53a5d68381dc00"}, {"Tomahawk (Digital Integration) (M3)/Tomahawk (1986)(Digital Integration)(M3)[cr].dsk"} },
   {0x5665d718, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tuareg (Topo Soft) (Spain)/Tuareg (1988)(Topo Soft)(es).dsk"} },
   {0xf6e7a23c, {"831aaf15d6d252a5a45f50c60d537238"}, {"Titanic (Topo Soft)/Titanic (1988)(Topo Soft)[cr][f].dsk"} },
   {0xe2f4e53c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tom & Jerry (Magic Bytes)/Tom & Jerry (1989)(Magic Bytes).dsk"} },
   {0x6f8b6c61, {"0f3ce766494c244fb3e069ee60809d95"}, {"Titan (Titus) (France)/Titan (1988)(Titus)(fr).dsk"} },
   {0x05d7a217, {"bc4294b4a6dc18c68628df6a38d03e3b"}, {"Thunder Zone (Firebird)/Thunder Zone (1987)(Firebird)[cr].dsk"} },
   {0x932fa54a, {"53724e4dd6882c81ec22102905906755"}, {"Troglo (Ace Software) (Spain)/Troglo (1986)(Ace Software)(es).dsk"} },
   {0xf4f79188, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tai-Pan (Ocean Software)/Tai-Pan (1987)(Ocean Software)[f].dsk"} },
   {0x4e2776a9, {"6f941d504259a5fba1646d7636adc2aa"}, {"Tiger Road (US Gold)/Tiger Road (1988)(US Gold).dsk"} },
   {0x4896b537, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tusker (System 3)/Tusker (1989)(System 3)[f].dsk"} },
   {0x09a6c7c0, {"465f5a583c3cabe156618efc55fb2ae3"}, {"Tales of the Arabian Nights (Interceptor Software)/Tales of the Arabian Nights (1985)(Interceptor Software)[cr].dsk"} },
   {0xec265b17, {"cbcdc06930d2930aa114e9dd10649699"}, {"Tennis Cup (Loriciels)/Tennis Cup (1989)(Loriciels).dsk"} },
   {0xa0a42352, {"85758463258c063dc6402889abe13db7"}, {"Thai Boxing (Anco Software)/Thai Boxing (1986)(Anco Software).dsk"} },
   {0xcd0a0395, {"0f3ce766494c244fb3e069ee60809d95"}, {"Trailblazer (Gremlin Graphics Software)/Trailblazer (1986)(Gremlin Graphics Software).dsk"} },
   {0x594266d7, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tarzan (Martech)/Tarzan (1986)(Martech)(v2).dsk"} },
   {0x1d921cd9, {"5f3a4462e670c784481af5917d5b27e1"}, {"Touchdown USA (Creative Sparks)/Touchdown USA (1987)(Creative Sparks)[cr].dsk"} },
   {0x71961d07, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Trivia (Anirog Software)/Trivia (1985)(Anirog Software)[cr].dsk"} },
   {0x2f4e9778, {"e29174166c5a232b4cdd53ac0c72d3f8"}, {"Throne of Fire (Melbourne House)/Throne of Fire (1987)(Melbourne House)[cr].dsk"} },
// {0xd36c1fdc, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"They Stole a Million (39 Steps) (de)/They Stole a Million (1986)(39 Steps)(de).dsk"} },
// {0x01945b8c, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Terre et Conquerants (Ubi Soft) (France)/Terre et Conquerants (1989)(Ubi Soft)(fr)(Side A).dsk"} },
   {0x6a99b71d, {"0210d845fdeb960cbc5e012f5daf615f"}, {"Trollie Wallie (Players)/Trollie Wallie (1986)(Players)[cr].dsk"} },
   {0x733852a6, {"ea4202f05d003a492dedfa3b803b16f2"}, {"Titanic (Topo Soft) (Spain)/Titanic (1988)(Topo Soft)(es)[cr].dsk"} },
// {0x1a6f0fff, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Tyrann (Norsoft) (France)/Tyrann (1985)(Norsoft)(fr)(Side A).dsk"} },
   {0xdcce9d75, {"5dd98a9433319af3e375a83eb63e05c5"}, {"Top Cat in Beverly Hills Cats (Hi-Tec Software)/Top Cat in Beverly Hills Cats (1990)(Hi-Tec Software)[cr].dsk"} },
   {0x5c0b2351, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tour 91 (Topo Soft) (Spain)/Tour 91 (1991)(Topo Soft)(es).dsk"} },
   {0x01f645af, {"3a34d4687a3959e08177d4503704b37e"}, {"Tour du Mond en 80 Jours, Le (Innelec) (France)/Tour du Mond en 80 Jours, Le (1984)(Innelec)(fr)[cr].dsk"} },
   {0x0ca4f0b5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Teenage Mutant Hero Turtles (Image Works) (Codes)/Teenage Mutant Hero Turtles (1990)(Image Works)[codes].dsk"} },
// {0xc48122b1, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Tombstowne (Amsoft)/Tombstowne (1985)(Amsoft).dsk"} },
   {0xb77647e6, {"eb0116247ba3050d5b55e67ad604ef74"}, {"Thrust (Firebird)/Thrust (1986)(Firebird)(v7-86)[cr].dsk"} },
   {0x55ebca5d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tau Ceti - Special Edition (CRL Group)/Tau Ceti - Special Edition (1986)(CRL Group).dsk"} },
   {0x78935458, {"e195f35ec2cb2d4a5ad86a9ee78f33fc"}, {"Tresor d'Ali Gator (Lankhor) (France)/Tresor d'Ali Gator (1991)(Lankhor)(fr)[o].dsk"} },
   {0x83705d03, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tokyo Gang (GLL Software) (Spain)/Tokyo Gang (1990)(GLL Software)(es).dsk"} },
   {0x8a357ad3, {"6f8d534b3a93a32fcc913f579a6b9dce"}, {"Turbo Esprit (Durell Software) (Spain)/Turbo Esprit (1986)(Durell Software)(es)[cr].dsk"} },
   {0x298e5492, {"8e19d7a23411e4287cd70668361508cf"}, {"Train, The - Escape to Normandy (Electronic Arts) (Spain)/Train, The - Escape to Normandy (1988)(Electronic Arts)(es)[cr].dsk"} },
   {0x725fb725, {"dbb8154d888ae2478e2c7ca689b70866"}, {"Turris (CPC Amstrad International) (de)/Turris (1991)(CPC Amstrad International)(de)[cr].dsk"} },
   {0xcccead08, {"75e1dc441c551c44746fee627f60d715"}, {"Tiefe, Die (Sun Soft) (de)/Tiefe, Die (1985)(Sun Soft)(de)[cr].dsk"} },
   {0x37789b0e, {"ead164a2cb12e56d2a33a50840aa6467"}, {"Tracer (Schneider Magazin)/Tracer (1988)(Schneider Magazin)[cr].dsk"} },
   {0xa7915c1c, {"680b37cadd9c9739d1350613c4e55907"}, {"Trivia (Anirog Software) (de)/Trivia (1985)(Anirog Software)(de).dsk"} },
   {0xe4154a1f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Target Renegade (Ocean Software)/Target Renegade (1988)(Ocean Software).dsk"} },
   {0x29ed4286, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Test Drive II - The Duel (Accolade)/Test Drive II - The Duel (1989)(Accolade).dsk"} },
   {0x7638271c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Trivial Pursuit - Edition Genius (Domark) (Spain)/Trivial Pursuit - Edition Genius (1986)(Domark)(es)(Side A).dsk"} },
   {0x30e38ee5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tetris (Mirrorsoft)/Tetris (1987)(Mirrorsoft).dsk"} },
   {0x2472f61f, {"0b3591de7c38b051f4106c895960589d"}, {"Tron (Bollaware) (de)/Tron (1989)(Bollaware)(PD)(de)[cr].dsk"} },
   {0xef69722f, {"92ebeff55e6399ca57183099211ef15a"}, {"Tetrix (Playfield)/Tetrix (1989)(Playfield)(PD)[cr].dsk"} },
   {0xf938d725, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Terminator 2 - Judgement Day (Ocean Software)/Terminator 2 - Judgement Day (1991)(Ocean Software)(v2).dsk"} },
// {0x0ccf7406, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Turbo Cup (Loriciels)/Turbo Cup (1988)(Loriciels).dsk"} },
   {0xad17f71f, {"8174f50412ee4a106187f0d330521c48"}, {"Turbo Cup (Loriciels) (France)/Turbo Cup (1988)(Loriciels)(fr).dsk"} },
   {0x83497f3c, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tank (Ocean Software)/Tank (1987)(Ocean Software).dsk"} },
   {0x94aa6cf3, {"0f3ce766494c244fb3e069ee60809d95"}, {"Trigger (Opera Soft) (Spain) (LightGun)/Trigger (1989)(Opera Soft)(es)(LightGun).dsk"} },
   {0x1b78e4f9, {"0c67bf82eb94b7d529858d225a110152"}, {"Tie Break (Sprites) (France)/Tie Break (1985)(Sprites)(fr)[cr].dsk"} },
   {0x419f8f00, {"7a25dc0cfe795649716383b58291a080"}, {"Talisman of Power, The (Chris Bury)/Talisman of Power, The (1990)(Chris Bury)[cr].dsk"} },
   {0x79a1ab46, {"92056f3392eb909b7dc0564b743a18fa"}, {"Tac Tic (PD) (France)/Tac Tic (19xx)(PD)(fr)[cr].dsk"} },
   {0x77e00286, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tobruk 1942 (PSS) (France)/Tobruk 1942 (1986)(PSS)(fr).dsk"} },
   {0xc8dfac8f, {"3a1a504f4ee2ee4a0c9b07474f0760fc"}, {"Tennis 3D (Loriciels) (France)/Tennis 3D (1986)(Loriciels)(fr).dsk"} },
   {0x6f968bd0, {"fc36210952557d7ad95258a665793e33"}, {"Trance (M. Remon)/Trance (1989)(M. Remon)[cr].dsk"} },
   {0x17e032f3, {"5556f9811a79533d3d325ba8ccde94fc"}, {"Turbo Chopper (Codemasters Software)/Turbo Chopper (1989)(Codemasters Software)[cr].dsk"} },
   {0x3854d175, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Trap (Alligata Software)/Trap (1987)(Alligata Software).dsk"} },
   {0x03b14d37, {"0f3ce766494c244fb3e069ee60809d95"}, {"Thing on a Spring (Gremlin Graphics Software)/Thing on a Spring (1986)(Gremlin Graphics Software).dsk"} },
// {0x3036e305, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"They Stole a Million (39 Steps) (France)/They Stole a Million (1986)(39 Steps)(fr).dsk"} },
   {0x78acf281, {"ee6195f2c61f54689154a945f703b8ff"}, {"Trivia (Anirog Software) (France)/Trivia (1985)(Anirog Software)(fr).dsk"} },
   {0xbf3bb944, {"414a3aaef88715db6e3213a14c372fc7"}, {"Twins (Amstrad Cent Pour Cent)/Twins (1991)(Amstrad Cent Pour Cent)[cr].dsk"} },
   {0x81d57297, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tenebres (Rainbow Productions) (France)/Tenebres (1987)(Rainbow Productions)(fr)(Side A)[cr].dsk"} },
   {0x5d6a048b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Thunder Jaws (Domark)/Thunder Jaws (1991)(Domark)(Side A).dsk"} },
   {0x87ba6d6d, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Trivial Pursuit - Edition Genius (Domark) (France)/Trivial Pursuit - Edition Genius (1986)(Domark)(fr)(Side A).dsk"} },
   {0xcbaca92a, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tesoro Perdido De Cuauhtemoc (4Mhz) (Spain)/Tesoro Perdido De Cuauhtemoc (2017)(4Mhz)(es)(v2).dsk"} },
   {0x41f8051c, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Total Eclipse (Incentive)/Total Eclipse (1988)(Incentive).dsk"} },
   {0x96bc4c3e, {"cc47001eccc28eebf8547dfa18b2c65b"}, {"Twin Turbo V8 (Codemasters Software)/Twin Turbo V8 (1989)(Codemasters Software)[cr].dsk"} },
   {0x7ffbf9fb, {"54e970ada26cb4fbe4b9c0664f29038d"}, {"Target Ball (Micro Mag)/Target Ball (1990)(Micro Mag)[cr].dsk"} },
   {0x34bc560d, {"c6cf25c67fcb28005b5c4b4f06f1d5e5"}, {"Tomahawk (Digital Integration) (M3) (Codes)/Tomahawk (1986)(Digital Integration)(M3)[codes].dsk"} },
   {0xb1062183, {"ce1581cb5e6db8f84f874256663ba142"}, {"Tizpan (The Adventure Workshop)/Tizpan (1990)(The Adventure Workshop)[cr].dsk"} },
   {0x3365f862, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Trantor - The Last Stormtrooper (US Gold)/Trantor - The Last Stormtrooper (1987)(US Gold).dsk"} },
   {0x38dde7c9, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Time and Magik Trilogy (Level 9 Computing)/Time and Magik Trilogy (1988)(Level 9 Computing)(Side A).dsk"} },
   {0x17f2e47a, {"00d470f8277bcfb8bf8a59fe9f86c61c"}, {"Terra Cognita (Codemasters Software)/Terra Cognita (1986)(Codemasters Software)[cr].dsk"} },
   {0x000ef371, {"0ac51d4a731adc5df0fbe3d99d75724b"}, {"Timelord (Alpha Omega Software)/Timelord (1985)(Alpha Omega Software)[cr].dsk"} },
   {0xd1992306, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Trivial Pursuit - Edition Genius (Domark) (de)/Trivial Pursuit - Edition Genius (1986)(Domark)(de)(Side A).dsk"} },
   {0xbe71d9f4, {"04ad315a0160aa975f457e33fe126c3d"}, {"Train, The - Escape to Normandy (Electronic Arts)/Train, The - Escape to Normandy (1988)(Electronic Arts).dsk"} },
   {0x09fa7625, {"9fc9a2f62d2fc2f24c3d406dbae3cf3d"}, {"Terror en la Facultad (Edisoft) (Spain)/Terror en la Facultad (1987)(Edisoft)(es)[cr].dsk"} },
   {0x785f93dc, {"0f3ce766494c244fb3e069ee60809d95"}, {"Thing Bounces Back (Gremlin Graphics Software)/Thing Bounces Back (1987)(Gremlin Graphics Software).dsk"} },
   {0x89d0562f, {"9601e317fe95eaaa95b2c374a88110f3"}, {"Turrican (Rainbow Arts) (Retail)/Turrican (1990)(Rainbow Arts)(Retail)(Side A)[f].dsk"} },
   {0xa015003f, {"1729d91fa8bd94cdbd38bc7b1a9dc581"}, {"Twice Shy (Mosaic Publishing)/Twice Shy (1986)(Mosaic Publishing)[cr].dsk"} },
// {0xc1de5e93, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Top Level (MBC Informatique) (France)/Top Level (1988)(MBC Informatique)(fr)(Side A).dsk"} },
   {0xbf095b3c, {"ba6c3e390b901f097106d266f4c0b70e"}, {"Traveller, The (Recreation Re-Creation Software)/Traveller, The (19xx)(Recreation Re-Creation Software)[cr].dsk"} },
   {0x6bfe99c9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tank Command (Amsoft)/Tank Command (1986)(Amsoft).dsk"} },
   {0xa0f88ab9, {"b34786e2116876a71bed62f66165b342"}, {"Trans Muter (Codemasters Software)/Trans Muter (1987)(Codemasters Software)[cr].dsk"} },
   {0x6c04428c, {"d89809cde7fb39fa92dde77387be4ae8"}, {"Tribble Trouble (Amsoft)/Tribble Trouble (1985)(Amsoft)[cr].dsk"} },
   {0x909d60ac, {"8dbac1717df6078215085bef1fecf32b"}, {"Tiddly Drinks (Gremlin Graphics Software)/Tiddly Drinks (1986)(Gremlin Graphics Software)[cr].dsk"} },
   {0x361b6f38, {"0f3ce766494c244fb3e069ee60809d95"}, {"Times of Lore (Origin Systems)/Times of Lore (1988)(Origin Systems)(Side A).dsk"} },
   {0x896dc22f, {"e03b603b1095ff230f060f09ee4e1c5b"}, {"Thundercats -The Lost Eye Of Thundera (Elite Systems)/Thundercats -The Lost Eye Of Thundera (1987)(Elite Systems).dsk"} },
   {0x89f5ee30, {"0f3ce766494c244fb3e069ee60809d95"}, {"Tintin on the Moon (Infogrames) (M3)/Tintin on the Moon (1989)(Infogrames)(M3).dsk"} },
   {0x37b5e3e9, {"321c16633ec087721464f584005dc701"}, {"Think! (Ariolasoft)/Think! (1985)(Ariolasoft)[cr].dsk"} },
   {0x62a0595f, {"2d0005e0a1f032659c1fbde2f306739b"}, {"Triple Comando (Dro Soft) (Spain) (Bugs)/Triple Comando (1988)(Dro Soft)(es)[b].dsk"} },
   {0x9a62e291, {"b7ab4bd6e44864e410d71631e4d5e985"}, {"Theseus (50-50 Club Software)/Theseus (1986)(50-50 Club Software)[cr].dsk"} },
   {0x66bb92e8, {"ded4c7f068d2f3335c2fb1f5eae3dc93"}, {"Troll (Palace Software)/Troll (1988)(Palace Software)[cr].dsk"} },
   {0x61940fb0, {"eba897a4d3c316ea0a0379542c744be0"}, {"Tomb of Kuslak, The (Intrigue Software)/Tomb of Kuslak, The (1985)(Intrigue Software)[cr].dsk"} },
   {0xafbe272a, {"dc65df1307c8288bb146f4ccdfe46e71"}, {"Tank Invader (Logipresse) (France)/Tank Invader (1987)(Logipresse)(fr)[cr].dsk"} },
   {0x53a9230a, {"e6f8adb06c5389a731dbf49823b07607"}, {"Tetris (Poesy)/Tetris (1990)(Poesy)(PD)[cr].dsk"} },
   {0x599ba9a4, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tom & Jerry II (Magic Bytes)/Tom & Jerry II (1989)(Magic Bytes).dsk"} },
   {0xd5160fc1, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tau Ceti (CRL Group)/Tau Ceti (1986)(CRL Group).dsk"} },
   {0x1a21baf5, {"6e2e842a575f9853b82d8b016977244d"}, {"Time Out (Zafiro Software) (Spain)/Time Out (1988)(Zafiro Software)(es).dsk"} },
   {0x39056da7, {"863aceac7f0017b43b76058998ceaf3b"}, {"Titan (Titus)/Titan (1989)(Titus).dsk"} },
   {0x3c894e45, {"d88628a434fc8f167ae61f80260441c7"}, {"Track Suit Manager 1.1 (Goliath Games)/Track Suit Manager 1.1 (1988)(Goliath Games)[cr].dsk"} },
   {0xd0dc75a0, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Toi Acid Game (Iber Soft) (Spain)/Toi Acid Game (1990)(Iber Soft)(es)(Side A).dsk"} },
   {0x8e84af41, {"f1651b9090cc2efd3b2ae1aed94ce25a"}, {"Trakers (Kennedy)/Trakers (1991)(Kennedy)[cr].dsk"} },
// {0x98fc3b45, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Thomas The Tank Engine's Fun With Words (Alternative Software)/Thomas The Tank Engine's Fun With Words (1990)(Alternative Software).dsk"} },
   {0x827e83ac, {"5e5c7f2dc83bb828e9dde22a1762cd1d"}, {"Thanatos (Durell Software)/Thanatos (1986)(Durell Software).dsk"} },
   {0xd13daabc, {"22a1b4c7d657cd6c372a556c91f5425d"}, {"Thunder Fighter (E.S.A.T. Software) (France)/Thunder Fighter (1988)(E.S.A.T. Software)(fr)[cr].dsk"} },
   {0x3ee5fb4a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Time Machine (Activision)/Time Machine (1990)(Activision).dsk"} },
// {0x668247d3, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Trivial Pursuit - Edition Revolution (Domark) (France)/Trivial Pursuit - Edition Revolution (1986)(Domark)(fr)(Side A).dsk"} },
   {0xbeb35fad, {"92911d66897eb716e97094a16bad255a"}, {"Tiny Skweeks, The (Loriciels) (France)/Tiny Skweeks, The (1992)(Loriciels)(fr).dsk"} },
   {0xa9f27d19, {"b636713c39a50f8ad89db5a3cfb16087"}, {"Transat One (Innelec) (France)/Transat One (1985)(Innelec)(fr)[cr].dsk"} },
   {0xcf1ef978, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Test Match (CRL Group)/Test Match (1984)(CRL Group)[cr].dsk"} },
   {0x30fec756, {"28650674e2c017a58f4ca53a7c1fe01b"}, {"Triple Comando (Dro Soft) (Spain)/Triple Comando (1988)(Dro Soft)(es)[tape][f].dsk"} },
   {0xfa3963aa, {"a93b23d6ff69a04192cba445edda2e3a"}, {"Tchernmisland (CPC) (France)/Tchernmisland (1987)(CPC)(fr)[cr].dsk"} },
   {0x36831ef5, {"a601e8c75c8c4def5a70bd68034adb66"}, {"Tetris 95 (Power System)/Tetris 95 (1995)(Power System)(PD)[cr].dsk"} },
   {0xfd22747c, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Toad Runner (Ariolasoft)/Toad Runner (1986)(Ariolasoft).dsk"} },
   {0x0a73146f, {"1a38f543d5c417aa4c197be2ff9ac46d"}, {"Thing (Players)/Thing (1988)(Players)[cr].dsk"} },
   {0xd12fb80e, {"6f941d504259a5fba1646d7636adc2aa"}, {"Toyota Celica GT Rally (Gremlin Graphics Software) (Codes)/Toyota Celica GT Rally (1991)(Gremlin Graphics Software)[codes].dsk"} },
   {0x97e0e484, {"60f1398e8875037edf344815b37cbde9"}, {"Top Secret (Loriciels) (France)/Top Secret (1986)(Loriciels)(fr)(Side A).dsk"} },
   {0x85fb8bba, {"0f3ce766494c244fb3e069ee60809d95"}, {"Target Plus (Dinamic Software) (Spain) (LightGun)/Target Plus (1988)(Dinamic Software)(es)(LightGun).dsk"} },
   {0x7a34c973, {"cbcdc06930d2930aa114e9dd10649699"}, {"Tennis Manager (Martin Huemmerich) (de)/Tennis Manager (19xx)(Martin Huemmerich)(PD)(de)[cr].dsk"} },
   {0xe5f9a3a8, {"c6cf25c67fcb28005b5c4b4f06f1d5e5"}, {"TT Racer (Digital Integration) (Codes)/TT Racer (1986)(Digital Integration)[codes].dsk"} },
   {0x1524c73a, {"6f941d504259a5fba1646d7636adc2aa"}, {"Teenage Mutant Hero Turtles 2 - Coin Op (Image Works) (Codes)/Teenage Mutant Hero Turtles 2 - Coin Op (1991)(Image Works)(Side A)[codes].dsk"} },
   {0x80f85f80, {"be8316b9d31f18fa2eec657ec8b941a0"}, {"Turbo-Pacman (PD) (de)/Turbo-Pacman (1987)(PD)(de)[cr].dsk"} },
   {0x3078c995, {"b2310edae293ea9856c7ad2b2c46d9ac"}, {"Tulgey Woods (Amstrad Adventure PD Library)/Tulgey Woods (1989)(Amstrad Adventure PD Library)(PD)[cr].dsk"} },
   {0x680c59c5, {"307583878c6cc53ae03265172190e9b2"}, {"Terrormolinos (Melbourne House)/Terrormolinos (1985)(Melbourne House)[cr].dsk"} },
   {0xdc5aaa0e, {"b9998996078ae8d7a140dfc0281fec90"}, {"Tank Busters (Design Design)/Tank Busters (1985)(Design Design)[cr].dsk"} },
   {0xf4a9b201, {"7228c85b9fdbf27e4d895a8891b54822"}, {"Turf-Form (CDS Software LTD)/Turf-Form (1988)(CDS Software LTD)[cr].dsk"} },
   {0xfd49f2a2, {"f747e26efbf72fac3459a9590e37dd14"}, {"Trader Joe (Ozzard)/Trader Joe (19xx)(Ozzard)(PD)[cr].dsk"} },
   {0xfa823501, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Turlogh le Rodeur (Cobra Soft) (France)/Turlogh le Rodeur (1988)(Cobra Soft)(fr)(Side A).dsk"} },
   {0xcbdafd77, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Techno Cop (Gremlin Graphics Software)/Techno Cop (1988)(Gremlin Graphics Software).dsk"} },
   {0x1e737e6c, {"8174f50412ee4a106187f0d330521c48"}, {"Turbo Girl (Dinamic Software)/Turbo Girl (1988)(Dinamic Software)[cr][f].dsk"} },
   {0x60a4a40f, {"b62ff9c06f2c81d4af71ff8369e93144"}, {"Three Weeks in Paradise (Mikrogen)/Three Weeks in Paradise (1985)(Mikrogen)[cr].dsk"} },
   {0x5eeb0371, {"0af4eb62898cf10ca0f7f878e0cd300e"}, {"Through the Trap Door (Piranha)/Through the Trap Door (1987)(Piranha).dsk"} },
   {0x1001a2c3, {"e42fd609f25d6f56ed134c5e9d853037"}, {"Trik Trak (Wave Software)/Trik Trak (1987)(Wave Software)(PD)[cr].dsk"} },
// {0x23c7634e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Trivial Pursuit II - A New Beginning (Domark) (France)/Trivial Pursuit II - A New Beginning (1988)(Domark)(fr)(Side A).dsk"} },
// {0xb2ea5762, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Titus the Fox (Titus)/Titus the Fox (1992)(Titus).dsk"} },
   {0xa9be8cb2, {"0f3ce766494c244fb3e069ee60809d95"}, {"Teenage Queen (ERE Informatique)/Teenage Queen (1988)(ERE Informatique)(Side A).dsk"} },
   {0xa2fcfa42, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Trans-Atlantic Balloon Challenge, The (Virgin Games)/Trans-Atlantic Balloon Challenge, The (1987)(Virgin Games).dsk"} },
   {0x857f0fc7, {"0f3ce766494c244fb3e069ee60809d95"}, {"Tuma 7 (Delta Software)/Tuma 7 (1990)(Delta Software).dsk"} },
   {0xc465f4c5, {"0f3ce766494c244fb3e069ee60809d95"}, {"Toobin' (Domark)/Toobin' (1989)(Domark).dsk"} },
   {0x484614fb, {"6df2b49cedbf1eaf580f1b7081e9a304"}, {"Terminus (Mastertronic)/Terminus (1986)(Mastertronic)[cr].dsk"} },
   {0xa5e0ab2b, {"e3f254a6381929cc04d3fdbb62626044"}, {"Targhan (Silmarils) (France)/Targhan (1990)(Silmarils)(fr)(Side A).dsk"} },
   {0xdd1eaf87, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Total Recall (Ocean Software)/Total Recall (1991)(Ocean Software).dsk"} },
   {0x87a9f7e8, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tubaruba (Advance Software Promotions)/Tubaruba (1987)(Advance Software Promotions).dsk"} },
   {0x90779315, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Traffic (Amsoft)/Traffic (1985)(Amsoft).dsk"} },
   {0x3041c53e, {"f63bdf46ddbeef97e72956080f39e0f6"}, {"Table Football (Alligata Software)/Table Football (1986)(Alligata Software)[cr].dsk"} },
   {0x53756a82, {"e39effe7fcfa7432a374c12023b9c82e"}, {"TT Racer (Digital Integration)/TT Racer (1986)(Digital Integration)[cr].dsk"} },
   {0x3269939a, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Traitement Bzzz (Chip) (France)/Traitement Bzzz (1987)(Chip)(fr).dsk"} },
   {0xc9d35be1, {"a002b8bc1ddb74b3284a153cd7cb022a"}, {"Terrorpods (Melbourne House) (Bugs)/Terrorpods (1989)(Melbourne House)[cr][b].dsk"} },
   {0xb699edb3, {"038409d853e1c0ea79cccd76b601e7bf"}, {"Tapper (Amsoft)/Tapper (1986)(Amsoft)[cr].dsk"} },
   {0xf62b8fb8, {"0f3ce766494c244fb3e069ee60809d95"}, {"Time Scanner (Activision)/Time Scanner (1989)(Activision).dsk"} },
   {0xd177b94b, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tempest (Activision)/Tempest (1986)(Activision).dsk"} },
   {0xc373f7ff, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Talisman d'Osiris, Le (Chip) (France)/Talisman d'Osiris, Le (1987)(Chip)(fr).dsk"} },
   {0x2d153648, {"bc4294b4a6dc18c68628df6a38d03e3b"}, {"Thunder Burner (Loriciels) (Bugs)/Thunder Burner (1991)(Loriciels)[b].dsk"} },
// {0xb9ddb20d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Tensions (ERE Informatique) (Spain)/Tensions (1986)(ERE Informatique)(es).dsk"} },
   {0xa43e38d6, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Turrican (Rainbow Arts)/Turrican (1990)(Rainbow Arts)(Side A).dsk"} },
   {0x02cce605, {"161e894cd3a3e316d9ad1471e8fa02fd"}, {"Tomy en el Slalom (G.T.S. Editorial) (Spain)/Tomy en el Slalom (1987)(G.T.S. Editorial)(es)[cr].dsk"} },
   {0x38b0cf7f, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Track and Field (Ocean Software) (Bugs)/Track and Field (1988)(Ocean Software)[b].dsk"} },
   {0xaf2aac9e, {"77ae0e6919767362cb3f9ce2d08d6887"}, {"Top Gun (Ocean Software)/Top Gun (1986)(Ocean Software).dsk"} },
   {0x69ffaa9a, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Tornado Low Level - TLL (Vortex Software)/Tornado Low Level - TLL (1985)(Vortex Software).dsk"} },
   {0xbd4ab417, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Turrican II - The Final Fight (Rainbow Arts)/Turrican II - The Final Fight (1991)(Rainbow Arts)(Side A).dsk"} },
   {0x8d62e680, {"8a60a96f87975b798692f2bd428dbdc8"}, {"Tony Truand (Loriciels) (France)/Tony Truand (1985)(Loriciels)(fr).dsk"} },
   {0x3a5242b9, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tres Luces de Glaurung, Las (Erbe Software) (Spain)/Tres Luces de Glaurung, Las (1986)(Erbe Software)(es).dsk"} },
   {0xb3b42030, {"eba897a4d3c316ea0a0379542c744be0"}, {"Tomb of Kuslak, The (Intrigue Software) (Spain) (Hack)/Tomb of Kuslak, The (2020)(Intrigue Software)(es)(Hack)[cr].dsk"} },
   {0x4c50e144, {"92911d66897eb716e97094a16bad255a"}, {"Tiny Skweeks, The (Loriciels)/Tiny Skweeks, The (1992)(Loriciels).dsk"} },
   {0x5d3513c1, {"116abbffef77607fc850e98c42565d73"}, {"Trouble in Space (Schneider Computer Partner)/Trouble in Space (1988)(Schneider Computer Partner)[cr].dsk"} },
   {0x37c07361, {"8174f50412ee4a106187f0d330521c48"}, {"Turbo Esprit (Durell Software)/Turbo Esprit (1986)(Durell Software).dsk"} },
   {0xbfad3be9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Terramex (Grandslam)/Terramex (1988)(Grandslam).dsk"} },
// {0x9ba80f9d, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Tyrann (Norsoft) (Spain) (Hack)/Tyrann (1985)(Norsoft)(es)(Hack)[cr].dsk"} },
   {0xf0ec6a9d, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Turbo Out Run (US Gold)/Turbo Out Run (1990)(US Gold)(Side A).dsk"} },
   {0xbdd66bf3, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Trivial Pursuit - Edition Genius (Domark)/Trivial Pursuit - Edition Genius (1986)(Domark)(v2)(Side A).dsk"} },
   {0x43011123, {"96b243a2e4175f07507d8d8642d60066"}, {"Tetris (Amstrad Action)/Tetris (1991)(Amstrad Action)[cr].dsk"} },
   {0x0f0b6fb0, {"2aa628b57637c303e857c0d4192fe302"}, {"Temple du Soleil, Le (CPC) (France)/Temple du Soleil, Le (1986)(CPC)(fr)[cr].dsk"} },
// {0x0e7422d2, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Thunder Blade (US Gold)/Thunder Blade (1988)(US Gold).dsk"} },
   {0x8878f148, {"0f3ce766494c244fb3e069ee60809d95"}, {"Times of Lore (Origin Systems) (France)/Times of Lore (1988)(Origin Systems)(fr)(v2)(Disk 1 Side A).dsk"} },
   {0x94e4554b, {"e3f254a6381929cc04d3fdbb62626044"}, {"Targhan (Silmarils) (Spain)/Targhan (1990)(Silmarils)(es)(Side A).dsk"} },
   {0x8dd0cf27, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Teenage Mutant Hero Turtles (Image Works)/Teenage Mutant Hero Turtles (1990)(Image Works)[cr].dsk"} },
   {0x670c303d, {"c8f50fa782300e3c1cd43a152f1f34fb"}, {"Tripods, The (Red Shift)/Tripods, The (1984)(Red Shift)[cr][f].dsk"} },
   {0xb00633ef, {"f137484a1082e6ce738adcdcc9a01fec"}, {"Trial of Arnold Blackwood, The (Nemesis)/Trial of Arnold Blackwood, The (1984)(Nemesis)[cr].dsk"} },
   {0xd8e6113b, {"3753cad019a31fdd258c3a6327ecfc91"}, {"Total Eclipse II - The Sphinx Jinx (Incentive)/Total Eclipse II - The Sphinx Jinx (1989)(Incentive)[cr].dsk"} },
   {0x48fda440, {"cbcdc06930d2930aa114e9dd10649699"}, {"Tennis Cup (Loriciels) (France)/Tennis Cup (1989)(Loriciels)(fr).dsk"} },
   {0x2fd6d077, {"fb104170b5f05c804c0e8d230c74daf3"}, {"Time (Rainbow Arts) (M2)/Time (1985)(Rainbow Arts)(M2)[cr].dsk"} },
   {0xd0a58cd5, {"ee3cc82455c62b77fbc46032b112ff56"}, {"Tut's Pyramid (Artic Computing)/Tut's Pyramid (1986)(Artic Computing)[cr].dsk"} },
   {0x9ee6f2ad, {"7381f106b17b9e9fa7117af7e7505e0f"}, {"Toyota Celica GT Rally (Gremlin Graphics Software)/Toyota Celica GT Rally (1991)(Gremlin Graphics Software)[cr].dsk"} },
// {0x21b3e058, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"They Stole a Million (39 Steps)/They Stole a Million (1986)(39 Steps).dsk"} },
   {0x2e05e857, {"0f3ce766494c244fb3e069ee60809d95"}, {"Thunderbirds (Grandslam)/Thunderbirds (1989)(Grandslam)(Side A).dsk"} },
   {0x92d89f49, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Typhoon (Ocean Software)/Typhoon (1988)(Ocean Software).dsk"} },
   {0xe3e92f9c, {"c68076620e353d3feae594cc90a2f4ca"}, {"Terror of the Deep (Mirrorsoft)/Terror of the Deep (1987)(Mirrorsoft).dsk"} },
   {0x1b049205, {"bfe0e941d0abe33b2e3588f046d9011e"}, {"Tujad (Ariolasoft)/Tujad (1986)(Ariolasoft).dsk"} },
   {0xc90ffc0b, {"0284da4413862e34a74bc08673f47638"}, {"Tron 90 (Micro Mag) (France)/Tron 90 (1990)(Micro Mag)(fr)[cr].dsk"} },
   {0x45b93021, {"1fad3218ddd9755f3876e3fdde2424dc"}, {"Thomas the Tank Engine (Alternative Software)/Thomas the Tank Engine (1990)(Alternative Software)[cr].dsk"} },
   {0xd49b4e2d, {"db7e2c5eec8047a7a89b9d94c67b96dc"}, {"Triaxos (Ariolasoft)/Triaxos (1987)(Ariolasoft).dsk"} },
   {0x323b8bcb, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Tetris (Crazy Piri)/Tetris (2020)(Crazy Piri).dsk"} },
   {0x59348ec7, {"2ec6033acd5515e7be096c23d824d0e6"}, {"Trivial Pursuit - Baby Boomer Edition (Domark)/Trivial Pursuit - Baby Boomer Edition (1986)(Domark)(Side A)[cr].dsk"} },
   {0x0ff7ddb7, {"53fdc4bcfb7e0f14761d6720da860a5f"}, {"Tolki (CPC Infos) (France)/Tolki (1992)(CPC Infos)(fr)[cr].dsk"} },
   {0xb14db43d, {"36e77afe5aac5e52b7dc5e732c74a695"}, {"Trap Door, The (Piranha)/Trap Door, The (1986)(Piranha)[f].dsk"} },
   {0xc6f33707, {"ee6195f2c61f54689154a945f703b8ff"}, {"Triviation (Robot PD)/Triviation (1989)(Robot PD)[cr].dsk"} },
   {0x4e89b72e, {"5cddf231ecddd0628bc90ddc7b7c58da"}, {"Tomcat (Players)/Tomcat (1989)(Players)[cr].dsk"} },
   {0x8b4b44c1, {"397d12a922488a8264228c56916d445a"}, {"Tensions (ERE Informatique) (M3)/Tensions (1986)(ERE Informatique)(M3).dsk"} },
   {0x3bef5d59, {"a8383966542202341f19602f811f7f12"}, {"Transx (G.T.S. Editorial) (Spain)/Transx (1987)(G.T.S. Editorial)(es)[cr].dsk"} },
   {0x77c7c536, {"0f3ce766494c244fb3e069ee60809d95"}, {"Turbo Girl (Dinamic Software) (Spain)/Turbo Girl (1988)(Dinamic Software)(es).dsk"} },
   {0xb0153216, {"da8c8665d94ce2198211070bb5ca1a98"}, {"Task Force (Players)/Task Force (1989)(Players)[cr].dsk"} },
   {0xfd402604, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Ultron 1 (Chip) (France) (Bugs)/Ultron 1 (1987)(Chip)(fr)[b].dsk"} },
   {0x5d683df1, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"UN Squadron (US Gold) (Bugs)/UN Squadron (1990)(US Gold)(Side A)[b].dsk"} },
   {0xa5ca2404, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Untouchables, The (Ocean Software)/Untouchables, The (1989)(Ocean Software)(Side A).dsk"} },
   {0x7ff95fd6, {"8b7eff05580948e3f4f45a36276dc041"}, {"Uchi Mata (Martech)/Uchi Mata (1987)(Martech).dsk"} },
   {0x6a27c3d0, {"e249c98c45aea3f1bae252e489f3bd7f"}, {"Une Affaire en Or (Free Game Blot) (France)/Une Affaire en Or (1985)(Free Game Blot)(fr)[cr].dsk"} },
   {0xfb2e07bb, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Unitrax (Domark)/Unitrax (1987)(Domark).dsk"} },
   {0x06aae413, {"d83186a8fa2d1e378d6e39853fddcc0c"}, {"Uranium (Audimicro) (Spain)/Uranium (1986)(Audimicro)(es)[cr].dsk"} },
   {0x1bd644cd, {"de0cbca2f55df01f54056e39fa2b364f"}, {"Ultima Ratio (Firebird)/Ultima Ratio (1987)(Firebird)[cr].dsk"} },
   {0xda55de2a, {"72ac20374e34e4254bbda91644f6636b"}, {"Ultimate Fight, The (CPC) (France)/Ultimate Fight, The (1987)(CPC)(fr)[cr].dsk"} },
   {0xcff9b5b4, {"0f3ce766494c244fb3e069ee60809d95"}, {"Ulises (Opera Soft)/Ulises (1989)(Opera Soft).dsk"} },
   {0xc2fb79b8, {"eb37a96c69bb5a42771700e33bbb1dad"}, {"Un Asunto de Dinero (Free Game Blot) (France) (Hack)/Un Asunto de Dinero (2019)(Free Game Blot)(fr)(Hack)[cr].dsk"} },
   {0xfa4fa45b, {"2ec80ce965244341a555bbd54bf06733"}, {"Uridium (Hewson)/Uridium (1987)(Hewson)[tape].dsk"} },
   {0x5ed475ff, {"b49014bfa47b8a4f6cb8365e20537cc2"}, {"Video Poker (Mastertronic)/Video Poker (1986)(Mastertronic)[cr].dsk"} },
   {0xbbce171e, {"c68076620e353d3feae594cc90a2f4ca"}, {"Viaje Al Centro De La Tierra - Version Extendida (Topo Soft)/Viaje Al Centro De La Tierra - Version Extendida (2012)(Topo Soft).dsk"} },
// {0x0d34f4df, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Vuelta al Mundo en 80 Dias, La (Innelec) (Spain) (Hack)/Vuelta al Mundo en 80 Dias, La (2022)(Innelec)(es)(Hack)[cr].dsk"} },
   {0x0fb1b947, {"e5c293e79348742fe6066c3735788cff"}, {"Vagan Attack (Atlantis Software)/Vagan Attack (1985)(Atlantis Software)[cr].dsk"} },
   {0xac94247b, {"d95bd205cee0da3dc438989f88195a53"}, {"Venom (Mastertronic)/Venom (1988)(Mastertronic)[cr].dsk"} },
   {0xc1afcd65, {"66a37f367dbc1d23c487429435528ac4"}, {"Venganza de Johny Comomolo, La (Dro Soft) (Spain)/Venganza de Johny Comomolo, La (1986)(Dro Soft)(es)[cr].dsk"} },
   {0x788ff9dc, {"36d950eb0eaa751fca4e4fe5baf00e94"}, {"Viaje Alucinante (Idealogic)/Viaje Alucinante (1986)(Idealogic)[tape].dsk"} },
   {0x0113997b, {"805fcbfcb82b8e417db09c6cf3a3844a"}, {"Very Big Cave Adventure, The (CRL Group)/Very Big Cave Adventure, The (1986)(CRL Group)[cr].dsk"} },
   {0x15e2c423, {"9eba4b7c40d6509119ca6d00599c1a3a"}, {"Vengeur (Eric Cubizolle) (France)/Vengeur (1990)(Eric Cubizolle)(fr)(PD)[cr].dsk"} },
   {0x4f6b8ae6, {"0f3ce766494c244fb3e069ee60809d95"}, {"Vera Cruz Affair, The (Infogrames)/Vera Cruz Affair, The (1986)(Infogrames).dsk"} },
   {0x7223a099, {"50f02fa698fc001bd2b1efcd70a3c678"}, {"Village of Lost Souls (Robico Software)/Village of Lost Souls (1987)(Robico Software)[tape].dsk"} },
   {0xa6247be4, {"fa73d3cabb0cde537e7340744567423c"}, {"VS4 (Bretagne Edit presse) (France)/VS4 (1987)(Bretagne Edit presse)(fr)[cr].dsk"} },
   {0xdeb966c7, {"a22527716804af40f297fd7302c243c0"}, {"Vector Ball (Mastertronic)/Vector Ball (1988)(Mastertronic)[cr].dsk"} },
   {0xdfb023f8, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Vendetta (System 3 Software)/Vendetta (1990)(System 3 Software).dsk"} },
   {0x9d417eac, {"27574116db2eac2b4dbd85a827d969e7"}, {"Virgin Atlantic Challenge (Virgin Games)/Virgin Atlantic Challenge (1986)(Virgin Games)[cr].dsk"} },
   {0xa4eca0d7, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Viaje Al Centro De La Tierra (Topo Soft) (Spain)/Viaje Al Centro De La Tierra (1989)(Topo Soft)(es).dsk"} },
   {0xb1acd5c1, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Vol en Plein Pacifique (Patrick Meilhan) (France)/Vol en Plein Pacifique (1999)(Patrick Meilhan)(fr)[cr].dsk"} },
   {0xb6753a1a, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Voyage au Centre de la Terre (Chip) (France)/Voyage au Centre de la Terre (1988)(Chip)(fr)(Side A).dsk"} },
   {0x234bc9ee, {"b0164de2582d688f9248d7cedd4179a9"}, {"Video Card Arcade (CDS Software LTD)/Video Card Arcade (1988)(CDS Software LTD)[cr].dsk"} },
   {0x949cd9bb, {"91f3eb3d66d27ef214fb85982ad45e09"}, {"Vampire Killer (Scorpio Gamesworld)/Vampire Killer (1984)(Scorpio Gamesworld)[cr].dsk"} },
   {0xd2228ffc, {"51d2b2e11539de1690ac9bc9f531cb08"}, {"Vikings, The (Kele Line)/Vikings, The (1986)(Kele Line).dsk"} },
   {0x98cc3562, {"a3e5f3aae9e684145292759c6e8c0248"}, {"V The Visitors (Ocean Software)/V The Visitors (1986)(Ocean Software).dsk"} },
   {0x1356d210, {"a7d8541af0ea91b6fc120e852369308a"}, {"Virus (LMC Software) (France)/Virus (1991)(LMC Software)(fr)[cr].dsk"} },
   {0x33c1c3cc, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Vindicator, The - Green Beret II (Ocean Software)/Vindicator, The - Green Beret II (1988)(Ocean Software).dsk"} },
   {0xdef897b5, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Viz - The Computer Game (Virgin Games)/Viz - The Computer Game (1991)(Virgin Games)(Side A).dsk"} },
   {0x5fe4ae5f, {"fe7f98785e5d4fcc3bd7bca881bdaef8"}, {"V2 (Ubi Soft) (France)/V2 (1988)(Ubi Soft)(fr)(Prototype)(Side A)[cr].dsk"} },
   {0x9ac0e9ef, {"008dbe16df03a1007b3a996f326714e0"}, {"Vixen (Martech)/Vixen (1988)(Martech).dsk"} },
   {0x1b43e5bf, {"0f3ce766494c244fb3e069ee60809d95"}, {"Vindicators (Domark)/Vindicators (1989)(Domark).dsk"} },
   {0x5568287b, {"eaf0e6abd44f7521688ef71e1f500ca1"}, {"Voodoo Rage (Artic Computing)/Voodoo Rage (1986)(Artic Computing)[cr].dsk"} },
   {0xaf4b1161, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Victory Road - The Pathway To Fear (Ocean Software)/Victory Road - The Pathway To Fear (1988)(Ocean Software).dsk"} },
   {0x481ce055, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Ville Infernale, La (Cobra Soft) (France)/Ville Infernale, La (1985)(Cobra Soft)(fr).dsk"} },
   {0x48738114, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Volley Ball (Chip) (France)/Volley Ball (1987)(Chip)(fr).dsk"} },
   {0xcc16367e, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"Vigilante (US Gold)/Vigilante (1989)(US Gold).dsk"} },
   {0xb01c6377, {"b0fca47017f90fb442e971b2dbba6b9f"}, {"Visitor from Space, A (Games Computing)/Visitor from Space, A (1984)(Games Computing)[cr].dsk"} },
   {0xa233f966, {"45f1d707d788163989bea1a5bcbe9599"}, {"World Class Rugby (Audiogenic Software)/World Class Rugby (1991)(Audiogenic Software).dsk"} },
   {0x42f0fa2b, {"9fc4c8fba81b18f28c1e7647d3024a97"}, {"World Games (US Gold)/World Games (1987)(US Gold)(v2)(Side A).dsk"} },
   {0xc6e6039a, {"5e4264213cc7fba5919d48544557ff66"}, {"Who's Afraid of the Balrog (Amstrad Action Magazine)/Who's Afraid of the Balrog (1993)(Amstrad Action Magazine)(PD)[cr].dsk"} },
   {0xb4dde954, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Wrath of Olympus (Alpha Omega Software)/Wrath of Olympus (1986)(Alpha Omega Software)(v2)[cr].dsk"} },
   {0xb49a4653, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Wells & Fargo (Topo Soft) (Spain)/Wells & Fargo (1988)(Topo Soft)(es)[cr].dsk"} },
   {0x71c3eff4, {"2281ceff03d7057e1c2ec21ff9394475"}, {"War Cars Construction Set (Firebird)/War Cars Construction Set (1987)(Firebird)[cr].dsk"} },
   {0xdc07d499, {"1abae7b31fdbe8d5512fc288006363a4"}, {"What IQ (Dave Andrews)/What IQ (1990)(Dave Andrews)[cr].dsk"} },
   {0xa302be17, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"World Championship Soccer (Elite Systems)/World Championship Soccer (1990)(Elite Systems).dsk"} },
   {0x099c7669, {"7db535b57edfe74e11c7c0f5e9dcab39"}, {"Windsurf Willy (Silmarils) (Spain)/Windsurf Willy (1989)(Silmarils)(es).dsk"} },
   {0x06153c44, {"b8303fda8495d7f379fbafd5db888b72"}, {"World Cup (Videoplay SL) (Spain)/World Cup (1991)(Videoplay SL)(es)[cr].dsk"} },
   {0xbf11d5ce, {"31a64fe2a3a5f1f63a4e672c59bbf2ba"}, {"Who Dares Wins II (Alligata Software)/Who Dares Wins II (1986)(Alligata Software).dsk"} },
   {0xa1b83838, {"a170238e4bd9a21c784f1fba738e919d"}, {"Warlock (The Edge)/Warlock (1987)(The Edge).dsk"} },
   {0xb1026135, {"c68076620e353d3feae594cc90a2f4ca"}, {"Wonderboy (Activision)/Wonderboy (1987)(Activision).dsk"} },
   {0xc748f073, {"c613ed6abfabf60215bf29058888f611"}, {"Whist Wizard (Computing With The Amstrad)/Whist Wizard (1988)(Computing With The Amstrad)[cr].dsk"} },
   {0x42efcb30, {"39bbc103eb501f51c372eb306d644644"}, {"Winter Wonderland (Incentive)/Winter Wonderland (1987)(Incentive)[cr].dsk"} },
   {0x3014d8d7, {"37849a4774b1235c6ff12c873024ea98"}, {"Wiz-Biz (Alternative Software)/Wiz-Biz (1987)(Alternative Software)[cr].dsk"} },
   {0x5732dcf3, {"8c6c5972921428584a06ee3a14e07eb2"}, {"Wacky Darts (Codemasters Software)/Wacky Darts (1992)(Codemasters Software)[cr].dsk"} },
   {0xdeae9918, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Wizball (Ocean Software)/Wizball (1987)(Ocean Software)[f].dsk"} },
   {0x637d1c58, {"0f3ce766494c244fb3e069ee60809d95"}, {"Western Games (Magic Bytes)/Western Games (1988)(Magic Bytes)(Side A).dsk"} },
   {0xadf6c176, {"b31b6b29bb596d6f98a869b05a2f2ddd"}, {"Wriggler (Romantic Robot) (Codes)/Wriggler (1985)(Romantic Robot)[codes].dsk"} },
   {0x67bfa084, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Wizard's Lair (Bubble Bus Software)/Wizard's Lair (1985)(Bubble Bus Software).dsk"} },
   {0x275f65d5, {"571f6ffd038ce9fce5a4584ebeb45038"}, {"World Cup Carnival Mexico 86 (US Gold) (M3)/World Cup Carnival Mexico 86 (1986)(US Gold)(M3).dsk"} },
   {0x4e22cf96, {"20d5561124830fcdac3a566da26d0bba"}, {"Whopper Chase (Erbe Software) (Spain)/Whopper Chase (1987)(Erbe Software)(es)[cr].dsk"} },
   {0xc88f468d, {"be05581e5a7368114dbe7f99e24820a1"}, {"Wriggler (Romantic Robot)/Wriggler (1985)(Romantic Robot)[cr].dsk"} },
   {0xd891bffa, {"be6c01661f5a2724e9ba99afa03255ae"}, {"Wise and Fool of Arnold Blackwood, The (Nemesis)/Wise and Fool of Arnold Blackwood, The (1984)(Nemesis)[cr].dsk"} },
   {0xa6cc07e1, {"aace8d987cbc6b6cd177b701147fd5b0"}, {"Warrior (Rainbow Production) (France)/Warrior (1986)(Rainbow Production)(fr)[cr].dsk"} },
   {0x24185bd5, {"969cb31d1ed7986b2bf6be36f40a2dc6"}, {"World Cup (Artic Computing)/World Cup (1985)(Artic Computing)[cr].dsk"} },
   {0x361c4a1e, {"f747405885ce4de5cdc9cad219e6950e"}, {"West Bank (Dinamic Software) (Spain)/West Bank (1985)(Dinamic Software)(es).dsk"} },
// {0x5b80457c, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Warrior Plus (Rainbow Productions) (France)/Warrior Plus (1986)(Rainbow Productions)(fr)(Side A).dsk"} },
   {0x78cbb409, {"93ea1199db95439280277136ee694941"}, {"Wulfpack (CDS Software LTD)/Wulfpack (1988)(CDS Software LTD)[cr].dsk"} },
   {0x378d91dc, {"f04c6961cc68c8584418ee8cc9dc5622"}, {"Welladay (Amstrad Adventure PD Library)/Welladay (1990)(Amstrad Adventure PD Library)[cr].dsk"} },
   {0xecade1c4, {"e6e194408921ed477a2ef79a6557a48f"}, {"Wings of Fury (Broderbund Software) (France)/Wings of Fury (1989)(Broderbund Software)(fr).dsk"} },
   {0x09b248f5, {"4cb57daf99ac03541c44023655117171"}, {"War Space (Amstrad Cent Pour Cent) (France)/War Space (1988)(Amstrad Cent Pour Cent)(fr)[cr].dsk"} },
   {0x331a6c9c, {"d0b54d56c41395bf0b0936b2d2291cb4"}, {"Wolfman (CRL Group)/Wolfman (1988)(CRL Group)[cr].dsk"} },
   {0x2b5acc0a, {"b333b223226f869cfcbc45b89f3c7ef1"}, {"Who Said That (Radical Software)/Who Said That (1994)(Radical Software)[cr].dsk"} },
   {0x0edfc1fd, {"3442a72af2821d747f1f64eb871607fc"}, {"Willow Pattern Adventure, The (Firebird)/Willow Pattern Adventure, The (1985)(Firebird)[cr].dsk"} },
   {0xf9c01c85, {"147f98c755879cceb7a6256e00bf2c60"}, {"Wreckless Roger (Blaby Computer Games)/Wreckless Roger (1986)(Blaby Computer Games)[tape].dsk"} },
   {0x5ba4fa75, {"987469a8c7dda79d80de2c25304cc0c4"}, {"Wacky Orchard (Argus Press Software)/Wacky Orchard (1985)(Argus Press Software)[cr].dsk"} },
   {0xb16409a2, {"df044493215078582843d84afe71217f"}, {"Witness, The (Infocom)/Witness, The (1984)(Infocom)[CPM].dsk"} },
   {0x06533fb5, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"WWF Wrestlemania (Ocean Software)/WWF Wrestlemania (1991)(Ocean Software).dsk"} },
   {0x45e767ce, {"0f3ce766494c244fb3e069ee60809d95"}, {"Welltris (Infogrames) (Codes)/Welltris (1991)(Infogrames)[codes].dsk"} },
   {0x87b30b9a, {"c45a7dcc2ea47ac1f8d9dd5f0b7099b4"}, {"Wembley Greyhounds (D&H Games)/Wembley Greyhounds (1989)(D&H Games)[cr].dsk"} },
   {0x8e655c1e, {"cca928769e5d12e934101bb2b6e9ffbb"}, {"Wibstars (A&F Software)/Wibstars (1987)(A&F Software)[cr].dsk"} },
   {0x1990f5a0, {"509aedb3dd0a2b51d4a28afad1348831"}, {"Winter Wonderland (Incentive) (Hack)/Winter Wonderland (1987)(Incentive)(Hack)[cr].dsk"} },
// {0x648dc666, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Wild Streets (Titus)/Wild Streets (1990)(Titus).dsk"} },
   {0x4031468f, {"48175a49c3fb64da8a3517bbc94659ac"}, {"Wooky and Moty (CRL Group)/Wooky and Moty (1987)(CRL Group)[cr].dsk"} },
   {0x6fda459c, {"4431da6b0f3c12c57b4650cb8e5ea5af"}, {"Way of Exploding Fist, The (Melbourne House)/Way of Exploding Fist, The (1985)(Melbourne House)[tape].dsk"} },
   {0x54c40e54, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"WEC Le Mans (Ocean Software)/WEC Le Mans (1988)(Ocean Software).dsk"} },
   {0xc0e7a0b2, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Wells & Fargo (Topo Soft) (Spain) (Hack)/Wells & Fargo (1988)(Topo Soft)(es)(Hack)[cr].dsk"} },
   {0xdea21916, {"b4e20cd45b8e29ec0d72a0543c3c48df"}, {"World Cup (Cult) (Spain)/World Cup (1992)(Cult)(es)[cr].dsk"} },
   {0xe814906d, {"39bbc103eb501f51c372eb306d644644"}, {"Winter Sports (Activision)/Winter Sports (1985)(Activision)(Side A).dsk"} },
   {0xc55164a4, {"24d35012c5f8e0d1d350c214425be258"}, {"World Championship Boxing Manager (Goliath Games)/World Championship Boxing Manager (1990)(Goliath Games)(m3).dsk"} },
   {0x701b03b6, {"c223c4c1f299b7ae377b2f67d660a911"}, {"Wombles, The (Alternative Software)/Wombles, The (1990)(Alternative Software)[cr].dsk"} },
   {0x294220ab, {"a25367109ad7a99958f771b6de8177b8"}, {"World Soccer (Zeppelin Games)/World Soccer (1990)(Zeppelin Games)[cr].dsk"} },
   {0x5332c3ad, {"6e0af14f10ceb709728353f331d20384"}, {"Wishbringer (Infocom)/Wishbringer (1985)(Infocom)[CPM].dsk"} },
   {0x60784c7d, {"e03b603b1095ff230f060f09ee4e1c5b"}, {"Wanderer 3D (Elite Systems)/Wanderer 3D (1989)(Elite Systems).dsk"} },
// {0xdbce3abc, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Winchester (Chip) (France)/Winchester (1988)(Chip)(fr).dsk"} },
   {0xd2d93aa9, {"0f3ce766494c244fb3e069ee60809d95"}, {"Way of the Tiger, The (Gremlin Graphics Software)/Way of the Tiger, The (1986)(Gremlin Graphics Software).dsk"} },
   {0xf114deb9, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"War in Middle Earth (Melbourne House) (Spain)/War in Middle Earth (1989)(Melbourne House)(es).dsk"} },
   {0xf45e1b37, {"c74f3935b1b85c91a4be2d9f68ac03da"}, {"Wipeout (Mastertronic)/Wipeout (1990)(Mastertronic)[cr].dsk"} },
   {0x055b2c21, {"8b61c961cac214c0729756077474cdda"}, {"Weetabix vs the Titchies (Romik Software)/Weetabix vs the Titchies (1984)(Romik Software)[tape].dsk"} },
   {0x8c37f466, {"4e3e3a90a775644e30ef0088b6b597a5"}, {"Wizard Willy (Codemasters Software)/Wizard Willy (1989)(Codemasters Software)[cr].dsk"} },
   {0xba91af38, {"9fc4c8fba81b18f28c1e7647d3024a97"}, {"Winter Games (Epyx)/Winter Games (1986)(Epyx)(v2)(Side A).dsk"} },
   {0x0c2ec5b0, {"39f91b44d5f94e6abe4be7f8bdf8b7c6"}, {"Warlord (Interceptor Software)/Warlord (1985)(Interceptor Software)[cr].dsk"} },
   {0x78daed17, {"0f3ce766494c244fb3e069ee60809d95"}, {"War in Middle Earth (Melbourne House)/War in Middle Earth (1989)(Melbourne House).dsk"} },
   {0x8d9ec690, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"World Class Leadboard (US Gold)/World Class Leadboard (1987)(US Gold)(Side A).dsk"} },
   {0x40d31555, {"73532ef91c3c0b3f827b2265ca46f4f1"}, {"Winter Olympics (Tynesoft)/Winter Olympics (1986)(Tynesoft)[cr].dsk"} },
   {0x8103c23a, {"93aa32ec6f050fa6baf74f95b0e66d0f"}, {"War Game (Logipresse) (France)/War Game (1987)(Logipresse)(fr)[cr].dsk"} },
   {0xf33045ef, {"2c0dc0eab28e3fe1fd43a21621d7b8e6"}, {"Wizard Warz (Us Gold)/Wizard Warz (1987)(Us Gold).dsk"} },
// {0x04f36745, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Worm Slickers (PC Amstrad International)/Worm Slickers (1991)(PC Amstrad International)[cr].dsk"} },
   {0xc7436ae1, {"3052e0d648b305a70e2ad21375265cd4"}, {"Well, The (Edmund Spicer)/Well, The (1991)(Edmund Spicer)[cr].dsk"} },
   {0xe02ada0e, {"a1a2b3359d2d2df6e713ad620d972fab"}, {"Werewolves of London (Ariolasoft)/Werewolves of London (1988)(Ariolasoft).dsk"} },
   {0x5b89d348, {"805764964f24b42dd8aa345ed4d8be5a"}, {"World Series Baseball (Ocean Software)/World Series Baseball (1985)(Ocean Software)[cr].dsk"} },
   {0xd396c1a5, {"ad28603a29cb85023b61e0a9dc6d4a6d"}, {"Wild Bunch, The (Firebird)/Wild Bunch, The (1985)(Firebird)[cr].dsk"} },
   {0x05022596, {"7db535b57edfe74e11c7c0f5e9dcab39"}, {"Windsurf Willy (Silmarils) (France)/Windsurf Willy (1989)(Silmarils)(fr).dsk"} },
   {0x6dcaf69d, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Xeno (A&F Software)/Xeno (1986)(A&F Software).dsk"} },
   {0xd634c814, {"0f3ce766494c244fb3e069ee60809d95"}, {"Xybots (Domark)/Xybots (1989)(Domark).dsk"} },
   {0xbadd5079, {"7abd66e1ce7cac051fe3b427b9dc6998"}, {"Xcel (Mastertronic)/Xcel (1987)(Mastertronic)[cr].dsk"} },
   {0x34cd836c, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Xenon (Melbourne House) (Spain)/Xenon (1988)(Melbourne House)(es).dsk"} },
// {0x80ae71bb, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Xarq (Activision)/Xarq (1986)(Activision).dsk"} },
   {0x8fbd4fc2, {"daf25ef2e78af7e07fe1436cbc151eec"}, {"X-Out (Rainbow Arts)/X-Out (1990)(Rainbow Arts).dsk"} },
   {0x5743999a, {"51ae5959dc551b4e322a29969c13a77f"}, {"Xenon (Amstar & CPC) (France)/Xenon (1988)(Amstar & CPC)(fr)[cr].dsk"} },
   {0x1a70210d, {"1ad1378c2d7e5f587e5d550d71557532"}, {"Xevious (US Gold)/Xevious (1986)(US Gold).dsk"} },
// {0xdb70571b, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Xyphoes Fantasy (Silmarils) (France)/Xyphoes Fantasy (1991)(Silmarils)(Side A)(fr).dsk"} },
// {0xde97e3ab, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Xanadu (-) (Spain) (Hack)/Xanadu (2020)(-)(es)(Hack)[cr].dsk"} },
   {0x0b122cad, {"c68076620e353d3feae594cc90a2f4ca"}, {"XOR (Logotron)/XOR (1987)(Logotron).dsk"} },
// {0xf0a1468e, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Xyphoes Fantasy (Silmarils) (Spain)/Xyphoes Fantasy (1991)(Silmarils)(Side A)(es).dsk"} },
   {0x91f26a80, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Xenon (Melbourne House)/Xenon (1988)(Melbourne House).dsk"} },
   {0x83ea5c5a, {"12805d95e338a137a49c5b6f0af94c01"}, {"Xanadu (-)/Xanadu (1986)(-)[cr].dsk"} },
   {0x5dfd5142, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Xenophobe (Micro Style)/Xenophobe (1989)(Micro Style).dsk"} },
   {0xb6ba6539, {"f74e8e852633b745ef50fb28076e169f"}, {"Yarkon Blues II (WOW Software)/Yarkon Blues II (1992)(WOW Software)[cr].dsk"} },
   {0x651cd158, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Yie Ar Kung-Fu II (Ocean Software)/Yie Ar Kung-Fu II (1986)(Ocean Software).dsk"} },
   {0xd7a00940, {"f3f3f4726f37a8d2be80f773a0f10475"}, {"Yahtzee (L'Abominable) (France)/Yahtzee (1985)(L'Abominable)(PD)(fr)[cr].dsk"} },
   {0x8948e0ba, {"f3f3f4726f37a8d2be80f773a0f10475"}, {"Yahtzee (John Packham)/Yahtzee (1989)(John Packham)(PD)[cr].dsk"} },
   {0x1c0e8af7, {"194f4152bc29d7f27636e18f13d7fa7e"}, {"Yarkon Blues (Red Five Software)/Yarkon Blues (1988)(Red Five Software)[cr].dsk"} },
   {0x29b7ec7c, {"8bde475e392d2e098483e70b04d4c5cf"}, {"Young Ones, The (Orpheus)/Young Ones, The (1986)(Orpheus)[cr].dsk"} },
   {0xb010705d, {"0b18a48caf09e2b9c73153d866e2dece"}, {"Yes Prime Minister (Mosaic Publishing)/Yes Prime Minister (1985)(Mosaic Publishing)(Side A).dsk"} },
   {0x0fdaa611, {"5ff7adc164288b7c5e10716818d9fe78"}, {"Yabba Dabba Doo! - Flintstones (Quicksilva)/Yabba Dabba Doo! - Flintstones (1986)(Quicksilva)[cr].dsk"} },
   {0x66fb5d06, {"a9d5492e5d73bc2a180107ec337ef0c3"}, {"Yogi Bear (Piranha)/Yogi Bear (1987)(Piranha)[cr].dsk"} },
   {0xe0240de6, {"a5ee7bc9c41cad9c0fc8e3f60160ba8b"}, {"Zork II - The Wizard of Frobozz (Infocom)/Zork II - The Wizard of Frobozz (1986)(Infocom)[CPM].dsk"} },
   {0x50827a8b, {"0379ace44eb0c5f88a3791b6e853700c"}, {"Zarxas (Chip) (France)/Zarxas (1987)(Chip)(fr)[cr].dsk"} },
   {0x38696747, {"ebfc96b2224e2a0bfb658c631f1455e2"}, {"Zombi (Ubi Soft)/Zombi (1986)(Ubi Soft)(Side A).dsk"} },
   {0x13f8cb86, {"0f3ce766494c244fb3e069ee60809d95"}, {"Z (Rino Marketing)/Z (1985)(Rino Marketing).dsk"} },
   {0xae24ce98, {"38cc27ed7e4e79dd1fc86b88e61e5d8a"}, {"Zorgos (Deltacom) (de)/Zorgos (1987)(Deltacom)(de)[cr].dsk"} },
   {0xf820f9ff, {"68031fcbd7790222277cf9ffea063266"}, {"Zygy (Infogrames) (France)/Zygy (1986)(Infogrames)(fr)[cr].dsk"} },
   {0x81ab7c38, {"334e81b2ea4561bb202cf1774d3768f3"}, {"Zaxx (Chip) (France)/Zaxx (1986)(Chip)(fr).dsk"} },
// {0xc13903e5, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Zombi (Ubi Soft) (Spain)/Zombi (1986)(Ubi Soft)(es)(Side A).dsk"} },
   {0x17fc88d6, {"38792bfd66e94672532c31fa3e87a59e"}, {"Zelda (Le Chat Cyril) (France)/Zelda (1991)(Le Chat Cyril)(fr)[cr].dsk"} },
   {0xa54b45be, {"e9c35cd7a259f377dba291667cacb19d"}, {"Zap 't' Balls (CPC Amstrad International)/Zap 't' Balls (1992)(CPC Amstrad International)[cr].dsk"} },
   {0xfd3724e2, {"6902493b9ffa2b6192636526b6f06531"}, {"Zorro (US Gold)/Zorro (1985)(US Gold).dsk"} },
// {0x8559909a, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Zap 't' Balls (NoName EDV-Service)/Zap 't' Balls (1992)(NoName EDV-Service)(Side A)[AZERTY].dsk"} },
   {0xb503d731, {"b1829bccf67a17551dc396485eb4ef28"}, {"Zox 2099 (Loriciels) (France)/Zox 2099 (1987)(Loriciels)(fr).dsk"} },
// {0x6b941913, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Zombi (Ubi Soft) (France)/Zombi (1986)(Ubi Soft)(fr)(Side A).dsk"} },
// {0x557ae5ef, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Zania (Myrddin Software)/Zania (1985)(Myrddin Software).dsk"} },
   {0xcd86c6a1, {"140f13bd7084f1acd850b53cf0303061"}, {"Zarkon (Budgie)/Zarkon (1987)(Budgie)[cr].dsk"} },
   {0x825af888, {"2453f1a3e4f2293a6c5de1bc2825c36c"}, {"Zona 0 (Topo Soft) (Spain)/Zona 0 (1991)(Topo Soft)(es).dsk"} },
   {0x39b134bc, {"e6c0e6325285db1f68d65737d0a62555"}, {"Zone (Micro Mag)/Zone (1989)(Micro Mag)[cr].dsk"} },
   {0x2b45253e, {"a2be5080ecd7bae427d31fc4dc455eeb"}, {"Zyclons (Wizcat)/Zyclons (1992)(Wizcat)(PD)[cr].dsk"} },
   {0xa3fb554f, {"46fce97b8487c20e5b476767b9a64535"}, {"Zork III - The Dungeon Master (Infocom)/Zork III - The Dungeon Master (1986)(Infocom)[CPM].dsk"} },
   {0x1339daf5, {"3093dfbbed3eb4ab880d8f3793fa837d"}, {"Zampabolas (System 4) (Spain)/Zampabolas (1988)(System 4)(es)[cr].dsk"} },
   {0x60771b5f, {"79e16db3f63d2df171115c7ce7d97100"}, {"Zombi Terror Reloaded (Bitzarro Games) (Spain)/Zombi Terror Reloaded (2016)(Bitzarro Games)(es).dsk"} },
   {0x28a9cbcc, {"ebb17a863fe8b02ba0fc7b54097dec2e"}, {"Zombi Terror Reloaded (Bitzarro Games) (France)/Zombi Terror Reloaded (2016)(Bitzarro Games)(fr).dsk"} },
   {0x26b37cdd, {"ebb17a863fe8b02ba0fc7b54097dec2e"}, {"Zombi Terror Reloaded (Bitzarro Games)/Zombi Terror Reloaded (2016)(Bitzarro Games).dsk"} },
   {0xa831626e, {"58cd29359f4d3e246d08641575637abf"}, {"Zeichner, Der (Bollaware) (de)/Zeichner, Der (1988)(Bollaware)(de)[cr].dsk"} },
   {0x7551f406, {"4024efe5fe161179fc17285d26eff8b0"}, {"Zub (Mastertronic)/Zub (1986)(Mastertronic)[cr].dsk"} },
// {0x777bce70, {"7617c4718e24dcc76aa5dd129e44b70f"}, {"Zombi (Ubi Soft) (de)/Zombi (1986)(Ubi Soft)(de)(Side A).dsk"} },
   {0xa02c3758, {"779e606a27a41e5ae013d02282ca8512"}, {"Zork I - The Great Underground Empire (Infocom)/Zork I - The Great Underground Empire (1986)(Infocom)[CPM].dsk"} },
   {0xe6a9ad7d, {"e46b01191fb555f55f1b6400bbf60fda"}, {"Zorakk The Conqueror (Icon Software)/Zorakk The Conqueror (1985)(Icon Software)[cr].dsk"} },
   {0x526f5115, {"76a59b402650feecd9f413f4acbb0125"}, {"Zipi y Zape (Dro Soft) (Spain)/Zipi y Zape (1989)(Dro Soft)(es)[f].dsk"} },
   {0x7ba6705f, {"a240f90ea9c9fa4ecfe57ea643c0dd79"}, {"Zynaps (Hewson)/Zynaps (1987)(Hewson).dsk"} },
   {0xb729a281, {"bfe0e941d0abe33b2e3588f046d9011e"}, {"Ziggurat (Ariolasoft)/Ziggurat (1988)(Ariolasoft).dsk"} },
   {0x81c617ee, {"ca61227bafbf0cca0b78a0eeef55c5ec"}, {"Zodera Schloss des Todes (Martin Stuehlmann) (de)/Zodera Schloss des Todes (19xx)(Martin Stuehlmann)(de)[cr].dsk"} },
};

// gen hash: 1655965296.4419272 - generate-tests.py
